package com.plumtree.portalpages.portlets.sitemap.prefs;

import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portalpages.portlets.sitemap.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Activity space for intrinsic portlet. The name of this activity space must
 * be the name of the portlet model + "Prefs".
 *
 * @author NaveenP
 */
public class SiteMapPortletPrefsEditorAS extends PTEditorAS
{
	/**
	 * SiteMapPortletPrefs. For intrinsic portlets, the name of the activity
	 * space is the same as the name of the model plus the suffix "Prefs".
	 */
	public static final String STR_MVC_CLASS_NAME = SiteMapPortletModel.STR_MVC_CLASS_NAME +
		IntrinsicPortletPrefsUtils.PREFS_SUFFIX;


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapPortletPrefsEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		// ***CHANGE_HERE*** Return the main title of the Editor.
		return GetString(572, "ptmsgs_portalcommonmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		// ***CHANGE_HERE*** Replace SiteMapPortletPrefsRepostControl below with your RepostControl.
		return (SiteMapPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		// ***CHANGE_HERE*** Replace SiteMapPortletPrefsModel below with your Model.
		m_strModelName = SiteMapPortletPrefsModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(SiteMapPortletPrefsModel.STR_MVC_CLASS_NAME);
		RegisterModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME);

		IModel mySortedModel = GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME);
		((SiteMapPortletPrefsSortedLinksModel) mySortedModel).DisableAddButton();

		// Register DisplayPages
		// ***CHANGE_HERE*** Register each DP of your AS.
		SiteMapPortletPrefsDP siteMapPortletPrefsDP = new SiteMapPortletPrefsDP();
		siteMapPortletPrefsDP.AddToValidationFunction(SiteMapPortletPrefsView.JSFUNCTION_VALIDNUMLINKS);
		siteMapPortletPrefsDP.AddToValidationFunction(SiteMapPortletPrefsView.JSFUNCTION_VALIDNAME);
		RegisterPage(siteMapPortletPrefsDP);

		// Register Views
		// ***CHANGE_HERE*** Register each Section of your AS.
		RegisterView(SiteMapPortletPrefsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SiteMapPortletPrefsSortedLinksView.STR_MVC_CLASS_NAME,
			mySortedModel);

		// Register Controls
		// ***CHANGE_HERE*** Register each Control of your AS.
		RegisterControl(SiteMapPortletPrefsRepostControl.STR_MVC_CLASS_NAME,
			myModel);
		RegisterControl(SiteMapPortletPrefsSortedLinksControl.STR_MVC_CLASS_NAME,
			mySortedModel);

		// Register plug-in sections
		// Sitemap link plug-in
		RegisterModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);

		IModel mySiteMapPluginModel = GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		//Register the display page
		RegisterPage(new SiteMapCreateWebLinkDP());
		//The Site map folder views
		RegisterView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
		RegisterView(SiteMapCreateWebLinkView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
		//The site map folder control
		RegisterControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME, mySiteMapPluginModel);


		// Set default page
		// ***CHANGE_HERE*** Replace SiteMapPortletPrefsDP below with the default DP.
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(SiteMapPortletPrefsDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// ***CHANGE_HERE*** Set the left nav menu using StartNewSubMenu and AddLinkToSubMenu.
		// ***COMMENT_1*** If you don't want any left nav menu just remove the lines below.
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(571, "ptmsgs_portalcommonmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			SiteMapPortletPrefsDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);
		
		String sPageName = page.GetName();

		if( SiteMapPortletPrefsDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_CommunityKnowledgeDirectory_EditFolders" );
		}
	}
}

