package com.plumtree.portalpages.portlets.sitemap.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * Intrinsic portlet prefs model, which extends the
 * IntrinsicPortletPrefsEditorModel, uses the editor framework.
 *
 * @version $Revision$
 * @author NaveenP
 */
public class SiteMapPortletPrefsModel extends IntrinsicPortletPrefsEditorModel
	implements ISiteMapPortletPrefsModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.sitemap.prefs.SiteMapPortletPrefsModel");

	/** SiteMapPortletPrefs */
	public static final String STR_MVC_CLASS_NAME = "SiteMapPortletPrefs";
	
	public static final String SETTING_NAME_FOLDERNAME = "FOLDERNAME";

	
	public static final String SETTING_NAME_FOLDERID = "FOLDERID";

	
	public static final String SETTING_NAME_LINKORDER = "LINKORDER";

	
	public static final String SETTING_NAME_SHOWDESC = "SHOWDESC";

	
	public static final String SETTING_NAME_NUMLINKS = "NUMLINKS";

	
	protected IPTSiteMapFolder m_ptSiteMapFolder;
	
	protected int m_nFolderID = 0;

	
	protected int m_nNumLinks = 10;

	
	protected int m_nShowDescriptions = 0;
	
	private boolean m_bNewlyCreatedFolder = false;

	// END ***************** save DP methods ***************** 
	// ***CHANGE_HERE*** Implement the repost action methods that you 
	//      will call from your Repost Control.
	// BEGIN ***************** repost action methods ***************** 

	public SiteMapPortletPrefsModel()
	{
		super();
	}

	/**
	 * Modifies the object name on repost.
	 */
	public void ActionOnRepost()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapPortletPrefsModel();
	}

	/**
	 * Create a site map folder for this portlet.
	 */
	public void CreateFolder()
	{
		try
		{
			IPTObjectManager omCommunity	  = (IPTObjectManager) m_ptSession.GetCommunities();
			IPTCommunity objCommunity		  = (IPTCommunity) omCommunity.Open(m_nCommunityID, false);
			IPTSiteMapFolder objSiteMapFolder = objCommunity.GetSiteMapRoot();
			IPTSiteMapFolder objNewFolder     = objSiteMapFolder.CreateSubfolder(m_asOwner.GetString(683, "ptmsgs_portalcommonmsgs"),
					"");
			SetFolderID(objNewFolder.GetObjectID());

			// set the folder name back to blank, which signifies that we are going to use
			// the name of the site map folder by default
			m_ptSiteMapFolder = objNewFolder;
		}
		catch (Exception e)
		{
			log.Error("CommunityEditorModel::CreateFolder: An exception occured" +
				" when trying to create a new folder.");
		}
	}

	/**
	 * Load the community preferences for the portlet.
	 *
	 * @param _htFormData 
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		Object[][] arSettings = GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_COMMUNITYPORTLET,
				null);

		String strLinkOrder = "";

		if (null != arSettings)
		{
			for (int i = 0; i < arSettings[0].length; i++)
			{
				String strSettingName = (String) arSettings[0][i];

				if (strSettingName.equals(
							SiteMapPortletPrefsModel.SETTING_NAME_FOLDERID))
				{
					int nFolderID = XPConvert.ToInteger(arSettings[1][i]);
					SetFolderID(nFolderID);
				}
				else if (strSettingName.equals(
							SiteMapPortletPrefsModel.SETTING_NAME_LINKORDER))
				{
					strLinkOrder = (String) arSettings[1][i];
				}
				else if (strSettingName.equals(
							SiteMapPortletPrefsModel.SETTING_NAME_SHOWDESC))
				{
					m_nShowDescriptions = XPConvert.ToInteger(arSettings[1][i]);
				}
				else if (strSettingName.equals(
							SiteMapPortletPrefsModel.SETTING_NAME_NUMLINKS))
				{
					m_nNumLinks = XPConvert.ToInteger(arSettings[1][i]);
				}
			}
		}

		m_ptSiteMapFolder = null;

		int nSiteMapFolder = GetFolderID();

		if (0 == nSiteMapFolder)
		{
			CreateFolder();
			m_bNewlyCreatedFolder = true;
		} else {
			try
			{
				IPTObjectManager ptOM = (IPTObjectManager) m_ptSession.GetSiteMapFolders();
				m_ptSiteMapFolder = (IPTSiteMapFolder) ptOM.Open(nSiteMapFolder, false);
			}
			catch (Exception e)
			{
				// DCA - portlet have no associated sitemap folder, clear out prefs
				m_nFolderID = 0;
				m_nNumLinks = 10;
				m_nShowDescriptions = 0;
				CreateFolder();
				m_bNewlyCreatedFolder = true;
			}
		}
		
		if(m_ptSiteMapFolder != null)
		{
			SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
				plugInModel.InitializePlugIn(m_ptSiteMapFolder);
			
			((SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)).InitializeLinkList(m_ptSession,
				1, strLinkOrder);
		}		
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 */
	public void Finish()
	{
		if(m_nFolderID != 0) 
		{
			String strLinkOrder = "";
	
			SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
			
			try {
				IPTObject objFolder = plugInModel.GetPTObject();
				objFolder.LockObject();
				objFolder.Store();
				objFolder.UnlockObject();
				plugInModel.StoreLinks();
			} catch(Exception e) {
				
				log.Error("Could not store folder or links: " + e);

				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(1625, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(1625, "ptmsgs_portalbrowsingmsgs"));
				myError.SetDisplayOnSeparatePage(false);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
				
				return;	
			}	
			
			if (!HasNoLinks())
			{
				strLinkOrder = ((SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)).GetItemsAsStringForStore();
			}
	
			int nPortletPrefToChange = -1;
	
			switch (GetPrefType())
			{
			case IntrinsicPortletPrefsEditorModel.PREF_TYPE_ADMIN:
				nPortletPrefToChange = IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN;
	
				break;
	
			case IntrinsicPortletPrefsEditorModel.PREF_TYPE_COMMUNITY:
				nPortletPrefToChange = IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_COMMUNITYPORTLET;
	
				break;
	
			case IntrinsicPortletPrefsEditorModel.PREF_TYPE_PERSONAL:
				nPortletPrefToChange = IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_PORTLET;
	
				break;
	
			default:
	
				// We should not get here.  If so, then there's a major problem. -jic.
				break;
			}
	
			if (-1 != nPortletPrefToChange)
			{
				SetSettingValue(nPortletPrefToChange, SETTING_NAME_FOLDERID,
					new Integer(GetFolderID()));
				SetSettingValue(nPortletPrefToChange, SETTING_NAME_LINKORDER,
					strLinkOrder);
				SetSettingValue(nPortletPrefToChange, SETTING_NAME_SHOWDESC,
					new Integer(m_nShowDescriptions));
				SetSettingValue(nPortletPrefToChange, SETTING_NAME_NUMLINKS,
					new Integer(m_nNumLinks));
			}
		}
	}

	/**
	 * Implement some code to execute when the user clicks on "Cancel".
	 */
	public void Cancel() {
		if (m_bNewlyCreatedFolder) {
			// delete created sitemap folder if user clicks on cancel
			try {
				((IPTSession) m_asOwner.GetUserSession()).GetSiteMapFolders().Delete(m_nFolderID);
			} catch(Exception e) {
				log.Error("Could not delete folder: " + m_nFolderID + " An error occured: " + e);
			}	
		}
	}
	
	/**
	 * 
	 *
	 * @return 
	 */
	public int GetFolderID()
	{
		return m_nFolderID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public ASQueryResultWrapper GetLinks()
	{
		if (m_ptSiteMapFolder != null)
		{
			ASQueryResultWrapper asqrWrapper = new ASQueryResultWrapper(m_ptSiteMapFolder.QueryLinks());

			return asqrWrapper;
		}
		else
		{
			return null;
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.portlets.sitemap.prefs.ISiteMapPortletPrefsModelRO#GetNumLinksToDisplay()
	 */
	public int GetNumLinksToDisplay()
	{
		return m_nNumLinks;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetSiteMapFolderIsNull()
	{
		return (m_ptSiteMapFolder == null);
	}

	/**
	 * 
	 *
	 * @return boolean
	 */
	public boolean HasNoLinks()
	{ 
		if (m_nFolderID ==0)
			return true;
			
		ASQueryResultWrapper qrLinks = GetLinks();
		if (qrLinks == null)
			return true;
				
		return (GetLinks().GetCount() == 0);
	}

	/**
	 *
	 * @see com.plumtree.portalpages.portlets.sitemap.prefs.ISiteMapPortletPrefsModelRO#OrderAlpha()
	 */
	public boolean OrderAlpha()
	{
		return ((SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)).IsAlpha();
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		// ***CHANGE_HERE*** Switch between your DP and for each one call 
		//       the associated save method.
		if (_sPageName.equals(SiteMapPortletPrefsDP.STR_MVC_CLASS_NAME))
		{
			SaveMainPage(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean ShowDescriptions()
	{
		return (1 == m_nShowDescriptions);
	}
    
	// ***CHANGE_HERE*** Implement one method per DP to save it
	// BEGIN ***************** save DP methods ***************** 

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
		String[] data;
		
		if (m_nFolderID != 0)
		{
			((SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
			
			data = (String[]) _htFormData.GetElement(SiteMapPortletPrefsView.HTMLBUTTON_SHOWDESC);

			if ((null != data) && !(0 == data.length))
			{
				m_nShowDescriptions = 1;
			}
			else
			{
				m_nShowDescriptions = 0;
			}

			data = (String[]) _htFormData.GetElement(SiteMapPortletPrefsView.HTMLBUTTON_ALPHA);

			if ((null != data) && !(0 == data.length))
			{
				((SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)).SetAlphaOrdering(true);
			}
			else
			{
				((SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)).SetAlphaOrdering(false);
			}

			data = (String[]) _htFormData.GetElement(SiteMapPortletPrefsView.HTMLINPUT_NUMLINKS);

			if ((null != data) && !(0 == data.length))
			{
				m_nNumLinks = XPConvert.ToInteger(data[0]);
			}
		}
	}

	/**
	 * 
	 *
	 * @param nFolderID 
	 */
	private void SetFolderID(int nFolderID)
	{
		if (m_nFolderID > 0)
		{
			return;
		}

		m_nFolderID = nFolderID;
	}

	// END ***************** repost action methods ***************** 
}

