package com.plumtree.portalpages.portlets.sitemap.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portalpages.browsing.sitemap.linkselector.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author NaveenP
 *
 */
public class SiteMapPortletPrefsSortedLinksModel extends ExpListModel
{
	
	public final static String STR_MVC_CLASS_NAME = "SiteMapPortletPrefsSortedLinks";

	/***/
	public final static int LINKS_COL_LINK_NAME = 1;

	
	public final static int LINKS_COL_LINK_OBJECTID = 2;

	
	public final static int LINKS_COL_LINK_DESCRIPTION = 3;

	
	public final static int LINKS_COL_LINK_TYPE = 4;

	
	public final static int LINKS_COL_LINK_INDEX = 5;
	
	
	public final static int LINKS_COL_LINK_UNIQUE_ID = 6;

	/**
	 * Default initial size for the sorted array.
	 */
	public static final int EXPLIST_DEFAULT_INITIAL_SIZE = 25;

	/** IPTSession */
	private IPTSession m_Session;
	private boolean m_bIsAlpha;
	private String m_strLinkOrder;
	private XPHashtable m_tableLinkOrder;
	private int m_nNumSortedLinks;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapPortletPrefsSortedLinksModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(XPHashtable)
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		
		PTLink link;
		Object[] oRow;
		XPArrayList newlyAddedLinks = plugInModel.GetNewlyAddedLinks();
		for(int i = 0; i < newlyAddedLinks.GetSize(); i++)
		{
			link = (PTLink) newlyAddedLinks.GetElement(i);
			
			oRow									   = new Object[6];
			oRow[0]     = new Integer(m_saData.GetCount());
			if(link.nType == PT_CLASSIDS.PT_COMMUNITY_ID) {
				oRow[1] = link.strName + " (" + link.strPageName + ")";	
			} else {
				oRow[1] = link.strName;	
			}
			oRow[2] = new Integer(link.nObjectID);
			oRow[3] = link.strDesc;
			oRow[4] = new Integer(link.nType);
			if(link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID) {
				oRow[5] = new Integer(link.nObjectID);
			} else if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID) {
				oRow[5] = new Integer(link.nPageID);
			} else {
				oRow[5] = new Integer(link.nLinkObjectID);
			}
			m_saData.AddRow(oRow);	
		}
		
		plugInModel.ClearNewlyAddedLinks();
	}

	public void UpdateRowsOnRepost(XPHashtable _htFormData)
	{
		SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		
		PTLink link;
		XPArrayList updatedWebLinks = plugInModel.GetUpdatedWebLinks();
		PTGrowableSortedArrayWrapper arrLinkItems = GetItems();
		int nNumLinks							  = arrLinkItems.GetCount();
		
		for(int i = 0; i < updatedWebLinks.GetSize(); i++)
		{
			link = (PTLink) updatedWebLinks.GetElement(i);
			
			for(int j = 0; j < nNumLinks; j++)
			{
				int nTypeID = XPConvert.ToInteger(arrLinkItems.GetItem(j,
						LINKS_COL_LINK_TYPE));
				int nUniqueID = XPConvert.ToInteger(arrLinkItems.GetItem(j,
						LINKS_COL_LINK_UNIQUE_ID));
						
				if(nTypeID == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID
					&& nUniqueID == link.nObjectID) 
				{
					arrLinkItems.SetItem(j, LINKS_COL_LINK_NAME, link.strName);
					arrLinkItems.SetItem(j, LINKS_COL_LINK_DESCRIPTION, link.strDesc);
					break;								
				}
			}	
		}			
	}	

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(XPHashtable)
	 */
	public void DeleteRowsOnRepost(XPHashtable _htFormData)
	{
		SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		XPArrayList xparrLinksToDelete = new XPArrayList();

		PTLink link;
		XPArrayList deletedLinks = plugInModel.GetDeletedLinks();
		for(int i = 0; i < deletedLinks.GetSize(); i++)
		{
			link = (PTLink) deletedLinks.GetElement(i);

			for(int j = 0; j < m_saData.GetCount(); j++)
			{
				int nListType = XPConvert.ToInteger(
					m_saData.GetItem(j, LINKS_COL_LINK_TYPE));
				int nListUniqueID = XPConvert.ToInteger(
					m_saData.GetItem(j, LINKS_COL_LINK_UNIQUE_ID));
				int nUniqueID;
				if(link.nType == nListType)
				{
					if(link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID) {
						nUniqueID = link.nObjectID;
					} else if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID) {
						nUniqueID = link.nPageID;
					} else {
						nUniqueID = link.nLinkObjectID;
					}
					
					if(nUniqueID == nListUniqueID) {
						xparrLinksToDelete.Add(new Integer(j));
						break;
					}
				}
			}
		}
		int[] aRowsToDelete = new int[xparrLinksToDelete.GetSize()];

		for(int i = 0; i < xparrLinksToDelete.GetSize(); i++)
		{
			aRowsToDelete[i] = XPConvert.ToInteger(xparrLinksToDelete.GetElement(i));
		}

		m_saData.RemoveRows(aRowsToDelete);

		plugInModel.ClearDeletedLinks();
	}

	/**
	 *
	 * @return int
	 */
	public int GetCurrNumLinks()
	{
		if (m_saData == null)
		{
			return 0;
		}
		else
		{
			return m_saData.GetCount();
		}
	}

	/**
	 *
	 * @return XPArrayList
	 */
	//public XPArrayList GetIDsToDelete()
	//{
	//	return m_xparrLinksToDelete;
	//}

	/**
	 *
	 * @return String
	 */
	public String GetItemsAsStringForStore()
	{
		if(m_bIsAlpha) {
			return "";
		} else {
			return CreateStringOfItemsForStore();
		}
	}

	/**
	 * 
	 *
	 * @param nIndex 
	 *
	 * @return 
	 */
	public String GetLinkName(int nIndex)
	{
		return ((String) GetItems().GetItem(nIndex, LINKS_COL_LINK_NAME));
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _arrObjectClassIDs Class ID of the Objects displayed on the list.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeLinkList(IPTSession _Session, int _nListKey,
		String strLinkOrder)
	{
		m_Session     = _Session;

		m_strLinkOrder = strLinkOrder;
		m_bIsAlpha = ("").equals(m_strLinkOrder);

		XPStringTokenizer strTok = new XPStringTokenizer(strLinkOrder, ",");
		m_tableLinkOrder = new XPHashtable();

		int nCount = 0;

		while (strTok.HasMoreElements())
		{
			m_tableLinkOrder.PutElement(new Integer(XPConvert.ToInteger(strTok.GetNextToken())),
				new Integer(nCount));
			nCount++;
		}

		m_nNumSortedLinks = nCount;

		Object[][] arrExpListColInfo = new Object[1][5];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(LINKS_COL_LINK_NAME);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(574, "ptmsgs_portalcommonmsgs");
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "2";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		super.InitializeExpandableList(m_asOwner.GetString(573, "ptmsgs_portalcommonmsgs"), arrExpListColInfo,
			PTImageType.ICON_URL, "", _nListKey);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(PTGrowableSortedArrayWrapper)
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		//ASQueryResultWrapper asqrLinks = ((SiteMapPortletPrefsModel) m_asOwner.GetModel(SiteMapPortletPrefsModel.STR_MVC_CLASS_NAME)).GetLinks();
		SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		XPArrayList arrItems = plugInModel.GetLinks();
		
		int nNumLinks				   = arrItems.GetSize();

		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, LINKS_COL_LINK_NAME,
				LINKS_COL_LINK_OBJECTID, LINKS_COL_LINK_DESCRIPTION,
				LINKS_COL_LINK_TYPE, LINKS_COL_LINK_UNIQUE_ID,
			};

		int[][] arrSort = new int[1][2];

		if (m_bIsAlpha)
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = LINKS_COL_LINK_NAME;
			m_bEnableMoveRowActions = false;
		}
		else
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
			m_bEnableMoveRowActions = true;
		}

		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		int nCount		   = m_nNumSortedLinks;
		Object[][] arrData = new Object[6][nNumLinks];

		for (int i = 0; i < nNumLinks; i++)
		{
			PTLink link = (PTLink) arrItems.GetElement(i);
			//int intClassID = XPConvert.ToInteger(asqrLinks.GetFields(i,
			//		PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID));

			int intClassID = link.nType;


			arrData[1][i] 	  = link.strName;
			arrData[2][i]     = new Integer(link.nObjectID);
			arrData[3][i]     = link.strDesc;
			arrData[4][i]     = new Integer(intClassID);
			
			if(link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID) {
				arrData[5][i] = new Integer(link.nObjectID);
			} else if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID) {
				arrData[5][i] = new Integer(link.nPageID);
			} else {
				arrData[5][i] = new Integer(link.nLinkObjectID);
			}

			Object oIndex  = m_tableLinkOrder.GetElement(arrData[2][i]);

			if (oIndex != null)
			{
				arrData[0][i] = oIndex;
			}
			else
			{
				arrData[0][i] = new Integer(nCount++);
			}
		}

		_saData.Initialize(arrColumns, arrData, arrSort, true, nNumLinks);			
	}

	/**
	 *
	 * @param bIsAlpha
	 */
	public void SetAlphaOrdering(boolean bIsAlpha)
	{
		int[][] arrSort = new int[1][2];

		if (bIsAlpha)
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]     = LINKS_COL_LINK_NAME;
			m_bEnableMoveRowActions 								   = false;
			m_bIsAlpha												   = true;
		}
		else
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]     = EXPLIST_SORTEDARRAY_PROPID_INDEX;
			m_bEnableMoveRowActions 								   = true;
			m_bIsAlpha												   = false;
		}

		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		m_saData.Sort(arrSort);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#SaveRow(PTGrowableSortedArrayWrapper, int, XPHashtable)
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 *
	 * @return String
	 */
	private String CreateStringOfItemsForStore()
	{		
		XPStringBuilder retVal = new XPStringBuilder(10);

		PTGrowableSortedArrayWrapper arrLinkItems = GetItems();
		int nNumLinks							  = arrLinkItems.GetCount();
		SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		XPArrayList arrLinksFromContainer = plugInModel.GetLinks();
		PTLink link;

		for (int i = 0; i < nNumLinks; i++)
		{			
			int nUniqueID = XPConvert.ToInteger(arrLinkItems.GetItem(i,
					LINKS_COL_LINK_UNIQUE_ID));
			int nTypeID = XPConvert.ToInteger(arrLinkItems.GetItem(i,
					LINKS_COL_LINK_TYPE));
			for(int j = 0; j < arrLinksFromContainer.GetSize(); j++)
			{
				link = (PTLink) arrLinksFromContainer.GetElement(j);
				
				if(link.nType == nTypeID)
				{
					int nLinkUniqueID;
					if(link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID) {
						nLinkUniqueID = link.nObjectID;
						if(nLinkUniqueID != nUniqueID)
						{
							nLinkUniqueID = link.nLinkObjectID;  // we need to check this if the web link has been stored.  in this case, the link.nObjectID has been updated
						}
					} else if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID) {
						nLinkUniqueID = link.nPageID;
					} else {
						nLinkUniqueID = link.nLinkObjectID;
					}
					
					if(nLinkUniqueID == nUniqueID) {
						if(retVal.GetLength() != 0) {
							retVal.Append(",");
						}
						retVal.Append(link.nObjectID);
						break;
					}
				}
			}
		}

		return retVal.ToString();
	}
	
	public boolean IsAlpha()
	{
		return m_bIsAlpha;	
	}
}

