package com.plumtree.portalpages.portlets.sitemap.prefs;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Section for a list of links in prefs pages.
 *
 * @author Naveen
 */
public class SiteMapPortletPrefsSortedLinksView extends ExpListView
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "SiteMapPortletPrefsLinkListView";
	
	public static final int MAX_DESC_LENGTH = 70;
	
	/** Use this if we need to access the _saData
	 * but don't get it passed into the function that if 
	 * being overriden.
	 */
	IPTGrowableSortedArrayWrapperRO m_saData;	

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapPortletPrefsSortedLinksView();
	}

	/** Logger Setup */
	/**
	 * Display the javascript functions that are needed in this view.
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = super.DisplayJavascript();

		return script;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(IPTGrowableSortedArrayWrapperRO, int)
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));

		if(!((SiteMapPortletPrefsSortedLinksModel)m_model).IsAlpha())
		{
			result.AddInnerHTMLElement(GetHTMLForMoveRowActions(_nRowIndex));
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForNameColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;

		// Object Name
		String strLinkName = (String) _saData.GetItem(_nRowIndex,
				SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_NAME);
		String strLinkDesc = (String) _saData.GetItem(_nRowIndex,
				SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_DESCRIPTION);
		int nLinkType	   = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
				SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_TYPE));
				
		if(strLinkDesc == null) {
			strLinkDesc = "";	
		}
		
		if(strLinkDesc.length() > MAX_DESC_LENGTH)
		{
			strLinkDesc = strLinkDesc.substring(0, MAX_DESC_LENGTH - 3) + "...";	
		}

		myCell			   = new HTMLTableCell();
		myCell.SetWidth("100%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// row icon
		myCell.AddInnerHTMLElement(GetIcon(nLinkType));
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLEncodedString(strLinkName);
		myCell.AddInnerHTMLElement(new HTMLBr());

		if (((SiteMapPortletPrefsModel) m_asOwner.GetModel(
					SiteMapPortletPrefsModel.STR_MVC_CLASS_NAME)).ShowDescriptions())
		{
			myCell.AddInnerHTMLEncodedString(strLinkDesc);
		}

		return myCell;
	}

	/**
	 * Helper method to get the HTML for the icon.
	 * (Each row has an icon before the input text.)
	 *
	 * @return HTMLImg
	 * @throws Exception
	 */
	protected HTMLImg GetIcon(int nLinkType)

	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		PTImageType _imgRowIcon;

		switch (nLinkType)
		{
		case PT_CLASSIDS.PT_COMMUNITY_ID:
			_imgRowIcon = PTImageType.ICON_COMMUNITY;

			break;

		case PT_CLASSIDS.PT_CATALOGCARD_ID:
			_imgRowIcon = PTImageType.ICON_DOCUMENT;

			break;

		case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
			_imgRowIcon = PTImageType.ICON_FOLDER;

			break;

		case PT_CLASSIDS.PT_USER_ID:
			_imgRowIcon = PTImageType.ICON_USER;

			break;

		case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
			_imgRowIcon = PTImageType.ICON_URL;

			break;

		default:
			_imgRowIcon = PTImageType.ICON_ERROR;

			break;
		}

		myConstruct     = UIConstructFactory.GetConstruct(_imgRowIcon, true,
				this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

		return (myImage);
	}
	
	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(HTMLTableRow)
	 */
	protected void AddHTMLToActionBar(HTMLTableRow _myRow)
	{
		SiteMapFolderPlugInView plugInView = (SiteMapFolderPlugInView) m_asOwner.GetView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME);
		
		m_saData = ((SiteMapPortletPrefsSortedLinksModel)
			m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)).GetReadOnlyItems();
		
		HTMLTableCell myCell = new HTMLTableCell();
		_myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		
		myCell.AddInnerHTMLElement(plugInView.GetHTMLForActionBar(m_saData.GetCount())); 
	}
	
	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForCheckBox(int)
	 */
	protected HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLInput myInput;
		
		int nType = XPConvert.ToInteger(m_saData.GetItem(_nRowIndex,
						SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_TYPE));
		int nUniqueID = XPConvert.ToInteger(m_saData.GetItem(_nRowIndex,
								SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_UNIQUE_ID));				

		myCell = new HTMLTableCell();
		//myCell.SetWidth("20");
		myCell.SetHeight("30");
		myCell.SetAlign(CommonHTMLStrings.CENTER);
		myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		// checkbox
		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
				((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW),
				m_asOwner.GetString(531, "ptmsgs_portalbrowsingmsgs"));
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetValue(nType + "," + nUniqueID);
		myCell.AddInnerHTMLElement(myInput);

		return (myCell);
	}
	
	/**
	 * Returns the HTML for the delete cell in the action bar.
	 * The plugin view already handle delete, so we'll just return a 
	 * space here
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForDeleteAction()
	{
		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		return myCell;
	}
}

