package com.plumtree.portalpages.portlets.userprofile.communities;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;

/**
 * 
 *
 * @author jennifersu
 */
public class CommunitiesPortletModel extends IntrinsicPortletModel implements ICommunitiesPortletModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.userprofile.communities.CommunitiesPortletModel");

	/** Class name for the model */
	public static final String STR_MVC_CLASS_NAME = "ManagedCommunitiesPortlet";
	public final static int NO_PROFILE_USER = 0;

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#ControlExists()
	 */
	public boolean ControlExists() {
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#GetName()
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#Create()
	 */
	public Object Create() {
		return new CommunitiesPortletModel();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#GetNewTempData()
	 */
	public Object GetNewTempData() {
		return null;
	}

	/**
	* This method determines what roles the user is a member of and obtains
	* the approriate text to be displayed in the introspective portlet.
	*
	* @param searchResponse  the search results for the user
	* @param index  the current index in the search results
	* @param iCurrentUser the current user id
	*
	* @return string the display string for the cell
	*/
	public String GetUserRoles(IPTQueryResult searchResponse, int index,
		int iCurrentUser)
	{
//		int Objectid     = searchResponse.ItemAsInt(index,
//			PT_PROPIDS.PT_PROPID_OBJECTID);

		int commAccess = searchResponse.ItemAsInt(index, PT_PROPIDS.PT_PROPID_ACCESSLEVEL);

		switch (commAccess) 
		{
			case PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN	: return (m_asOwner.GetString(41, "ptmsgs_portletsmsgs"));
			case PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT : return (m_asOwner.GetString(4, "ptmsgs_portletsmsgs"));
			default : return "";
		}
	}

	/**
	 * This method uses the Plumtree Profile API to
	 *
	 * @param ptSession a valid plumtree session
	 * @param profileUserID the profile user id that will be used to search
	 *        information on.
	 *
	 * @return IPTSearchResponse
	 */
	public IPTQueryResult GetSearchResults(int profileUserID)
	{
		//get the profile pages object manager
		// MJD - local variable not used: IPTObjectManager profilePagesObjMgr = ptSession.GetProfilePages();

		//log.Info("Retrieved the Plumtree portal session successfully.");

		IPTProfileManager pm = (IPTProfileManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER,
				false);

		IPTQueryResult qr = pm.GetManagedCommunities(profileUserID);

		return qr;
	}

	public int GetProfileID() {
		IPTUserInfo userInfo = m_ptSession.GetUserInfo();
		return userInfo.GetProfileUserID();
	}
	
	public int GetCurrentUser() {
		IPTSessionInfo sessionInfo = m_ptSession.GetSessionInfo();
		return sessionInfo.GetCurrentUserID();
	}

	/**
	 * @see com.plumtree.xpportlets.expatriate.ext.introspective.IProfilePortlet#getTitle()
	 */
	public String GetTitle()
	{
		return "";
	}

	/**
	 * 
	 */
	public String GetPortletDescription()
	{
		return m_ptPortlet.GetDescription();
	}
}

