package com.plumtree.portalpages.portlets.userprofile.eoddisplay;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;

/**
 *
 *
 * @author jennifersu
 */
public class EODPortletModel extends IntrinsicPortletModel implements IEODPortletModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.userprofile.eoddisplay.EODPortletModel");

	/** Class name for the model */
	public static final String STR_MVC_CLASS_NAME = "EODPortlet";

	public final static int NO_PROFILE_USER = 0;
	public final static int DATA_INDEX_PROFILEPAGEID = 0;
	private int m_profilePageID;

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#ControlExists()
	 */
	public boolean ControlExists()
	{
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#Create()
	 */
	public Object Create()
	{
		return new EODPortletModel();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#GetNewTempData()
	 */
	public Object GetNewTempData()
	{
		return null;
	}
	
	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws XPException 
	 */
	public Object[] GetData()
	{
		try
		{
			IPTAdminSettings ptAdminSettings = (IPTAdminSettings) m_ptPortlet;

			String[] aSettings = new String[1];
			aSettings[0]     = EODPortletPrefsModel.SETTING_PROFILEPAGEID;

			Object[][] arData = (Object[][]) ptAdminSettings.LookupAdminGadgetSettings(aSettings);
			Object[] arEODSettings = null;

			if (null != arData)
			{
				arEODSettings = new Object[1];

				for (int i = 0; i < arData[0].length; i++)
				{
					String strSettingName = (String) arData[0][i];
					Object oSettingValue = arData[1][i];

					if (strSettingName.equals(EODPortletPrefsModel.SETTING_PROFILEPAGEID))
					{
						m_profilePageID     = XPConvert.ToInteger(oSettingValue);

						arEODSettings[DATA_INDEX_PROFILEPAGEID] = oSettingValue;
					}
				}
			}

			return arEODSettings;
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetData  " + 
				m_asOwner.GetString(553, "ptmsgs_portalcommonmsgs") + ":" + e.getMessage());

			throw new XPException(m_asOwner.GetString(553, "ptmsgs_portalcommonmsgs"), e);
		}
	}

	public XPHashtable PutUserPropertiesIntoHashtable(int _profileUserID)
	{
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		//get all the properties for this user
		IPTProfileManager ptProfileManager = (IPTProfileManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER, false);
		IPTObjectProperties ptUserProperties = ptProfileManager.GetUserProperties(_profileUserID, false);

		//put all the properties in a hashtable
		//key=property id; value=XPArrayList of values
		XPHashtable xphtProfileData = new XPHashtable();
		XPArrayList xpalPropertyValues;

		// First get non-reference property data
		// Results are returned one row per property value, even
		// if it's for the same property.  So need to iterate through
		// each property and add all values for the same property to
		// a single XPArrayList.
		IASQueryResult profileQR = GetObjectPropData(ptUserProperties);
		int indProperty = 0;
		while (indProperty < profileQR.GetCount())
		{
			xpalPropertyValues = GetAllValues(profileQR, indProperty, false);
			xphtProfileData.PutElement(profileQR.GetFields(indProperty, PT_PROPIDS.PT_PROPID_OBJECTID), xpalPropertyValues);

			if (xpalPropertyValues.GetSize() == 0)
			{
				break;
			}

			indProperty += xpalPropertyValues.GetSize();
		}

		// Then get property reference data
		IASQueryResult profileRefQR = GetObjectPropRefData(ptUserProperties);
		indProperty = 0;
		while (indProperty < profileRefQR.GetCount())
		{
			// get value type
			xpalPropertyValues = GetAllValues(profileRefQR, indProperty, true);
			xphtProfileData.PutElement(profileRefQR.GetFields(indProperty, PT_PROPIDS.PT_PROPID_OBJECTID), xpalPropertyValues);

			if (xpalPropertyValues.GetSize() == 0)
			{
				break;
			}

			indProperty += xpalPropertyValues.GetSize();
		}

		return xphtProfileData;
	}

	/**
	 * Return object property non-reference data
	 *
	 * @param _ptObjProp IPTObjectProperties
	 *
	 * @return Data in query result
	 *
	 * @throws XPException
	 */
	protected IASQueryResult GetObjectPropData(IPTObjectProperties _ptObjProp)
	{
		IASQueryResult asqrObjectPropData = null;

		try
		{
			if (null != _ptObjProp)
			{
				IPTQueryResult qrObjectPropData = _ptObjProp.GetPropertyData(PT_PROPIDS.PT_PROPID_ALL);
				asqrObjectPropData = new ASQueryResultWrapper(qrObjectPropData);
			}
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetObjectPropData " + m_asOwner.GetString(97, "ptmsgs_portalinfrastructure") + ". The following exception occured: " + e);
			throw new XPException(m_asOwner.GetString(97, "ptmsgs_portalinfrastructure"), e);
		}

		return asqrObjectPropData;
	}

	/**
	 * Return object property reference data
	 *
	 * @param _ptObjProp IPTObjectProperties
	 *
	 * @return Data in query result
	 *
	 * @throws XPException
	 */
	protected IASQueryResult GetObjectPropRefData(IPTObjectProperties _ptObjProp)
	{
		IASQueryResult asqrObjectPropRefData = null;

		try
		{
			if (null != _ptObjProp)
			{
				IPTQueryResult qrObjectPropRefData = _ptObjProp.GetPropertyRefData(PT_PROPIDS.PT_PROPID_ALL);
				asqrObjectPropRefData = new ASQueryResultWrapper(qrObjectPropRefData);
			}
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetObjectPropRefData " + m_asOwner.GetString(97, "ptmsgs_portalinfrastructure") + ". The following exception occured: " + e);
			
			throw new XPException(m_asOwner.GetString(97, "ptmsgs_portalinfrastructure"), e);
		}

		return asqrObjectPropRefData;
	}

	private XPArrayList GetAllValues(IASQueryResult _qrData, int _nRowIndex, boolean _bRefData)
	{
		XPArrayList xpalAllValues = new XPArrayList();

		int currPropID = XPConvert.ToInteger(_qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
		int nextPropID;
		Object propVal;

		// first add the current property value
		propVal     = _qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE);
		xpalAllValues.Add(propVal);

		// now check for multiple values
		while (_nRowIndex < (_qrData.GetCount() - 1))
		{
			IPTProperty nextProp;
			nextPropID = XPConvert.ToInteger(_qrData.GetFields(_nRowIndex + 1, PT_PROPIDS.PT_PROPID_OBJECTID));

			// as long as the next property ID is the same as the current one,
			// there is another value to add to the list.
			if (nextPropID == currPropID)
			{
				_nRowIndex++;
				propVal     = _qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE);

				if (propVal != null)
				{
					xpalAllValues.Add(propVal);
				}
			}
			else
			{
				return xpalAllValues;
			}
		}

		return xpalAllValues;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public IPTProfilePage GetProfilePage()
	{
		IPTObjectManager profilePageMgr = ((IPTSession)m_asOwner.GetUserSession()).GetProfilePages();
		IPTProfilePage profilePage = (IPTProfilePage)profilePageMgr.Open(m_profilePageID, false);

		return profilePage;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetProfileID()
	{
		IPTUserInfo userInfo = m_ptSession.GetUserInfo();

		return userInfo.GetProfileUserID();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCurrentUser()
	{
		IPTSessionInfo sessionInfo = m_ptSession.GetSessionInfo();

		return sessionInfo.GetCurrentUserID();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetPortletName()
	{
		return m_ptPortlet.GetName();
	}
	
	public String GetPortletDescription()
	{
		return m_ptPortlet.GetDescription();
	}
	
	/**
	 * @see com.plumtree.xpportlets.expatriate.ext.introspective.IProfilePortlet#getTitle()
	 */
	public String GetTitle()
	{
		return "";
	}

	/**
	 * Check if the portlet is located in a community.
	 * If not, it should display an error message.
	 */
	public boolean OnCommunityPage()
	{
		if ( PT_CLASSIDS.PT_COMMUNITY_ID == m_nContainerClassID )
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Returns the name for an object
	 *
	 * @param nClassID Class ID of object
	 * @param nObjectID Object ID of object
	 *
	 * @return Name of object.
	 */
	public String GetNameFromObjectID(int nClassID, int nObjectID)
	{
		// Get the name of the reference object
		switch (nClassID)
		{
		case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
		{
			IPTAdminCatalog ptAC = ((IPTSession)m_asOwner.GetUserSession()).GetAdminCatalog();

			if (ptAC.IsAdminFolderAccessible(nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
			{
				IPTAdminFolder ptAdminFolder = ptAC.OpenAdminFolder(nObjectID, false);

				return ptAdminFolder.GetLocalizedName();
			}

			break;
		}

		case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
		{
			IPTCatalog ptCatalog = ((IPTSession)m_asOwner.GetUserSession()).GetCatalog();

			if (ptCatalog.IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID, nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
			{
				IPTFolder ptFolder = ptCatalog.OpenFolder(nObjectID, false);

				return ptFolder.GetLocalizedName();
			}

			break;
		}

		default:
		{
			// Get the object manager for the object and query for the name
			IPTAdminCatalog ptAC = ((IPTSession)m_asOwner.GetUserSession()).GetAdminCatalog();
			IPTObjectManager ptOM = ptAC.GetObjectManager(nClassID);
			IPTQueryResult ptQR = ptOM.QuerySingleObject(nObjectID);

			if (0 < ptQR.RowCount())
			{
				return ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
			}

			break;
		}
		}

		return null;
	}
}

