package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portalpages.portlets.userprofile.eoddisplay.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 * The activity space for the portlet admin pref page.  It registers the
 * classes for user profile layout.
 */
public class EODPortletPrefsEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsEditorAS");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = EODPortletModel.STR_MVC_CLASS_NAME + IntrinsicPortletPrefsUtils.PREFS_SUFFIX;

	/** pop up constants used for keying pop up display pages */
	public static final String strStorageProfileSectionList = "storageProfileSectionList";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EODPortletPrefsEditorAS();
	}

	/**
	 * Gets the Editor title.
	 *
	 */
	public String GetEditorTitle()
	{
		return (GetString(47, "ptmsgs_portletsmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes used for the profile pages.
	 */
	public void InitProfilePage(EODPortletPrefsModel _model, IPTProfilePage _ptProfilePage)
	{
		/* register display page */
		RegisterPage(new EODPortletPrefsMainDP(_ptProfilePage.GetName(), _ptProfilePage.GetDescription()));

		/* rename category dp and view */
		RegisterPage(new EODPortletPrefsRenameCtgDP(_ptProfilePage.GetName()));
		RegisterView(EODPortletPrefsRenameCtgView.STR_MVC_CLASS_NAME, _model);

		// Register the select PTObject list as a plug-in for each section
		Object[] arProfileSectionIDs = _ptProfilePage.GetChildSections();
		for (int indSection = 0; indSection < arProfileSectionIDs.length; indSection++)
		{
			int nSectionID = XPConvert.ToInteger(arProfileSectionIDs[indSection]);
			RegisterProfileSection(nSectionID);
		}
		
		SetCurrentPage(EODPortletPrefsMainDP.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		/* set the main model name and call super class's init */
		m_strModelName = EODPortletPrefsModel.STR_MVC_CLASS_NAME;
		super.Init();

		/* get the main model and repost control and register them */
		EODPortletPrefsModel myModel = (EODPortletPrefsModel) GetModel(m_strModelName);
		RegisterControl(EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME, myModel);

		// display page/view for creating new categories
		RegisterPage(new EODPortletPrefsNewCtgDP(), EODPortletPrefsNewCtgDP.STR_MVC_CLASS_NAME);
		RegisterView(EODPortletPrefsNewCtgView.STR_MVC_CLASS_NAME, myModel);

		// objects for renaming sections and categories.  This "subclasses" the 
		// LocNames* objects for localizing strings
		EODPortletPrefsLocNamesDP myLocNamesDP = new EODPortletPrefsLocNamesDP();
		myLocNamesDP.AddToValidationFunction(LocNamesPrimaryNameView.VALIDATION_FUNC_NAME);
		RegisterPage(myLocNamesDP, EODPortletPrefsLocNamesDP.STR_MVC_CLASS_NAME);

		/* reorder and delete objects */
		RegisterPage(new EODPortletPrefsMoveCtgDP());
		RegisterModel(EODPortletPrefsProfileSectionListModel.STR_MVC_CLASS_NAME, strStorageProfileSectionList);
		IModel sectionsModel = GetModel(strStorageProfileSectionList);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageProfileSectionList, sectionsModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageProfileSectionList, sectionsModel);

	}

	/**
	 * This is a helper method that all classes that inherit from AFormDP can
	 * override if they like.  The method provides a hook into the head so
	 * that DP's can add javascript. Simply override and return and
	 * HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 *
	 * @return HTMLScriptCollection the Javascript from the Child IViews
	 * @throws HTMLException If error occurs while creating or populating
	 * HTML Elements.
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()
	 *      Override this method to Display javascript from child IViews
	 */
	public HTMLScriptCollection DisplayCommonJavaScript()
	{
		HTMLScriptCollection scripts = super.DisplayCommonJavaScript();

		HTMLScript script = new HTMLScript("text/javascript");
		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(this) + "opennewwindow.js");
		scripts.AddInnerHTMLElement(script);

		script = new HTMLScript("text/javascript");
		scripts.AddInnerHTMLElement(script);

		XPStringBuilder sb = new XPStringBuilder(200);
		sb.Append("\n").Append("function ").Append(CommunityEditorAS.JS_ALERTSAVEFORPREFS_FUNC).Append("()").Append("{\n").Append("		if ( confirm('").Append(GetString(1228, "ptmsgs_portalbrowsingmsgs")).Append("') )\n").Append("		{\n").Append("			return true;").Append("		}\n").Append("		return false;").Append("}\n");

		script.AddInnerHTMLString(sb.ToString());

		return scripts;
	}

	/**
	 * Registers the objects associated with a PTProfileSection
	 * (i.e. Model, View, Control).
	 *
	 * @param __intProfileSectionID
	 */
	public void RegisterProfileSection(int _intProfileSectionID)
	{
		/* section select explist */
		String key = EODPortletPrefsModel.GetProfileSectionKey(_intProfileSectionID);
		RegisterModel(EODPortletPrefsSelectPTObjectModel.STR_MVC_CLASS_NAME, key);

		IModel myModel = GetModel(key);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, key, myModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, key, myModel);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if (page instanceof EODPortletPrefsMainDP)
		{
			SetHelpTopic("PT_UserProfilePortletConfiguration");
		}
		else if (page instanceof EODPortletPrefsMoveCtgDP)
		{
			SetHelpTopic("PT_DeleteOrderCategories");
		}
		else if (page instanceof EODPortletPrefsRenameCtgDP)
		{
			SetHelpTopic("PT_RenameCategory");
		}
		else if (EODPortletPrefsLocNamesDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_RenameCategories");
		}
	}
}

