package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 * This class calls the Localized Names Views to display profile object names
 * and descriptions in localized formats.
 */
public class EODPortletPrefsLocNamesDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsLocNamesDP");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "EODDisplayPrefsLocNames";

	/** html element names */
	public static final String HTMLBUTTON_DONE = "in_bu_done";
	public static final String HTMLBUTTON_CANCEL = "in_bu_cancel";

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(978, "ptmsgs_portaladminmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @return HTMLElement
	 * @throws HTMLException on error
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		/* done & cancel buttons */
		HTMLTable myTable = GetActionRow();
		result.AddInnerHTMLElement(myTable);

		/* add views to a row of this table */
		HTMLTableRow myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);

		HTMLTableCell myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetColSpan("2");

		HTMLElementCollection views = new HTMLElementCollection();

		//MES- Add the primary name/desc
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME)).Display());

		//MES- Add the list of languages we're localized into, IF we support localization AND we're localized!
		LocNamesModel model = (LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);

		if (model.m_bSupportsLocalization && model.GetIsLocalized())
		{
			views.AddInnerHTMLElement(new HTMLBr());
			views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME)).Display());
		}

		myCell.AddInnerHTMLElement(views);

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection scripts = super.DisplayJavaScriptFromChild();

		scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME).DisplayJavascript());

		//MES- Add the JavaScript for the list of languages we're localized into, IF we support localization!
		LocNamesModel model = (LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);

		if (model.GetIsLocalized())
		{
			scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME).DisplayJavascript());
		}

		return scripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()
	 */
	private HTMLTable GetActionRow()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		try
		{
			// action Row begin
			myTable = new HTMLTable();
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("10");
			myTable.SetCellSpacing("0");
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);

			/* title */
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign("left");

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(985, "ptmsgs_portaladminmsgs"));

			/* buttons */
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign("right");

			// ***Done Action*** begins here
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_DONE, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(979, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			myInput.SetOnClick("postToSelf('" + // mj: removed 'Javascript:' from function name
				EODPortletPrefsRepostControl.POSTTOSELF_ACTION_RENAMEOBJ_DONE + "');");

			// ***Done Action*** ends here
			// spacer
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			// ***Cancel Action*** begins here
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(980, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			myInput.SetOnClick("postToSelf('" + // mj: removed 'Javascript:' from function name
				EODPortletPrefsRepostControl.POSTTOSELF_ACTION_RENAMEOBJ_CANCEL + "');");

			// ***Cancel Action*** ends here
			// action Row end
		}
		catch (Exception e)
		{
			log.Error(e, "EODPortletPrefsMainDP::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(981, "ptmsgs_portaladminmsgs"), e);
		}

		return myTable;
	}
}

