package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 */
public class EODPortletPrefsMainDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsMainDP");

	public static final String STR_MVC_CLASS_NAME = "EODDisplayPrefsMain";

	/** HTML Form constants */
	public static final String HTMLHIDDEN_NEWPAGE = "in_hi_NewPage";
	public static final String HTMLHIDDEN_NEWPAGEDESC = "in_hi_NewPageDesc";
	public static final String HTMLHIDDEN_NEWCTG = "in_hi_NewCtg";
	public static final String HTMLHIDDEN_NEWCTGDESC = "in_hi_NewCtgDesc";

	/** localized pagename from ProfilePage object */
	private String m_sPageTitle;
	private String m_strDescription;

	/**
	 * 
	 * @param _strTitle
	 * @param _strDescription
	 */
	public EODPortletPrefsMainDP(String _strTitle, String _strDescription)
	{
		// get the page title		
		m_sPageTitle = _strTitle;
		m_strDescription = _strDescription;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_sPageTitle;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the Layout Description.
	 *
	 * @return String
	 */
	public String GetDescription()
	{
		return (m_strDescription == null) ? "" : XPHttpUtility.HtmlEncode(m_strDescription);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());
		result.AddInnerHTMLElement(CreateLeftNavBar(CreateViews()));

		// Add hidden inputs used for new page name and descr
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_NEWPAGE, "");
		result.AddInnerHTMLElement(myInput);

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_NEWPAGEDESC, "");
		result.AddInnerHTMLElement(myInput);

		// Add hidden input used for new category name and descr
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_NEWCTG, "");
		result.AddInnerHTMLElement(myInput);

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_NEWCTGDESC, "");
		result.AddInnerHTMLElement(myInput);

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// loop through the view and add the various Profile Pages as EditorViews
		// fixing j2c -mgs
		EODPortletPrefsProfileSectionListModel catModel = (EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList);
		int cnt = catModel.GetItems().GetCount();

		for (int indSection = 0; indSection < cnt; indSection++)
		{
			int intSectionID = XPConvert.ToInteger(catModel.GetItems().GetItem(indSection, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
			String sectKey = EODPortletPrefsModel.GetProfileSectionKey(intSectionID);
			myScripts.AddInnerHTMLElement(m_asOwner.GetView(sectKey).DisplayJavascript());
		}

		myScripts.AddInnerHTMLElement(GetMoveCtgActionJS());
		myScripts.AddInnerHTMLElement(GetNewCtgActionJS());
		myScripts.AddInnerHTMLElement(GetRenameCtgActionJS());

		return myScripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()
	 */
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		HTMLElementCollection subHeaders = new HTMLElementCollection();

		try
		{
			/* if the properties list for user objects is empty, don't display actionbar */
			/* create the action bar */
			subHeaders.AddInnerHTMLElement(CreateActionBar());
			subHeaders.AddInnerHTMLElement(GetSpacerTable());

			/* instruction/description bar */
			subHeaders.AddInnerHTMLElement(CreateExplantoryBar());
		}

		catch (Exception e)
		{
			log.Error(e, "EODPortletPrefsMainDP::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(984, "ptmsgs_portaladminmsgs"), e);
		}

		return subHeaders;
	}

	/**
	 * Helper method: returns empty table.
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	private HTMLElement GetSpacerTable()
	{
		HTMLElementCollection myResult = new HTMLElementCollection();

		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			HTMLComment myComment = new HTMLComment("Begin: Spacer table");
			myResult.AddInnerHTMLElement(myComment);

			myTable = new HTMLTable();
			myResult.AddInnerHTMLElement(myTable);
			myTable.SetBorder("0");
			myTable.SetWidth("100%");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("0");

			// 1st Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImage.SetAlt("");
			myImage.SetWidth("225");
			myImage.SetHeight("1");
			myImage.SetBorder("0");
			myCell.AddInnerHTMLElement(myImage);

			myComment = new HTMLComment("End: Spacer table");
			myResult.AddInnerHTMLElement(myComment);
		}
		catch (Exception e)
		{
			log.Error(e, "EditorDP::GetSpacerTable An error occured when trying to display the HTML.");
		}

		return myResult;
	}

	/**
	 * Helper Method that creates action bar for the subHeader.
	 *
	 * @return HTMLElementCollection
	 * @throws HTMLException
	 */
	private HTMLElement CreateExplantoryBar()
	{
		if (GetDescription().equals(""))
		{
			return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2152, "ptmsgs_portaladminmsgs"), this.m_asOwner);
		}
		else
		{
			return HTMLConstructHelpers.GetSubHeader(GetDescription(), this.m_asOwner);
		}
	}

	/**
	 * Helper Method that creates action bar for the subHeader.
	 *
	 * @return HTMLElementCollection
	 * @throws HTMLException
	 */
	private HTMLElement CreateActionBar()
	{
		HTMLElementCollection anchors = new HTMLElementCollection();
		HTMLAnchor myAnchor;

		/* create category anchor */
		myAnchor = CreateAnchor(m_asOwner.GetString(983, "ptmsgs_portaladminmsgs"), PTImageType.ACTION_CREATE, "NewCtgAction(); return false;");
		anchors.AddInnerHTMLElement(myAnchor);

		/* only show if we have categories */
		PTGrowableSortedArrayWrapper arProfileSections;
		arProfileSections = ((EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList)).GetItems();
		if (arProfileSections.GetCount() > 0)
		{
			/* rename category anchor */
			myAnchor = CreateAnchor(m_asOwner.GetString(985, "ptmsgs_portaladminmsgs"), PTImageType.ACTION_RENAME, "RenameCtgAction(); return false;");
			anchors.AddInnerHTMLElement(myAnchor);

			/* delete/order category anchor */
			myAnchor = CreateAnchor(m_asOwner.GetString(986, "ptmsgs_portaladminmsgs"), PTImageType.ACTION_EDIT, "MoveCtgAction(); return false;");
			anchors.AddInnerHTMLElement(myAnchor);
		}

		/* create action bar */
		return HTMLConstructHelpers.GetActionBar(anchors, m_sPageTitle, this.m_asOwner);
	}

	/**
	 * Helper Method that creates anchors for the subHeader.
	 *
	 * @return HTMLElementCollection
	 * @throws HTMLException
	 */
	private HTMLAnchor CreateAnchor(String _btnText, PTImageType _imgType, String _onClick)
	{
		HTMLImg img = (HTMLImg) UIConstructFactory.GetConstruct(_imgType).GetHTMLElement();
		HTMLAnchor anchor = HTMLConstructHelpers.GetActionBarAnchor(0, img, _btnText, _btnText, _onClick, this.m_asOwner);

		return anchor;
	}

	/**
	 * Helper Method that gets calls the display method for each
	 * profile view.
	 *
	 * @return HTMLElementCollection
	 * @throws HTMLException
	 */
	private HTMLElementCollection CreateViews()
	{
		HTMLElementCollection views = new HTMLElementCollection();

		// loop through the view and add the various sections as EditorViews
		// fixing j2c -mgs
		/* get the select object for this ProfilePage */
		EODPortletPrefsProfileSectionListModel profilePageModel = (EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList);
		PTGrowableSortedArrayWrapper arSections = profilePageModel.GetItems();

		for (int indSection = 0; indSection < arSections.GetCount(); indSection++)
		{
			Object objSectionID = arSections.GetItem(indSection, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
			int nSectionID = XPConvert.ToInteger(objSectionID);
			String strProfileSectionKey = EODPortletPrefsModel.GetProfileSectionKey(nSectionID);
			EditorView profileSectionView = (EditorView) m_asOwner.GetView(strProfileSectionKey);
			views.AddInnerHTMLElement(profileSectionView.Display());

			// add a spacer table if there are more ProfileSections
			if ((indSection + 1) < arSections.GetCount())
			{
				views.AddInnerHTMLElement(EditorView.GetSpacerTable());
			}
		}

		return views;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 */
	private HTMLScript GetMoveCtgActionJS()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		// The URL to open the pop-up
		ASURL myPopUp = new ASURL(m_asOwner);
		myPopUp.SetLinkGetCachedSpace(m_asOwner);
		myPopUp.SetDisplayPage(EODPortletPrefsMoveCtgDP.STR_MVC_CLASS_NAME);
		myPopUp.SetControl(EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
		myPopUp.AddControlArgument(ASConstants.PAGE_INPUT, STR_MVC_CLASS_NAME);
		myPopUp.AddControlArgument(EODPortletPrefsRepostControl.HTMLINPUT_POSTTOSELF, XPConvert.ToString(EODPortletPrefsRepostControl.POSTTOSELF_ACTION_MOVECTG));

		XPStringBuilder sb;

		try
		{
			// Open Pop Up function
			sb = new XPStringBuilder(200);
			sb.Append("function MoveCtgAction()\n");
			sb.Append("{\n");
			sb.Append("    window.open('").Append(myPopUp.GetURLAsString()).Append("', '_EODDisplayPrefsMainDP_PP', 'scrollbars=yes,location=no,menubar=no,height=500,width=400');\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME + "::GetCtgMoveActionJS The following error occured when trying to display the JavaScript: " + he.GetMessage());
			
		}

		return myScript;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 */
	private HTMLScript GetNewCtgActionJS()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		// The URL to open the pop-up
		ASURL myPopUp = new ASURL(m_asOwner);
		myPopUp.SetLinkGetCachedSpace(m_asOwner);
		myPopUp.SetDisplayPage(EODPortletPrefsNewCtgDP.STR_MVC_CLASS_NAME);
		myPopUp.SetControl(EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
		myPopUp.AddControlArgument(ASConstants.PAGE_INPUT, STR_MVC_CLASS_NAME);
		myPopUp.AddControlArgument(EODPortletPrefsRepostControl.HTMLINPUT_POSTTOSELF, XPConvert.ToString(EODPortletPrefsRepostControl.POSTTOSELF_ACTION_NEWCTG));

		XPStringBuilder sb;

		try
		{
			// Open Pop Up function
			sb = new XPStringBuilder(200);
			sb.Append("function NewCtgAction()\n");
			sb.Append("{\n");
			sb.Append("    window.open('").Append(myPopUp.GetURLAsString()).Append("', '_EODDisplayPrefsMainDP_PP', 'location=no,menubar=no,height=180,width=400');\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, "EODPortletPrefsMainDP::GetCtgryActionJS An error occured when trying to display the JavaScript.");
		}

		return myScript;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 */
	private HTMLScript GetRenameCtgActionJS()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		// The URL to open the pop-up
		ASURL myPopUp = new ASURL(m_asOwner);
		myPopUp.SetLinkGetCachedSpace(m_asOwner);
		myPopUp.SetDisplayPage(EODPortletPrefsRenameCtgDP.STR_MVC_CLASS_NAME);
		myPopUp.SetControl(EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
		myPopUp.AddControlArgument(ASConstants.PAGE_INPUT, STR_MVC_CLASS_NAME);

		XPStringBuilder sb;

		try
		{
			// Open Pop Up function
			sb = new XPStringBuilder(200);
			sb.Append("function RenameCtgAction()\n");
			sb.Append("{\n");
			sb.Append("    window.open('").Append(myPopUp.GetURLAsString()).Append("', '_EODDisplayPrefsMainDP_PP', 'scrollbars=yes,location=no,menubar=no,height=400,width=600');\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, "EODPortletPrefsMainDP::GetRenameCtgActionJS An error occured when trying to display the JavaScript.");
		}

		return myScript;
	}
}

