package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author JHQ, jennifersu
 *
 */
public class EODPortletPrefsModel extends IntrinsicPortletPrefsEditorModel implements IEODPortletPrefsModelRO, IDescriptionModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsModel");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "EODPortletPrefs";

	public final static String SETTING_PROFILEPAGEID = "LAYOUTID";
	private IPTProfilePage m_profilePage;

	/** array of new object ids */
	private XPArrayList m_newObjectKeys = new XPArrayList();
	private int m_nIndRenameObj;

	/**
	 * Creates a new EODPortletPrefsModel object.
	 */
	public EODPortletPrefsModel()
	{
		super();
		
		this.SetHideLeftNav(true);
	}

	/**
	 * helper method that returns the key of a profile section object used to
	 * identify profile section objects on the profile page editor ui.
	 *
	 * @param _section the section in question.
	 *
	 * @return String id of section object.
	 */
	public static String GetProfileSectionKey(int _intSectionID)
	{
		return "" + PT_CLASSIDS.PT_PROFILESECTION_ID + _intSectionID;
	}

	/**
	 * called by the repost control to create a new category.
	 *
	 * @param _htFormData hashtable with form data including the new name and
	 * description of the category to be created.
	 *
	 * @return int whether successful or not.
	 */
	public int ActionOnRepost_NewCtg(XPHashtable _htFormData)
	{
		/* get new category name */
		String[] newName = (String[]) _htFormData.GetElement(EODPortletPrefsMainDP.HTMLHIDDEN_NEWCTG);

		if ((newName == null) || newName[0].equals(""))
		{
			log.Error(STR_MVC_CLASS_NAME + "::ActionOnRepost_NewCtg() category name cannot be null or blank.");

			return RepostControl.PAGE_STATUS_INVALID;
		}

		/* get new category description */
		String[] newDesc = (String[]) _htFormData.GetElement(EODPortletPrefsMainDP.HTMLHIDDEN_NEWCTGDESC);

		/* create new Profile Section*/
		IPTObjectManager profileSectionMgr = ((IPTSession)m_asOwner.GetUserSession()).GetProfileSections();
		IPTProfileSection newProfileSection = (IPTProfileSection)profileSectionMgr.Create(m_profilePage.GetAdminFolderID());
		newProfileSection.SetName(newName[0]);
		newProfileSection.SetDescription(newDesc[0]);
		newProfileSection.SetChildProperties(new Object[0]);

		/* register new Profile Section to Profile Page */
		((EODPortletPrefsEditorAS) m_asOwner).RegisterProfileSection(newProfileSection.GetObjectID());

		/* get the select object for this ProfilePage */
		EODPortletPrefsProfileSectionListModel profilePageModel = (EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList);

		/* add a new row for this new Profile Section */
		Object[][] oRow = new Object[1][EODPortletPrefsProfileSectionListModel.EXPLIST_COL_MAX];
		oRow[0][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(profilePageModel.m_nNextIndex);
		profilePageModel.m_nNextIndex++;
		oRow[0][SelectPTObjectModel.EXPLIST_COL_CLASSID]	  = new Integer(PT_CLASSIDS.PT_PROFILESECTION_ID);
		oRow[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = new Integer(newProfileSection.GetObjectID());
		oRow[0][SelectPTObjectModel.EXPLIST_COL_STRING]		  = newProfileSection.GetName();
		oRow[0][EODPortletPrefsProfileSectionListModel.EXPLIST_COL_PROFILESECTION]		  = newProfileSection;

		/* if this model doesn't have any items yet, then use default method */
		PTGrowableSortedArrayWrapper items = profilePageModel.GetItems();

		if (null == items)
		{
			profilePageModel.SetDefaultObjects(oRow);
		}
		else
		{
			items.AddRows(oRow);
		}
		

		/* create this categories select object */
		profilePageModel.StartCtgSelectPTObject(newProfileSection, profilePageModel.GetItems().GetCount());

		/* add to new object keys array */
		m_newObjectKeys.Add(GetProfileSectionKey(newProfileSection.GetObjectID()));
		
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * called by repost control to rename a category.
	 *
	 * @param _htFormData posted form data that contains page and section
	 * keys to identify the section to be renamed.
	 */
	public void ActionOnRepost_RenameCtg(XPHashtable _htFormData)
	{
		/* get index of section to rename */
		String[] strIndSection = (String[]) _htFormData.GetElement(EODPortletPrefsRepostControl.HTMLINPUT_PASSTHRU_ARGS);
		m_nIndRenameObj = XPConvert.ToInteger(strIndSection[0]);
		
		/* get the section to update via the main DP */
		PTGrowableSortedArrayWrapper arProfileSections = ((EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList)).GetItems();
		IPTProfileSection ptProfileSection = (IPTProfileSection)arProfileSections.GetItem(m_nIndRenameObj, EODPortletPrefsProfileSectionListModel.EXPLIST_COL_PROFILESECTION);

		if (ptProfileSection == null)
		{
			return;
		}

		/* initialize the locNamesModel with the appropriate category */
		LocNamesModel locNamesModel = (LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);
		locNamesModel.InitializeNameDescEditor(ptProfileSection, 14);

	}

	/**
	 * called by repost control when the renaming of an object is complete.
	 *
	 * @param _htFormData posted form data that identifies ojbect to be renamed
	 */
	public void ActionOnRepost_RenameObjDone(XPHashtable _htFormData)
	{
		/* get locname model */
		LocNamesModel locNamesModel = (LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);

		/* save the changes in memory */
		locNamesModel.SaveSection(_htFormData);
		locNamesModel.Finish();
		
		PTGrowableSortedArrayWrapper arProfileSections = ((EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList)).GetItems();
		arProfileSections.SetItem(m_nIndRenameObj, EODPortletPrefsProfileSectionListModel.EXPLIST_COL_STRING, locNamesModel.GetPrimaryName());
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Cancel()
	 */
	public void Cancel()
	{
		if (m_profilePage.GetLockState() != PT_LOCKSTATES.PT_NEWLYCREATED)
		{
			m_profilePage.UnlockObject();			
		}
		super.Cancel();		
	}

	/**
	 * Initializes the property type member variable with  the one from
	 * IPTProperty in Edit mode and the default  value in create mode.
	 *
	 * @param _htFormData
	 *
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		super.DoTaskOnStartEditor(_htFormData);
		int nProfilePageID = GetProfilePageIDFromPrefs();
		IPTObjectManager profilePageMgr = ((IPTSession)m_asOwner.GetUserSession()).GetProfilePages();
		if (nProfilePageID == -1)
		{
			m_profilePage = (IPTProfilePage)profilePageMgr.Create(PT_INTRINSICS.PT_ADMIN_FOLDER_PROFILELAYOUT);
		}
		else
		{
			m_profilePage = (IPTProfilePage)profilePageMgr.Open(nProfilePageID, true);
		}
		m_profilePage.SetName(GetPortletName());
		((EODPortletPrefsEditorAS) m_asOwner).InitProfilePage(this, m_profilePage);
		InitializeProfilePage();
	}

	/**
	 *
	 *
	 */
	private int GetProfilePageIDFromPrefs()
	{
		int nProfilePageID = -1;

		try
		{
			Object oSetting = GetSettingValue(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, SETTING_PROFILEPAGEID);

			if (oSetting != null)
			{
				nProfilePageID = XPConvert.ToInteger(oSetting);
			}
		}
		catch (Exception e)
		{
			
			log.Info(e, STR_MVC_CLASS_NAME + "::InitLayoutIDFromPrefs No Admin Settings Found.");
			
		}
		
		return nProfilePageID;
	}

	/**
	 * Sets a new value for the member variable "LayoutID".
	 *
	 * @returns _LayoutID
	 */
	public int GetProfilePageID()
	{
		return m_profilePage.GetObjectID();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EODPortletPrefsModel();
	}

	/**
	 * Code executed in finish.
	 *
	 */
	public void Finish()
	{
		PTGrowableSortedArrayWrapper arProfileSections = ((EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList)).GetItems();
		
		for (int indSection = 0; indSection < arProfileSections.GetCount(); indSection++)
		{
			IPTProfileSection ptProfileSection = (IPTProfileSection)arProfileSections.GetItem(indSection, EODPortletPrefsProfileSectionListModel.EXPLIST_COL_PROFILESECTION);
			StoreObject(ptProfileSection, GetProfileSectionKey(ptProfileSection.GetObjectID()));
		}

		GetProfilePage().Store();
		GetProfilePage().UnlockObject();

		SetSettingValue(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, SETTING_PROFILEPAGEID, new Integer(m_profilePage.GetObjectID()));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);

	}

	/**
	 * Returns true if the object description cannot be set/changed from the Editor.
	 * This is here mainly because ObjEditor has this method and the
	 * locNamesPrimaryNameView uses this to determine whether or not to display
	 * the description field and js validation.  For our proposes, we will
	 * always display the discription field.  So this will always return false.
	 *
	 * @return boolean
	 */
	public boolean IsDescriptionDisabled()
	{
		return false;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		/* save page for user profile layout */
		if (_sPageName.equals(EODPortletPrefsLocNamesDP.STR_MVC_CLASS_NAME))
		{
			return SaveRenameObject(_htFormData);
		}

		else if (_sPageName.equals(EODPortletPrefsMainDP.STR_MVC_CLASS_NAME))
		{
			return SaveMainPage(_sPageName, _htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Helper method to determine activity rights.
	 */
	protected boolean CheckActivityRight()
	{
		return ((IPTSession)m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_PROFILE_LAYOUT);
	}

	/**
	 * Helper method to Store the Object.
	 *
	 */
	protected void StoreObject(IPTObject _object, String _key)
	{
		log.Debug(STR_MVC_CLASS_NAME + "::StoreObject Object ownerId= " + _object.GetOwnerID());
		

		try
		{
			// JF- Shouldn't lock the Object if this is a new one
			if (!m_newObjectKeys.Contains(_key))
			{
				_object.LockObject();
			}

			_object.Store();
		}

		catch (Exception e)
		{
			log.Error(e, "EODPortletPrefsModel::StoreObject Unable to store the Object.");
			throw new XPException(m_asOwner.GetString(994, "ptmsgs_portaladminmsgs"), e);
		}

		finally
		{
			_object.UnlockObject();
		}
	}

	/**
	 * returns the Layout object that represents the current user profile layout
	 *
	 * @return Layout
	 */
	public IPTProfilePage GetProfilePage()
	{
		return m_profilePage;
	}

	/**
	 * Initializes the SelectPTObjectModel object for the profile page and
	 * SelectPTObjectModel objects for each section.  The section model is a
	 * ExpList of properties, limited to properties mapped to user objects via
	 * the global object properties map.
	 *
	 */
	private void InitializeProfilePage()
	{
		/* initialize list */
		EODPortletPrefsProfileSectionListModel catModel = (EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList);

		catModel.InitializeSelectPTObject("", m_asOwner.GetString(988, "ptmsgs_portaladminmsgs"), PTImageType.SPACER, "", new int[]{PT_CLASSIDS.PT_PROFILESECTION_ID}, 1);
		catModel.SetNoRowIcons(true);
		
		// set the explainatory text
		catModel.SetTableInstructions(m_asOwner.GetString(2447, "ptmsgs_portaladminmsgs"));

		// set message and instructions to display when the list is empty.
		catModel.SetEmptyListMessages(m_asOwner.GetString(1906, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1907, "ptmsgs_portaladminmsgs"));

		/* we don't want the users to add this list */
		catModel.DisableAddButton();

		/* initialize the delete functionality */
		catModel.SetDeleteIconAlt(m_asOwner.GetString(65, "ptmsgs_portaladminmsgs"));
		catModel.SetDelRowConfirmMsg(m_asOwner.GetString(2366, "ptmsgs_portaladminmsgs"));

		catModel.LoadProfileSections(m_profilePage);

// mel: Workaround for 47674: The CheckEmptyList javascript functions called from validatePage were overridden
// to display an alert popup when a category has no properties or when there are no categories.
// However, the UI produces an error on Finish, so these checks were a "nice to have" feature.
// Unfortunately, when you delete a user profile section, the CheckEmptyListN() for that section
// is no longer in the javascript of the page, even though its called from validatePage.
// This results in a javascript error. 
// The workaround is to disable the javascript validation of category and property lists.
//
        // add JavaScript validation to make sure the list has at least one row.
//		String sJSFunctionName = ((SelectPTObjectModel) catModel).SetEnableEmptyListClientValidation(m_asOwner.GetString(1906, "ptmsgs_portaladminmsgs"));
//		EODPortletPrefsMoveCtgDP profileManagerDP = (EODPortletPrefsMoveCtgDP) m_asOwner.GetPage(EODPortletPrefsMoveCtgDP.STR_MVC_CLASS_NAME);
//		profileManagerDP.AddToValidationFunction(sJSFunctionName);

		/* move rows up and down */
		catModel.SetEnableMoveRowActions(true);
	}

	/**
	 * Move categories up or down.
	 */
	private void MoveProfileSection(String _strProfileSectionKey, int _position)
	{
		//fixing j2c -mgs
//		Object[] arProfileSectionIDs = _ptProfilePage.GetChildSections();
//		int cnt = arProfileSectionIDs.length;
//
//		for (int i = 0; i < cnt; i++)
//		{
//			int nSectionID = XPConvert.ToInteger(arProfileSectionIDs[i]);
//			String strThisProfileSectionKey = GetProfileSectionKey(nSectionID);
//
//			if (strThisProfileSectionKey.equals(_strProfileSectionKey))
//			{
//				boolean moveUp = _position < i;
//
//				//fixing j2c -mgs
//				int moveCnt = ((i - _position) < 0) ? (-(i - _position)) : (i - _position);
//				int curPos = i;
//
//				if (moveUp)
//				{
//					while (moveCnt > 0)
//					{
//						_ptProfilePage.MoveCategoryUp(curPos);
//						moveCnt--;
//						curPos--;
//					}
//				}
//				else
//				{
//					while (moveCnt > 0)
//					{
//						_ptProfilePage.MoveCategoryDown(curPos);
//						moveCnt--;
//						curPos++;
//					}
//				}
//
//				return;
//			}
//		}
	}

	/**
	 * Before a repost, save the current state of the main page.
	 *
	 * @param _sPageName page to save
	 * @param _htFormData posted form data
	 *
	 * @return int whether save was successful.
	 */
	private int SaveMainPage(String _sPageName, XPHashtable _htFormData)
	{
		int nSaveStatus = RepostControl.PAGE_STATUS_VALID;

		EODPortletPrefsProfileSectionListModel profilePageModel = (EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList);

		/* create a mapping of the category keys to their location in the
		 * growable array so that we can update the names in case they have
		 * been renamed */
		PTGrowableSortedArrayWrapper arProfileSections = profilePageModel.GetItems();

		//fixing j2c -mgs
		int cnt = arProfileSections.GetCount();
		
		if (cnt == 0)
		{
			// throw error
			nSaveStatus = RepostControl.PAGE_STATUS_INVALID;					
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null,
				m_asOwner.GetString(48, "ptmsgs_portletsmsgs"),
				m_asOwner.GetString(48, "ptmsgs_portletsmsgs"));
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
						
			return nSaveStatus;
			
		}

		// make sure the same property does not exist on other profile sections
		for (int indCurrSection = 0; indCurrSection < arProfileSections.GetCount(); indCurrSection++)
		{
			int nCurrSectionID = XPConvert.ToInteger(arProfileSections.GetItem(indCurrSection, EODPortletPrefsProfileSectionListModel.EXPLIST_COL_OBJECTID));
			String strProfileSectionKey = EODPortletPrefsModel.GetProfileSectionKey(nCurrSectionID);
			EODPortletPrefsSelectPTObjectModel profileSectionModel = (EODPortletPrefsSelectPTObjectModel) m_asOwner.GetModel(strProfileSectionKey);
	
			for (int indNextSection = indCurrSection + 1; indNextSection < arProfileSections.GetCount(); indNextSection++)
			{
				int nNextSectionID = XPConvert.ToInteger(arProfileSections.GetItem(indNextSection, EODPortletPrefsProfileSectionListModel.EXPLIST_COL_OBJECTID));
				String strNextProfileSectionKey = EODPortletPrefsModel.GetProfileSectionKey(nNextSectionID);
				EODPortletPrefsSelectPTObjectModel nextProfileSectionModel = (EODPortletPrefsSelectPTObjectModel) m_asOwner.GetModel(strNextProfileSectionKey);

				for (int indRow = 0; indRow < profileSectionModel.GetNumObjects(); indRow++)
				{
					int propID = XPConvert.ToInteger(profileSectionModel.GetItems().GetItem(indRow, EODPortletPrefsSelectPTObjectModel.EXPLIST_COL_OBJECTID));
					if (nextProfileSectionModel.ContainsObject(PT_CLASSIDS.PT_PROPERTY_ID, propID))
					{
						// throw error
						nSaveStatus = RepostControl.PAGE_STATUS_INVALID;					
						UIError myError = new UIError(UIErrorLevel.FRIENDLY,

							UIErrorScope.CURRENT_USER, null,
								m_asOwner.GetString(45, "ptmsgs_portletsmsgs"),

							m_asOwner.GetString(45, "ptmsgs_portletsmsgs"));
						UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
							m_asOwner.GetApplication());
						
						return nSaveStatus;
					}
				}
			}
		}

		/* call the SavePages of each category's selectModel and update name */
		XPArrayList xpalProfileSections = new XPArrayList();
		for (int indSection = 0; indSection < arProfileSections.GetCount(); indSection++)
		{			
			int nSectionID = XPConvert.ToInteger(arProfileSections.GetItem(indSection, EODPortletPrefsProfileSectionListModel.EXPLIST_COL_OBJECTID));	
			String strProfileSectionKey = EODPortletPrefsModel.GetProfileSectionKey(nSectionID);
			EODPortletPrefsSelectPTObjectModel profileSectionModel = (EODPortletPrefsSelectPTObjectModel) m_asOwner.GetModel(strProfileSectionKey);

			if (RepostControl.PAGE_STATUS_INVALID == profileSectionModel.SaveSection(_htFormData))
			{
				nSaveStatus = RepostControl.PAGE_STATUS_INVALID;
			}

			/* update section name on select model */
			IPTProfileSection ptProfileSection = (IPTProfileSection)arProfileSections.GetItem(indSection, EODPortletPrefsProfileSectionListModel.EXPLIST_COL_PROFILESECTION);
			profileSectionModel.SetSectionTitle(XPHttpUtility.HtmlEncode(ptProfileSection.GetName()));

			if (ptProfileSection.GetDescription().equals(""))
			{
				profileSectionModel.SetTableInstructions(m_asOwner.GetString(2153, "ptmsgs_portaladminmsgs"));
			}
			else
			{
				profileSectionModel.SetTableInstructions(XPHttpUtility.HtmlEncode(ptProfileSection.GetDescription()));
			}

			/* if successful save, update layout by re-adding properties from model */
			if (nSaveStatus == RepostControl.PAGE_STATUS_VALID)
			{
				XPArrayList xpalPropertyIDs = new XPArrayList();
//				ptProfileSection.RemoveAllProperties();

				PTGrowableSortedArrayWrapper properties = profileSectionModel.GetItems();

				//fixing j2c -mgs
				cnt = properties.GetCount();

				if (cnt == 0)
				{
					// throw error
					nSaveStatus = RepostControl.PAGE_STATUS_INVALID;					
					UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null,
						m_asOwner.GetString(49, "ptmsgs_portletsmsgs"),
						m_asOwner.GetString(49, "ptmsgs_portletsmsgs"));
					UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
						m_asOwner.GetApplication());
						
					return nSaveStatus;
			
				}

				for (int i = 0; i < cnt; i++)
				{
					Object objPropID = properties.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
					xpalPropertyIDs.Add(objPropID);
				}
				ptProfileSection.SetChildProperties(xpalPropertyIDs.ToArray());
			}
			xpalProfileSections.Add(new Integer(nSectionID));
		}
		
		m_profilePage.SetChildSections(xpalProfileSections.ToArray());

		return nSaveStatus;
	}

	/**
	 * helper method to use LocNamesModel to rename objects.
	 *
	 * @param _htFormData posted form data.
	 *
	 * @return int if successful
	 */
	private int SaveRenameObject(XPHashtable _htFormData)
	{
		/* get locname model */
		LocNamesModel locNamesModel = (LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);

		/* save the changes in memory */
		if (RepostControl.PAGE_STATUS_INVALID == locNamesModel.SaveSection(_htFormData))
		{
			return RepostControl.PAGE_STATUS_INVALID;
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetPortletID()
	{
		return m_nPortletID;
	}
}

