package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 * Pop up page that lists all the sections in the current page.  The
 * sections can be managed from this pop: they can be deleted and/or moved
 * up/down.  The constructor for this class overrides the mvc class name.  This
 * page is used for mutiple sections on a given page.
 */
public class EODPortletPrefsMoveCtgDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
			"com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsMoveCtgDP");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "EODDisplayPrefsMoveCtg";

	/** html element names */
	public static final String HTMLINPUT_POPUPSTRING = "in_tx_PopUpString";
	public static final String HTMLBUTTON_DONE = "in_bu_done";
	public static final String HTMLBUTTON_CANCEL = "in_bu_cancel";

	public EODPortletPrefsMoveCtgDP()
	{
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(998, "ptmsgs_portaladminmsgs");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// action Row begin
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;

		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);

		/* title */
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetAlign("left");
		myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
		myCell.AddInnerHTMLString(m_asOwner.GetString(998, "ptmsgs_portaladminmsgs"));

		/* actions */
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetAlign("right");

		// ***Done Action*** begins here
		myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_DONE, "");
		myCell.AddInnerHTMLElement(myInput);

		myInput.SetValue(m_asOwner.GetString(2, "ptmsgs_portalcommonmsgs"));
		myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
		myInput.SetOnClick("OnDone(); return false;");

		// spacer
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		// ***Cancel Action*** begins here
		myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL, "");
		myCell.AddInnerHTMLElement(myInput);

		myInput.SetValue(m_asOwner.GetString(1000, "ptmsgs_portaladminmsgs"));
		myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
		myInput.SetOnClick("window.close();"); // mj: removed 'Javascript:' from function name

		/* add view's display */
		EditorView view = (EditorView) m_asOwner.GetView(EODPortletPrefsEditorAS.strStorageProfileSectionList);
		result.AddInnerHTMLElement(view.Display());

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		myScripts.AddInnerHTMLElement(DisplayOnDoneJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(EODPortletPrefsEditorAS.strStorageProfileSectionList).DisplayJavascript());

		return myScripts;
	}
	
	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayOnDoneJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		XPStringBuilder sb;

		try
		{
			// JF- OnDone JavaScript function
			sb = new XPStringBuilder(200);
			sb.Append("function OnDone()\n");
			sb.Append("{\n");

			// JF- Then we repost the main form
			sb.Append("   window.opener.").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(EODPortletPrefsRepostControl.POSTTOSELF_ACTION_MOVECTG_DONE).Append(");\n");

			// JF- Finally we close the pop-up window
			sb.Append("   window.close();\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME + "::DisplayOnDoneJavascript The following error occured when trying to display the JavaScript: " + he.GetMessage());
			
		}

		return myScript;
	}

}

