package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 * Pop up page lists all sections of a page.  Users can select a section to
 * rename and the localized names and description dp and model are called.
 * The DP is initialized by passing in a section object representing a section
 * in a user profile page.  The MVC name is overwritten via the constructor.
 * When trying to reference this class, use the name it was registered with.
 * If attempting to find out if a particular class if of this type, use
 * instanceof insteand of the MVC string.
 */
public class EODPortletPrefsRenameCtgDP extends EditorDP
{
	/** object name */
	public static final String STR_MVC_CLASS_NAME = "EODDisplayPrefsRenameCtg";

	/** html element names */
	public static final String HTMLINPUT_POPUPSTRING = "in_tx_PopUpString";
	public static final String HTMLBUTTON_DONE = "in_bu_done";
	public static final String HTMLBUTTON_CANCEL = "in_bu_cancel";
	public static final String HIDDEN_CTGNAME = "in_hi_CtgName";

	/** current page */
	private String m_pageTitle;

	/**
	 * 
	 * @param _strTitle
	 */
	public EODPortletPrefsRenameCtgDP(String _strTitle)
	{
		m_pageTitle = _strTitle;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript GetJavascript()
	{
		return null;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_pageTitle;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Add hidden inputs used for new name
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HIDDEN_CTGNAME, "");
		result.AddInnerHTMLElement(myInput);

		/* add view's display */
		EODPortletPrefsRenameCtgView view = (EODPortletPrefsRenameCtgView) m_asOwner.GetView(STR_MVC_CLASS_NAME);
		result.AddInnerHTMLElement(view.Display());

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		EODPortletPrefsRenameCtgView view = (EODPortletPrefsRenameCtgView) m_asOwner.GetView(STR_MVC_CLASS_NAME);
		myScripts.AddInnerHTMLElement(view.DisplayJavascript());

		return myScripts;
	}
}

