package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 * Pop up view lists all sections of a page.  Users can select a section to
 * rename and the localized names and description dp and model are called.
 */
public class EODPortletPrefsRenameCtgView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsRenameCtgView");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "EODDisplayPrefsRenameCtg";

	/** html elements names */
	public static final String HTMLBUTTON_DONE = "in_bu_done";
	public static final String HTMLBUTTON_CANCEL = "in_bu_cancel";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EODPortletPrefsRenameCtgView();
	}

	/**
	 * Returns the HTML for the Section.  Should be used instead of Display()
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		try
		{
			result.AddInnerHTMLElement(new HTMLComment("Begin: Display EODPortletPrefsRenameCtgView"));

			// create main table
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// Header/Action Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);

			// header
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign("left");
			myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(1015, "ptmsgs_portaladminmsgs"));

			// Close Button
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign("right");

			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_DONE, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			myInput.SetOnClick("OnDone();");

			// Content Table (wrapper)
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("10");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// instructional text table
			myCell.AddInnerHTMLElement(new HTMLComment("Start Instructional Text"));
			myCell.AddInnerHTMLElement(GetInstructionalHtml());

			// spacer table
			myCell.AddInnerHTMLElement(GetShortSpacerTable());

			// directory header table
			myCell.AddInnerHTMLElement(new HTMLComment("Start Dir Header"));
			myCell.AddInnerHTMLElement(GetDirHeaderHtml());

			// section list table
			myCell.AddInnerHTMLElement(new HTMLComment("Start Categories List"));
			myCell.AddInnerHTMLElement(GetListHtml());

			result.AddInnerHTMLElement(new HTMLComment("End: Display EODPortletPrefsRenameCtgView"));
		}
		catch (Exception e)
		{
			log.Error(e, "EODPortletPrefsRenameCtgView::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(1018, "ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	private HTMLElement GetInstructionalHtml()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

		myCell.AddInnerHTMLString(m_asOwner.GetString(2361, "ptmsgs_portaladminmsgs"));

		return myTable;
	}

	/**
	 * 
	 *
	 * @param _name 
	 *
	 * @return 
	 */
	private HTMLElement GetDirHeaderHtml()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.DIALOGUE_HEADER_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.DIALOGUE_SUBHEAD);
		IEODPortletPrefsModelRO mainModel = (IEODPortletPrefsModelRO)m_asOwner.GetModel(EODPortletPrefsModel.STR_MVC_CLASS_NAME);
		String strName = mainModel.GetProfilePage().GetName();
		mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(2362, "ptmsgs_portaladminmsgs"), XPHttpUtility.HtmlEncode(strName)));

		return myTable;
	}

	/**
	 * 
	 *
	 * @param _section 
	 *
	 * @return 
	 */
	private HTMLElement GetListHtml()
	{
		HTMLTable myTable;
		HTMLTable mySubTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		/* wrapper table */
		myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);

		/* inner table with content */
		mySubTable = new HTMLTable();
		myCell.AddInnerHTMLElement(mySubTable);
		mySubTable.SetWidth("100%");
		mySubTable.SetBorder("0");
		mySubTable.SetCellPadding("5");
		mySubTable.SetCellSpacing("0");

		/* list header row */
		myRow = new HTMLTableRow();
		mySubTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetNoWrap(true);
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myCell.SetHeight("20");
		myCell.AddInnerHTMLString(m_asOwner.GetString(1347, "ptmsgs_portaladminmsgs"));

		/* list of categories */
		PTStyleClass listStyle = PTStyleClass.LIST_ITEM_TWO_BG;

		EODPortletPrefsProfileSectionListModel profilePageModel = (EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList);
		PTGrowableSortedArrayWrapper arProfileSections = profilePageModel.GetItems();
		
		for (int indSection = 0; indSection < arProfileSections.GetCount(); indSection++)
		{
			Object objSectionName = arProfileSections.GetItem(indSection, SelectPTObjectModel.EXPLIST_COL_STRING);		
			String strSectionName = XPConvert.ToString(objSectionName);
			
			/* row for each section */
			myRow = new HTMLTableRow();
			mySubTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(listStyle);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

			// url to localized names DP
			ASURL myPopUp = new ASURL(m_asOwner);
			myPopUp.SetLinkGetCachedSpace(m_asOwner);
			myPopUp.SetDisplayPage(EODPortletPrefsLocNamesDP.STR_MVC_CLASS_NAME);
			myPopUp.SetControl(EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
			myPopUp.AddControlArgument(ASConstants.PAGE_INPUT, EODPortletPrefsRenameCtgDP.STR_MVC_CLASS_NAME);
			myPopUp.AddControlArgument(EODPortletPrefsRepostControl.HTMLINPUT_POSTTOSELF, "" + EODPortletPrefsRepostControl.POSTTOSELF_ACTION_RENAMECTG_OPEN + "");
			myPopUp.AddControlArgument(EODPortletPrefsRepostControl.HTMLINPUT_PASSTHRU_ARGS, XPConvert.ToString(indSection));

			String url = myPopUp.GetURLAsString();

			/* anchor element for popup */
			HTMLAnchor myAnchor = new HTMLAnchor(url);
			myCell.AddInnerHTMLElement(myAnchor);
			myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strSectionName));

			/* flip style */
			if (listStyle.equals(PTStyleClass.LIST_ITEM_TWO_BG))
			{
				listStyle = PTStyleClass.LIST_ITEM_ONE_BG;
			}
			else
			{
				listStyle = PTStyleClass.LIST_ITEM_TWO_BG;
			}
		}

		return myTable;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		XPStringBuilder sb;

		try
		{
			// JF- OnDone JavaScript function
			sb = new XPStringBuilder(200);
			sb.Append("function OnDone()\n");
			sb.Append("{\n");

			// JF- Then we repost the main form
			sb.Append("   window.opener.").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(EODPortletPrefsRepostControl.POSTTOSELF_ACTION_ONRETURN_FROM_SUBEDITOR).Append(");\n");

			// JF- Finally we close the pop-up window
			sb.Append("   window.close();\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			myScript.AddInnerHTMLString(GetOpenJS());
		}
		catch (HTMLException he)
		{
			log.Error(he, "EODPortletPrefsRenameCtgView::DisplayJavascript An error occured when trying to display the JavaScript.");
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 */
	private String GetOpenJS()
	{
		XPStringBuilder sb;

		// Open Pop Up function
		sb = new XPStringBuilder(100);
		sb.Append("function Open(url)\n");
		sb.Append("{\n");
		sb.Append("    window.open(url, '_EODDisplayPrefsRenameCtgView_DP', 'scrollbars=yes,location=no,menubar=no,height=400,width=600');\n");
		sb.Append("}\n");

		return sb.ToString();
	}
}

