package com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/***
 * SelectPTObjectModel for selecting Properties to be part of the Category.
 * 
 * @author jennifersu
 */
public class EODPortletPrefsSelectPTObjectModel extends SelectPTObjectModel implements ISelectPTObjectModelRO
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "EODDisplayPrefsSelectPTObject";
	private XPArrayList m_propMapList;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EODPortletPrefsSelectPTObjectModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex, XPHashtable _htFormData)
	{
		Object addedID = _saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_OBJECTID);

		if (m_propMapList.Contains(addedID))
		{
			return RepostControl.PAGE_STATUS_VALID;
		}
		else
		{
			// raise error to display to user
			String strErrorMsg = GetRowErrorMessage(_nRowIndex, m_asOwner.GetString(579, "ptmsgs_portalbrowsingmsgs"));
			UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER, strErrorMsg, strErrorMsg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			return RepostControl.PAGE_STATUS_INVALID;
		}
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _arrObjectClassIDs Class ID of the Objects displayed on the list.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeSelectPTObject(String _sSectionTitle, String _sSectionSubTitle, PTImageType _imgAddIcon, String _sAddLabel, int[] _arrObjectClassIDs, int _nListKey)
	{
		super.InitializeSelectPTObject(_sSectionTitle, _sSectionSubTitle, _imgAddIcon, _sAddLabel, _arrObjectClassIDs, _nListKey);

		// load all properties that are mapped to users into an array so we can easily
		// check against it later.
		IPTObjectPropertyMap propMap = (IPTObjectPropertyMap) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_OBJECTPROPERTYMAP, false);
		IPTQueryResult results = propMap.QueryClassPropertyMappings(PT_CLASSIDS.PT_USER_ID, PT_PROPIDS.PT_PROPID_OBJECTID);
		m_propMapList = new XPArrayList();

		int nCount = results.RowCount();

		for (int i = 0; i < nCount; i++)
		{
			int propID = results.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
			m_propMapList.Add(new Integer(propID));
		}
	}

	/**
	 * Return an error message for row
	 *
	 * @param _nRowIndex Row index
	 * @param strMessage Message
	 *
	 * @return Error message for row
	 */
	protected String GetRowErrorMessage(int _nRowIndex, String strMessage)
	{
		XPStringBuilder sb = new XPStringBuilder(100);
		String strPropertyName = GetRowName(_nRowIndex);

		sb.Append(strPropertyName).Append(": ");
		sb.Append(strMessage);

		return sb.ToString();
	}

	/**
	 * Returns the name of the property in the indicated row
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Name of property
	 */
	public String GetRowName(int _nRowIndex)
	{
		return (String) m_saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_STRING);
	}
}

