package com.plumtree.portalpages.portlets.userprofile.folders;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.server.*;

/**
 *
 *
 * @author jennifersu
 */
public class FoldersPortletModel extends IntrinsicPortletModel implements IFoldersPortletModelRO
{
	/** Class name for the model */
	public static final String STR_MVC_CLASS_NAME = "ExpertFoldersPortlet";

	public final static int NO_PROFILE_USER = 0;

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#ControlExists()
	 */
	public boolean ControlExists()
	{
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#Create()
	 */
	public Object Create()
	{
		return new FoldersPortletModel();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#GetNewTempData()
	 */
	public Object GetNewTempData()
	{
		return null;
	}

	/**
	 * This method determines what roles the user is a member of and obtains
	 * the approriate text to be displayed in the introspective portlet.
	 *
	 * @param searchResponse  the search results for the user
	 * @param index  the current index in the search results
	 * @param iCurrentUser the current user id
	 *
	 * @return String the display string for the cell
	 */
	public String GetUserRoles(IPTSearchResponse searchResponse, int index, int iCurrentUser)
	{
		String expertrole = searchResponse.GetFieldsAsString(index, PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS);
		String conmanagerrole = searchResponse.GetFieldsAsString(index, PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS);
		boolean bisExpert = false;
		boolean bisConManager = false;

		// check to see if the user belongs to the expert role
		if (belongsToRole(expertrole, iCurrentUser))
		{
			bisExpert = true;
		}

		// check to see if the user belongs to the content manager role
		if (belongsToRole(conmanagerrole, iCurrentUser))
		{
			bisConManager = true;
		}

		// return the appropriate string
		if (bisExpert && bisConManager)
		{
			return m_asOwner.GetString(19, "ptmsgs_portletsmsgs");
		}
		else if (bisExpert)
		{
			return m_asOwner.GetString(15, "ptmsgs_portletsmsgs");
		}
		else if (bisConManager)
		{
			return m_asOwner.GetString(14, "ptmsgs_portletsmsgs");
		}

		return "";
	}

	/**
	 * This method uses the Plumtree search API and searches all folders that a
	 * user is a expert or content manager of.
	 *
	 * @param ptSession a valid plumtree session
	 * @param profileUserID the profile user id that will be used to search
	 *        information on.
	 *
	 * @return IPTSearchResponse
	 */
	public IPTSearchResponse GetSearchResults(int profileUserID)
	{
		IPTSearchRequest searchRequest;
		IPTFilter ptFilter;

		searchRequest = m_ptSession.GetSearchRequest();

		// Restrict the search to our top level test folders
		searchRequest.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, new int[]
			{
				PT_CLASSIDS.PT_CATALOGFOLDER_ID
			});

		// make sure the expert and content manager information is returned.
		searchRequest.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS, new int[]
			{
				PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS,
				PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS
			});

		ptFilter = PortalObjectsFactory.CreateSearchFilter();

		IPTPropertyFilterClauses ptClause = (IPTPropertyFilterClauses) ptFilter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);
		ptClause.SetOperator(PT_BOOLOPS.PT_BOOLOP_OR);

		// check for expert
		addStatement(ptFilter, ptClause, PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS, PT_FILTEROPS.PT_FILTEROP_CONTAINS, profileUserID);

		// check for community manager
		addStatement(ptFilter, ptClause, PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS, PT_FILTEROPS.PT_FILTEROP_CONTAINS, profileUserID);

		ptFilter.SetPropertyFilter(ptClause);

		IPTSearchQuery query = searchRequest.CreateAdvancedQuery(ptFilter);

		return searchRequest.Search(query);
	}

	/**
	 * Helper function to add a statement to a filter. The filter API is
	 * somewhat confusing. A filter holds a clause, which can in turn hold a
	 * number of statements. This method creates a statement equivalent to
	 * "propID opID value" and adds it to the clause. We presume that the
	 * caller has created the clause using the filter.
	 *
	 * @param ptFilter
	 * @param ptClause
	 * @param propID Integer id of a property, e.g. 101 corresponds to the
	 *        "Keywords" property. These numbers are object ids in the
	 *        PTPROPERTIES database table.
	 * @param opID Integer id of an operator, e.g. PT_FILTEROPS.
	 *        PT_FILTEROP_CONTAINS
	 * @param value String value to use for the search.
	 */
	private void addStatement(IPTFilter ptFilter, IPTPropertyFilterClauses ptClause, int propID, int opID, int value)
	{
		IPTPropertyFilterStatement ptStatement = (IPTPropertyFilterStatement) ptFilter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
		ptStatement.SetOperand(propID);
		ptStatement.SetOperator(opID);
		ptStatement.SetValue(value);

		int count = ptClause.GetCount();
		ptClause.AddItem(ptStatement, count);
	}

	/**
	 * checks to see if the user is in a particular role (expert or content
	 * manager).  The way the EOD role data is indexed in Plumtree is by a
	 * space delimited string of all the userids. This method loops through to
	 * determine if this user exists in the string.
	 *
	 * @param sData The data being inspected
	 * @param sUserid the user id to be checked
	 *
	 * @return boolean
	 */
	private boolean belongsToRole(String sData, int sUserid)
	{
		if (null != sData)
		{
			XPStringTokenizer stRole = new XPStringTokenizer(sData, " ");
			String sKey;

			while (stRole.HasMoreElements())
			{
				sKey = (String) stRole.GetNextElement();

				if (XPConvert.ToInteger(sKey) == sUserid)
				{
					return true;
				}
			}
		}

		return false;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetProfileID()
	{
		IPTUserInfo userInfo = m_ptSession.GetUserInfo();

		return userInfo.GetProfileUserID();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCurrentUser()
	{
		IPTSessionInfo sessionInfo = m_ptSession.GetSessionInfo();

		return sessionInfo.GetCurrentUserID();
	}
	
	/**
	 * @see com.plumtree.xpportlets.expatriate.ext.introspective.IProfilePortlet#getTitle()
	 */
	public String GetTitle()
	{
		return "";
	}

	public String GetPortletDescription()
	{
		return m_ptPortlet.GetDescription();
	}
}

