package com.plumtree.portalpages.portlets.userprofile.infrastructure;

import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author chrisb
 */
public interface IProfileCell
{
	/**
	 * Tells the caller whether or not this ProfileCell contains  HTML. If it
	 * has markup, the caller will not encode it so that  the markup gets
	 * interpreted. If it returns false, you're telling the caller that you
	 * want to HTMLEncode the text.
	 *
	 * @return Whether or not this ProfileCell contains HTML.
	 */
	public boolean isHTML();

	/**
	 * Tells the caller if the cell that is being displayed is an image.  If
	 * the cell is an image it is displayed differently in the TablePage.
	 *
	 * @return boolean
	 */
	public boolean isImg();

	/**
	 * Returns an HTMLAnchor element if the Profile Cell is using a click
	 * through URI and/or an onclick action.
	 *
	 * @return HTMLAnchor the anchor element that is used for the cell.
	 */
	public HTMLAnchor GetHTMLAnchor();

	/**
	 * If there is an image set on the Profile Cell it will return the image
	 * object
	 *
	 * @return HTMLImg
	 */
	public HTMLImg GetImage();

	/**
	 * Returns a description of the ProfileCell that will be shown as
	 * mouse-over (pop-up) text. This method is optional. If you  don't want
	 * to have a mouse-over, implement this method to return  an empty string.
	 *
	 * @return A description of the ProfileCell to be shown as a mouse-over.
	 */
	public String GetMouseOver();

	/**
	 * Returns the sub text that will be displayed below the text of the cell.
	 * This sub text will not be associated with the click through URI.
	 *
	 * @return boolean
	 */
	public String GetSubText();

	/**
	 * Returns the text to go in the ProfileCell. This method must return a
	 * value.
	 *
	 * @return The text to display in the ProfileCell.
	 */
	public String GetText();
}

