package com.plumtree.portalpages.portlets.userprofile.infrastructure;

import com.plumtree.openfoundation.util.*;

/**
 * Describes the methods required to be an Introspective User Profile  Portlet.
 * Examples of these portlets may include "Documents Submitted," "Folders
 * Created," "Gadgets Created," etc.
 *
 * @author chrisb
 */
public interface IProfileTable
{
	/**
	 * Returns the portlet's description.
	 *
	 * @return The portlet's description.
	 */
	public String GetDescription();

	/**
	 * Optionally returns a "header" row. This row will be formatted like a
	 * header for your ProfileTable. If you don't want to have a ProfileRow
	 * that looks like a header, return null.
	 *
	 * @return A ProfileRow object to represent the header row of the
	 *         ProfileTable or null if you don't want a header row.
	 */
	public IProfileRow GetHeaderRow();

	/**
	 * Returns the number of ProfileRow objects in the ProfileTable.
	 *
	 * @return The number of ProfileRow objects in the ProfileTable.
	 */
	public int GetNumProfileRows();

	/**
	 * Returns the ProfileItem objects corresponding to the profile  username.
	 * Each ProfileItem represents one row of content  (e.g. the name and
	 * description of a folder or document created  by the profile user).
	 *
	 * @param profileUserID The ID of the user who's profile is currently being
	 *        viewed.
	 * @param profileLogOnToken The log on token of the user that is being
	 *        viewed. This is used to search on Plumtree specific information
	 * @param viewingUserID The ID of the user who is currently viewing the
	 *        profile.
	 *
	 * @return An XPEnumerator of ProfileItem objects.
	 */
	public IXPEnumerator GetProfileRows(int profileUserID,
		String profileLogOnToken, int viewingUserID);

	/**
	 * Returns the portlet's title.
	 *
	 * @return The Portlet's title.
	 */
	public String GetTitle();

	/**
	 * Indicates whether the source content has been updated since the supplied
	 * date. This method enables the UI to cache the content until it changes.
	 * To turn off caching, implement this method always to return true. To
	 * use caching, implement this method as a fast way to tell if the content
	 * you're supplying has changed since the date passed into this method.
	 *
	 * @param lastUpdatedDate Indicates the date/time at which the content was
	 *        last updated.
	 *
	 * @return true if the content has been updated; false otherwise.
	 */
	public boolean hasBeenUpdatedSince(XPDateTime lastUpdatedDate);
}

