package com.plumtree.portalpages.rest;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;

/**
 * This class manages all the REST errors to provide easy lookup and make sure
 * that there aren't any conflicts.
 */
public class RESTErrors
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
		"com.plumtree.portalpages.rest.RestErrors");

	/**
	 * This needs to be initialized before any of the specific errors are created.
	 */
	protected static final XPHashtable ERRORS = new XPHashtable();

	/**
	 * Add a REST error to the global map for easy lookup and conflict checking.
	 * 
	 * @param _error the error to add.
	 * @throws XPIllegalStateException if the code is already in use.
	 */
	public static void AddRestError(IRESTError _error) throws XPIllegalStateException
	{
		if (ERRORS.GetElement(new Integer(_error.GetCode())) != null)
		{
			String strError = "Error inserting Rest error " + _error.GetCode() + " into enum. " +
				"That code already exists for error [" + _error.GetMessage() + "].";
			log.Warn(strError);
			throw new XPIllegalStateException(strError);
		}

		ERRORS.PutElement(new Integer(_error.GetCode()), _error);
	}

	/**
	 * Lookup a IRestError object from the error code.
	 * 
	 * @param _nCode the error code to lookup
	 * @return the matching error object.
	 * @throws XPIllegalArgumentException if the error can not be found.
	 */
	public static IRESTError GetError(int _nCode)
	{
		IRESTError error = (IRESTError) ERRORS.GetElement(new Integer(_nCode));

		if (error == null)
		{
			throw new XPIllegalArgumentException("Error " + _nCode + " does not exist.");
		}

		return error;
	}
}