/**
 * 
 */
package com.plumtree.portalpages.rest.dojo;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.rest.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * Processes AJAX Request from Dojo QueryDataStore. Checks for folderid parameter to get
 * documents in that folder
 * 
 * @author rozhang
 */
public class KDDocumentDataStoreControl extends QueryStoreControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
		"com.plumtree.portalpages.rest.dojo.KDDocumentDataStoreControl");
	
	public static final String STR_MVC_CLASS_NAME = "folderQuery";
	
	/** Specifies what kd folder to get documents from **/
	public static final String QS_FOLDERID 		= "folderid";
	/** Additional properties to query for **/
	public static final String QS_QUERYPROPIDS 	= "propids";
	public static final String QS_DATETIMEFORMAT= "dtformat";
	public static final String QS_LOCALE		= "loc";
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// NOTE: when adding a new querystring paramater, also add it in Friendlyurlplugin class
		super.CheckActionSecurityAndExecute(arguments);
		
		KDDocumentDataStoreModel model = (KDDocumentDataStoreModel)m_model;
		
		// Parse locale
		// @TODO: can we replace this with just reading locale settings from personal prefs? How would it work when viewing through ensemble?
		String localeString = HTTPHelpers.GetArgumentAsString(arguments, QS_LOCALE, XPLocale.GetDefault().toString());
		model.SetLocale(localeString);
		
		// Parse date format
		String dateTimeFormat = HTTPHelpers.GetArgumentAsString(arguments, QS_DATETIMEFORMAT, "3,3");
		try {
			XPStringTokenizer tok = new XPStringTokenizer(dateTimeFormat, ",");
			String strDateFormat = tok.GetNextElement();
			String strTimeFormat = tok.GetNextElement();
		
			model.SetDateFormat(XPConvert.ToInteger(strDateFormat));
			model.SetTimeFormat(XPConvert.ToInteger(strTimeFormat));
		} catch (XPException e) {
			log.Warn(e, "There was an error parsing date and time format from request. The invalid string received was: '"+dateTimeFormat+"' Using default values.");
		}
		
		
		// parse and store the folderid parameter, if none is found set as 0 so that the model returns an empty response
		// and not an error response
		int folderId = HTTPHelpers.GetArgumentAsInt(arguments, QS_FOLDERID, KDDocumentDataStoreModel.NOFOLDER_EMPTYRESPONSE);
		model.SetCurrFolderId(folderId);
		
		String propIds = HTTPHelpers.GetArgumentAsString(arguments, QS_QUERYPROPIDS, null);
		
		if ( propIds != null ) {
			XPStringTokenizer propIdsStrTok = new XPStringTokenizer(propIds, ",");
			int[] propIdIntArray = new int[propIdsStrTok.GetTokenCount()];
			int count = 0;
			while ( propIdsStrTok.HasMoreElements() ) {
				try {
					propIdIntArray[count] = XPConvert.ToInteger(propIdsStrTok.GetNextElement());
				} catch (Exception e) {
					propIdIntArray[count] = 1;
				} 
				count++;
			}
			model.SetQueryPropIds(propIdIntArray);
		} else {
			model.SetError(CommonRestErrors.PARAM_MISSING_REQUESTARGUMENT.ParameterizeRESTError(QS_QUERYPROPIDS));
		}
		
		return GetDPRedirect();
	}
	
	public Redirect GetDPRedirect()
	{
		Redirect redirect = new Redirect();
		redirect.SetLinkGetCachedSpace(m_space);
		redirect.SetDisplayPage(KDDocumentDataStoreDP.STR_MVC_CLASS_NAME);

		return redirect;
	}
	
	/**
	 * This helper method sets the error on the model and redirects to the
	 * REST API display page.
	 * 
	 * @param _nErrorID the current error code.
	 * @return The redirect to the User REST API display page.
	 */
	public Redirect ProcessError(IRESTError _error)
	{
		Redirect redirect = GetDPRedirect();
		m_model.SetError(_error);
		return redirect;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_space = space;
		m_model = (AQueryStoreModel)model;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new KDDocumentDataStoreControl();
	}
}
