/**
 * 
 */
package com.plumtree.portalpages.rest.dojo;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.rest.*;
import com.plumtree.portalpages.rest.utils.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author rozhang
 *
 */
public class KDDocumentDataStoreDP implements IDisplayPage
{
	public static final String STR_MVC_CLASS_NAME = "KDDocumentDataStore";
	
	private static OpenLogger log = 
		OpenLogService.GetLogger(
				OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
				"com.plumtree.portalpages.rest.dojo.KDDocumentDataStoreDP");
	
	protected AActivitySpace m_space;
	protected KDDocumentDataStoreModel m_model; 

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display(com.plumtree.uiinfrastructure.activityspace.IWebData)
	 */
	public void Display(IWebData webData)
	{
		
		try
		{
			// This will turn off HTML performance comments, allowing us to output
			// a valid JSON response.  Note that adding comment filtering allows us
			// to add the comments after the comment and Dojo will ignore them.  We
			// should still disable them anyways, in case someone wants to use a
			// library other than Dojo.
			webData.SetIsHTMLText(false);
			// Say that this data is JSON.
			webData.SetHeader(HTTPHeaderConstants.CONTENT_TYPE, "application/json");

			// This currently only supports JSON output

			IRESTError error = m_model.GetError();
			if (error != null) {
				// This handles outputting the error to the webdata object.
				new RESTHelper().OutputError(error, webData, false);
			} else {
				
				XPHashtable restObject = m_model.GetQueryStoreResult();
				
				JSONSerializer json = new JSONSerializer(restObject);
				String jsonResponse = json.GenerateStringRepresentation(true);
				
				webData.SetStatus(200);
				webData.SetData(jsonResponse);
				
			} 
		} catch (Exception e) {
			log.Error(e, "Unable to display JSON output in User REST API.");

			// This handles outputting the error to the webdata object.
			new RESTHelper().OutputError(CommonRestErrors.GENERAL, webData, false);
		}

	}


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_space = parent;
		m_model = (KDDocumentDataStoreModel) m_space.GetModel(KDDocumentDataStoreModel.STR_MVC_CLASS_NAME);
		if ( m_model == null ) {
			throw new XPIllegalStateException("Required model:"+KDDocumentDataStoreModel.STR_MVC_CLASS_NAME+
					" not found in Activityspace: "+parent.GetName());
		}

	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()
	 */
	public AActivitySpace GetOwner()
	{
		return m_space;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}
