/**
 * 
 */
package com.plumtree.portalpages.rest.dojo;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.rest.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * Handles REST requests for retrieving subfolders in a KD Folders
 * @author rozhang
 */
public class KDFolderDataStoreControl implements IControl
{
	public static final String STR_MVC_CLASS_NAME = "folders";
	
	/** query string parameter with folder id **/ 
	public static final String QS_FOLDERID = "folderid"; 
	
	protected AActivitySpace m_space;
	protected KDFolderDataStoreModel m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// lookup the folderid to retrieve subfolders from and set it on the model
		int folderId = HTTPHelpers.GetArgumentAsInt(arguments, QS_FOLDERID, 1);
		m_model.SetParentFolderId(folderId);
		
		return GetDPRedirect();
	}
	
	/**
	 * This helper method sets the error on the model and redirects to the
	 * REST API display page.
	 * 
	 * @param _nErrorID the current error code.
	 * @return The redirect to the User REST API display page.
	 */
	public Redirect ProcessError(IRESTError _error)
	{
		Redirect redirect = GetDPRedirect();
		m_model.SetError(_error);
		return redirect;
	}
	
	public Redirect GetDPRedirect()
	{
		Redirect redirect = new Redirect();
		redirect.SetLinkGetCachedSpace(m_space);
		redirect.SetDisplayPage(KDFolderDataStoreDP.STR_MVC_CLASS_NAME);

		return redirect;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_space = space;
		m_model = (KDFolderDataStoreModel)model;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new KDFolderDataStoreControl();
	}
}
