/**
 * 
 */
package com.plumtree.portalpages.rest.dojo;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.rest.*;
import com.plumtree.portalpages.rest.utils.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Generates JSON response for REST request from dojo DataStore objects 
 * @author rozhang
 */
public class KDFolderDataStoreDP implements IDisplayPage
{
	public static final String STR_MVC_CLASS_NAME = "KDFolderDataStore";
	
	private static OpenLogger log = 
		OpenLogService.GetLogger(
				OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
				"com.plumtree.portalpages.rest.dojo.KDFolderDataStoreDP");

	protected AActivitySpace m_space;
	protected KDFolderDataStoreModel m_model; 
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display(com.plumtree.uiinfrastructure.activityspace.IWebData)
	 */
	public void Display(IWebData webData)
	{
		try
		{
			// This will turn off HTML performance comments, allowing us to output
			// a valid JSON response.  Note that adding comment filtering allows us
			// to add the comments after the comment and Dojo will ignore them.  We
			// should still disable them anyways, in case someone wants to use a
			// library other than Dojo.
			webData.SetIsHTMLText(false);
			// Say that this data is JSON.
			webData.SetHeader(HTTPHeaderConstants.CONTENT_TYPE, "application/json");

			// This currently only supports JSON output

			IRESTError error = m_model.GetError();
			if (error != null) {
				// This handles outputting the error to the webdata object.
				new RESTHelper().OutputError(error, webData, false);
			} else {
				IXPList subFolders = m_model.GetKDSubFoldersForCurrentParentFolder();
				
				// create datastore response object representation with the search results
				XPHashtable restObject = new XPHashtable();
				restObject.PutElement(AQueryStoreModel.DATASTORE_PROP_IDENTIFIER, AQueryStoreModel.COL_OBJECTID);
				restObject.PutElement(AQueryStoreModel.DATASTORE_PROP_LABEL, AQueryStoreModel.COL_NAME);
				restObject.PutElement(AQueryStoreModel.DATASTORE_PROP_ITEMS, subFolders);
				
				// convert object representation to JSON text
				JSONSerializer json = new JSONSerializer(restObject);
				String jsonResponse = json.GenerateStringRepresentation(true);
				
				webData.SetStatus(200);
				webData.SetData(jsonResponse);
				
			} 
		} catch (Exception e) {
			log.Error(e, "Unable to display JSON output in User REST API.");

			// This handles outputting the error to the webdata object.
			new RESTHelper().OutputError(CommonRestErrors.PARAM_SERVER_ERROR.ParameterizeRESTError(e.getMessage()), webData, false);
		}

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()
	 */
	public AActivitySpace GetOwner()
	{
		return m_space;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_space = parent;
		m_model = (KDFolderDataStoreModel) m_space.GetModel(KDFolderDataStoreModel.STR_MVC_CLASS_NAME);
		if ( m_model == null ) {
			throw new XPIllegalStateException("Required model:"+KDFolderDataStoreModel.STR_MVC_CLASS_NAME+
					" not found in Activityspace: "+parent.GetName());
		}
		
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}
