/**
 * 
 */
package com.plumtree.portalpages.rest.dojo;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.rest.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Model to retrieve subfolders in a specific KD folder 
 * @author rozhang
 */
public class KDFolderDataStoreModel extends ARESTModel implements IModel
{
	public static final String STR_MVC_CLASS_NAME = "KDFolderDataStore";
	
	/** property name for kd folder level (from root level 1) **/
	public static final String COL_FOLDERLEVEL = "folderlevel";
	/** property to flag that an entry has children **/
	public static final String COL_CHILDREN = "children";
	public static final String COL_ID 		= "id"; // unique identifier for each entry
	
	/**
	 * 
	 */
	private static final int FOLDER_MAXSEARCHLIMIT = 100;

	protected AActivitySpace m_space;
	/** parent folder id to retrieve sub folders from, set from a Control **/
	private int m_parentFolderId = 0;
	
	/**
	 * Wrapper for returning sub folders from set parent folder id
	 * @return null if invalid/no parent folder id was set
	 */
	public IXPList GetKDSubFoldersForCurrentParentFolder()
	{
		if ( m_parentFolderId > 0 ) {
			return GetKDSubFolders(m_parentFolderId);
		} else {
			return null;
		}
	}
	
	/**
	 * Returns a list of dojo datastore object representations as a hashtable with properties
	 * The property names are synchronized with clientside javascript
	 * @param folderId
	 * @return
	 */
	public IXPList GetKDSubFolders(int folderId)
	{
		IPTSession session = (IPTSession)m_space.GetUserSession();
		IPTSearchRequest ptSR = session.GetSearchRequest();

		int[] folderid = { folderId };
		// setup search parameters
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS, folderid);
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS, Boolean.FALSE);
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, new Integer(PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL));
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, new int[] { PT_CLASSIDS.PT_CATALOGFOLDER_ID });

		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, PT_INTRINSICS.PT_PROPERTY_NAMEINDEX);

		// properties to return 
		int[] arPropIDs = {
			PT_INTRINSICS.PT_PROPERTY_OBJECTID,
			PT_INTRINSICS.PT_PROPERTY_OBJECTNAME, // 1
			PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY, // 2
//			PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED, // 3
			PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL, // 11 folderlevel
		};
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_USUAL_FIELDS, Boolean.FALSE);
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS, arPropIDs);
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS, new Integer(0));
		ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, new Integer(FOLDER_MAXSEARCHLIMIT));

		IPTSearchQuery ptQuery;
		if ( folderId == PT_INTRINSICS.PT_FOLDER_ROOTFOLDER ) {
			ptQuery = ptSR.CreateAdvancedQuery(CreateSubFolderSearchFilter(1));
		} else {
			ptQuery = ptSR.CreateBasicQuery("*", "");
		}
		// perform search
		IPTSearchResponse searchResponse = ptSR.Search(ptQuery);
		
		// put search results in hashtables, converted to json/other format by caller
		XPArrayList results = new XPArrayList();
		for (int i = 0; i < searchResponse.GetResultsReturned(); i++ ) {
			XPHashtable resultEntry = new XPHashtable();

			resultEntry.PutElement(AQueryStoreModel.COL_OBJECTID, new Integer( searchResponse.GetFieldsAsInt(i, PT_INTRINSICS.PT_PROPERTY_OBJECTID)));
			resultEntry.PutElement(AQueryStoreModel.COL_NAME, searchResponse.GetFieldsAsString(i, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME));
			resultEntry.PutElement(AQueryStoreModel.COL_DESCRIPTION, 		  searchResponse.GetFieldsAsString(i, PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY));
			resultEntry.PutElement(COL_FOLDERLEVEL, 			  new Integer( searchResponse.GetFieldsAsInt(i, PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL) ));
			// create an empty child node to flag that this is an expandable node
			resultEntry.PutElement(COL_CHILDREN, new XPArrayList());
			resultEntry.PutElement(COL_ID, i+"");
			results.Add(resultEntry);
		}

		return results;
	}
	
	/**
	 * Search specific code, not sure why it is needed
	 * @param nCurrentLevel
	 * @return
	 */
	public IPTFilter CreateSubFolderSearchFilter(int nCurrentLevel)
	{
		IPTFilter filter = PortalObjectsFactory.CreateSearchFilter();
		
		IPTPropertyFilterStatement statementThisLevel = (IPTPropertyFilterStatement) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
		statementThisLevel.SetOperand(PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
		statementThisLevel.SetOperator(PT_FILTEROPS.PT_FILTEROP_EQ);
		statementThisLevel.SetValue(XPConvert.ToString(nCurrentLevel + 1));
		
		IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);
		clause.AddItem(statementThisLevel, 0);
		
		if( FOLDER_MAXSEARCHLIMIT > 0)
		{
			filter.SetPropertyFilter(clause);
		}
		else
		{
			filter.SetPropertyFilter(statementThisLevel);
		}
		
		return filter;
	}

	public void SetParentFolderId(int folderId)
	{
		m_parentFolderId = folderId;
	}
	
	public int GetParentFolderId()
	{
		return m_parentFolderId;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_space = parent;

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new KDFolderDataStoreModel();
	}
	
}
