/**
 * 
 */
package com.plumtree.portalpages.rest.dojo;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * Common control to parse request from dojo QueryStoreControl store
 * The QueryStoreControl handles server-side loading, paging, and sorting by requesting bits
 * of data, specified with query string arguments 
 * @author rozhang
 */
public class QueryStoreControl implements IControl
{
	public static final String STR_MVC_CLASS_NAME = "QueryStoreControl";
	/** Query string parameters sent by QueryStoreControl **/
	public static final String QS_QUERY 		= "query";
	public static final String QS_ORDERBY 		= "sort";
	public static final String QS_RESULTSIZE 	= "count";
	public static final String QS_STARTINDEX	= "start";
	
	protected AActivitySpace m_space;
	protected AQueryStoreModel m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// parse request parameters
		int resultSize 			= HTTPHelpers.GetArgumentAsInt(arguments, QS_RESULTSIZE, 0);
		int startIndex 			= HTTPHelpers.GetArgumentAsInt(arguments, QS_STARTINDEX, 0);
		String orderByColName	= HTTPHelpers.GetArgumentAsString(arguments, QS_ORDERBY, null); 
		String query 			= HTTPHelpers.GetArgumentAsString(arguments, QS_QUERY, null);
		
		if ( orderByColName != null ) { // use default set in model if none is passed
			int orderBy 			= m_model.GetSearchPropIdFromColumnName(orderByColName); 
			m_model.SetOrderById(orderBy);
		}
		if ( resultSize != 0 ) { // use default set in model if none is passed
			m_model.SetResultSize(resultSize);
		}
		if ( query != null ) { // use default set in model if none is passed
			m_model.SetQuery(query);
		}
		
		m_model.SetStartIndex(startIndex);
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_space = space;
		m_model = (AQueryStoreModel)model;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new QueryStoreControl();
	}
}
