/**
 * 
 */
package com.plumtree.portalpages.rest.ldap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.interpreter.*;
import com.plumtree.uiinfrastructure.interpreter.filter.*;

/**
 * @author rozhang
 *
 */
public class CSPLoginTokenAuthenticatorFilter extends BaseInterpreterFilter
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portalpages.rest.ldap.CSPLoginTokenAuthenticatorFilter");
	
	public static final String CSPLOGINTOKEN_REQUHEADER_NAME = "CSP-Session-Token"; 
	
	// @TODO: debug variable
	public static int count = 0;
	
	/**
	 * Logs in current session with csp login token if one is found
	 *  
	 * NOTE: No exceptions should bubble up from this method. Let the gateway handler take care of any errors.
	 */
	public boolean PreFilter(RequestData requestData)
	{
		IXPRequest xpRequest = requestData.m_xpRequest;
		// look for presence of csp login token
		String loginToken = xpRequest.GetHeader(CSPLOGINTOKEN_REQUHEADER_NAME);
		if ( loginToken == null ) {
			// none found, just return;
			return false;
		}

		IPTSession currSession = PortalObjectsFactory.CreateSession();
		try {
			// @TODO what happens if the same source (http session) is reused with different csp logintokens?
			// is this step bypassed once the session is authenticated or will we authenticate every request (wanted behavior)
			currSession.Reconnect(loginToken);
			requestData.SetUserSession(currSession);
			// need to set this to flag a valid sessions
			requestData.m_smSandbox.SetAttribute(Interpreter.USERSESSIONVALID, new Boolean(true));
			log.Debug("User "+currSession.GetSessionInfo().GetCurrentUserID()+" logging in with CSP Login token");
		} catch (XPException e) {
			log.Warn(e, "CSP Login authoriazation failure for token: "+loginToken);
		}
		
		return false;
	}
}
