package com.plumtree.portalpages.rest.ldap;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.rest.*;
import com.plumtree.portalpages.rest.utils.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * DisplayPage that generates the response for lookup of user object id from LDAP auth name
 * Returns XML 
 * 
 * @author rozhang
 */
public class UserIdLookupDP implements IDisplayPage
{
	public static final String STR_MVC_CLASS_NAME = "UserIdLookup";
	
	private static OpenLogger log = 
		OpenLogService.GetLogger(
				OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
				"com.plumtree.portalpages.rest.ldap.UserIdLookupDP");

	protected AActivitySpace m_space;
	protected UserIdLookupModel m_model; 

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display(com.plumtree.uiinfrastructure.activityspace.IWebData)
	 */
	public void Display(IWebData webData)
	{
		try
		{
			// This will turn off HTML performance comments, allowing us to output
			// a valid JSON response.  Note that adding comment filtering allows us
			// to add the comments after the comment and Dojo will ignore them.  We
			// should still disable them anyways, in case someone wants to use a
			// library other than Dojo.
			webData.SetIsHTMLText(false);
			// Say that this data is JSON.
			webData.SetHeader(HTTPHeaderConstants.CONTENT_TYPE, "text/xml");

			// This currently only supports JSON output

			IRESTError error = m_model.GetError();
			if (error != null) {
				// This handles outputting the error to the webdata object.
				new RESTHelper().OutputXMLError(error, webData);
			} else {
				int userId = m_model.GetUserIdFromCurrentAuthName();

				// @TODO: figure out how to generate xml, XPDocument doesn't seem to have a method to convert
				// the dom to a string representation
				// just hardcode it for now
				String returnXML = 
					"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"+
					"<userid>"+userId+"</userid>";
				// create datastore response object representation with the search results
				
				webData.SetStatus(200);
				webData.SetData(returnXML);
			} 
		} catch (Exception e) {
			log.Error(e, "Unable to display JSON output in User REST API.");

			// This handles outputting the error to the webdata object.
			new RESTHelper().OutputError(CommonRestErrors.PARAM_SERVER_ERROR.ParameterizeRESTError(e.getMessage()), webData, false);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()
	 */
	public AActivitySpace GetOwner()
	{
		return m_space;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_space = parent;
		m_model = (UserIdLookupModel)parent.GetModel(UserIdLookupModel.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}
