package com.plumtree.portalpages.rest.utils;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.utils.*;

/**
 * @TODO move this entire package to uiinfrastructure project 
 * 
 * This JSON parser handles simple values and nested objects and arrayssimple objects only.
 */
public class JSONParser extends JavascriptParser implements IJSONParser 
{
	/**
	 * @return an instance of a IJSONParser.
	 */
	public static IJSONParser GetInstance()
	{
		// If necessary, this method could be adapted to include
		// a mock JSON parser.
		return new JSONParser();
	}
	
	/**
	 * Gets the name of a javascript object member 
	 * Expects the next token of the string tokenizer to be the double quote around the label.
	 * This method will also consume the ending double quote and following colon.    
	 * @param tokz
	 * @return
	 */
	protected String ParseJSOMemberLabel(XPStringTokenizer tokz)
	{
		String token = GetToken(tokz);

		if (token.charAt(0) != QUOTE )
		{
			throw new XPFormatException("Expecting token double quote when parsing object members, but found [ " + token + " ]");
		}

		// Get the unquoted name.  This unescapes it and reads the end quote. Pass in true in the 2nd arg if double quote, false for single quote
		String memberName = GetEscapedTokenAndEndQuote(tokz, true );

		SkipToken(tokz, COLON);
		
		return memberName;
	}

	protected String m_strObjectName = null;
	protected XPHashtable m_xpMembers = new XPHashtable();

	/**
	 * Private constructor so it can only be accessed by the GetInstance method.
	 * rob: changed to public for now since the ijsoninterface is only meant for a narrow use-case
	 * when this parser has been extended to a generic json parser
	 * @TODO create a constructor that supports javascript notation, i.e: dont require quotes on member labels, accept single quotes inplace of double quotes, allow variable references as member values  
	 */
	public JSONParser() {}
	
	

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.directory.rest.utils.IJSONParser#ParseJSONObject(Java.lang.String)
	 */
	public void ParseJSONObject(String _strJSON)
	{
		// Comment filtering is often used to thwart JSON security attacks.
		// The text should be wrapped in /* */.  While we don't need to parse
		// comment filtered JSON, since comment filtering should really only
		// be generated on the server side, it doesn't hurt to handle it.

		// Remove any leading/trailing whitespace to help checking for comment filtering.
		_strJSON = XPStringUtility.Trim(_strJSON);

		if (XPStringUtility.StartsWith(_strJSON, "/*") &&
			XPStringUtility.EndsWith(_strJSON, "*/"))
		{
			// Remove the comment filtering.
			_strJSON = XPStringUtility.Substring(_strJSON, 2, _strJSON.length() - 2);
		}
		// TODO: This should also handle single quotes.
	
		// NOTE: This JSON "parser" only handles single objects with string member pairs.
		// It does not handle arrays or non-string values. 
		// We need to tokenize the whitespace because we need it sometimes.
		XPStringTokenizer tokenizer = new XPStringTokenizer(_strJSON, "[{\"\\:,}] \t\n\r\f", true);

		if (!tokenizer.HasMoreTokens())
		{
			throw new XPFormatException("JSON text cannot be empty. [ " + _strJSON + " ]");
		}

		// Check for initial open curly bracket.
		SkipToken(tokenizer, OPEN_CURLY_BRACKET);

		// Check for quote at beginning of object name.
		SkipToken(tokenizer, QUOTE);

		// Get the unquoted object name.  This unescapes it and reads the end quote.
		m_strObjectName = GetEscapedTokenAndEndQuote(tokenizer, true);

		// Check for semi-colon, and open curly bracket at end of object name.
		SkipToken(tokenizer, COLON);
		SkipToken(tokenizer, OPEN_CURLY_BRACKET);

		// Parse the object members
		String strToken;
		do
		{
			// Get the start of the next object member.
			String memberName = ParseJSOMemberLabel(tokenizer);
			
			
			Object memberValue = ParseJSOMemberValue(memberName, tokenizer);
			m_xpMembers.PutElement(memberName, memberValue);
			
			// If the object member name/value pair ends with a comma, then we need to
			// read the next member.
			strToken = GetNextToken(tokenizer);
		} while (strToken.charAt(0) == COMMA);

		// The end of the JSON object member list.
		if (strToken.charAt(0) != CLOSE_CURLY_BRACKET)
		{
			throw new XPFormatException("Expecting token [ " + CLOSE_CURLY_BRACKET + " ] at end of object members list, but found [" + strToken + "]");
		}

		// The end of the JSON object.
		SkipToken(tokenizer, CLOSE_CURLY_BRACKET);
	}
	
	

	

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.directory.rest.utils.IJSONParser#GetObjectName()
	 */
	public String GetObjectName() {
		return m_strObjectName;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.directory.rest.utils.IJSONParser#GetMember(Java.lang.String)
	 */
	public String GetMember(String _strName) {
		return (String) m_xpMembers.GetElement(_strName);
	}
	
	
	/**
	 * For string or 
	 * @param strName
	 * @return
	 */
	public String GetMemberAsString(String name) {
		return (String) m_xpMembers.GetElement(name);
	}
	
	/**
	 * For boolean member values
	 * @param name
	 * @return
	 */
	public Boolean GetMemberAsBool(String name) {
		return (Boolean) m_xpMembers.GetElement(name);
	}
	
	/**
	 * For integer member values
	 * @param name
	 * @return
	 */
	public Integer GetMemberAsInt(String name) {
		return (Integer) m_xpMembers.GetElement(name);
	}
	
	/**
	 * For array object members  
	 * @param name
	 * @return
	 */
	public IXPList GetMemberAsList(String name) {
		return (IXPList) m_xpMembers.GetElement(name);
	}
	
	/**
	 * For members with nested object values
	 * @return
	 */
	public XPHashtable GetMemberAsMap(String name) {
		return (XPHashtable) m_xpMembers.GetElement(name);
	}
	
	
}