package com.plumtree.taskapi.portalui;

import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * TaskAPI function related to the Administration Portal.
 * 
 */
public class TaskAPIUIAdministration
{
	/**
	 * Gets the URL to the Administration Portal. 
	 * 
	 * @param owner		Current Activityspace.
	 * @return	<code>IPTURL</code> with the URL to the Administrative portal, or <code>null</code> if user does not have access to it.
	 */
	public static IPTURL GetURLForAdministrationPortal(AActivitySpace owner)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		
		if (HasAdminLinkAccess(owner))
		{
			String strTitle = owner.GetString(275, "ptmsgs_portalcommonmsgs");
			String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
			
			CommonOpenerOpenASURL ptURL = new CommonOpenerOpenASURL(strTitle, ObjMgrAS.STR_MVC_CLASS_NAME, owner);
			ptURL.AddControlParameter(ASConstants.CONTROL, AdminRedirectControl.STR_MVC_CLASS_NAME);

		
			ptURL.SetURLImageType(PTImageType.ICON_ADMINISTRATION, strImageServerURL);
			
			return ptURL;
		}			
		
		return null;
		
	}
	
	/**
	 * @see TaskAPIUIUser.HasAdminLinkAccess
	 *  
	 */
	static public boolean HasAdminLinkAccess(AActivitySpace owner)
	{
		return TaskAPIUIUser.HasAdminLinkAccess(owner); 
		
	}
	
	
	
	
}
