/*
 */
package com.plumtree.taskapi.portalui;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.communities.CommunityPageAS;
import com.plumtree.portalpages.browsing.myportal.mypages.MyPageAS;
import com.plumtree.portalpages.browsing.objectselection.flyout.*;
import com.plumtree.portalpages.browsing.sitemap.sitemappage.*;
import com.plumtree.portalpages.common.mediator.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common functions used by other TaskAPI packages.
 * 
 */
public class TaskAPIUICommon
{
	public static final int INVALID_OBJECTID = 0;
	
	/**
	 * 
	 * @param env			IEnvironment type
	 * @return					An AActivityspace object
	 * 
	 * @throws XPIllegalArgumentException		If the provided IEnvironment is null
	 * @throws XPClassCastException						If the provided IEnvironment is not of the required AActivityspace type
	 */
	public static final AActivitySpace GetEnvTypeObject(IEnvironment env) throws XPIllegalArgumentException, XPClassCastException
	{
		// TODOCR DONH: This method name doesn't make sense.  It takes an IEnvironment
		// as an argument, it doesn't return it.  It should be called something more like
		// GetAActivitySpace.
		ValidateEnvironmentArgumenmt(env);

		AActivitySpace owner = null;
		try {
			owner = (AActivitySpace)env;
		} catch (Exception cce) {
			throw new XPClassCastException("The provided IEnvironment object it not of the required type, need an AActivityspace.");
		} 
		
		return owner;
	}
	
	/**
	 * Method to determine and obtain if object is a valid MyPage or CommunityPage AActivitySpace.
	 *  
	 * @param env	IEnvironment type
	 * @return		A MyPage or CommunityPage AActivityspace object or null if it is not available
	 * 
	 * @throws XPIllegalArgumentException		If the provided IEnvironment is null
	 */
	public static final AActivitySpace GetMyPageOrCommunityAActivitySpace(IEnvironment env) throws XPIllegalArgumentException, XPClassCastException
	{
		ValidateEnvironmentArgumenmt(env);

		AActivitySpace owner = null;
		try 
		{
			owner = (AActivitySpace)env;
			String spaceName = owner.GetName();

			// Check current space name, if not MyPage or CommunityPage, check the parent space
			if (0 != spaceName.compareToIgnoreCase(CommunityPageAS.STR_MVC_CLASS_NAME) &&
					0 != spaceName.compareToIgnoreCase(MyPageAS.STR_MVC_CLASS_NAME) &&
					0 != spaceName.compareToIgnoreCase(SiteMapAS.STR_MVC_CLASS_NAME))
			{
				if (0 == spaceName.compareToIgnoreCase(FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME) ||
						0 == spaceName.compareToIgnoreCase(FlyoutCommunitySelectionAS.STR_MVC_CLASS_NAME)) {
					if ( owner.GetParentSpace() != null ) {
					
						spaceName = owner.GetParentSpace().GetName();
						
						if (0 == spaceName.compareToIgnoreCase(CommunityPageAS.STR_MVC_CLASS_NAME) ||
								0 == spaceName.compareToIgnoreCase(MyPageAS.STR_MVC_CLASS_NAME))
						{
							// Ok, parent space is the one we should use
							owner = owner.GetParentSpace();
						}
						else
						{
							// Not a MyPage or CommunityPage ActivitySpace, return null. 
							owner = null;
						}				
					}
				} else {
					// DCA - not the flyout editor, don't check the parent space.
					owner = null;
				}
			}
		} 
		catch (Exception cce) 
		{
			owner = null;
		} 
		
		return owner;
	}
	
	/**
	 * INTERNAL
	 * 
	 * @param env	IEnvironemnt object.
	 * @throws XPIllegalArgumentException	If IEnvironment object is <code>null</code>.
	 */
	static void ValidateEnvironmentArgumenmt(IEnvironment env) throws XPIllegalArgumentException
	{
	    if(null == env)
	        throw new XPIllegalArgumentException("Invalid IEnvironment object provided - its value is null.");
	    else
	        return;
	}
	
	/**
	 * INTERNAL
	 * 
	 * @param owner	 Activityspace object.
	 * @throws XPIllegalArgumentException	If Activityspace object is <code>null</code>. 
	 */
	static void ValidateActivitySpaceArgument(AActivitySpace owner) throws XPIllegalArgumentException
	{
	    if(null == owner)
	        throw new XPIllegalArgumentException("Invalid actvityspace object provided - its value  is null.");
	    else
	        return;
	}
	
	/**
	 * INTERNAL
	 * 
	 * @param nObjectID
	 * @throws XPIllegalArgumentException If nObjectID has the value of <code>0</code> or a negative number.
	 */
	static void ValidateObjectIDArgument(int nObjectID) throws XPIllegalArgumentException
	{
	    if( nObjectID <= INVALID_OBJECTID)
	        throw new XPIllegalArgumentException("Invalid object id provided: "+nObjectID+" - must be positive.");
	    else
	        return;
	}
	
	/**
	 * 
	 * 
	 * @param nObjectID
	 * @return true if the provided nObjectID is valid (value greater than 0) 
	 */
	static boolean IsValidObjectIDArgument(int nObjectID) 
	{
		return ( nObjectID > INVALID_OBJECTID ); 
		
	}
	
	
	/**
	 * Helper function to convert an <code>ICPListEntryIterator</code> object to an array with <code>FullURL</code>s.
	 * Used for backwards compatibility.
	 * 
	 * @param owner		Current Activityspace.
	 * @param cpList		ICPListEntryIterator with URL data.
	 * @return					An array of <code>FullURL</code> objects with the URL, URL Title from the <code>ICPListEntryIterator</code>. 
	 * Icons and other components are not included.
	 */
	public static FullURL[] GetFullURLFromListEntryIterator(AActivitySpace owner, ICPListEntryIterator cpList)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		int nListCount = cpList.GetTotalCount();
		FullURL[] arURLs = new FullURL[nListCount];

		for ( int i = 0;  null != cpList && i < nListCount; i++ )
		{
			CListURLFullLinkMediator mediator = new CListURLFullLinkMediator(owner, cpList);
			HTMLAnchor anchor = (HTMLAnchor)mediator.GetEntryAtIndex(i);
			String strFullURL 	= anchor.GetHRef();
			String strText 			= anchor.GetInnerHTML();

			FullURL url = new FullURL(strText, strFullURL);
	
			arURLs[i] = url;
		}

		return arURLs;
	}
	
	/**
	 * Gets the Plumtree Session from the Activityspace.
	 * 
	 * @param owner		Current Activityspace.
	 * @return					Plumtree session.
	 * 
	 * @throws XPIllegalArgumentException		If the provided AActivityspace is <code>null</code>.
	 * @throws XPClassCastException						If the provided AActivityspace has not been initialized correctly.
	 */
	public static final IPTSession GetPTSession(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		IPTSession session = null;
		try {
			session = (IPTSession)owner.GetUserSession();
		} catch (Exception cce) {
			throw new XPClassCastException("Invalid AActivityspace provided - unable to get the IPTSession.");
		}
		
		return session;
	}

	
	/**
	 * Helper method that checks whether or not the NavigationModel
	 * object is present on the activityspace.
	 * 
	 * @param owner		Current Activityspace object.		
	 * @return	<code>true</code> implies the NavigationModel is present, <code>false</code> otherwise.
	 * 
	 * @throws XPIllegalArgumentException		If the provided AActivityspace is null
	 *
	 */
	public static boolean GetNavigationModelExists(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		return owner.GetModelExists(NavigationModel.STR_MVC_CLASS_NAME);
	}

	/**
	 * Helper method that gets the NavigationModel object from an activityspace or throws
	 * an exception if the AActivityspace is invalid.
	 * 
	 * @param owner		AActivityspace object		
	 * @return	NavigationModel object
	 * 
	 * @throws XPIllegalArgumentException If the provided AActivityspace is <code>null</code>
	 * or the <code>NavigationModel</code> is not available on the current Activity Space.
	 *
	 *@deprecated	All functionality is available from TaskAPI functions, no need for <code>NavigationModel</code>.
	 */
	public static NavigationModel GetNavigationModel(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);

		if (GetNavigationModelExists(owner))
		{
			return (NavigationModel)owner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
		}

		throw new XPIllegalArgumentException("Invalid activityspace object, Unable to  get NavigationModel from activityspace");
	}
	
	/**
	 * Helper method to check if the specified Model object exists in the current Activityspace.
	 * 
	 * @param owner		Current Activityspace.
	 * @param strModelName		Name of the Model object, defined as a static constant on every model object
	 * named <code>STR_MVC_CLASS_NAME</code>
	 * @return	<code>true</code> if the specified model exists on the activutyspace, <code>false</code> otherwise.
	 */
	public static boolean GetASModelExist(AActivitySpace owner, String strModelName)
	{
		ValidateActivitySpaceArgument(owner);
		
		return owner.GetModelExists(strModelName);
	
	}
	
	/**
	 * Gets the specified Activityspace Model object. 
	 * 
	 * @param owner		Current Activityspace.
	 * @param strModelName		Name of the Model object, defined as a static constant on every model object
	 * named <code>STR_MVC_CLASS_NAME</code>
	 * @return	The requested Activityspace Model object or <code>null</code> if it does not exist.
	 */
	public static Object GetASModel(AActivitySpace owner, String strModelName)
	{
		ValidateActivitySpaceArgument(owner);
		
		return owner.GetModel(strModelName);
	
	}
	
	/**
	 * Gets the <code>MyPortalModel</code> object.
	 * 
	 * @param owner		Current Activityspace.
	 * @return <code>MyPortalModel</code> object, or <code>null</code> if MyPortalModel was not found
	 */
	public static MyPortalModel GetMyPortalPageModel(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		MyPortalModel model = null;
		try {
			model = (MyPortalModel)owner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
		} catch (Exception e) {
			// Do not do anything, just return null;
			;
		}
		
		return model;
	}
	
	/**
	 * Checks if the <code>MyPortalModel</code> exists in the current Activityspace.
	 * 
	 * @param owner		Current Activityspace.
	 * @return	<code>true</code> if the MyPortalModel exists, <code>false</code> otherwise.
	 */
	public static boolean GetMyPortalPageModelExists(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		return owner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME);
	}
	
	/**
	 * Gets the <code>SiteMapModel</code> object.
	 * 
	 * @param owner		Current Activityspace.
	 * @return <code>SiteMapModel</code> object, or <code>null</code> if MyPortalModel was not found
	 */
	public static SiteMapModel GetSiteMapPageModel(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		SiteMapModel model = null;
		try {
			model = (SiteMapModel)owner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
		} catch (Exception e) {
			// Do not do anything, just return null;
			;
		}
		
		return model;
	}
	
	/**
	 * Checks if the <code>SiteMapModel</code> exists in the current Activityspace.
	 * 
	 * @param owner		Current Activityspace.
	 * @return	<code>true</code> if the SiteMapModel exists, <code>false</code> otherwise.
	 */
	public static boolean GetSiteMapPageModelExists(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		return owner.GetModelExists(SiteMapModel.STR_MVC_CLASS_NAME);
	}
	
	/**
	 * Gets the <code>GatewayModel</code> object.
	 * 
	 * @param owner		Current Activityspace.
	 * @return <code>SiteMapModel</code> object, or <code>null</code> if GatewayModel was not found
	 */
	public static GatewayModel GetGatewayPageModel(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		GatewayModel model = null;
		try {
			model = (GatewayModel)owner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
		} catch (Exception e) {
			// Do not do anything, just return null;
			;
		}
		
		return model;
	}
	
	/**
	 * Checks if the <code>GatewayModel</code> exists in the current Activityspace.
	 * 
	 * @param owner		Current Activityspace.
	 * @return	<code>true</code> if the GatewayModel exists, <code>false</code> otherwise.
	 */
	public static boolean GetGatewayPageModelExists(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		return owner.GetModelExists(GatewayModel.STR_MVC_CLASS_NAME);
	}
	
	
	/**
	 * Gets the name of the provided Activityspace.
	 * 
	 * @param owner		Current Activityspace.
	 * @return		Name of the Activityspace.
	 */
	public static String GetActivitySpaceName(AActivitySpace owner)
	{
		ValidateActivitySpaceArgument(owner);
		
		String strASName = owner.GetName();
		return strASName;
		
	}
	
	/**
     * Checks if the current Page is a Preview Page.
     * For example, Preview Portlet or Preview Community page.
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the current <code>page</code> is a preview page, false otherwise.
     */
    public static boolean IsCurrentPageInPreviewMode(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        boolean bIsPreviewPage = false;
		if(GetASModelExist(owner, MyPortalModel.STR_MVC_CLASS_NAME)) {
			MyPortalModel myPortalModel = (MyPortalModel) owner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);

			bIsPreviewPage = myPortalModel.IsPreviewPage();
		}
		
		if(owner.GetModelExists(SiteMapModel.STR_MVC_CLASS_NAME)) {
			SiteMapModel siteMapModel = (SiteMapModel) owner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
			
			bIsPreviewPage = siteMapModel.IsPreviewPage(); 	
		}
		
		return bIsPreviewPage;
    	
    }
    
    /**
     * Checks if the current page is an Edit Default Profile page.
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the current page is a Edit Default Profile page, <code>false</code> otherwise.
     */
    public static boolean IsCurrentPageInEditDefaultProfileMode(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	
    	return PlumtreeHelpers.IsEditingDefaultProfile(owner);
    }
    
    /**
     * Checks if the current Activityspace is the specified Activityspace type, E.g. MyPageAS.
     * 
     * @param owner		Current Activityspace.
     * @param strASName		Name of Activityspace type to check for.
     * @return <code>true</code> if the current Activityspace is of the specified type, <code>false</code> if not or Activityspace name is <code>null</code>.
     */
    public static boolean IsCurrentActivitySpace(AActivitySpace owner, String strASName)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	if ( null == strASName ) {
    		return false;
    	}
    	
    	return strASName.equals(GetActivitySpaceName(owner));
    	
    }
    
    /**
     * Checks if the current DisplayPage is the specified DisplayPage type, E.g. PlumtreeDP or MyPortalDP.
     * 
     * @param owner		Current Activityspace.
     * @param strPageName	Name of the DisplayPage, defined on each DisplayPage as a static constant named
     * <code>STR_MVC_CLASS_NAME</code>.
     * @return <code>true</code> if the current DisplayPage is of the specified type, <code>false</code> if not or DisplayPage name is <code>null</code>.
     */
    public static boolean IsCurrentDisplayPage(AActivitySpace owner, String strPageName)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	if ( null == strPageName ) {
    		return false;
    	}
    	return strPageName.equals(owner.GetCurrentPage().GetName());
    
    }
	
    /**
	 * Checks whether the classId supports friendly URLs
	 * 
	 * This method is primarily used to check if specific opener links should generate friendly URLs
	 * or regular opener URLs.
	 * 
	 * @param classId	Class Id of the object type to create URL for
	 * @return Result whether friendly URLs should be used for the class type
	 */
	public static final boolean UseFriendlyURLS(int classId)
	{
		// Friendly URL defined for a particular classId if there are friendly url token defined 
		return UseFriendlyURLS(classId, null);
	}
	
	/**
	 * Checks whether the classId supports friendly URLs also considering any additional
	 * query string parameters.
	 * 
	 * This method is primarily used to check if specific opener links should generate friendly URLs
	 * or regular opener URLs.  
	 * 
	 * @param classId	Class Id of the object type to create URL for
	 * @param queryStringArgs	Any query string parameters on the URL
	 * @return Result whether friendly URLs should be used for the class type
	 */
	public static final boolean UseFriendlyURLS(int classId, String queryStringArgs)
	{
		return PTConfigService.getPTInstance().UseFriendlyURLS(classId, queryStringArgs);
	}
	
}
