/*
 */
package com.plumtree.taskapi.portalui;

import com.plumtree.openfoundation.reflect.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portalpages.browsing.editors.editportletprefs.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.objectselection.communities.*;
import com.plumtree.portalpages.browsing.objectselection.flyout.*;
import com.plumtree.portalpages.browsing.objectselection.portlets.*;
import com.plumtree.portalpages.browsing.sitemap.sitemappage.*;
import com.plumtree.portalpages.browsing.unsubscribe.communities.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * Community related TaskAPI functions.
 * 
 */
public class TaskAPIUICommunity 
{
	private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.taskapi.portalui.TaskAPIUICommunity");

	public static final String URLDATA_PAGEID 		= "pageid";
	public static final String URLDATA_PAGENAME 	= "pagename";
	public static final String URLDATA_COMMID 		= "commid";
	public static final String URLDATA_COMMNAME 	= "commname";
	public static final String URLDATA_OBJECTID 	= "objectid";
	public static final String URLDATA_CLASSID 		= "classid";
	
	
	
    /**
     * Gets the name of the specified Community.
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID	Object ID of the Community to retrieve the name for.
     * @return	Name of the specified Community.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static String GetCommunityName(AActivitySpace owner, int nCommunityID)
    {
    	 TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	 TaskAPIUICommon.ValidateObjectIDArgument(nCommunityID);
    	 
    	 IPTSession session = TaskAPIUICommon.GetPTSession(owner);
    	 String strCommName = TaskAPIServerCommunity.GetCommunityName(session, nCommunityID);
    	 
        return strCommName;
    }

    /**
     * Gets the Subcommunities for the specified Community as an integer array.
     * Subcommunites are Communities directly below a Community in the administrative folder hierarchy.
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID	Object ID for the Community to retrieve Subcommunities from.
     * @return	Array of integers with Object IDs of the Subcommunities in the specified Community. 
     * 
     * @throws XPException									If the Community could not be accessed, for example if the Object ID
     * is not valid.
	 * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static int[] GetSubCommununityIDs(AActivitySpace owner, int nCommunityID)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	 TaskAPIUICommon.ValidateObjectIDArgument(nCommunityID);
    	 
    	 IPTSession session = TaskAPIUICommon.GetPTSession(owner);
    	 
    	 IPTQueryResult qrRelComms = TaskAPIServerCommunity.GetCommunitySubCommunities(session, nCommunityID);
    	 int[] arSubCommIDs = new int[qrRelComms.RowCount()];
    	 
    	 for ( int i  = 0; i < qrRelComms.RowCount(); i++ ) {
    	 	int nSubCommID = qrRelComms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
    	 	arSubCommIDs[i] = nSubCommID; 
    	 }
    	 
        return arSubCommIDs;
    }

    /**
     * Gets the Related Communities for the specified Community as an integer array.
     * Related Communities are Communities in the same administrative folder.
     *
     * @param owner		Current Activityspace.
     * @param nCommunityID	Object ID for the Community to retrieve Related Communities from.
     * @return	Array of integers with Object IDs of the Related Communities  in the specified Community. 
     * 
     * @throws XPException									If the Community could not be accessed, for example if the Object ID
     * is not valid.
	 * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static int[] GetRelatedCommununityIDs(AActivitySpace owner, int nCommunityID)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	 TaskAPIUICommon.ValidateObjectIDArgument(nCommunityID);
    	 
    	 IPTSession session = TaskAPIUICommon.GetPTSession(owner);
    	 
    	 IPTQueryResult qrRelComms = TaskAPIServerCommunity.GetCommunityPeerCommIDs(session, nCommunityID);
    	 int[] arRelCommIDs = new int[qrRelComms.RowCount()];
    	 for ( int i  = 0; i < qrRelComms.RowCount(); i++ ) {
    	 	int nRelCommID = qrRelComms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
    	 	arRelCommIDs[i] = nRelCommID; 
    	 }
    	 
        return arRelCommIDs;
    }

    /**
     * 
     * Get Community Pages in the specified Community as a list of <code>IPTURL</code>s.
     * The <code>PTURLConstants.KEY_CURRENTMARKER</code> flag is set on an URL entry if is leading to the current
     * Community Page. 
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID	Object Id of the Communitu to list pages of.
     * @return A list with Community Pages as <code>IPTURL</code> objects or an empty list of no pages exist.
     * 
     *  @throws XPIllegalArgumentException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetCommunityPagesAsURLs(AActivitySpace owner, int nCommunityID)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	TaskAPIUICommon.ValidateObjectIDArgument(nCommunityID);
    	IPTSession session = TaskAPIUICommon.GetPTSession(owner);

    	 // get the community pages
    	 IPTQueryResult qrCommPages = TaskAPIServerCommunity.GetCommunityPages(session, nCommunityID);
    	 
    	 // create the arraylist to return
    	 XPArrayList list = new XPArrayList(qrCommPages.RowCount());

    	 for ( int i  = 0; i < qrCommPages.RowCount(); i++ )
    	 {
     	 	// Get the pageid and page name from the queryresult
     	 	int nPageID = qrCommPages.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
     	 	String strPageName  = qrCommPages.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
     	 	
     	 	IPTURL url = CreateCommunityPageCommonOpenerURL(owner, nCommunityID, nPageID, strPageName);
     	 	
     	 	// Add the link to the arraylist
     	 	list.Add(url);
     	 }
    	 
    	 return list;
    }
    
	/**
	 * Gets to URL to the Community Knowledge Directory f0r the current Community.
	 * The <code>PTURLConstants.KEY_CURRENTMARKER</code> flag is set on the URL if the current page is a Community Knowledge
	 * Directory page.
	 *  
	 * @param owner		Current Activityspace
	 * @param nCommunityID	Object ID of the Community to get pages from.
	 * @return <code>IPTURL</code> with the URL to the Community Knowledge Directory for the specified Community.
	 *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 *  
	 * @see PTURLConstants
	 */
    public static IPTURL GetURLForCommunityKnowledgeDirectory(AActivitySpace owner, int nCommunityID)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
    	
    	// Don't want to display the knowledge directory or members folder for profile community
		if (  nCommunityID <= TaskAPIUICommon.INVALID_OBJECTID ||
				TaskAPIUICommunity.IsCurrentCommunityUserProfileCommunity(owner) || 
			   TaskAPIServerCommunity. GetCommunityInfoObject(ptSession, nCommunityID).GetSiteMapDisabled()	
			)
		{
			return null;
		}

		// If it's a guest user, check if the sitemap is enabled for guests.
		if (ptSession.GetSessionInfo().CheckCurrentUserIsGuest())
		{
			// Get the string value first, since getasint will throw an exception if it's not present.
			String strValue = PTConfigHelper.GetConfigVariableAsString(PTConfigConstants.COMMUNITIES_SECTION,
				PTConfigConstants.SITE_MAP_ENABLED_FOR_GUEST_SUBSECTION,
				PTConfigConstants.VALUE_ATTRIBUTE, owner);
	
			if ((null != strValue) && (!"".equals(strValue)))
			{
				int nEnabled = PTConfigHelper.GetConfigVariableAsInt(PTConfigConstants.COMMUNITIES_SECTION,
					PTConfigConstants.SITE_MAP_ENABLED_FOR_GUEST_SUBSECTION,
					PTConfigConstants.VALUE_ATTRIBUTE, owner);
	
				if (nEnabled != 1)
				{
					// disabled
					return null;
				}
			} else
			{
				// Missing config section, assume disabled for security purposes.
				return null;
			}
		}

		String strTitle = owner.GetString(1647, "ptmsgs_portalbrowsingmsgs");	
		String strApplBaseURL   =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
		String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
		String strASName 				= SiteMapAS.STR_MVC_CLASS_NAME;
		int nUserID 							= TaskAPIUIUser.GetCurrentUserID(owner);
		
		CommonOpenerOpenASURL url = new CommonOpenerOpenASURL(strTitle, strApplBaseURL, strASName, nUserID); 
		url.AddControlParameter(ASConstants.CONTROL, SetSiteMapControl.STR_MVC_CLASS_NAME);	
		url.AddControlParameter(SetSiteMapControl.m_CommunityID, nCommunityID);
		url.AddControlParameter(SetSiteMapControl.m_Mode , SetSiteMapControl.BROWSE);
		
		if ( TaskAPIUICommon.IsCurrentPageInPreviewMode(owner) )
		{
			url.AddControlParameter(SetSiteMapControl.PREVIEW, "");
		}
		
		if ( TaskAPIUICommon.IsCurrentActivitySpace(owner, SiteMapAS.STR_MVC_CLASS_NAME) &&
			  !TaskAPIUICommon.IsCurrentDisplayPage(owner, MembersDP.STR_MVC_CLASS_NAME) 	
		     )
		{
			// Show Community Knowledge Dir as label if in it except when in the members page,
			// The member will appear as selected instead.
			url.SetURLData(PTURLConstants.KEY_CURRENTMARKER, "");
		}
		// Set image
		url.SetURLImageType(PTImageType.ICON_KNOWLEDGE_DIRECTORY, strImageServerURL);
			
		return url;
    	
    }

    /**
     * Gets URLs to Related Communities for the specified Community in a list of <code>IPTURL</code>s.
     * Related Communities are Communities in the same administrative folder.
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID	Object ID for the Community to retrieve Related Communities from.
     * @return <code>XPArrayList</code> with <code>IPTURL</code>s to Related Communities or an empty <code>XPArrayList</code> if none exists.
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetRelatedCommununitiesAsURLs(AActivitySpace owner, int nCommunityID)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	 if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCommunityID) ) 
    	 {
    	 	return new XPArrayList();
    	 }
    	 IPTSession session = TaskAPIUICommon.GetPTSession(owner);
    	 
    	 // get the community pages
		 
    	 IPTQueryResult qrRelComms = null;
		 try {
			 qrRelComms = TaskAPIServerCommunity.GetCommunityPeerCommIDs(session, nCommunityID);
		 } catch (XPException e) {
			 log.Warn(e, "Exception encountered while retrieving Related Communities IDs for Community: "+nCommunityID);
			 return new XPArrayList();
		 }
    	 
    	 // create the arraylist to return
    	 XPArrayList list = new XPArrayList(qrRelComms.RowCount());
    	 
    	 for ( int i  = 0; i < qrRelComms.RowCount(); i++ ) {
    	 	// Get the pageid and page name from the queryresult
    	 	int nRelCommID = qrRelComms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
    	 	String strRelCommName = qrRelComms.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
    	 	
    	 	// Create a common opener url
    	 	IPTURL url = CreateCommunityCommonOpenerURL(owner, nRelCommID, strRelCommName);
    	 	// Add the link to the arraylist
    	 	list.Add(url);
    	 }
    	 return list;
    	 
    }
    
     /**
     * Gets the Community Name of the current Community.
     * 
     * @param owner		Current Activityspace.
     * @return	Community Name of the current community or <code>null</code> value if not currently on a Community Page. 
     * 
     * @throws XPIllegalArgumentException		If the provided <code>AActivityspace</code> is <code>null</code>.
     */
    public static String GetCurrentCommunityName(AActivitySpace owner) throws XPIllegalArgumentException
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
		
		int nCurrCommID = GetCurrentCommunityID(owner);
		
		if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
		{
			return null;
		}
		
		String strCommName = TaskAPIServerCommunity.GetCommunityName(ptSession, nCurrCommID);
		
		return strCommName;
    }

	/**
	 * Gets the Community Page Name of the current Community Page. If current
	 * page is not a Community related page, i.e., Community portlet, Sitemap
	 * or Community Gatewaypage page, a null value is returned.
	 * 
	 * @param owner		Current Activityspace.
	 * @return	Community Page Name of the current community pageor null value if not currently on a Community Page. 
	 * 
	 * @throws XPIllegalArgumentException		If the provided <code>AActivityspace</code> is <code>null</code>
	 */
	public static String GetCurrentCommunityPageName(AActivitySpace owner) throws XPIllegalArgumentException
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		
		String strPageName = null;
		
		if ( TaskAPIUICommon.GetMyPortalPageModelExists(owner) ) 
		{
			MyPortalModel ptModel =  TaskAPIUICommon.GetMyPortalPageModel(owner);
			strPageName = ptModel.GetPageName();
		}
		else if ( FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME.equals(TaskAPIUICommon.GetActivitySpaceName(owner)) )
		{
			// rob: The flyout AS is always preceded by community or mypage AS, so call the same function with the parent space  
			strPageName = GetCurrentCommunityPageName(owner.GetParentSpace());
		}
		
		return strPageName;
		
	}

   
    /**
     * Gets the Community ID of the current Community. If current page is not a Community page,
     * i.e., Community portlet, Sitemap or Community Gatewaypage page, <code>TaskAPIUICommon.INVALID_OBJECTID</code> is returned.
     * 
     * @param owner		Current Activityspace
     * @return	Community ID of the current community or <code>TaskAPIUICommon.INVALID_OBJECTID</code> if not in a Community.
     * 
     * @throws XPIllegalArgumentException		If the provided <code>AActivityspace</code> is <code>null</code>
     */
    public static int GetCurrentCommunityID(AActivitySpace owner)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        
        int nCommID = TaskAPIUICommon.INVALID_OBJECTID;
		if (TaskAPIUICommon.GetMyPortalPageModelExists(owner) )
		{
			MyPortalModel portalMod = TaskAPIUICommon.GetMyPortalPageModel(owner);

			if (null != portalMod)
			{
				nCommID = portalMod.GetCommunityID();
			} 
		}
		else if (TaskAPIUICommon.GetSiteMapPageModelExists(owner)  )
		{
			SiteMapModel sitemapMod = TaskAPIUICommon.GetSiteMapPageModel(owner);
			if ( sitemapMod != null  )
			{
				nCommID			= sitemapMod.GetCommunityID();
			}
		}
		else if ( TaskAPIUICommon.GetGatewayPageModelExists(owner) )
		{
			// We are on a gatewayed page, community ID in the Gateway model
			IGatewayModelRO gatewayModel = (IGatewayModelRO) TaskAPIUICommon.GetGatewayPageModel(owner);
			if ( gatewayModel != null ) 
			{
				nCommID 		= gatewayModel.GetCommunityID();
			}
		}
		else if ( FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME.equals(TaskAPIUICommon.GetActivitySpaceName(owner)) )
		{
			// rob: The flyout AS is always preceded by community or mypage AS, so call the same function with the parent space  
			nCommID = GetCurrentCommunityID(owner.GetParentSpace());
		}
		
		return nCommID;
	}
        
    
    /**
     * Gets the current Community Page ID, If current page is not a Community page,
     * the <code>TaskAPIUICommon.INVALID_OBJECTID</code> value is returned.
     * 
     * @param owner Current Activityspace.
     * @return	Current Community Page ID or <code>TaskAPIUICommon.INVALID_OBJECTID</code> if not in on Community Page.
     * 
     * @throws XPIllegalArgumentException		If the provided <code>AActivityspace</code> is <code>null</code>.
     */
    public static int GetCurrentCommunityPageID(AActivitySpace owner) throws XPIllegalArgumentException
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        int nPageID = TaskAPIUICommon.INVALID_OBJECTID;
        
        if ( !TaskAPIUICommunity.IsCurrentPageCommunityPage(owner) )
        {
       		return nPageID;
        }
        
		if ( TaskAPIUICommon.GetMyPortalPageModelExists(owner) ) 
		{
			MyPortalModel ptModel =  TaskAPIUICommon.GetMyPortalPageModel(owner);
			nPageID = ptModel.GetPageID();
		}
		else if ( FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME.equals(TaskAPIUICommon.GetActivitySpaceName(owner)) )
		{
			// rob: The flyout AS is always preceded by community or mypage AS, so call the same function with the parent space  
			nPageID = GetCurrentCommunityPageID(owner.GetParentSpace());
		}
		
		return nPageID;
        
        
    }

    /**
     * Gets the current Page as an object of type<code>IPTURL</code>. Returns  
     * 
     * @param owner Current Activityspace
     * @return IPTURL to the current community page or null if the current page is not a community page. 
     * @throws XPIllegalArgumentException
     */
    public static IPTURL GetCurrentPageAsURL(AActivitySpace owner) throws XPIllegalArgumentException
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	IPTURL url = null;
    	
    	int commId 		= GetCurrentCommunityID(owner);
    	int pageId 		= TaskAPIUICommon.INVALID_OBJECTID;
    	String pageName = null;
    	
    	if ( commId == TaskAPIUICommon.INVALID_OBJECTID ) {
    		pageId = TaskAPIUIMyPages.GetCurrentMyPageID(owner);
    		pageName = TaskAPIUIMyPages.GetCurrentMyPageName(owner);
    		url = TaskAPIUIMyPages.CreateMyPageCommonOpenerURL(owner, pageId, pageName);
    		
    	} else {
    		pageId 	= GetCurrentCommunityPageID(owner);
    		pageName = GetCurrentCommunityPageName(owner);
    		url = CreateCommunityPageCommonOpenerURL(owner, commId, pageId, pageName);
    	}
    	
    	return url;
    }

	
    /**
     * Gets Subcommunities in the current Community as an <code>XPArrayList</code> with <code>IPTURL</code> entries.
     * 
     * @param owner	Current Activityspace.
     * @return Array list with <code>IPTURL</code> of Subcommunities.  An empty list is returned if there are 
     * no subcommunities exist or not in a Community.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
     public static XPArrayList GetCurrentSubCommunitiesAsURLs(AActivitySpace owner)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        int nCommunityID =  GetCurrentCommunityID(owner);
        
         if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCommunityID) ) 
    	 {
    	 	return new XPArrayList();
    	 }

        XPArrayList list = GetSubCommununitiesAsURLs(owner, nCommunityID);
       
        return list;
    }

    
    
    /**
     * INTERNAL
     *Helper function that performs the common checks for whether Community Actions should be displayed or not. 
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the Community Actions are displayable in the current context, or <code>false</code> if not.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
     static boolean IsCommunityActionsDisplayable(AActivitySpace owner)
    {
     	
    	if ( IsCommunityFeatureEnabledInSubPortal(owner) &&
    			//IsCurrentPageCommunityPage(owner) &&
				!TaskAPIUICommon.IsCurrentPageInPreviewMode(owner) &&
				!TaskAPIUIUser.IsCurrentUserGuestUser(owner) &&
				!TaskAPIUICommon.IsCurrentPageInEditDefaultProfileMode(owner)
    		 )
    	{
    		return true;
    	}
    	
    	return false;
    	
    }
     
     /**
      * Checks if the Community Feature is enabled in the current Experience Definition.
      * 
      * @param owner		Current Activityspace.
      * @return	<code>true</code> if Community feature is enabled in the current Experience Definintion, <code>false</code> otherwise. 
      * 
      *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
      */
     static boolean IsCommunityFeatureEnabledInSubPortal(AActivitySpace owner)
     {
     	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
     	IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
     	
     	return TaskAPIServerSubPortal.IsSubPortalFeatureEnabled(ptSession, PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS);
     	
     }
    
    
	/**
     * Gets the URL to the Unsubscribe from Communities Editor.
     * 
     * @param owner		Current Activityspace.
     * @return		<code>IPTURL</code> with URL to the Unsubscribe from Communities Editor, or <code>null</code> if the URL is not
     * valid in the current context.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
	public static IPTURL GetURLForUnsubscribeCommunitiesEditor(AActivitySpace owner)
	{
	 	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
	 	AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { 
			// DCA - we don't really need a community or my page AS specifically here
			// so just set to the activity space that was passed in
			communityAS = owner; 
		}
		
		CommonOpenerOpenASURL url = null;
		if ( IsCommunityFeatureEnabledInSubPortal(communityAS) &&
				!TaskAPIUICommon.IsCurrentPageInPreviewMode(communityAS)  &&
				!TaskAPIUIUser.IsCurrentUserGuestUser(communityAS) || 
				(TaskAPIUIUser.IsCurrentUserGuestUser(communityAS) && TaskAPIUICommon.IsCurrentPageInEditDefaultProfileMode(communityAS))
				)
		{
			String strURLTitle 			= communityAS.GetString(638, "ptmsgs_portalcommonmsgs");
			// Use current AActivitySpace for the following calls
			String strApplBaseURL 	=  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
			String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
			String strASName 				= UnsubscribeCommunitiesAS.STR_MVC_CLASS_NAME;
			int nUserID 							= TaskAPIUIUser.GetCurrentUserID(communityAS);
			
			url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL, strASName, nUserID);
			url.AddControlParameter(ASConstants.CONTROL,  EditorStartControl.STR_MVC_CLASS_NAME);
			url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE,  EditorStartControl.EDITOR_START_FLAG_MISC);
			
			url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
			url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());

			// Set image
			url.SetURLImageType(PTImageType.ACTION_COMMUNITIES_UNSUB, strImageServerURL);
		}

		return url;
	}

	/**
     * Gets the URL to the Community Editor for the current Community.
     * 
     * @param owner		Current Activityspace.
     * @return		<code>IPTURL</code> with URL to the Editor for the current Community, or <code>null</code> if the URL is not
     * valid in the current context.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
	public static IPTURL GetURLForCurrentCommunityEditor(AActivitySpace owner)
	{
	 	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
	 	AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { return null; }
		
		CommonOpenerOpenObjIDURL url = null;
		if ( (communityAS.GetAccessStyle() != AccessStyles.SECTION_508) && IsCommunityActionsDisplayable(communityAS) )
		{
			if ( IsCurrentPageCommunityPage(communityAS) &&  IsCurrentUserCommunityOwner(communityAS) )
			{
				String strURLTitle 			= communityAS.GetString(308, "ptmsgs_portalcommonmsgs");
				int nCommunityID 			= TaskAPIUICommunity.GetCurrentCommunityID(communityAS);
				// Use current AActivitySpace for the following calls
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
				
				url = new CommonOpenerOpenObjIDURL(strURLTitle, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, IPTOpenerConstants.OPENER_MODE_EDIT, owner);
				
				url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
				url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());

				// Set image
				url.SetURLImageType(PTImageType.ACTION_COMMUNITIES_EDIT, strImageServerURL);
			}
		}
		return url;
	 	
	}
	
	 /**
    * Gets an XPArrayList with a single entry for the URL for the current Community.
    * 
    * @param owner		Current Activityspace.
    * @return		<code>XPArrayList</code> list containing a single URL to the current Community, 
    * or <code>null</code> if the URL is not valid in the current context.
    * 
    *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
    */
	public static XPArrayList GetURLForCurrentCommunity(AActivitySpace owner)
	{
	 	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		// This will get the Parent activity space if the current space is not CommunityAS
		// We need to pass in the correct space for the checks below.
	 	AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
	 	if ( communityAS == null) { return null;	 }
	 	
	 	// get the URL
		CommonOpenerOpenObjIDURL url = null;
		if ( (communityAS.GetAccessStyle() != AccessStyles.SECTION_508) )
		{
			if ( IsCurrentPageCommunityPage(communityAS) && IsUserAbleToAccessCurrentCommunity(communityAS) )
			{
				String strURLTitle 			= GetCurrentCommunityName(communityAS);
				int nCommunityID 			= GetCurrentCommunityID(communityAS);
				// Use current AActivitySpace for the following calls
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
				
				url = new CommonOpenerOpenObjIDURL(strURLTitle, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, IPTOpenerConstants.OPENER_MODE_VIEW, owner);

				url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
				url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());

				// Set image
				url.SetURLImageType(PTImageType.ICON_COMMUNITY, strImageServerURL);
				
				// Set metadata about this community and page on this URL object
				url.SetURLData(URLDATA_OBJECTID, XPConvert.ToString(nCommunityID));
				url.SetURLData(URLDATA_CLASSID, XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID));
				url.SetURLData(URLDATA_COMMNAME, strURLTitle);
				url.SetURLData(URLDATA_COMMID, XPConvert.ToString(nCommunityID));
			}
		}

		// put the URL in the array
		XPArrayList list = null;
		if (url != null)
		{
			list = new XPArrayList(1);
			list.Add(url);
		}
		return list;
	}
	
	
	/**
	 * Gets the URL to the Community Add Portlets Editor.
	 * 
	 * @param owner		Current Activityspace.
	 * @return		<code>IPTURL</code> with URL to the Community Add Portlets Editor, or <code>null</code> if the URL is not
     * valid in the current context.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static IPTURL GetURLForAddCommunityPortletsEditor(AActivitySpace owner)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
		AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { return null; }
		
		CommonOpenerOpenASURL url = null;
		if ( IsCommunityActionsDisplayable(communityAS) )
		{
			if ( IsCurrentPageCommunityPage(communityAS) &&  IsCurrentUserCommunityOwner(communityAS) )
			{
				String strURLTitle 			= communityAS.GetString(307, "ptmsgs_portalcommonmsgs");
				// Use current AActivitySpace for the following calls
				String strApplBaseURL   =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
				String strASName 				= PortletSelectionEditorAS.STR_MVC_CLASS_NAME;
				int nUserID 							= TaskAPIUIUser.GetCurrentUserID(communityAS);
				int nCommunityID 				= TaskAPIUICommunity.GetCurrentCommunityID(communityAS);
				int nPageID								= TaskAPIUICommunity.GetCurrentCommunityPageID(communityAS);
				
				url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL,  strASName, nUserID);
				
				url.AddControlParameter(ASConstants.CONTROL , EditorStartControl.STR_MVC_CLASS_NAME);
				url.AddControlParameter(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORCOMMUNITYID, nCommunityID);
				url.AddControlParameter(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID, nPageID);
				url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
				
				url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
				url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());
				
				// Set image
				url.SetURLImageType(PTImageType.ACTION_PORTLET_ADD, strImageServerURL);
			}
		}
		return url;	
	}
	
	/**
	 * Gets the URL to the Community Add Portlets Flyout.
	 * 
	 * @param owner		Current Activityspace.
	 * @return		<code>IPTURL</code> with URL to the Community Add Portlets Flyout, or <code>null</code> if the URL is not
     * valid in the current context.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static IPTURL GetURLForAddCommunityPortletsFlyout(AActivitySpace owner)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		
		CommonOpenerOpenASURL url = null;
		if ( IsCommunityActionsDisplayable(owner) )
		{
			if ( IsCurrentPageCommunityPage(owner) &&  IsCurrentUserCommunityOwner(owner) )
			{
				String strURLTitle 			= owner.GetString(307, "ptmsgs_portalcommonmsgs");
				String strApplBaseURL   =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
				String strASName 				= FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME;
				int nUserID 							= TaskAPIUIUser.GetCurrentUserID(owner);
				int nCommunityID 				= TaskAPIUICommunity.GetCurrentCommunityID(owner);
				int nPageID								= TaskAPIUICommunity.GetCurrentCommunityPageID(owner);
				
				url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL,  strASName, nUserID);
				
				url.AddControlParameter(ASConstants.CONTROL , EditorStartControl.STR_MVC_CLASS_NAME);
				url.AddControlParameter(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORCOMMUNITYID, nCommunityID);
				url.AddControlParameter(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID, nPageID);
				url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
				
				url.AddControlParameter(ASConstants.PARENTSPACEID, owner.GetSpaceID());
				url.AddControlParameter(ASConstants.PARENTSPACENAME, owner.GetName());
				// Set image
				url.SetURLImageType(PTImageType.ACTION_PORTLET_ADD, strImageServerURL);
			}
		}
		return url;
		
	}
	
	/**
	 * Gets the URL to the Create Community page in the Community Editor.
	 * 
	 * @param owner		Current Activityspace.
	 * @return		<code>IPTURL</code> with URL to Create Community Page in the Community Editor, 
	 * or <code>null</code> if the URL is not valid in the current context.
	 * 
	 *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static IPTURL GetURLForCreateCommunityPage(AActivitySpace owner)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
		AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { return null; }
		
		CommonOpenerOpenObjIDURL url = null;
		if ( IsCommunityActionsDisplayable(communityAS) )
		{
			if ( IsCurrentPageCommunityPage(communityAS) &&  IsCurrentUserCommunityOwner(communityAS) && communityAS.GetIsAccessStyleStandard())
			{
				String strURLTitle 			= communityAS.GetString(309, "ptmsgs_portalcommonmsgs");
				// Use current AActivitySpace for the following calls
				String strApplBaseURL   =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
				int nUserID 							= TaskAPIUIUser.GetCurrentUserID(communityAS);
				int nCommunityID 				= TaskAPIUICommunity.GetCurrentCommunityID(communityAS);
				
				
				url = new CommonOpenerOpenObjIDURL(strURLTitle, strApplBaseURL, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, IPTOpenerConstants.OPENER_MODE_EDIT, nUserID);
				url.AddControlParameter(ASConstants.CONTROL , EditorStartControl.STR_MVC_CLASS_NAME);
				url.AddControlParameter(EditPortletPrefsAS.QS_PARAM_COMMUNITYID, nCommunityID);
				url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
				
				url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
				url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());
				
				
				// Set image
				url.SetURLImageType(PTImageType.ACTION_MYPAGE_NEW, strImageServerURL);
			}
		}
		return url;
		
	}
	
	/**
	 * Gets the URL to the Create Community page in the Community Editor.
	 * 
	 * @param owner		Current Activityspace.
	 * @return		<code>IPTURL</code> with URL to Create Community Page in the Community Editor, 
	 * or <code>null</code> if the URL is not valid in the current context.
	 * 
	 *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	
	public static IPTURL GetURLForCreateCommunityPageOneClick(AActivitySpace owner, boolean bInheritTemplate, int nPageTemplate)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
		AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { return null; }
		
		CommonOpenerOpenASURL url = null;
		if ( IsCommunityActionsDisplayable(communityAS) )
		{
			if ( IsCurrentPageCommunityPage(communityAS) &&  IsCurrentUserCommunityOwner(communityAS) && communityAS.GetIsAccessStyleStandard())
			{
				String strURLTitle 			= communityAS.GetString(803, "ptmsgs_portalcommonmsgs");
				// Use current AActivitySpace for the following calls
				String strApplBaseURL   =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
				int nUserID 							= TaskAPIUIUser.GetCurrentUserID(communityAS);
				int nCommunityID 				= TaskAPIUICommunity.GetCurrentCommunityID(communityAS);
				String strASName 				= CommunityEditorAS.STR_MVC_CLASS_NAME;
				if (nPageTemplate == -1)
					nPageTemplate = PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID;

				url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL,  strASName ,nUserID);
				url.AddControlParameter(ASConstants.CONTROL , PageCreateDefaultControl.STR_MVC_CLASS_NAME);
				url.AddControlParameter(PageCreateDefaultControl.HTMLINPUT_COMMUNITY_ID, XPConvert.ToString(nCommunityID));
				url.AddControlParameter(PageCreateDefaultControl.HTMLINPUT_INHERIT_TEMPLATE, XPConvert.ToString(bInheritTemplate));
				url.AddControlParameter(PageCreateDefaultControl.HTMLINPUT_PAGE_TEMPLATE_ID, XPConvert.ToString(nPageTemplate));

				// Set image
				url.SetURLImageType(PTImageType.ACTION_MYPAGE_NEW, strImageServerURL);
			}
		}
		return url;
		
	}
	
	/**
     * Gets the URL for the Join Community Editor where users add Communities to their My Communities list.
     * 
     * @param owner		Current Activityspace.
     * @return		<code>IPTURL</code> with URL to the Join Communities Editor, or <code>null</code> if the URL is not
     * valid in the current context.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
	public static IPTURL GetURLForJoinCommunitiesEditor(AActivitySpace owner)
	{
	 	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
	 	AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { 
			// DCA - we don't really need a community or my page AS specifically here
			// so just set to the activity space that was passed in
			communityAS = owner; 
		}
		
		CommonOpenerOpenASURL url = null;
		if ( (IsCommunityFeatureEnabledInSubPortal(communityAS) &&
				!TaskAPIUICommon.IsCurrentPageInPreviewMode(communityAS)) &&
				!TaskAPIUIUser.IsCurrentUserGuestUser(communityAS) || 
				(TaskAPIUIUser.IsCurrentUserGuestUser(communityAS) && TaskAPIUICommon.IsCurrentPageInEditDefaultProfileMode(communityAS))
				)
		{
		
			String strURLTitle = communityAS.GetString(297, "ptmsgs_portalcommonmsgs");
			// Use current AActivitySpace for the following calls
			String strApplBaseURL =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
			String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
			String strASName = CommunitySelectionEditorAS.STR_MVC_CLASS_NAME;
			int nUserID = TaskAPIUIUser.GetCurrentUserID(communityAS);
			
			url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL, strASName, nUserID);
			url.AddControlParameter(ASConstants.CONTROL,  EditorStartControl.STR_MVC_CLASS_NAME);
			url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE,  EditorStartControl.EDITOR_START_FLAG_CREATE);
			
			url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
			url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());
				
			// Set image
			url.SetURLImageType(PTImageType.ACTION_COMMUNITIES_JOIN, strImageServerURL);
		}
		return url;
	 	
	}
	
	/**
     * Gets the URL for the Join Community Editor where users add Communities to their My Communities list.
     * 
     * @param owner		Current Activityspace.
     * @return		<code>IPTURL</code> with URL to the Join Communities Editor, or <code>null</code> if the URL is not
     * valid in the current context.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
	public static IPTURL GetURLForJoinCommunitiesFlyout(AActivitySpace owner)
	{
	 	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
	 	AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { 
			// DCA - we don't really need a community or my page AS specifically here
			// so just set to the activity space that was passed in
			communityAS = owner; 
		}
		
		CommonOpenerOpenASURL url = null;
		if ( (IsCommunityFeatureEnabledInSubPortal(communityAS) &&
				!TaskAPIUICommon.IsCurrentPageInPreviewMode(communityAS)) &&
				!TaskAPIUIUser.IsCurrentUserGuestUser(communityAS) || 
				(TaskAPIUIUser.IsCurrentUserGuestUser(communityAS) && TaskAPIUICommon.IsCurrentPageInEditDefaultProfileMode(communityAS))
				)
		{
		
			String strURLTitle = communityAS.GetString(297, "ptmsgs_portalcommonmsgs");
			// Use current AActivitySpace for the following calls
			String strApplBaseURL =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
			String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
			String strASName = FlyoutCommunitySelectionAS.STR_MVC_CLASS_NAME;
			int nUserID = TaskAPIUIUser.GetCurrentUserID(communityAS);
			
			url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL, strASName, nUserID);
			url.AddControlParameter(ASConstants.CONTROL,  EditorStartControl.STR_MVC_CLASS_NAME);
			url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE,  EditorStartControl.EDITOR_START_FLAG_CREATE);
			
			url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
			url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());
				
			// Set image
			url.SetURLImageType(PTImageType.ACTION_COMMUNITIES_JOIN, strImageServerURL);
		}
		return url;
	 	
	}
	
	/**
	 * Gets the URL to the Community Edit Portlet Preferences Editor.
	 * 
	 * @param owner		Current Activityspace.
	 * @return		<code>IPTURL</code> with URL to the Community Edit Portlet Preferences Editor, or <code>null</code> if the URL is not
     * valid in the current context.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static IPTURL GetURLForEditPortletPreferencesEditor(AActivitySpace owner)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
		AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
		if ( communityAS == null) { return null; }
		
		CommonOpenerOpenASURL url = null;
		if ( IsCommunityActionsDisplayable(communityAS) )
		{
			if ( IsCurrentPageCommunityPage(communityAS) &&  IsUserAbleToAccessCurrentCommunity(communityAS) )
			{
				String strURLTitle 			= communityAS.GetString(306, "ptmsgs_portalcommonmsgs");
				// Use current AActivitySpace for the following calls
				String strApplBaseURL   =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
				String strASName 				= EditPortletPrefsAS.STR_MVC_CLASS_NAME;
				int nUserID 							= TaskAPIUIUser.GetCurrentUserID(communityAS);
				int nCommunityID 			= TaskAPIUICommunity.GetCurrentCommunityID(communityAS);
				int nPageID								= TaskAPIUICommunity.GetCurrentCommunityPageID(communityAS); 
				
				url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL,  strASName ,nUserID);
				
				url.AddControlParameter(ASConstants.CONTROL , EditorStartControl.STR_MVC_CLASS_NAME);
				url.AddControlParameter(EditPortletPrefsAS.QS_PARAM_COMMUNITYID, nCommunityID);
				url.AddControlParameter(EditPortletPrefsAS.QS_PARAM_PAGEID, nPageID);
				url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
				
				url.AddControlParameter(ASConstants.PARENTSPACEID, communityAS.GetSpaceID());
				url.AddControlParameter(ASConstants.PARENTSPACENAME, communityAS.GetName());
				
				// Set image
				url.SetURLImageType(PTImageType.ACTION_PORTLET_PREF, strImageServerURL);
			}
		}
		return url;
		
	}
	
	
    /**
     * Checks if the current user is already subscribed to the current Community, i.e. if the current Community
     * is already on the user's My Community list.
     * 
     * @param owner		Current activityspace.
     * @return <code>true</code> if current Community is already subscribed by the user, <code>false</code> if not member, or on User profile community
     * or  not or if not currently in a Community.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static boolean IsUserMemberOfCurrentCommunity(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
    	
    	int nCurCommID = GetCurrentCommunityID(owner);
    	
    	if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurCommID) )
    	{
    		return false;
    	}
    
		if (nCurCommID == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
		{
			return true;
		}
		
    	IPTQueryResult qrMyComms = TaskAPIServerCommunity.GetMyCommunityMembership(ptSession, true);
    	
    	for (int i = 0; i < qrMyComms.RowCount(); i++)
		{
			int nCommID    = qrMyComms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
			if ( nCurCommID == nCommID ) {
				return true;	
			}	
		}
    	return false;
    }

    /**
     * Checks if the current page is in a Community.
     * Note that this function does NOT check if this is a Community Portlet Page. Use <code>IsCurrentPageMyPortalPage</code>
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the current page is in a Community, <code>false</code> otherwise.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static boolean IsCurrentPageCommunityPage(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	boolean bIsCommunityPage = false;
    	String strASName = TaskAPIUICommon.GetActivitySpaceName(owner);
    	
    	if ( CommunityPageAS.STR_MVC_CLASS_NAME.equals(strASName)  ||
    		   SiteMapAS.STR_MVC_CLASS_NAME.equals(strASName) ) { 
    		bIsCommunityPage = true;
    	}
    	if ( FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME.equals(strASName) ) {
    		IObjectSelectionModelRO model = (IObjectSelectionModelRO) TaskAPIUICommon.GetASModel(owner, ObjectSelectionModel.STR_MVC_CLASS_NAME);
    		if ( model.GetSelectorCommunityID() > 0 ) {
    			bIsCommunityPage = true;
    		}
    		
    	}
		
    	return bIsCommunityPage;
    }

    /**
     * Checks if the current Community is the User Profile Community.
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the current Community is the User Profile Community, <code>false</code> otherwise.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static boolean IsCurrentCommunityUserProfileCommunity(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        int nCurCommID =  GetCurrentCommunityID(owner);
		return ( nCurCommID == PT_INTRINSICS.PT_PROFILE_COMMUNITY );
    	
    }
    
    
	/**
	 * Checks if the current user has access (requires EDIT access) to use the Community Editor on the current
	 * Community Page.
	 * 
	 * @param owner		Current Activityspace.
	 * @return	<code>true</code> if the current user has at least EDIT access to the current Community Page, <code>false</code> otherwise.
	 * 
	 *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
    public static boolean IsCurrentUserAbleToEditCurrentCommunityPage(AActivitySpace owner)
    {
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);

		boolean bAbleToEditCurrentCommunityPage = CheckUserAccessLevelToCurrentCommunityPage(owner, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);

		return bAbleToEditCurrentCommunityPage;    	
    }
    

    /**
     * Checks if the current user is the owner of the current Community.
     * The check only works on Community pages or Community Knowledge directory pages, not in Community editors.
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the current user has at least EDIT access to the current Community, <code>false</code> otherwise.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static boolean IsCurrentUserCommunityOwner(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);

    	boolean bIsOwner = CheckUserAccessLevelToCurrentCommunity(owner, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
    	
	    return bIsOwner;
    }

    /**
     * Checks if the current user has at least SELECT access to the current Community.
     * Only works on Community pages or Community Knowledge directory pages, not in Community Editors.
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the current user has at least SELECT access to the current Community, <code>false</code> otherwise.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static boolean IsUserAbleToJoinCurrentCommunity(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        
    	boolean bCanJoin = TaskAPIUICommunity.CheckUserAccessLevelToCurrentCommunity(owner, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
    	
    	return bCanJoin;
    	
    }
	
	/**
	 * Checks if the current user has at least READ access to the current Community.
	 * Only works on Community pages or Community Knowledge directory pages, not in Community editors.
	 * 
	 * @param owner		Current Activityspace.
	 * @return	<code>true</code> if the current user has at least READ access to the current Community, <code>false</code> otherwise.
	 * 
	 *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static boolean IsUserAbleToAccessCurrentCommunity(AActivitySpace owner)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		
		boolean bCanJoin = TaskAPIUICommunity.CheckUserAccessLevelToCurrentCommunity(owner, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
    	
    	return bCanJoin;
	}
    
    /**
     * Checks if the current page is a Myportal page, i.e. either a MyPage or Community Portlet Page.
     * 
     * @param owner		Current Activityspace.
     * @return	<code>true</code> if the current page is either a MyPage or Community Page, <code>false</code> otherwise.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static boolean IsCurrentPageMyPortalPage(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        boolean bMyPortalModelExists = TaskAPIUICommon.GetASModelExist(owner, MyPortalModel.STR_MVC_CLASS_NAME);
    	
	    return bMyPortalModelExists;
    }

    /**
     * Gets Community Actions as an XPArrayList with IPTURL entries.
     * Most Community actions only display when in an Community and only if a user has access 
     * to perform the actions.  
     * 
     * @param owner		Current Activityspace.
     * @return	An <code>XPArrayList</code> with <code>IPTURL</code> entries with Community Actions. 
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner)
    {
    	return GetCommunityActionsAsURLs(owner, false, true, -1);
    }    

    /**
     * Gets Community Actions as an XPArrayList with IPTURL entries.
     * Most Community actions only display when in an Community and only if a user has access 
     * to perform the actions.  
     * 
     * @param owner		Current Activityspace.
     * @param includeOneClick		Flag to include the "one-click page creation" link
     * @return	An <code>XPArrayList</code> with <code>IPTURL</code> entries with Community Actions. 
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner, boolean bIncludeOneClick, boolean bInheritTemplate, int nPageTemplate)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        
        XPArrayList listURL = new XPArrayList();
        
        IPTURL url = null;
        
        url = GetURLForJoinCurrentCommunityAction(owner);
        if ( null != url ) listURL.Add(url);
        url = GetURLForJoinCommunitiesEditor(owner);
        if ( null != url ) listURL.Add(url);
        url = GetURLForUnsubscribeCurrentCommunityAction(owner);
        if ( null != url ) listURL.Add(url);
        url = GetURLForUnsubscribeCommunitiesEditor(owner);
        if ( null != url ) listURL.Add(url);
        url = GetURLForAddCommunityPortletsEditor(owner);
        if ( null != url ) listURL.Add(url);
        url = GetURLForCurrentCommunityEditor(owner);
        if ( null != url ) listURL.Add(url);
        url = GetURLForCreateCommunityPage(owner);
        if ( null != url ) listURL.Add(url);

        if (bIncludeOneClick)
        {
	        url = GetURLForCreateCommunityPageOneClick(owner, bInheritTemplate, nPageTemplate);
	        if ( null != url ) listURL.Add(url);
        }

        url = GetURLForEditPortletPreferencesEditor(owner);
        if ( null != url ) listURL.Add(url);

        return listURL;
    }
    
    /**
     * Helper function to create an URL to a specified Community. 
     * The <code>PTURLConstants.KEY_CURRENTMARKER</code> flag is set on the URL if is leading to the current
     * Community.
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID		Object ID of the Community to create an URL to.
     * @param strCommunityName	Name of the URL, normally the name of the Community.
     * @return	<code>IPTURL</code> with an URL to the specified Community.
     * 
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static IPTURL CreateCommunityCommonOpenerURL(AActivitySpace owner, int nCommunityID, String strCommunityName)
    {
    	// DCA - check if it's the user profile community and create a user profile URL instead
    	if (PT_INTRINSICS.PT_PROFILE_COMMUNITY == nCommunityID) {
    		int userId = TaskAPIUIUser.GetCurrentUserID(owner);
    		String userName = TaskAPIUIUser.GetCurrentUserName(owner);
    		return TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(owner, userId, userName, strCommunityName);
    	}
    	
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
		
		IPTURL url = null;
		if (TaskAPIUICommon.UseFriendlyURLS(PT_CLASSIDS.PT_COMMUNITY_ID)) {
			url = new CommonOpenerFriendlyURL(strCommunityName, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, owner );
		} else {
			String strAppBaseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
			int nUserID = TaskAPIUICommon.GetPTSession(owner).GetSessionInfo().GetCurrentUserID();
			url = new CommonOpenerOpenObjIDURL(strCommunityName, strAppBaseURL, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, IPTOpenerConstants.OPENER_MODE_VIEW, nUserID);
		}
        
		((ACommonOpenerURL) url).SetURLImageType(PTImageType.ICON_COMMUNITY, strImageServerURL);
        
    	if ( nCommunityID == TaskAPIUICommunity.GetCurrentCommunityID(owner) ) {
    		url.SetURLData(PTURLConstants.KEY_CURRENTMARKER, "");
    	}
    	url.SetURLData(URLDATA_COMMNAME, 	strCommunityName);
		url.SetURLData(URLDATA_COMMID, 		XPConvert.ToString(nCommunityID));
		url.SetURLData(URLDATA_PAGENAME, 	GetCurrentCommunityPageName(owner));
		url.SetURLData(URLDATA_PAGEID, 		XPConvert.ToString(GetCurrentCommunityPageID(owner)));
    	
    	return url;
    	
    }
    
    /**
     * Helper function to create an URL to a specified Community Page. 
     * The <code>PTURLConstants.KEY_CURRENTMARKER</code> flag is set on the URL if is leading to the current
     * Community Page. In case the page is a profile page, the link generated will be of the viewed profile,
     * not the current user's.
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID		Object ID of the Community where the Page is located in.
     * @param nCommunityPageID	Object ID of the Page to create a URL to.
     * @param strCommunityPageName	Title of the URL, normally the name of the Page.
     * @return <code>IPTURL</code> with an URL to the specified Community Page.
     * 
     *  @throws XPIllegalArgumentException			If the user does not have sufficient access to the Community.
     */
    public static IPTURL CreateCommunityPageCommonOpenerURL(AActivitySpace owner, int nCommunityID, int nCommunityPageID, String strCommunityPageName)
    {
    	// DCA - check if it's the user profile community and create a user profile URL instead
    	if (PT_INTRINSICS.PT_PROFILE_COMMUNITY == nCommunityID) {
    		// DCA - we're getting the user profile Id here in case we are viewing someone's profile;
    		// we want the other page's link to be the viewed profile not the user's
    		int userId = TaskAPIUICommunity.GetUserProfileId(owner);
    		// We don't have the profile name available, so just have it look it up from the cache.
    		return TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(owner, userId, null, strCommunityPageName, nCommunityPageID, strCommunityPageName);
    	}
    	
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
    	
		IPTURL url = null;
    	if (TaskAPIUICommon.UseFriendlyURLS(PT_CLASSIDS.PT_COMMUNITY_ID)) {
	    	if ( nCommunityPageID == 0 ) {
	    		// go to community home page
	    		url = new CommonOpenerFriendlyURL(strCommunityPageName, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, owner );
	    	} else {
	    		url = new CommonOpenerFriendlyURL(strCommunityPageName, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, nCommunityPageID, owner  );
	    	}
	    	
	    	//Bug fix 8483962- FLYOUT EDITOR DOES NOT WORK ON ADAPTIVE LAYOUT PAGES WITH FRIENDLY URLS DISABLED
	    	//adding PageID as the url indicator for the community pages (instead of "childid" which still exists but will not be used in the layout)
	    	url.SetURLData(PTCommunities.STR_PAGE_ID, XPConvert.ToString(nCommunityPageID));
    	} else {
    		String strAppBaseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
    		int nUserID = TaskAPIUICommon.GetPTSession(owner).GetSessionInfo().GetCurrentUserID();
    		// Bug fix 8483962 - FLYOUT EDITOR DOES NOT WORK ON ADAPTIVE LAYOUT PAGES WITH FRIENDLY URLS DISABLED
    		// adding this new constructor to store the community page id of the community the portlet selection editor is trying to access.
    		url = new CommonOpenerOpenObjIDURL(strCommunityPageName, strAppBaseURL, PT_CLASSIDS.PT_COMMUNITY_ID, nCommunityID, IPTOpenerConstants.OPENER_MODE_VIEW,  nUserID, nCommunityPageID);
       	 	url.AddControlParameter(PTCommunities.STR_PAGE_ID, nCommunityPageID);
    	}
    	
		//url.SetURLData(PTURLConstants.KEY_CLASSID, XPConvert.ToString(PT_CLASSIDS.PT_PAGE_ID));
		//url.SetURLData(PTURLConstants.KEY_OBJECTID, XPConvert.ToString(nCommunityPageID));
		((ACommonOpenerURL) url).SetURLImageType(PTImageType.ICON_MYPAGE, strImageServerURL);

    	if ( nCommunityID == TaskAPIUICommunity.GetCurrentCommunityID(owner) && nCommunityPageID == TaskAPIUICommunity.GetCurrentCommunityPageID(owner) ) {
    		url.SetURLData(PTURLConstants.KEY_CURRENTMARKER, "");
    	}
    	String commPageId = XPConvert.ToString(nCommunityPageID);
    	
    	url.SetURLData(URLDATA_CLASSID,  PT_CLASSIDS.PT_PAGE_ID+"");
    	url.SetURLData(URLDATA_OBJECTID, commPageId);
    	url.SetURLData(URLDATA_COMMNAME, GetCommunityName(owner, nCommunityID));
		url.SetURLData(URLDATA_COMMID,   XPConvert.ToString(nCommunityID));
		url.SetURLData(URLDATA_PAGENAME, strCommunityPageName);
		url.SetURLData(URLDATA_PAGEID,   commPageId);
    	
         
        return url;
    }

    private static int GetUserProfileId(AActivitySpace owner) 
    {
    	IPTSession session = TaskAPIUICommon.GetPTSession(owner);
		// Determine user name and ID - the user info object stores
		// data about the current profile being viewed - checking this
		// allows us to avoid a DB query.
    	int nUserID = session.GetUserInfo().GetProfileUserID();

    	// If we can't find the user ID, it probably means that the user profile
    	// community hasn't been properly initialized and is displaying the
    	// incorrect user data, so we're in a pretty bad shape.  This used to
    	// happen when we were redirected here from an editor finishing and the
    	// redirect URL was missing the profile ID, but now the default control
    	// resets the profile ID, so this shouldn't happen anymore.
    	// ID of 0 means not a user profile page
    	// ID of -1 means view current user, but this should be replaced with
    	// the actual user ID during community page init, and if this hasn't
    	// happened yet, we're in trouble.
    	if (nUserID <= 0)
    	{
    		log.Debug("Unable to find user profile ID when displaying the user profile community.  " +
				"The profile page does not appear to have been correctly initialized.");
		 
    		// Try to get the profile information (which user are we looking at?)
    		// from the model.  This may or may not work.
    		if ( TaskAPIUICommon.GetMyPortalPageModelExists(owner) ) 
    		{
    			MyPortalModel ptModel =  TaskAPIUICommon.GetMyPortalPageModel(owner);
    			nUserID = ptModel.GetProfileID();
    		}
    	}
    	if (nUserID <= 0)
    	{
    		// DCA - if all else fails, set to the current user
			nUserID = TaskAPIUIUser.GetCurrentUserID(owner);
    	}
    	
    	return nUserID;
    }

    /**
     *Gets an URL to a UserProfile page for the specified user.
     * 
     * @param owner		Current Activityspace.
     * @param nProfileUserID	The Object ID of the user to open the User Profile page for.
     * @param sProfileUserName	The name of the user to open the User Profile page for.  Also used for the link title.
     * @return	<code>IPTURL</code> with the URL to the user profile page for the specified user.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
   public static IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner, int nProfileUserID, String sProfileUserName)
   {
   	return TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(owner, nProfileUserID, sProfileUserName, sProfileUserName, 0, null);
   }

     /**
      *Gets an URL to a UserProfile page for the specified user.
      * 
      * @param owner		Current Activityspace.
      * @param nProfileUserID	The Object ID of the user to open the User Profile page for.
      * @param sProfileUserName	The name of the user to open the User Profile page for.
      * @param strURLTitle		The title of the URL.
      * @return	<code>IPTURL</code> with the URL to the user profile page for the specified user.
      * 
      * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
      */
    public static IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner, int nProfileUserID, String sProfileUserName, String strURLTitle)
    {
    	return TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(owner, nProfileUserID, sProfileUserName, strURLTitle, 0, null);
    }
    
    /**
     *Gets an URL to a UserProfile page for the specified user.
     * 
     * @param owner		Current Activityspace.
     * @param nProfileUserID	The Object ID of the user to open the User Profile page for.
     * @param sProfileUserName	The name of the user to open the User Profile page for.
     * @param strURLTitle		The title of the URL.
     * @return	<code>IPTURL</code> with the URL to the user profile page for the specified user.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
   public static IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner, int nProfileUserID, String sProfileUserName,
	   String strURLTitle, int nPageId, String strPageName)
   {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
    	
    	IPTURL url = null;
		if (TaskAPIUICommon.UseFriendlyURLS(PT_CLASSIDS.PT_USER_ID)) {
			url = new CommonOpenerFriendlyURL(strURLTitle, PT_CLASSIDS.PT_USER_ID, nProfileUserID, sProfileUserName, nPageId, strPageName, owner);
		} else {
			String strAppBaseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
	    	int nCurrUserID = TaskAPIUICommon.GetPTSession(owner).GetSessionInfo().GetCurrentUserID();
	    	int nUserProfileCommunityID = PT_INTRINSICS.PT_PROFILE_COMMUNITY;
	    	
	    	url = new CommonOpenerOpenObjIDURL(strURLTitle, strAppBaseURL, PT_CLASSIDS.PT_COMMUNITY_ID, nUserProfileCommunityID, IPTOpenerConstants.OPENER_MODE_VIEW,  nCurrUserID);
	    	url.AddControlParameter(SetCommunityControl.PROFILEID, nProfileUserID);
		}
    	
		((ACommonOpenerURL) url).SetURLImageType(PTImageType.ICON_USER, strImageServerURL);
		
		if ( PT_INTRINSICS.PT_PROFILE_COMMUNITY == TaskAPIUICommunity.GetCurrentCommunityID(owner) && 
				(nPageId == 0 || nPageId == TaskAPIUICommunity.GetCurrentCommunityPageID(owner)) ) {
    		url.SetURLData(PTURLConstants.KEY_CURRENTMARKER, "");
    	}
		url.SetURLData(URLDATA_CLASSID, 	XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
		url.SetURLData(URLDATA_COMMNAME, 	sProfileUserName);
		url.SetURLData(URLDATA_COMMID, 		XPConvert.ToString(nProfileUserID));
		url.SetURLData(URLDATA_PAGENAME, 	strPageName);
		url.SetURLData(URLDATA_PAGEID, 		XPConvert.ToString(nPageId));
		
        return url;
    }
   
	  /**
	 * Check the if the current user has at least the accesslevel specified to the current
	 * community 
	 * 
	 * @param 							AccessLevel to check for. Example: PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ or PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT
	 * @param							nCommunityID Object ID of the Community to check security of
	 * @return boolean			True if the current user has at least the specified accesslevel, false if the user does not have access or there is no current community.
	 * 
	 *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 * @see PT_ACCESS_LEVELS
	 */
	public static boolean CheckUserAccessLevelToCommunity(AActivitySpace owner, int nAccessLevel, int nCommunityID)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		
		boolean bHasAccess				 = false;
		IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
		
		
		if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCommunityID) ) 
		{
			return bHasAccess;
		}
		
		IPTCommunityInfo ptCommInfo = TaskAPIServerCommunity.GetCommunityInfoObject(ptSession, nCommunityID);
		
		// mj: pretend that everyone has only read access to the profile community, 
		// so that the "edit" button will be hidden.
//		if (ptCommInfo.GetObjectID() == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
//		{
//			bHasAccess = (nAccessLevel <= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
//		}
//		else
//		{
			bHasAccess = (nAccessLevel <= ptCommInfo.GetAccessLevel());
//		}
		
		return bHasAccess;
	}
	
     /**
	 * Check the if the current user has at least the accesslevel specified to the current
	 * community 
	 * 
	 * @param 							AccessLevel to check for. Example: PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ or PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT
	 * @return boolean			True if the current user has at least the specified accesslevel, false if the user does not have access or there is no current community.
	 * 
	 * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 * @see PT_ACCESS_LEVELS
	 */
	public static boolean CheckUserAccessLevelToCurrentCommunity(AActivitySpace owner, int nAccessLevel)
	{
		int nCurrCommID = TaskAPIUICommunity.GetCurrentCommunityID(owner);
		
		return CheckUserAccessLevelToCommunity(owner, nAccessLevel, nCurrCommID);
	}
	
	/**
	* Check the if the current user has at least the accesslevel specified to the current
	* community page
	* 
	* @param 							AccessLevel to check for. Example: PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ or PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT
	* @return boolean			True if the current user has at least the specified accesslevel, false if the user does not have access or there is no current community page.
	* 
	* @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	* @see PT_ACCESS_LEVELS
	*/
	public static boolean CheckUserAccessLevelToCurrentCommunityPage(AActivitySpace owner, int nAccessLevel)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		
		boolean bHasAccess				 = false;
		IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
		int nCurrCommID = TaskAPIUICommunity.GetCurrentCommunityID(owner);
		
		if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
		{
			return bHasAccess;
		}
		
		// mj: pretend that everyone has only read access to the profile community, 
		// so that the "edit" button will be hidden.
		if ( TaskAPIUICommunity.IsCurrentCommunityUserProfileCommunity(owner) )
		{
			bHasAccess = (nAccessLevel <= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
		}
		else
		{
			int nCurrPageID = TaskAPIUICommunity.GetCurrentCommunityPageID(owner);

			if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
			{
				return bHasAccess;
			}

			IPTPageInfo ptPageInfo = ((IPTPageManager)ptSession.GetPages()).CachedOpenPageInfo(nCurrPageID, false, false);

			bHasAccess = (nAccessLevel <= ptPageInfo.GetAccessLevel());
		}
		
		return bHasAccess;
	}
	
	/**
	 * Gets the Object ID of the parent Community in the specified Community.  (the Community where the current Community is located in the administrative hierarchy).
	 * 
	 * @param owner		Current Activityspace.
	 * @param nCommunityID	Object ID of the Community to get the parent Community from.
	 * @return Object ID of current parent Community ID, or <code>0 /code>  if non-existant.
	 * 
	 * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static int GetParentCommunityID(AActivitySpace owner, int nCommunityID)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	 TaskAPIUICommon.ValidateObjectIDArgument(nCommunityID);
    	 
    	 IPTSession session = TaskAPIUICommon.GetPTSession(owner);
    	 
    	 IPTQueryResult qrParentComm = TaskAPIServerCommunity.GetCommunityParentComm(session, nCommunityID);
    	 
		 int nParentCommID = 0;
    	 if ( qrParentComm.RowCount() == 1) {
    	 	nParentCommID = qrParentComm.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
    	 }
    	 
        return nParentCommID;
	}
	
    /**
     * Gets the Object ID of the parent Community in the current Community. 
     * Parent Community is the Community where the current Community is located in the administrative hierarchy.
     * 
     * @param owner		Current Activityspace.
     * @return Object ID of current parent Community ID, or <code>0</code> if not currently in a Community or
     * the current Community does not have a parent Community.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static int GetCurrentParentCommunityID(AActivitySpace owner)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        
        int nCurrCommID = GetCurrentCommunityID(owner);
        
         if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
    	 {
    	 	return 0;
    	 }
        
        int id = GetParentCommunityID(owner, nCurrCommID);

        return id;
    }
	
    /**
     * Gets Related Communities (a.k.a. peer Communities) of the current Community as an integer array.
     * Related Communities are Communities located in one Community in the administrative hierarchy.  
     * 
     * @param owner		Current Activityspace.
     * @return Array with Object IDs of Related Community to the current Community.  
     * Empty array if the current Community has no Related communities or if not in a Community.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static int[] GetCurrentRelatedCommununityIDs(AActivitySpace owner)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        
        int nCurrCommID = GetCurrentCommunityID(owner);
        
         if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
    	 {
    	 	return new int[0];
    	 }
        
        int[] ids = GetRelatedCommununityIDs(owner, nCurrCommID);

        return ids;
    }
    
    /**
     * Gets the URL to Join Current Community Action.
     * The URL goes to a page that subscribes the user to the current Community. This URL is only visible
     * on Communities a user is not already member of.  
     * 
     * @param owner		Current Activityspace.
     * @return <code>IPTURL</code> to join current community or <code>null</code> if the current user is already a member or does not have access to join the current community.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static IPTURL GetURLForJoinCurrentCommunityAction(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	CommonOpenerOpenASURL url = null;
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
    	AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
    	if ( communityAS == null) { return null; }
    	
    	
    	if ( IsCommunityActionsDisplayable(communityAS) )
    	{
    		if ( 	!IsUserMemberOfCurrentCommunity(communityAS) &&
					IsUserAbleToJoinCurrentCommunity(communityAS) 
				)
    		{
    			String strURLTitle = communityAS.GetString(653, "ptmsgs_portalbrowsingmsgs");
    			// Use current AActivitySpace for the following calls
    			String strApplBaseURL =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
    			String strASName = CommunityPageAS.STR_MVC_CLASS_NAME;
    			int nUserID = TaskAPIUIUser.GetCurrentUserID(communityAS);
    			
    			url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL, strASName,nUserID);
    			url.AddControlParameter(ASConstants.CONTROL,  JoinCurCommunityControl.STR_MVC_CLASS_NAME);
                url.AddControlParameter(SetCommunityControl.STR_COMMUNITY_ID, GetCurrentCommunityID(communityAS));

				// Set image
				url.SetURLImageType(PTImageType.ACTION_COMMUNITIES_JOIN, strImageServerURL);
    		}
    	}
    	return url;
    	
    }
    
    /**
     * Gets the URL to Unsubscribe Current Community Action.
     * The URL goes to a page that unsubscribes the user to the current Community. This URL is only visible
     * on Communities a user is not already member of.  
     * 
     * @param owner		Current Activityspace.
     * @return <code>IPTURL</code> to unsubscribe current community or <code>null</code> if the current user is already not a member or does not have access to unsubscribe the current community.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static IPTURL GetURLForUnsubscribeCurrentCommunityAction(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	CommonOpenerOpenASURL url = null;
 		// This will get the Parent activity space if the current space is not CommunityAS
 		// We need to pass in the correct space for the checks below.
    	AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
    	if ( communityAS == null) { return null; }
    	
    	if ( IsCommunityActionsDisplayable(communityAS) )
    	{
    		if ( 	IsUserMemberOfCurrentCommunity(communityAS) &&
					IsUserAbleToJoinCurrentCommunity(communityAS) 
				)
    		{
    			int nCurrentCommunityID = GetCurrentCommunityID(communityAS);

    			// true means use cached data
    			IPTQueryResult ptMemberships = TaskAPIServerCommunity.GetMyCommunityMembership(TaskAPIUICommon.GetPTSession(communityAS), true); 

    			// Check if the current community is mandatory.
    			if ( null != ptMemberships )
    			{
    				for (int i = 0; i < ptMemberships.RowCount(); i++)
    				{
    					int nCommunityID = ptMemberships.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
    					if (nCommunityID == nCurrentCommunityID)
    					{
    		    			int nMembershipType = ptMemberships.ItemAsInt(i, PT_PROPIDS.PT_PROPID_MEMBERSHIP_TYPE);

    		    			if ((nMembershipType == PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_TAB) ||
    		    				(nMembershipType == PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_MANDATORY))
    		    			{
    		    				// Can't unsubscribe from the current community if it's mandatory,
    		    				// so just return null.
    		    				return null;
    		    			}
    					}
    				}
    			 }

    			String strURLTitle = communityAS.GetString(1919, "ptmsgs_portalbrowsingmsgs");
    			// Use current AActivitySpace for the following calls
    			String strApplBaseURL =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
				String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
    			String strASName = CommunityPageAS.STR_MVC_CLASS_NAME;
    			int nUserID = TaskAPIUIUser.GetCurrentUserID(communityAS);
    			
    			url = new CommonOpenerOpenASURL(strURLTitle, strApplBaseURL, strASName,nUserID);
    			url.AddControlParameter(ASConstants.CONTROL,  UnsubscribeCurCommunityControl.STR_MVC_CLASS_NAME);
                url.AddControlParameter(SetCommunityControl.STR_COMMUNITY_ID, GetCurrentCommunityID(communityAS));

				// Set image
				url.SetURLImageType(PTImageType.ACTION_COMMUNITIES_UNSUB, strImageServerURL);
    		}
    	}

    	return url;
    }

    /**
     * Gets the Subcommunities of the current Community as a integer array.
     * Subcommunties are Communities located in another Community in the adminstrative hierarchy.
     * 
     * @param owner		Current Activityspace.
     * @return An integer array with Object IDs to Subcommunity.  
     * Returns an empty array if the current Community has no Subcommunities or not currently in a Community.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static int[] GetCurrentSubCommunityIDs(AActivitySpace owner)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        int nCurrCommID = GetCurrentCommunityID(owner);
        
        if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
    	 {
    	 	return new int[0];
    	 }
        
        int[] ids = GetSubCommununityIDs(owner, nCurrCommID);
        
        return ids;
    }

    
     /**
     * Gets the Community Pages of the current Community as an <code>XPArraylist</code> with <code>IPTURL</code> entries.
     * 
     * @param owner		Current Activityspace.
     * @return An <code>XPArrayList</code> with <code>IPTURL</code> to CommunityPages, or empty <code>XPArrayList</code> if the current page is not a Community Page or valid Page.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetCurrentCommunityPagesAsURLs(AActivitySpace owner)
    {
       TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
       int nCurrCommID = 0;
       
       // This condition is to return the list of URLs when the Gateway Page is in
       // community and displays an outside page in hosted display mode. 
       if(XPStringUtility.EqualsIgnoreCase(owner.GetName(), GatewayAS.STR_MVC_CLASS_NAME) )
       {
    	   nCurrCommID = GetCurrentCommunityID(owner);
    	   if(nCurrCommID > 0 )
    	   {
    		   return GetCommunityPagesAsURLs(owner, nCurrCommID);
    	   }
       }
    	   
       // This will get the Parent activity space if the current space is not CommunityAS
       // We need pass in the correct space for the checks below.
       AActivitySpace communityAS = TaskAPIUICommon.GetMyPageOrCommunityAActivitySpace(owner);
       if ( communityAS == null) { return new XPArrayList(); }
       
       nCurrCommID = GetCurrentCommunityID(communityAS);
       if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) )
       {
       		return new XPArrayList();
       }
        
        XPArrayList list = GetCommunityPagesAsURLs(owner, nCurrCommID);
        
        return list;
    }

    /**
     * Gets URLs to Related Communities for for the current Community in a list of <code>IPTURL</code>s.
     * Related Communities are Communities in the same administrative folder.
     * 
     * @param owner		Current Activityspace.
     * @return <code>XPArrayList</code> with <code>IPTURL</code>s to Related Communities or an empty <code>XPArrayList</code> if none exists.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetCurrentRelatedCommunitiesAsURLs(AActivitySpace owner)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        
        int nCurrCommID = GetCurrentCommunityID(owner);
         
        if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
    	 {
    	 	return new XPArrayList();
    	 }
        
        XPArrayList list = GetRelatedCommununitiesAsURLs(owner, nCurrCommID);

        return list;
    }

	/**
	 * Gets the URL to the parent Community of the current Community. 
     * Parent Community is the Community where the current Community is located in the administrative hierarchy.
	 * 
	 * @param owner		Current Activityspace.
	 * @return IPTURL to current Parent Community  or <code>null</code> if no parent Community exists, or if not currently
	 * in a Community.
	 * 
	 * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static IPTURL GetCurrentParentCommunityAsURL(AActivitySpace owner)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        
        int nCurrCommID = GetCurrentCommunityID(owner);
         
        if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCurrCommID) ) 
    	 {
    	 	return null;
    	 }
        
        IPTURL ptURL = GetParentCommunityAsURL(owner, nCurrCommID);

        return ptURL;
    }
	
	 /**
     * Gets the URL to the parent Community of the specified Community. 
     * Parent Community is the Community where the current Community is located in the administrative hierarchy.
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID
     * @return  IPTURL to current Parent Community  or <code>null</code> if no parent Community exists, or if the 
     * specified Community is invalid.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static IPTURL GetParentCommunityAsURL(AActivitySpace owner, int nCommunityID)
    {
        TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	 if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCommunityID) ) 
    	 {
    	 	return null;
    	 }
    	 IPTSession session = TaskAPIUICommon.GetPTSession(owner);
    	 
    	 // get the parent community
		 IPTQueryResult qrParentComm = null;
		 try {
			 qrParentComm = TaskAPIServerCommunity.GetCommunityParentComm(session, nCommunityID);
		 } catch (XPException e) {
			 log.Warn(e, "Exception encountered while retrieving Parent Community ID for Community: "+nCommunityID);
			 return null;
		 }
		 
		 IPTURL url = null;
    	 if ( qrParentComm.RowCount() == 1 )
		 {
	    	 // Get the pageid and page name from the queryresult
	    	 int nParentCommID = qrParentComm.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
	    	 String strParentCommName = qrParentComm.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
	    	 	
	    	 // Create a common opener url
	    	 url = CreateCommunityCommonOpenerURL(owner, nParentCommID, strParentCommName);
		 }
		 return url;
    }



    /**
     * Gets the Subcommunities for the specified Community as a list with <code>IPTURL</code> entries.
     * Subcommunities are Community located below another Community in the administrative hierarchy. 
     * 
     * @param owner		Current Activityspace.
     * @param nCommunityID	Object ID for the Community to get Subcommunities from.
     * @return	An <code>XPArrayList</code> with <code>IPTURL</code> entries to Subcommunities, or
     * empty array if the specified Community does no thave any Subcommunities or it is invalid.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetSubCommununitiesAsURLs(AActivitySpace owner, int nCommunityID)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	
    	if ( !TaskAPIUICommon.IsValidObjectIDArgument(nCommunityID) )
    	{
    		return new XPArrayList();
    	}
    	
    	IPTSession session = TaskAPIUICommon.GetPTSession(owner);
    	 
    	// get the subcommunities 
    	IPTQueryResult qrSubComms = TaskAPIServerCommunity.GetCommunitySubCommunities(session, nCommunityID);
    	 
    	// create the arraylist to return
    	XPArrayList list = new XPArrayList(qrSubComms.RowCount());
    	
    	for ( int i  = 0; i < qrSubComms.RowCount(); i++ ) {
    		// Get the pageid and page name from the queryresult
    		int nSubCommID = qrSubComms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
    		String strSubCommName = qrSubComms.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
    	 	
    		// Create a common opener url
    		IPTURL url = CreateCommunityCommonOpenerURL(owner, nSubCommID, strSubCommName);
    		// Add the link to the arraylist
    		list.Add(url);
    	}
    	return list;
    	
    }
    
    /**
     * Gets the default Community ID, the first Community in a user's My Community list.
     * 
     * @param owner		Current Activityspace.
     * @return	Object ID of the first Community in the current user's My Community list, or <code>-1</code> if
     * the user is not a member of any communities.
     * 
     * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static int GetDefaultCommunityID(AActivitySpace owner)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	
    	IPTQueryResult  ptCommMembership = null;
    	ptCommMembership = TaskAPIServerCommunity.GetMyCommunityMembership(TaskAPIUICommon.GetPTSession(owner), true );
    	if ( ptCommMembership.RowCount() == 0 ) {
    		return -1;
    	} else {
    		int nFirstCommunityID = ptCommMembership.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
    		return nFirstCommunityID; 
    	}
    	
    }

    /**
     * Gets a user's My Communities list as an <code>XPArrayList</code> with <code>IPTURL</code> entries.
     * The <code>PTURLConstants.KEY_CURRENTMARKER</code> flag is set on an URL entry if is leading to the current
     * Community. 
     * 
     * @param owner		Current Activityspace.	
     * @param bUseCachedData 	Get the current user's mandatory Communities with Tabs from a cache that contains at 
     * most 15 minutes old data if true. Will query the database for the mandatory communities if false.
     * @return	<code>XPArrayList</code> with <code>IPTURL</code>s to the current user's My Communities ,
     *  or <code>null</code> if Communities features is disabled in the current Experience Definition.
     *  
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetMyCommunitiesAsURLs(AActivitySpace owner, boolean bUseCachedData)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
        IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
		
		if ( TaskAPIUICommon.IsCurrentPageInPreviewMode(owner) )
		{
			return new XPArrayList();
		}
    	 
    	 IPTQueryResult qrMyComms = TaskAPIServerCommunity.GetMyCommunityMembership(ptSession, bUseCachedData);
    	 
    	 XPArrayList list = null;
    	 
    	 if ( null != qrMyComms && IsCommunityFeatureEnabledInSubPortal(owner) )
    	 {
    	 	list = new XPArrayList( qrMyComms.RowCount() );

    	 	int COL_COMM_NAME = 0;
			int COL_COMM_ID = 1;
			int NUM_COLS = 2;
			int[] arrColumns = new int[]{COL_COMM_NAME, COL_COMM_ID};

			int[][] arrSort							 					= new int[1][2];
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		= COL_COMM_NAME;
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]	= PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
			
			Object[][] arrData = new Object[NUM_COLS][qrMyComms.RowCount()];
			for (int i = 0; i < qrMyComms.RowCount(); i++)
			{
				arrData[COL_COMM_ID][i]		= new Integer(qrMyComms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID));
				arrData[COL_COMM_NAME][i]	= qrMyComms.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
			}
			PTSortedArrayWrapper saData = new PTSortedArrayWrapper();
			saData.Initialize(arrColumns, arrData, arrSort, true);
			
			for (int i = 0; i < saData.GetCount(); i++)
			{
				// Don't think we need to show no link for current comm
				int nCommID    					= XPConvert.ToInteger( saData.GetItem(i, COL_COMM_ID) );
				String strCommName  	= XPConvert.ToString( saData.GetItem(i, COL_COMM_NAME) );
				
				IPTURL url = CreateCommunityCommonOpenerURL(owner, nCommID, strCommName);
				
				list.Add(url);
				
			}
    	 	
    	 }
        return list;
    }

    /**
     * Gets a user's Mandatory with Tab Communities as an <code>XPArrayList</code>  with <code>IPTURL</code> entries. 
     * 
     * @param owner 		Current Activityspace.
     * @param bUseCachedData Get the current user's mandatory Communities with Tabs from a cache that contains at most 15 minutes old data if true. Will query the database 
     *  for the mandatory communities if false.
     * 
     * @return <code>XPArrayList</code> with <code>IPTURL</code>s to the current user's mandatory Communities with Tabs,
     *  or <code>null</code> if Communities features is disabled in the current Experience Definition.
     *  
     *  @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
     */
    public static XPArrayList GetMyMandatoryCommunitiesWithTabsAsURLs(AActivitySpace owner, boolean bUseCachedData)
    {
    	TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
    	IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
         
		if (TaskAPIUICommon.IsCurrentPageInPreviewMode(owner) )
		{
			return new XPArrayList();
		}
		
        IPTQueryResult ptMandComms = TaskAPIServerCommunity.GetMandatoryCommunitiesWithTabsForCurrentUser(ptSession, bUseCachedData);
        
        XPArrayList list = null;
        
        if ( null != ptMandComms )
        {
        	list = new XPArrayList(ptMandComms.RowCount());
        	
        	for ( int i = 0; i < ptMandComms.RowCount(); i++ )
        	{
	        	int nCommID    					= ptMandComms.ItemAsInt(i,PT_PROPIDS.PT_PROPID_OBJECTID);
				String strCommName  = ptMandComms.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
				
				IPTURL url = CreateCommunityCommonOpenerURL(owner, nCommID, strCommName);
				
				list.Add(url);
        	}
        	
        }
        
        return list;
    }
	
	/**
	 * Gets the Community ID from an IPTURL with an URL to a Community or Community Page.
	 * 
	 * @param ptURL	<code>IPTURL</code> to a Community or Community Page.
	 * @return The Community ID, or <code>0</code> if none is found in the URL.
	 * 
	 * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static int GetCommunityIDFromPTURL(IPTURL ptURL)
	{
		if ( null == ptURL ) {
			return 0;
		}
		
		int nCommID = 0;
		String strCommID = "";
		if ( ptURL instanceof CommonOpenerFriendlyURL ) {
			// DCA - handle profile community properly
			if (XPConvert.ToInteger(ptURL.GetData(CommonOpenerFriendlyURL.KEY_CLASSID)) == PT_CLASSIDS.PT_USER_ID) {
				nCommID = PT_INTRINSICS.PT_PROFILE_COMMUNITY;
			} else {
				strCommID = ptURL.GetData(CommonOpenerFriendlyURL.KEY_FRIENDLYURL_OBJECTID);
			}
		} else if ( ptURL instanceof CommonOpenerOpenObjIDURL ) {
			strCommID = ptURL.GetData(CommonOpenerOpenObjIDURL.KEY_COMMONOPENER_OBJECTID);
		} else {
			throw new XPException("Unsupported IPTURL type!");
		}
		
		
		if (null != strCommID && strCommID.length() > 0) {
			try {
				nCommID = XPConvert.ToInteger(strCommID);
			} catch (XPFormatException e) {
				// Don't do anything, we will just return the default page id
			}
		}
		
		return nCommID;
		
	}
	
	/**
	 * Gets the Community Page ID from an IPTURL with an URL to a Community Page.
	 * 
	 * @param ptURL		<code>IPTURL</code> to a Community Page.
	 * @return The Community Page ID, or <code>0</code> if none is found in the URL.
	 * 
	 * @throws XPIllegalAccessException			If the user does not have sufficient access to the Community.
	 */
	public static int GetCommunityPageIDFromPTURL(IPTURL ptURL)
	{
		if ( null == ptURL ) {
			return 0;
		}
		
		int nPageID = 0;
		String strPageID = null;
		if ( ptURL instanceof CommonOpenerFriendlyURL ) {
			strPageID = ptURL.GetData(CommonOpenerFriendlyURL.KEY_FRIENDLYURL_CHILDID);
		} else if ( ptURL instanceof CommonOpenerOpenObjIDURL ) {
			strPageID = ptURL.GetData(PTCommunities.STR_PAGE_ID);
		} else {
			throw new XPException("Unsupported IPTURL type!");
		}
		
		
		if ( null != strPageID )
		{
			try {
				nPageID = XPConvert.ToInteger(strPageID);
			} catch (XPFormatException e) {
				// Don't do anything, we will just return the default page id
			}
		}
		
		return nPageID;
		
	}
    
    
}

