package com.plumtree.taskapi.portalui;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This class manages instances of the ITaskAPIUIDirectory interface
 * for both production and testing purposes.
 * 
 * It is a replacement for the TaskAPIUIDirectory class, since that
 * class uses static methods and cannot be mocked for testing.
 */
public class TaskAPIUIDirectoryService implements ITaskAPIUIDirectory
{
	private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.taskapi.portalui.TaskAPIUIDirectoryService");

	private static ITaskAPIUIDirectory m_DEBUG_INSTANCE = null;

	/**
	 * @return An instance of the ITaskAPIUIDirectory interface.
	 */
	public static ITaskAPIUIDirectory GetInstance()
	{
		if (m_DEBUG_INSTANCE != null)
		{
			return m_DEBUG_INSTANCE;
		}

		return new TaskAPIUIDirectoryService();
	}

	/**
	 * This method sets the debug instance of the ITaskAPIUIDirectory interface
	 * for use as a mock object.  This should never be used in a production
	 * environment.
	 * 
	 * This should be reset to null at the end of testing to ensure other code
	 * does not get an old mock instance.
	 * 
	 * @param _instance The mock instance of the ITaskAPIUIDirectory interface.
	 * When the mock instance is done being used it should be reset to null by
	 * calling this method again with a null argument.
	 */
	public static void SetMockInstanceForDebug(ITaskAPIUIDirectory _instance)
	{
		m_DEBUG_INSTANCE = _instance;
	}

	/**
	 * Private constructor to force people to use the GetInstance() method..
	 */
	private TaskAPIUIDirectoryService() {}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#CreateCommonOpenerDirectoryFolderURL(AActivitySpace, Java.lang.String, int, int)
	 */
	public IPTURL CreateCommonOpenerDirectoryFolderURL(AActivitySpace owner,
			String strTitle, int nDirMode, int nFolderID) {
		return TaskAPIUIDirectory.CreateCommonOpenerDirectoryFolderURL(owner, strTitle, nDirMode, nFolderID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#CreateCommonOpenerDirectoryFolderURL(AActivitySpace, Java.lang.String, int, int, Java.lang.String)
	 */
	public IPTURL CreateCommonOpenerDirectoryFolderURL(AActivitySpace owner,
			String strTitle, int nDirMode, int nFolderID, String strFolderName) {
		return TaskAPIUIDirectory.CreateCommonOpenerDirectoryFolderURL(owner, strTitle, nDirMode, nFolderID, strFolderName);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#CreateCommonOpenerDocumentURL(AActivitySpace, Java.lang.String, int)
	 */
	public IPTURL CreateCommonOpenerDocumentURL(AActivitySpace owner,
			String strTitle, int nDocumentID) {
		return TaskAPIUIDirectory.CreateCommonOpenerDocumentURL(owner, strTitle, nDocumentID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#CreateCommonOpenerDocumentURL(AActivitySpace, Java.lang.String, int, Java.lang.String)
	 */
	public IPTURL CreateCommonOpenerDocumentURL(AActivitySpace owner,
			String strTitle, int nDocumentID, String strDocumentName) {
		return TaskAPIUIDirectory.CreateCommonOpenerDocumentURL(owner, strTitle, nDocumentID, strDocumentName);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#GetURLForBrowseDirectory(AActivitySpace, int)
	 */
	public IPTURL GetURLForBrowseDirectory(AActivitySpace owner, int nFolderID) {
		return TaskAPIUIDirectory.GetURLForBrowseDirectory(owner, nFolderID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#GetURLForEditDirectory(AActivitySpace, int)
	 */
	public IPTURL GetURLForEditDirectory(AActivitySpace owner, int nFolderID) {
		return TaskAPIUIDirectory.GetURLForEditDirectory(owner, nFolderID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#IsCurrentPageDirectoryPage(AActivitySpace)
	 */
	public boolean IsCurrentPageDirectoryPage(AActivitySpace owner) {
		return TaskAPIUIDirectory.IsCurrentPageDirectoryPage(owner);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#IsDirectoryFeaturedEnabledInSubPortal(AActivitySpace)
	 */
	public boolean IsDirectoryFeaturedEnabledInSubPortal(AActivitySpace owner) {
		return TaskAPIUIDirectory.IsDirectoryFeaturedEnabledInSubPortal(owner);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#GetSubmitDataSources(AActivitySpace)
	 */
	public IXPList GetSubmitDataSources(AActivitySpace owner)
	{
		// Todo share with dirmodel, which does similar processing in the views.

		IXPList results = new XPArrayList();
		
		// This method packages two sets of methods that are used commonly.
		// The first queries for the card submit web services, and the second
		// retrieves the names.  It's possible the first query could be redone
		// to retrieve the name in the future, but for now this method does
		// n+1 uncached queries.
		IPTSession session = (IPTSession) owner.GetUserSession();

		// Query for data sources with web services that have the card submit
		// simple bit mask set.  This query only returns object IDs, not names.
		// NOTE: The Publisher KD and Crawler Data Sources are set incorrectly
		// to be of type simple and advanced, but they are not (Bug#69636).
		IPTQueryResult ptQR = session.GetCatalog().GetCardSubmitDataSources(
			PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_SIMPLE);

		int[] nIDs = new int[ptQR.RowCount()];

		if ((nIDs == null) || (nIDs.length == 0))
		{
			// No data sources available for this user.
			return results;
		}

		// Gather all the object IDs into a query filter so we can get all the
		// object names in a single query.
		for (int i = 0; i < ptQR.RowCount(); i++)
		{
			nIDs[i] = ptQR.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
		}

		PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(session.GetDataSources());

		// Query for all the object names.
		omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME, -1, null,
			PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID,
			PT_FILTEROPS.PT_FILTEROP_IN, nIDs));

		// Combine the name and ID into a new format, in the same order as the original
		// query.
		for (int i = 0; i < ptQR.RowCount(); i++)
		{
			int nDataSourceID = ptQR.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);

			String strDataSourceName = null;

			// Search for the name that corresponds to this object ID.
			for (int j = 0; j < omqw.GetCount(); j++)
			{
				int nCurID = XPConvert.ToInteger(omqw.GetFields(j, PT_PROPIDS.PT_PROPID_OBJECTID));
				if (nCurID == nDataSourceID)
				{
					strDataSourceName = (String) omqw.GetFields(j, PT_PROPIDS.PT_PROPID_NAME);
					break;
				}
			}

			if (strDataSourceName == null)
			{
				// This should never happen.
				log.Error("Unable to find name for data source " + nDataSourceID);
			}

			// Add the data to the combined result
			HashtableDataObject source = new HashtableDataObject();
			source.SetData(SubmitDataSourceConstants.NAME, strDataSourceName);
			source.SetData(SubmitDataSourceConstants.ID, XPConvert.ToString(nDataSourceID));

			results.Add(source);
		}

		return results;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#AddWebServiceURLs(AActivitySpace, IXPList)
	 */
	public IXPList AddUploadData(AActivitySpace owner, IXPList _sources)
	{
		IPTSession session = (IPTSession) owner.GetUserSession();

		// NOTE: The Publisher KD and Crawler Data Sources are set incorrectly
		// to be of type simple and advanced, but they are not (Bug#69636).
		// Therefore, any data source in here that is not of type upload should
		// be removed from the list.
		IXPCollection invalid = new XPArrayList();

		for (int i = 0; i < _sources.GetSize(); i++)
		{
			HashtableDataObject source = (HashtableDataObject) _sources.GetElement(i);

			int nID = XPConvert.ToInteger(source.GetData(SubmitDataSourceConstants.ID));

			// Set an empty URL and web service ID for all sources.
			source.SetData(SubmitDataSourceConstants.URL, "");
			source.SetData(SubmitDataSourceConstants.WEB_SERVICE_ID, "");

			if (nID > 0)
			{
				IPTDataSource ptDataSource = (IPTDataSource) session.GetDataSources()
					.Open(nID, false);

				/* web data sources do not support upload */
				if (IsWebDataSource(ptDataSource, session))
				{
					source.SetData(SubmitDataSourceConstants.TYPE,
						SubmitDataSourceConstants.TYPE_WEB);					
				} else
				{
					source.SetData(SubmitDataSourceConstants.TYPE,
						SubmitDataSourceConstants.TYPE_FILE);

					int nWebServiceID = ptDataSource.GetWebServiceID();

					source.SetData(SubmitDataSourceConstants.WEB_SERVICE_ID, XPConvert.ToString(nWebServiceID));

					IPTWebService ptWebService = (IPTWebService) 
						session.GetWebServices().Open(nWebServiceID, false);

					// NOTE: The Publisher KD and Crawler Data Sources are set incorrectly
					// to be of type simple and advanced, but they are not (Bug#69636).
					// Therefore, any data source in here that is not of type upload should
					// be removed from the list.
					boolean bValidUpload = false;

					/* upload support is specified on the data source's web service */
					int type = ptWebService.GetCardSubmitType();

					// Check if this web service has the card submit upload bit flag
					if (0 != (type & 
							PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD))
					{
						// Not all web services have this URL.
						String strUploadUrl = ptWebService.
							GetAbsoluteURL(AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL);

						if ((strUploadUrl != null) && (strUploadUrl.length() > 0))
						{
							source.SetData(SubmitDataSourceConstants.URL, strUploadUrl);
							bValidUpload = true;
						}
					}

					if (!bValidUpload)
					{
						// Mark this source as invalid for later removal.
						invalid.Add(source);
					}
				}
			}
		}

		// Remove invalid data sources from the list.
		_sources.RemoveAll(invalid);

		return _sources;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.taskapi.portalui.ITaskAPIUIDirectory#IsWebDataSource(IPTDataSource, IPTSession)
	 */
	public boolean IsWebDataSource(IPTDataSource _dataSource, IPTSession _session)
	{
		try
		{
			String strProviderCLSID = _dataSource.GetDataSourceProviderCLSID();

			IPTClassTypeDescManager ptObjDescMgr = PTConfigService.getPTInstance().GetPTClassTypeDescrManager();

			String strProvEnglishName = ptObjDescMgr.GetProviderEnglishNameGivenCLSID(strProviderCLSID);

			IDocProvInfo docPI = (IDocProvInfo) ptObjDescMgr.GetRegisteredProvInfoGivenEnglishName(strProvEnglishName);

			return docPI.SupportsWebPaths();
		}
		catch (Exception e)
		{
			log.Error(e, "CardSubmitSimple - ITaskAPIUIDirectory::IsWebDataSource Error retrieving WebService on DataSource " +
				_dataSource.GetObjectID() + ".");

			return false;
		}
	}
}