package com.plumtree.taskapi.portalui;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * HTML Related TaskAPI functions.
 * 
 */
public class TaskAPIUIHTML
{

	/**
	 * Adds a spacer cell with a cell width of 4to the specified HTMLTableRow
	 * 
	 * @param myTableRow			HTMLTableRow to add the spacer cell to
	 */
	public static void CreateHorizontalSpacerCell(HTMLTableRow myTableRow)
	{
		NavigationCommonHelpers.CreateHorizontalSpacerCell(myTableRow);
	}

	/**
	 * Gets an HTML Image element for the specified Plumtree Image Construct.
	 * 
	 * @param owner		Current Activityspace.
	 * @param construct	A Plumtree Image Construct.
	 * @return	HTML img element created from the Plumtree Image Construct object.
	 */
	public static  HTMLImg GetImageConstruct(AActivitySpace owner,  PTConstructType construct)
	{
		return (HTMLImg)UIConstructFactory.GetConstruct(construct, true, owner).GetHTMLElement(); 
				
	}
	
	/**
	 * Gets a blank spacer image element with the specified width and height.
	 * 
	 * @param strWidth	Width value that goes directly into the width attribute in the HTML img element. 
	 * @param strHeight Height value that goes directly into the width attribute in the HTML img element.
	 * @return	HTMLImg element with a spacer image in the specified width and height. 
	 */
	public static HTMLImg GetSpacerImage(String strWidth, String strHeight)
	{
		return PlumtreeHelpers.GetSpacerImage(strWidth, strHeight);
		
	}

	/**
	 * Returns an HTML-encoded version of the input string, or
	 * empty string if input is null. 
	 * @param strValue a string of characters to encode for use as HTML text.
	 * @return an encoded version of the input, or empty string if <code>null</code>.
	 */
	public static String HTMLEncode(String strValue)
	{
		return XPHttpUtility.HtmlEncode(strValue);
	}
	
	/**
	 * Returns a decoded version of the input string, 
	 * assuming it was a valid HTML encoding.
	 * 
	 * @param strValue the string to decode.
	 * @return a decoded version of the input.
	 * @throws XPNullPointerException if input is <code>null</code>.
	 * @throws XPUnsupportedEncodingException if an invalid ampersand escape is found.
	 *  
	 */
	public static String HTMLDecode(String strValue)
	{
		return XPHttpUtility.HtmlDecode(strValue);
	}
	
	/**
	 * 
	 * @param e			Element to add table to, or null to not add it to any element
	 * @param padding	Table padding
	 * @param spacing	Table spacing
	 * @param width		Table width (in percentage or pixels) or null if no width is needed
	 * @return			HTMLTable element
	 */
	public static HTMLTable CreateTable(HTMLElement e, int padding, int spacing, String width)
	{
		HTMLTable table = new HTMLTable();
		if ( e != null ) {
			e.AddInnerHTMLElement(table);
		}
		table.SetCellPadding(padding+"");
		table.SetCellSpacing(spacing+"");
		if ( width != null && !"".equals(width) ) {
			table.SetWidth(width);
		}
		
		return table;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @return			HTMLTableRow element or null if e is null
	 */
	public static HTMLTableRow CreateTableRow(HTMLTable e, String style)
	{
		if (e == null ) { return null; }
		HTMLTableRow row = new HTMLTableRow();
		e.AddInnerHTMLElement(row);
		if ( style != null && !"".equals(style) ) {
			row.SetStyleClass(style);
		}
		
		return row;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @return			HTMLTableRow element or null if e is null
	 */
	public static HTMLTableRow CreateTableRow(HTMLTable e, PTStyleClass style)
	{
		if (e == null ) { return null; }
		HTMLTableRow row = CreateTableRow(e, style.GetStyleName());
		return row;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @return			HTMLTableCell element or null if e is null
	 */
	public static HTMLTableCell CreateTableCell(HTMLTableRow e, String style)
	{
		if (e == null ) { return null; }
		HTMLTableCell cell = new HTMLTableCell();
		e.AddInnerHTMLElement(cell);
		if ( style != null && !"".equals(style) ) {
			cell.SetStyleClass(style);
		}
		
		return cell;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @return			HTMLTableCell element or null if e is null
	 */
	public static HTMLTableCell CreateTableCell(HTMLTableRow e, PTStyleClass style)
	{
		if (e == null ) { return null; }
		HTMLTableCell cell = CreateTableCell(e, (style==null) ? null : style.GetStyleName());
		
		return cell;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @param height	Table cell height
	 * @param width		Table cell width (in percentage or pixels)
	 * @return			HTMLTableCell element or null if e is null
	 */
	public static HTMLTableCell CreateTableCell(HTMLTableRow e, String style, int height, String width)
	{
		if (e == null ) { return null; }
		HTMLTableCell cell = CreateTableCell(e, style);
		cell.SetHeight(height+"");
		cell.SetWidth(width);
		
		return cell;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @param height	Table cell height
	 * @param width		Table cell width (in percentage or pixels)
	 * @return			HTMLTableCell element or null if e is null
	 */
	public static HTMLTableCell CreateTableCell(HTMLTableRow e, PTStyleClass style, int height, String width)
	{
		if (e == null ) { return null; }
		HTMLTableCell cell = CreateTableCell(e, (style==null) ? null : style.GetStyleName(), height, width);
		
		return cell;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @param value		Content to add to table cell, string is html encoded
	 * @param height	Table cell height
	 * @param width		Table cell width (in percentage or pixels)
	 * @return			HTMLTableCell element or null if e is null
	 */
	public static HTMLTableCell CreateTableCell(HTMLTableRow e, String value, String style, int height, String width)
	{
		if (e == null ) { return null; }
		HTMLTableCell cell = CreateTableCell(e, style, height, width);
		if ( value != null ){
			cell.AddInnerHTMLEncodedString(value);
		}
		return cell;
	}
	
	/**
	 * 
	 * @param e			Element to add table to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @param value		Content to add to table cell, string is html encoded
	 * @param height	Table cell height
	 * @param width		Table cell width (in percentage or pixels)
	 * @return			HTMLTableCell element or null if e is null
	 */
	public static HTMLTableCell CreateTableCell(HTMLTableRow e, String value, PTStyleClass style, int height, String width)
	{
		if (e == null ) { return null; }
		
		HTMLTableCell cell = CreateTableCell(e, (style==null) ? null : style.GetStyleName(), height, width);
		if ( value != null ){
			cell.AddInnerHTMLEncodedString(value);
		}
		return cell;
	}
	
	/**
	 * 
	 * @param e			HTMLTableCell element to add span to
	 * @param style		CSS Style for the row or null if no style is needed
	 * @param content	Content to add to table cell, string is html encoded
	 * @return			The created HTMLSpan or null if e is null
	 */
	public static HTMLSpan CreateSpanToCell(HTMLTableCell e, PTStyleClass style, String content)
	{
		if (e == null ) { return null; }
		HTMLSpan span = new HTMLSpan();
		e.AddInnerHTMLElement(span);
		span.SetStyleClass(style);
		span.AddInnerHTMLEncodedString(content);
		return span;
	}
	
	/**
	 * 
	 * @param e			HTMLTableCell element to add span to
	 * @param type		Type of input element
	 * @param inputName	Input name 
	 * @param alt		Alt text
	 * @return	
	 */
	public static HTMLInput CreateInputToCell(HTMLTableCell e, HTMLInputTypes type, String inputName, String alt)
	{
		if (e == null ) { return null; }
		HTMLInput input = new HTMLInput(type, inputName, alt);
		e.AddInnerHTMLElement(input);
		return input;
	}
	
	
}
