/*
 * Created on Jan 12, 2005
 */
package com.plumtree.taskapi.portalui;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.utils.*;
import com.plumtree.xpshared.htmlelements.*;
/**
 * Javascript related TaskAPI functions.  
 * 
 */
public class TaskAPIUIJavascript
{
	/**
	 * Call this function to use SafeJSVars on a page.
	 * 
	 * Create the container to hold the safe variables.
	 * The container is just a javascript object and we but
	 * the vars on it as object properties.
	 * 
	 * 
	 * @return HTMLScript Element with javascript to initialize SafeJSVars .
	 */
	public static HTMLScript InitializeSafeJSVarElements()
	{
		return JSHelper.InitializeSafeJSVarElements();
	}
	
	/**
	 * Helper function to define a safe javascript variable.
	 * The safe variable will be defined in its on javascript block, so it won't
	 * affect any other javascript if the assigned value is invalid.
	 * 
	 * Reference it by using the javascript getSafeVariable or getSafeVariableWarn
	 * helper functions or <code>GetSafeJSVariable</code> or <code>GetSafeJSVariableWarn
	 * </code> java helper functions to generate the javascript calls.
	 * 
	 * NOTE: The strValue is the string with the javascript value so don't surround
	 * it with quotes. For javascript string values, use the <code>AddSafeJSStringVariable</code>
	 * method.
	 * E.g. 
	 * 
	 * <code>strValue = new Object()</code> - will assign a new object to the variable while
	 * <code>strValue = "new Object()"</code> - will assign the string "new Object()"   
	 * 
	 * @param strName	Name of the variable to create. Should be unqiue from other name on a page. 
	 * @param strValue   Value of the variable. Either a number or a reference to another javascript variable.
	 * @return HTMLScript	Javascript element with javascript to create the specfied variable. 
	 * 
	 * @see AddSafeJSVariable, GetSafeJSVariable, GetSafeJSVariableWarn
	 */
	public static HTMLScript AddSafeJSVariable(String strName, String strValue)
	{
		return JSHelper.AddSafeJSVariable(strName, strValue);
	}
	
	/**
	 * Helper function to define a safe javascript variable.
	 * The safe variable will be defined in its on javascript block, so it won't
	 * affect any other javascript if the assigned value is invalid.
	 * 
	 * Reference it by using the javascript getSafeVariable or getSafeVariableWarn
	 * helper functions or <code>GetSafeJSVariable</code> or <code>GetSafeJSVariableWarn
	 * </code> java helper 	 * functions to generate the javascript calls.
	 * 
	 * Adds quotes around the provided String and escapes any quotes and whitespace in the string.  
	 * For example, passing in 'Text' (without quotes) will create a javascript string with the value Text.
	 *  
	 * @param strName	Name of the variable to create. Should be unqiue from other name on a page. 
	 * @param strValue   String value of the variable. 
	 * @return HTMLScript	Javascript element with javascript to create the specfied variable.
	 */
	public static HTMLScript AddSafeJSStringVariable(String strName, String strValue)
	{
		return JSHelper.AddSafeJSVariable(strName, "'"+TaskAPIUIJavascript.EscapeJavaScriptString( strValue)+"'");
	}
	
	/**
	 * Helper function to retrieve a safe javascript variable.
	 * The javascript function will return <code>false</code> if it is unable
	 * to get the variable.
	 * 
	 * @param strName	Name of the variable to retrieve.
	 * @return String  		A string with Javascript code to retrieve the named SafeJS variable. The
	 * <code>String</code> should be added to a <code>HTMLScript</code> element.
	 * 
	 * @see InitializeSafeJSVarElements, AddSafeJSVariable, GetSafeJSVariableWarn
	 */
	public static String GetSafeJSVariable(String strName)
	{
		return JSHelper.GetSafeJSVariable(strName);
	
	}
	
	/**
	 * Helper function to retrieve a safe javascript variable.
	 * The javascript function will display a javascript alert error with the name of the variable. 
	 * Use for critical variables that absolutely need to be defined for a page to function.
	 * 
	 * @param strName	Name of the variable to retrieve.
	 * @return String  		A string with Javascript code to retrieve the named SafeJS variable. The
	 * <code>String</code> should be added to a <code>HTMLScript</code> element.
	 * 
	 * @see InitializeSafeJSVarElements, AddSafeJSVariable, GetSafeJSVariable
	 */
	public static String GetSafeJSVariableWarn(String strName)
	{
		return JSHelper.GetSafeJSVariableWarn(strName);
	}
	
	/**
	 * 
	 * 
	 * @param strFunctionName
	 * @return
	 */
	public static JSFunctionCallBuilder GetJSFunctionCallBuilder(String strFunctionName)
	{
		return new JSFunctionCallBuilder(strFunctionName);
	}
	
	/**
	 * Returns a new helper object to generate a <code>String</code> with javascript code to declare
	 * a one-dimensional array.  
	 * 
	 * @return	JS1DArrayBuilder object.
	 */
	public static JS1DArrayBuilder GetJS1DArrayBuilder()
	{
		return new JS1DArrayBuilder();
	}
	
	/**
	 * Returns a new helper object to generate a <code>String</code> with javascript code to declare
	 * a two-dimensional array.
	 * 
	 * @param nColumnCount Number of columns in the array.
	 * @return JS2DArrayBuilder object.
	 */
	public static JS2DArrayBuilder GetJS2DArrayBuilder(int nColumnCount)
	{
		return new JS2DArrayBuilder(nColumnCount);
	}
	
	/**
	 * Escapes a string to use with javascript. Escapes characters such as carriage returns,
	 * tabs and < and >.
	 * 
	 * @param strJSString	<code>String</code> to escape. 
	 * @return Escaped string or empty string if provided string is <code>null</code>.
	 */
	public static String EscapeJavaScriptString(String strJSString)
	{
		return JSHelper.escapeJS(strJSString);
	}
	
	
	/**
	 * Generates javascript to include  specified jscomponent onto the page. 
	 * 
	 * @param strComponentName	Name of the JSComponent. Constants for the JSComponents are defined in
	 * <code>ConfigHelper</code>.
	 * @param locale		The locale to use in the jscomponent. Will affect language and date/time formats. 
	 * @param owner		Current Activityspace.
	 * 
	 * @see ConfigHelper
	 * 
	 * @return	<code>HTMLElementCollection</code> with a script element that includes the specified jscomponent. 
	 */
	public static HTMLElementCollection GenerateJSComponentInclude(String strComponentName, XPLocale locale, AActivitySpace owner)
	{
		TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
		return ConfigHelper.GetJSIncluderJSComponentInclude(strComponentName, false, owner, locale);
	}
	
	
}
