package com.plumtree.taskapi.portalui;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portalpages.browsing.search.network.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * Search related TaskAPI functions.  
 * 
 */
public class TaskAPIUISearch
{
	
	private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.taskapi.portalui.TaskAPIUISearch");
	
	/**
	 * Gets an URL to the Advanced Search Page.   
	 * 
	 * @param owner		Current Activityspace.
	 * @return	<code>IPTURL</code> with the URL to the Advanced Search Page.
	 */
	public static IPTURL GetURLForAdvancedSearchPage(AActivitySpace owner)
	{
		String strPageName = owner.GetName();
		if ((XPStringUtility.CompareIgnoreCase(strPageName,SearchResultAS.STR_MVC_CLASS_NAME) != 0) &&
				(XPStringUtility.CompareIgnoreCase(strPageName, AdvancedSearchAS.STR_MVC_CLASS_NAME) !=0))
		{
			String strText = owner.GetString(339, "ptmsgs_portalcommonmsgs");
			String strApplBaseURL =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
			String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
			int nUserID = TaskAPIUIUser.GetCurrentUserID(owner);
	
			CommonOpenerOpenASURL url = new CommonOpenerOpenASURL(strText, strApplBaseURL, AdvancedSearchAS.STR_MVC_CLASS_NAME, nUserID);
			url.AddControlParameter(ASConstants.CONTROL , EditorStartControl.STR_MVC_CLASS_NAME);
			url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
	
			url.SetURLImageType(PTImageType.ACTION_SEARCH_BUTTON_ADVANCED, strImageServerURL);
			
			return url;
		} else {
			return null;
		}
	}
	
	/**
	 * Gets an URL to the Federated Search Page
	 * 
	 * @param owner		Current Activityspace.
	 * @return <code>IPTURL</code> with the URL to the Federated Search Page.
	 */
	public static IPTURL GetURLForFederatedSearchPage(AActivitySpace owner)
	{
		String strText = owner.GetString(340, "ptmsgs_portalcommonmsgs");
		String strApplBaseURL =  TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
		String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
		int nUserID = TaskAPIUIUser.GetCurrentUserID(owner);

		CommonOpenerOpenASURL url = new CommonOpenerOpenASURL(strText, strApplBaseURL, NetworkSearchAS.STR_MVC_CLASS_NAME, nUserID);

		url.SetURLImageType(PTImageType.ACTION_SEARCH_BUTTON_NETWORK, strImageServerURL);
		
		return url;
	}
}
