package com.plumtree.portalpages.browsing.mock.myportal;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.ASURL;

/**
 * @author btse
 *
 */
public class MockMyPortalModel extends MyPortalModel implements IMyPortalModelRO, IMyPortalModel 
{
	// TODO CR DLH: package should be com.plumtree.portalpages.mock.browsing.myportal
	protected String KEY_PORTLETNAME = "name";
	protected String KEY_PORTLETID = "objid";
	protected String KEY_PORTLETREGION = "region";
	protected String KEY_PAGE = "pageId";
	
	public int m_pageId = 0;
	public int m_commId = 0;
	// start object ids at 200
	public int m_idcounter = 200;
	public int m_nRegions = 1;
	public String m_strRawHeaders = "";
	private XPArrayList m_RecentlyAddedPortlets = new XPArrayList();
	private int m_nRecentlyRemovedPortlet = 0;

	public XPArrayList m_regions = new XPArrayList();
	
	/**
	 * 
	 */
	public MockMyPortalModel(int regions) 
	{
		m_nRegions = regions;
		
		// initialize regions list with list of portlets
		for ( int i = 0; i < m_nRegions; i++ ) {
			m_regions.Add(new XPArrayList());
		}
	}
	
	public int GetPortletCount()
	{
		int count = 0;
		for ( int i = 0; i < m_regions.GetSize(); i++ ) {
			count += ((XPArrayList)m_regions.GetElement(i)).GetSize();
		}
		return count;
	}
	
	/**
	 * Helper function to reset the portlet columns.
	 * 
	 * @return XPHashtable
	 */
	public void ResetPortletColumns()
	{
		m_regions.Clear();
		
		// initialize regions list with list of portlets
		for ( int i = 0; i < m_nRegions; i++ ) {
			m_regions.Add(new XPArrayList());
		}
	}	
	
	/**
	 * Internal hepler function to lookup the portlet object from main index
	 * 
	 * Portlets are indexed by their order in a region and the region order so
	 * index = 0 starts with the first portlet in the first region. 
	 * 
	 * @param index
	 * @return XPHashtable
	 */
	protected XPHashtable GetPortletFromIndex(int index)
	{
		int totalCount = 0;
		for ( int i = 0; i < m_regions.GetSize(); i++ ) {
			int curCount = ((XPArrayList)m_regions.GetElement(i)).GetSize();
			
			// comparing size with index, so add 1 to index
			if ( (totalCount+curCount) >= index+1  ) {
				// we know the portlet is in the current region, calculate the index within the region
				int regionIndex = index-totalCount;
				
				XPHashtable portlet = (XPHashtable)((XPArrayList)m_regions.GetElement(i)).GetElement(regionIndex);
				return portlet;
			}
			totalCount += curCount;
		}
		throw new XPIllegalArgumentException("Invalid portlet index: "+index);
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetFirstPortletIndexInColumn(int)
	 */
	public int GetFirstPortletIndexInColumn(int nPortletColumn)
	{
		XPArrayList arrPortletColumn = (XPArrayList)m_regions.GetElement(nPortletColumn);
		int nPortletID = -1;
		
		if (arrPortletColumn.GetSize() > 0)
		{
			XPHashtable portlet = (XPHashtable)arrPortletColumn.GetElement(0);
			Integer id = (Integer)portlet.GetElement(KEY_PORTLETID);
			nPortletID = id.intValue();
		}
		
		return nPortletID;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetLastPortletIndexInColumn(int)
	 */
	public int GetLastPortletIndexInColumn(int nPortletColumn) 
	{
		XPArrayList arrPortletColumn = (XPArrayList)m_regions.GetElement(nPortletColumn);
		int nPortletID = -1;
		
		if (arrPortletColumn.GetSize() > 0)
		{
			XPHashtable portlet = (XPHashtable)arrPortletColumn.GetElement(arrPortletColumn.GetSize()-1);
			Integer id = (Integer)portlet.GetElement(KEY_PORTLETID);
			nPortletID = id.intValue();
		}
		
		return nPortletID;
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletColumnFromIndex(int)
	 */
	public int GetPortletColumnFromIndex(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		Integer region = (Integer)portlet.GetElement(KEY_PORTLETREGION);
		
		return region.intValue();
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletIDFromIndex(int)
	 */
	public int GetPortletIDFromIndex(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		Integer id = (Integer)portlet.GetElement(KEY_PORTLETID);
		
		return id.intValue();
		
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletNameFromIndex(int)
	 */
	public String GetPortletNameFromIndex(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String name = (String)portlet.GetElement(KEY_PORTLETNAME);
		
		return name;
		
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#IsGuestSession(AActivitySpace)
	 */	
	public static boolean IsGuestSession(AActivitySpace owner) {
		// Assume non-guest user.
		return false;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#SetProfileID(int)
	 */
	public boolean SetProfileID(int profileID) {
		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#SetPage(int)
	 */
	public boolean SetPage(int nPageID) {
		m_pageId = nPageID;
		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetRecentlyAddedPortlets()
	 */
	public XPArrayList GetRecentlyAddedPortlets() 
	{
		return m_RecentlyAddedPortlets;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#ResetRecentlyAddedPortlets()
	 */
	public void ResetRecentlyAddedPortlets() 
	{
		m_RecentlyAddedPortlets = new XPArrayList();
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetRecentlyRemovedPortlet()
	 */
	public int GetRecentlyRemovedPortlet() 
	{
		return m_nRecentlyRemovedPortlet;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#ResetRecentlyRemovedPortlet()
	 */
	public void ResetRecentlyRemovedPortlet() 
	{
		m_nRecentlyRemovedPortlet = 0;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#SetRawHeaders(String)
	 */
	public void SetRawHeaders(String strRawHeaders)
	{
		m_strRawHeaders = strRawHeaders;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#AddSinglePortlet(int, int)
	 */
	public void AddSinglePortlet(int nPageID, int nPortletID) 
	{
		// Check to see if gadget is already in the page
		Integer nPortletId;
		boolean bIsInPage = false;

		for (int i = 0; i < ((XPArrayList)m_regions.GetElement(0)).GetSize(); i++)
		{
			XPHashtable portlet = (XPHashtable)((XPArrayList)m_regions.GetElement(0)).GetElement(i);			
			nPortletId = (Integer)portlet.GetElement(KEY_PORTLETID);

			if (nPortletId.intValue() == nPortletID)
			{
				bIsInPage = true;
				break;
			}
		}
		
		if (!bIsInPage)
		{
			// add the gadget to the first column in the page
			// regions are 0 based in list
			// TODO: Mock up PTPage/PTGadget so that we can differentiate
			// portlet alignment and add to the appropriate column?
			XPHashtable table = new XPHashtable();
			table.PutElement(KEY_PORTLETID, new Integer(nPortletID));
			table.PutElement(KEY_PORTLETNAME, "portlet"+nPortletID);
			table.PutElement(KEY_PAGE, new Integer(nPageID));
			table.PutElement(KEY_PORTLETREGION, new Integer(0));
			((XPArrayList)m_regions.GetElement(0)).Add(table);
			
			m_RecentlyAddedPortlets.Add(new Integer(nPortletID));
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#RemoveSinglePortlet(int, int)
	 */
	public void RemoveSinglePortlet(int nPageID, int nPortletID) {
		// Check to see if portlet is already in the page
		Integer portletId;
		int index = -1;
		boolean bIsInPage = false;

		for (int i = 0; i < ((XPArrayList)m_regions.GetElement(0)).GetSize(); i++)
		{
			XPHashtable portlet = (XPHashtable)((XPArrayList)m_regions.GetElement(0)).GetElement(i);			
			portletId = (Integer)portlet.GetElement(KEY_PORTLETID);

			if (portletId.intValue() == nPortletID)
			{
				bIsInPage = true;
				index = i;
				break;
			}
		}
		
		if (bIsInPage)
		{
			// TODO: Mock up PTPage to remove the portlet appropriately
			// rather than just from the first column in this array list?
			((XPArrayList)m_regions.GetElement(0)).RemoveAt(index);
			
			m_nRecentlyRemovedPortlet = nPortletID;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#CollapsePortlet(int, int, int)
	 */
	public void CollapsePortlet(int communityID, int pageID,
			int portletToCollapse) {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#ExpandPortlet(int, int, int)
	 */
	public void ExpandPortlet(int communityID, int pageID, int portletToExpand) {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#ReassignPortlets(int[], int, int)
	 */
	public void ReassignPortlets(int[] arrPortletIDs, int column, int pageID) {
		// Simulate PTPage::AssignPortlets. This will remove the current portlets 
		// in the column first before adding the portlets in arrPortletIDs.

		// Remove the current portlets in the column first.
		while (0 < ((XPArrayList)m_regions.GetElement(column)).GetSize())
		{
			((XPArrayList)m_regions.GetElement(column)).RemoveAt(0);
		}

		// add the list of portlets to the specified column in the page
		// regions are 0 based in list
		for (int j = 0; j < arrPortletIDs.length; j++)
		{
			XPHashtable table = new XPHashtable();
			table.PutElement(KEY_PORTLETID, new Integer(arrPortletIDs[j]));
			table.PutElement(KEY_PORTLETNAME, "portlet"+arrPortletIDs[j]);
			table.PutElement(KEY_PAGE, new Integer(pageID));
			table.PutElement(KEY_PORTLETREGION, new Integer(column));
			((XPArrayList)m_regions.GetElement(column)).Add(table);
		}
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetCollapsedOrErrorContent(int)
	 */
	public Object[][] GetCollapsedOrErrorContent(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetCommunityID()
	 */
	public int GetCommunityID() {
		// TODO Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetCommunityName()
	 */
	public String GetCommunityName() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetCommunityPages()
	 */
	public IPTQueryResult GetCommunityPages() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetDisplayPortletHeaderDueToError(int)
	 */
	public boolean GetDisplayPortletHeaderDueToError(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetHelper()
	 */
	public IMyPortalModelHelper GetHelper() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetIDStringForPortlet(int)
	 */
	public String GetIDStringForPortlet(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetIsCommunityPage()
	 */
	public boolean GetIsCommunityPage() {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageASURL()
	 */
	public ASURL GetPageASURL() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageID()
	 */
	public int GetPageID() {
		// TODO Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageName()
	 */
	public String GetPageName() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageType()
	 */
	public int GetPageType() {
		// TODO Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletAdminPrefsURL(int)
	 */
	public String GetPortletAdminPrefsURL(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletCollapseExpandURL(int, java.lang.String)
	 */
	public String GetPortletCollapseExpandURL(int portletIndex,
			String strControl) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletCollapsed(int)
	 */
	public boolean GetPortletCollapsed(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletCommunityPrefsURL(int)
	 */
	public String GetPortletCommunityPrefsURL(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletDisabledMessage(int)
	 */
	public String GetPortletDisabledMessage(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletEnabled(int)
	 */
	public boolean GetPortletEnabled(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHTMLTextFromIndex(int)
	 */
	public Object[][] GetPortletHTMLTextFromIndex(int gadgetIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasAdminPrefsURL(int)
	 */
	public boolean GetPortletHasAdminPrefsURL(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasCollapseExpandURL(int)
	 */
	public boolean GetPortletHasCollapseExpandURL(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasCommunityPrefsURL(int)
	 */
	public boolean GetPortletHasCommunityPrefsURL(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasHelpURL(int)
	 */
	public boolean GetPortletHasHelpURL(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasRefreshButton(int)
	 */
	public boolean GetPortletHasRefreshButton(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasTitleBar(int)
	 */
	public boolean GetPortletHasTitleBar(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasUserPrefsURL(int)
	 */
	public boolean GetPortletHasUserPrefsURL(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHelpURL(int)
	 */
	public String GetPortletHelpURL(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletIsMandatory(int)
	 */
	public boolean GetPortletIsMandatory(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletLayoutId()
	 */
	public int GetPortletLayoutId() {
		// TODO Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletPrefButtonBoolean()
	 */
	public String GetPortletPrefButtonBoolean() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletRemoveURL(int)
	 */
	public String GetPortletRemoveURL(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletSupports508(int)
	 */
	public boolean GetPortletSupports508(int portletIndex) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletSupportsPersonalization(int)
	 */
	public int GetPortletSupportsPersonalization(int portletIndex) {
		// TODO Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletUUID(int)
	 */
	public String GetPortletUUID(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletUserPrefsURL(int)
	 */
	public String GetPortletUserPrefsURL(int portletIndex) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetSession()
	 */
	public IPTSession GetSession() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#QuerySinglePortletContent(int)
	 */
	public void QuerySinglePortletContent(int portletId) {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#SetDisplayPortletHeaderDueToError(int, boolean)
	 */
	public void SetDisplayPortletHeaderDueToError(int portletIndex,
			boolean displayHeader) {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#UsesPortletLayout()
	 */
	public boolean UsesPortletLayout() {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName() {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#SetCommunity(int, int)
	 */
	public boolean SetCommunity(int communityID, int pageID) {
		// TODO Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModel#SetIsPreviewPage(boolean)
	 */
	public void SetIsPreviewPage(boolean isPreviewPage) {
		// TODO Auto-generated method stub

	}
}
