package com.plumtree.portalpages.test.admin.serversettings.general;

import junit.framework.*;

import com.plumtree.openfoundation.mockobjects.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.serversettings.general.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This class tests the basic get/set functionality of the server
 * settings model where possible/easy.
 */
public class SetServerSettingsModelTest extends TestCase
{
	//  Test Data
	public static final int PASSWORD_LENGTH = 7;
	public static final int PASSWORD_REUSE_HISTORY = 4;
	public static final int PASSWORD_EXPIRATION = 90;
	public static final int PASSWORD_EXPIRATION_WARNING = 5;

	protected SetServerSettingsModel m_model;

	protected IApplication m_application = null;
	protected AActivitySpace m_asParent = null;
	protected MockPTSession m_userSession = null;
	protected ISessionManager m_subSession = null;

	/*
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() throws Exception 
	{
		m_application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), m_application);

   		m_asParent = new MockEnvironment();

   		m_subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
   		m_asParent.SetSubSession(m_subSession);

   		m_userSession = new MockPTSession();
   		m_asParent.SetUserSession(m_userSession);

   		m_model = new SetServerSettingsModel();
   		m_model.Init(m_asParent);
	}

	/* 
	 * @see junit.framework.TestCase#tearDown()
	 */
	public void tearDown() throws Exception 
	{
		m_model = null;
	}

	/**
	 * This method tests saving the page in the SetServerSettingsModel
	 * and verifying the results.
	 */
	public void testSetSettings()
	{
		// Test defaults
		Assert.assertEquals("Password Length default is not correct.",
			-1, m_model.GetPasswordLength());
		Assert.assertEquals("Password Include Numbers default is not correct.",
			false, m_model.GetPasswordIncludeNumbers());
		Assert.assertEquals("Password Include Casing default is not correct.",
			false, m_model.GetPasswordIncludeCasing());
		Assert.assertEquals("Password Include Punctuation default is not correct.",
			false, m_model.GetPasswordNoUserIDs());
		Assert.assertEquals("Password No User IDs default is not correct.",
			false, m_model.GetPasswordNoUserIDs());
		Assert.assertEquals("Password Reuse History default is not correct.",
			-1, m_model.GetPasswordReuseHistory());
		Assert.assertEquals("Password Expiration default is not correct.",
			-1, m_model.GetPasswordExpiration());
		Assert.assertEquals("Password Expiration Warning default is not correct.",
			-1, m_model.GetPasswordExpirationWarning());

		// Fill out required control arguments to add a portlet
		XPHashtable htArgs = new XPHashtable();
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_LENGTH,
			new String[] {XPConvert.ToString(PASSWORD_LENGTH)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_NUMBERS,
			new String[] {XPConvert.ToString(true)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_CASING,
			new String[] {XPConvert.ToString(true)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_PUNCTUATION,
			new String[] {XPConvert.ToString(true)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_NO_USER_IDS,
			new String[] {XPConvert.ToString(true)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_REUSE_HISTORY,
			new String[] {XPConvert.ToString(PASSWORD_REUSE_HISTORY)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION,
			new String[] {XPConvert.ToString(PASSWORD_EXPIRATION)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION_WARNING,
			new String[] {XPConvert.ToString(PASSWORD_EXPIRATION_WARNING)});
		
		// Test saving page
		int nPageStatus = m_model.SavePage(UserSettingsDP.STR_MVC_CLASS_NAME, htArgs);

		Assert.assertEquals("Page Status is incorrect after saving page.", RepostControl.PAGE_STATUS_VALID, nPageStatus);

		Assert.assertEquals("Password Length was not updated correctly.",
			PASSWORD_LENGTH, m_model.GetPasswordLength());
		Assert.assertEquals("Password Include Numbers was not updated correctly.",
			true, m_model.GetPasswordIncludeNumbers());
		Assert.assertEquals("Password Include Casing was not updated correctly.",
			true, m_model.GetPasswordIncludeCasing());
		Assert.assertEquals("Password Include Punctuation was not updated correctly.",
			true, m_model.GetPasswordIncludePunctuation());
		Assert.assertEquals("Password No User IDs was not updated correctly.",
			true, m_model.GetPasswordNoUserIDs());
		Assert.assertEquals("Password Reuse History was not updated correctly.",
			PASSWORD_REUSE_HISTORY, m_model.GetPasswordReuseHistory());
		Assert.assertEquals("Password Expiration was not updated correctly.",
			PASSWORD_EXPIRATION, m_model.GetPasswordExpiration());
		Assert.assertEquals("Password Expiration Warning was not updated correctly.",
			PASSWORD_EXPIRATION_WARNING, m_model.GetPasswordExpirationWarning());
	}

	/**
	 * This method tests the validation while saving the page in the SetServerSettingsModel.
	 */
	public void testSetSettingsValidation()
	{
		// Test defaults
		Assert.assertEquals("Password Length default is not correct.",
			-1, m_model.GetPasswordLength());
		Assert.assertEquals("Password Reuse History default is not correct.",
			-1, m_model.GetPasswordReuseHistory());
		Assert.assertEquals("Password Expiration default is not correct.",
			-1, m_model.GetPasswordExpiration());
		Assert.assertEquals("Password Expiration Warning default is not correct.",
			-1, m_model.GetPasswordExpirationWarning());

		// Fill out control arguments
		XPHashtable htArgs = new XPHashtable();
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_LENGTH,
			new String[] {XPConvert.ToString(4)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_REUSE_HISTORY,
			new String[] {XPConvert.ToString(15)});
		
		// Test saving page
		int nPageStatus = m_model.SavePage(UserSettingsDP.STR_MVC_CLASS_NAME, htArgs);

		Assert.assertEquals("Page Status is incorrect after saving invalid page.", RepostControl.PAGE_STATUS_INVALID, nPageStatus);

		IXPEnumerator errors = UIErrorHandler.GetErrors(m_subSession, m_application, null, true, false);
		Assert.assertTrue("Failed validation should have raised UI errors.", errors.MoveNext());

		Assert.assertEquals("Password Length was updated with invalid data.",
			-1, m_model.GetPasswordLength());
		Assert.assertEquals("Password Reuse History was updated with invalid data.",
			-1, m_model.GetPasswordReuseHistory());

		// Fill out control arguments
		htArgs = new XPHashtable();
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_LENGTH,
			new String[] {XPConvert.ToString(400)});
		
		// Test saving page
		nPageStatus = m_model.SavePage(UserSettingsDP.STR_MVC_CLASS_NAME, htArgs);

		Assert.assertEquals("Page Status is incorrect after saving invalid page.", RepostControl.PAGE_STATUS_INVALID, nPageStatus);

		errors = UIErrorHandler.GetErrors(m_subSession, m_application, null, true, false);
		Assert.assertTrue("Failed validation should have raised UI errors.", errors.MoveNext());

		Assert.assertEquals("Password Length was updated with invalid data.",
			-1, m_model.GetPasswordLength());

		// Fill out required control arguments to add a portlet
		htArgs = new XPHashtable();
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_LENGTH,
			new String[] {XPConvert.ToString(-5)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_REUSE_HISTORY,
			new String[] {XPConvert.ToString(-5)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION,
			new String[] {XPConvert.ToString(-5)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION_WARNING,
			new String[] {XPConvert.ToString(-5)});
		
		// Test saving page
		nPageStatus = m_model.SavePage(UserSettingsDP.STR_MVC_CLASS_NAME, htArgs);

		Assert.assertEquals("Page Status is incorrect after saving invalid page.", RepostControl.PAGE_STATUS_INVALID, nPageStatus);

		errors = UIErrorHandler.GetErrors(m_subSession, m_application, null, true, false);
		Assert.assertTrue("Failed validation should have raised UI errors.", errors.MoveNext());

		Assert.assertEquals("Password Length was updated with invalid negative data.",
			-1, m_model.GetPasswordLength());
		Assert.assertEquals("Password Reuse History was updated with invalid negative data.",
			-1, m_model.GetPasswordReuseHistory());
		Assert.assertEquals("Password Expiration was updated with invalid negative data.",
			-1, m_model.GetPasswordExpiration());
		Assert.assertEquals("Password Expiration Warning was updated with invalid negative data.",
			-1, m_model.GetPasswordExpirationWarning());

		// Test expiration warning failure last, since it will set a valid password expiration value.

		// Fill out control arguments
		htArgs = new XPHashtable();
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION,
			new String[] {XPConvert.ToString(5)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION_WARNING,
			new String[] {XPConvert.ToString(10)});	

		// Test saving page
		nPageStatus = m_model.SavePage(UserSettingsDP.STR_MVC_CLASS_NAME, htArgs);

		Assert.assertEquals("Page Status is incorrect after saving invalid page.", RepostControl.PAGE_STATUS_INVALID, nPageStatus);

		errors = UIErrorHandler.GetErrors(m_subSession, m_application, null, true, false);
		Assert.assertTrue("Failed validation should have raised UI errors.", errors.MoveNext());

		Assert.assertEquals("Password Expiration Warning was updated with invalid data.",
			-1, m_model.GetPasswordExpirationWarning());
	}

	/**
	 * Make sure we can set both to 0 (there was a bug about this earlier).
	 */
	public void testDisabledExpirationAndWarningValidation()
	{
		// Fill out control arguments
		XPHashtable htArgs = new XPHashtable();
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION,
			new String[] {XPConvert.ToString(0)});
		htArgs.PutElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION_WARNING,
			new String[] {XPConvert.ToString(0)});	

		// Test saving page
		int nPageStatus = m_model.SavePage(UserSettingsDP.STR_MVC_CLASS_NAME, htArgs);

		Assert.assertEquals("Page Status is incorrect after saving valid page.", RepostControl.PAGE_STATUS_VALID, nPageStatus);
	}
}