package com.plumtree.portalpages.test.browsing.myportal;

import junit.framework.*;

import com.plumtree.openfoundation.mockobjects.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.mock.myportal.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This class tests adding and removing portlets via the AddRemoveControl
 * 
 * In general, the tests will use a MockMyPortalModel for interaction between
 * the control and the model and verify the results.
 * 
 * @author btse
 *
 */
public class AddRemovePortletControlTest extends TestCase
{
	protected int nCommunityId = 200;
	protected int nPageId = 300;
	protected int nPortletId = 3;
	protected AddRemovePortletControl testObject = null;
	protected AActivitySpace asParent = null;
	protected MockPTSession userSession = null;
	protected MockMyPortalModel myPortalModel = null;
	public ISessionManager subSession = null;
	public MockPTConfigHelper m_helper;
	
	/**
	 */
	public AddRemovePortletControlTest(String name)
   	{
		super(name);
   	}
	
	/*
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() throws Exception 
	{
		IApplication application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
   		XPHashtable htLookupTable = new XPHashtable();
		htLookupTable.PutElement(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID+"", "mypage");
   		
   		IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
		friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, friendlyURLManager);
		
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);
		
		testObject = new AddRemovePortletControl();
   		asParent = new MockEnvironment();
   		subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
   		subSession.SetAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG, "true");
   		asParent.SetPersistentSubSession(subSession);
   		userSession = new MockPTSession();
   		asParent.SetUserSession(userSession);
   		myPortalModel = new MockMyPortalModel(3);
		testObject.Init(myPortalModel, asParent);

		IXPRequest request = null;

   		try 
   		{
   			request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/mypage/home_page/");
   			asParent.SetCurrentHTTPRequestResponseObjects(request, null);
   		} catch (XPException ex) {
   			ex.PrintStackTrace();
   		}
	}

	/* 
	 * @see junit.framework.TestCase#tearDown()
	 */
	public void tearDown() throws Exception 
	{
		testObject = null;
		asParent = null;
		subSession = null;
		userSession = null;
		myPortalModel = null;
	}

	/**
	 * This method tests calling the AddRemoveControl to add a portlet
	 * and verifying the results in the model.
	 */
	public void testAddPortletControl()
	{
		// Fill out required control arguments to add a portlet
		XPHashtable htArgs = new XPHashtable();
		htArgs.PutElement(SetPageControl.STR_PAGE_ID, new String[] {XPConvert.ToString(nPageId)});
		htArgs.PutElement(AddRemovePortletControl.STR_PORTLET_TO_ADD, new String[] {XPConvert.ToString(nPortletId)});
		
		// Test call to control to add portlet.
		myPortalModel.ResetRecentlyAddedPortlets();
		Assert.assertEquals("Recently removed portlet id is incorrect after calling ResetRecentlyAddedPortlets.", 0, myPortalModel.GetRecentlyAddedPortlets().GetSize());
		testObject.CheckActionSecurityAndExecute(htArgs);
		Assert.assertNotNull("Checking recently added portlet list exists.", myPortalModel.GetRecentlyAddedPortlets());
		Assert.assertEquals("Recently added portlet list length is incorrect.", 1, myPortalModel.GetRecentlyAddedPortlets().GetSize());
		Assert.assertEquals("Recently added portlet id is incorrect.", nPortletId, XPConvert.ToInteger(myPortalModel.GetRecentlyAddedPortlets().GetElement(0)));
		
		// Test call to control to add portlet a second time. It should not add it again.
		myPortalModel.ResetRecentlyAddedPortlets();
		Assert.assertEquals("Recently removed portlet id is incorrect after calling ResetRecentlyAddedPortlets.", 0, myPortalModel.GetRecentlyAddedPortlets().GetSize());
		testObject.CheckActionSecurityAndExecute(htArgs);
		Assert.assertNotNull("Checking recently added portlet list exists.", myPortalModel.GetRecentlyAddedPortlets());
		Assert.assertTrue("There should not be a Recently added portlet.", myPortalModel.GetRecentlyAddedPortlets().IsEmpty());
	}
	
	/**
	 * This method tests calling the AddRemoveControl to remove a portlet
	 * and verifying the results in the model.
	 */
	public void testRemovePortletControl()
	{
		// Add a portlet to the model first to test removal.
		myPortalModel.AddSinglePortlet(nPageId, nPortletId);
		
		// Fill out required control arguments to remove a portlet
		XPHashtable htArgs = new XPHashtable();
		htArgs = new XPHashtable();
		htArgs.PutElement(SetPageControl.STR_PAGE_ID, new String[] {XPConvert.ToString(nPageId)});
		htArgs.PutElement(AddRemovePortletControl.STR_PORTLET_TO_REMOVE, new String[] {XPConvert.ToString(nPortletId)});
		
		// Test call to control to remove portlet.
		myPortalModel.ResetRecentlyRemovedPortlet();
		Assert.assertEquals("Recently removed portlet id is incorrect after calling ResetRecentlyRemovedPortlet.", 0, myPortalModel.GetRecentlyRemovedPortlet());
		testObject.CheckActionSecurityAndExecute(htArgs);
		Assert.assertEquals("Recently removed portlet id is incorrect.", nPortletId, myPortalModel.GetRecentlyRemovedPortlet());

		// Test call to control to remove portlet a second time. It should not remove it again.
		myPortalModel.ResetRecentlyRemovedPortlet();
		Assert.assertEquals("Recently removed portlet id is incorrect after calling ResetRecentlyRemovedPortlet.", 0, myPortalModel.GetRecentlyRemovedPortlet());
		testObject.CheckActionSecurityAndExecute(htArgs);
		Assert.assertEquals("Recently removed portlet id is incorrect.", 0, myPortalModel.GetRecentlyRemovedPortlet());
	}
}