package com.plumtree.portalpages.test.browsing.myportal;

import com.plumtree.openfoundation.mockobjects.XPRequestSimulator;
import com.plumtree.openfoundation.mockobjects.XPSessionSimulator;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.mock.myportal.MockMyPortalModel;
import com.plumtree.portalpages.browsing.myportal.ReorderPortletsControl;
import com.plumtree.portalpages.browsing.myportal.SetPageControl;
import com.plumtree.portalpages.browsing.myportal.mypages.MyPageAS;
import com.plumtree.portaluiinfrastructure.statichelpers.PlumtreeHelpers;
import com.plumtree.server.mock.core.MockPTSession;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.web.ISessionManager;
import com.plumtree.uiinfrastructure.web.SessionManagerFactory;
import junit.framework.*;

import junit.framework.TestCase;

/**
 * This class tests reordering portlets via the ReoderPortletsControl
 * 
 * In general, the tests will use a MockMyPortalModel for interaction between
 * the control and the model and verify the results.
 * 
 * @author btse
 *
 */
public class ReorderPortletsControlTest extends TestCase 
{
	protected int nCommunityId = 200;
	protected int nPageId = 300;
	protected ReorderPortletsControl testObject = null;
	protected AActivitySpace asParent = null;
	protected MockPTSession userSession = null;
	protected MockMyPortalModel myPortalModel = null;
	public ISessionManager subSession = null;
	
	/**
	 */
	public ReorderPortletsControlTest(String name)
   	{
		super(name);
   	}

	/* 
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() throws Exception
	{
		testObject = new ReorderPortletsControl();
   		asParent = new MyPageAS();
   		subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
   		subSession.SetAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG, "true");
   		asParent.SetPersistentSubSession(subSession);
   		userSession = new MockPTSession();
   		asParent.SetUserSession(userSession);
   		myPortalModel = new MockMyPortalModel(3);
		testObject.Init(myPortalModel, asParent);

		IXPRequest request = null;

   		try 
   		{
   			request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/mypage/home_page/");
   			asParent.SetCurrentHTTPRequestResponseObjects(request, null);
   		} catch (XPException ex) {
   			ex.PrintStackTrace();
   		}
	}

	/* 
	 * @see junit.framework.TestCase#tearDown()
	 */
	public void tearDown() throws Exception 
	{
		testObject = null;
		asParent = null;
		subSession = null;
		userSession = null;
		myPortalModel = null;
	}

	/**
	 * This method tests calling the ReorderPortletsControl to update the portlets in a 
	 * column (region) and verifying the results in the model.
	 * 
	 * This method will test the following cases:
	 * (1) Reordering of portlets in same column.
	 * (2) Reordering of portlets between columns.
	 */	
	public void testReorderPortletsControl()
	{
		// Add in some initial portlets to the model before testing the control.
		myPortalModel.AddSinglePortlet(nPageId, 1);
		myPortalModel.AddSinglePortlet(nPageId, 2);
		myPortalModel.AddSinglePortlet(nPageId, 3);
		Assert.assertEquals("Portlet count is incorrect.", 3, myPortalModel.GetPortletCount());
		Assert.assertEquals("First Portlet in Column 0 is incorrect.", 1, myPortalModel.GetFirstPortletIndexInColumn(0));
		Assert.assertEquals("Last Portlet in Column 0 is incorrect.", 3, myPortalModel.GetLastPortletIndexInColumn(0));
		
		// Reorder portlets in the column 0
		String strSourcePortletIDs = "1_2_3";
		String strTargetPortletIDs = "3_2_1";
		
		XPHashtable htArgs = new XPHashtable();
		htArgs.PutElement(SetPageControl.STR_PAGE_ID, new String[] {XPConvert.ToString(nPageId)});
		htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION, new String[] {XPConvert.ToString(0)});
		htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION_PORTLET_LIST, new String[] {strSourcePortletIDs});
		htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION, new String[] {XPConvert.ToString(0)});
		htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION_PORTLET_LIST, new String[] {strTargetPortletIDs});
		
		testObject.CheckActionSecurityAndExecute(htArgs);
		Assert.assertEquals("First Portlet in Column 0 is incorrect.", 3, myPortalModel.GetFirstPortletIndexInColumn(0));
		Assert.assertEquals("Last Portlet in Column 0 is incorrect.", 1, myPortalModel.GetLastPortletIndexInColumn(0));

		// Reorder portlets from column 0 to column 1
		myPortalModel.ResetPortletColumns();
		Assert.assertEquals("Portlet count is incorrect.", 0, myPortalModel.GetPortletCount());
		strSourcePortletIDs = "";
		strTargetPortletIDs = "1_2_3";
		
		htArgs = new XPHashtable();
		htArgs.PutElement(SetPageControl.STR_PAGE_ID, new String[] {XPConvert.ToString(nPageId)});
		htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION, new String[] {XPConvert.ToString(0)});
		htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION_PORTLET_LIST, new String[] {strSourcePortletIDs});
		htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION, new String[] {XPConvert.ToString(1)});
		htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION_PORTLET_LIST, new String[] {strTargetPortletIDs});
		
		testObject.CheckActionSecurityAndExecute(htArgs);
		Assert.assertEquals("Portlet count is incorrect.", 3, myPortalModel.GetPortletCount());
		Assert.assertEquals("First Portlet in Column 0 is incorrect.", -1, myPortalModel.GetFirstPortletIndexInColumn(0));
		Assert.assertEquals("Last Portlet in Column 0 is incorrect.", -1, myPortalModel.GetLastPortletIndexInColumn(0));
		Assert.assertEquals("First Portlet in Column 1 is incorrect.", 1, myPortalModel.GetFirstPortletIndexInColumn(1));
		Assert.assertEquals("Last Portlet in Column 1 is incorrect.", 3, myPortalModel.GetLastPortletIndexInColumn(1));
	}
}