/**
 * 
 */
package com.plumtree.portalpages.test.browsing.prefs;


import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.portlet.*;
import com.plumtree.portalpages.browsing.mock.prefs.*;
import com.plumtree.portalpages.browsing.mock.webservice.*;
import com.plumtree.portalpages.portlets.intrinsicpageletparamprefeditor.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.server.mock.portlet.*;
import com.plumtree.server.mock.webservice.*;

/**
 * Tests the intrinsic preference editor for pagelet portlets
 * Test user, community and admin level preferences and different loading, storing scenarios
 * 
 * @author rozhang
 */
public class PageletParameterPreferenceEditorTest extends TestCase
{
	
	public void setUp() throws Exception 
	{
		
	}
	
	public void tearDown() 
	{
		
	}
	
	public void testModelAdminPrefs()
	{
		Object[] adminParams1 		= new Object[] {"Admin Param 1", "Admin Param 2"};
		Object[] adminParamDescs1 	= new Object[] {"Admin Param 1 Desc", "Admin Param 2 Desc"};
		Object[] adminParams2 		= new Object[] {"Admin Param A", "Admin Param B", "Admin Param 1"};
		Object[] adminParamDescs2 	= new Object[] {"Admin Param A Desc", "Admin Param B Desc", "Admin Param 1 Desc"};
		Object[] adminValues1 		= new Object[] {"Admin Value 1", "Admin Value 2"};
		int wsId					= 300;
		int portletId				= 200;
		// #test1: setup scenario for first load of editor after webservice object mapping
		MockIntrinsicPrefsEditorForPageletParametersModel model = InitializeWithAdminPrefs(wsId, portletId, adminParams1, adminParamDescs1);

		// check first load model state
		AssertStringArraysEqual(adminParams1,  model.GetPortletPrefNames(), "Parameter names not stored correctly in the model!");
		AssertStringArraysEqual(adminParamDescs1,  model.GetPortletPrefDescriptions(), "Parameter descriptions not stored correctly in the model!" );
		AssertStringArraysEqual(new Object[] {"", ""},  model.GetPortletPrefValues(), "Parameter values not empty for first time editor!" );

		// check model values were properly updated
		UpdateParamValues(model, adminValues1);
		AssertStringArraysEqual(adminValues1,  model.GetPortletPrefValues(), "Parameter values not updated after updating parameter values!" );
		
		// check prefs were properly stored
		model.Finish();
		Object[][] storedPrefs = model.GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, null);
		AssertPrefsArrayMatchParams(storedPrefs, adminParams1, adminValues1, "Stored preference values do not match initial parameter values!");
		
		// #test2: setup scenario for loading model with stored prefs values
		StartModel(model, 0, 0, portletId, true);
		
		// check model names, descs and values were properly loaded
		AssertStringArraysEqual(adminParams1,  model.GetPortletPrefNames(), "Parameter names not loaded correctly in the model!");
		AssertStringArraysEqual(adminParamDescs1,  model.GetPortletPrefDescriptions(), "Parameter descriptions not loaded correctly in the model!" );
		// sort both value arrays, the prefs values might get loaded in a different order since it is an enum of a hashtable
		Object[] loadedPrefs = model.GetPortletPrefValues();
		XPArray.Sort(adminValues1);
		XPArray.Sort(loadedPrefs);
		AssertStringArraysEqual(adminValues1, loadedPrefs, "Parameter values not loaded correctly from prefs data!" );
		
		// #test3: setup scenario for pagelet change in webservice so new set of parameters  
		SetupWSObject(wsId, 
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN_DESCS,
				adminParams2, adminParamDescs2, (MockEnvironment)model.m_asOwner);
		
		StartModel(model, 0, 0, portletId, true);
		AssertStringArraysEqual(adminParams2,  model.GetPortletPrefNames(), "Parameter names not loaded correctly in the model after updated mapping!");
		AssertStringArraysEqual(adminParamDescs2,  model.GetPortletPrefDescriptions(), "Parameter descriptions not loaded correctly in the model after updated mapping!" );
		Object[] loadedPrefs2 = model.GetPortletPrefValues();
		Object[] checkVals   = new Object[] {"", "", adminValues1[0]};
		XPArray.Sort(checkVals);
		XPArray.Sort(loadedPrefs2);
		AssertStringArraysEqual(checkVals, loadedPrefs2, "Parameter values not loaded correctly from prefs data after updated mapping!" );
		
	}
	
	public void testModelPersonalPrefs()
	{
		Object[] userParams1 		= new Object[] {"User Param 1", "User Param 2"};
		Object[] userParamDescs1 	= new Object[] {"User Param 1 Desc", "User Param 2 Desc"};
		Object[] userParams2 		= new Object[] {"User Param A", "User Param B", "User Param 1"};
		Object[] userParamDescs2 	= new Object[] {"User Param A Desc", "User Param B Desc", "User Param 1 Desc"};
		Object[] userValues1 		= new Object[] {"User Value 1", "User Value 2"};
		int wsId					= 300;
		int portletId				= 200;
		int commId					= 0;
		int pageId					= 0;
		// #test1: setup scenario for first load of editor after webservice object mapping
		MockIntrinsicPrefsEditorForPageletParametersModel model = InitializeWithPersonalPrefs(wsId, portletId, pageId, commId, userParams1, userParamDescs1);

		// check first load model state
		AssertStringArraysEqual(userParams1,  model.GetPortletPrefNames(), "Parameter names not stored correctly in the model!");
		AssertStringArraysEqual(userParamDescs1,  model.GetPortletPrefDescriptions(), "Parameter descriptions not stored correctly in the model!" );
		AssertStringArraysEqual(new Object[] {"", ""},  model.GetPortletPrefValues(), "Parameter values not empty for first time editor!" );

		// check model values were properly updated
		UpdateParamValues(model, userValues1);
		AssertStringArraysEqual(userValues1,  model.GetPortletPrefValues(), "Parameter values not updated after updating parameter values!" );
		
		// check prefs were properly stored
		model.Finish();
		Object[][] storedPrefs = model.GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_PORTLET, null);
		AssertPrefsArrayMatchParams(storedPrefs, userParams1, userValues1, "Stored preference values do not match initial parameter values!");
		
		// #test2: setup scenario for loading model with stored prefs values
		StartModel(model, pageId, commId, portletId, false);
		
		// check model names, descs and values were properly loaded
		AssertStringArraysEqual(userParams1,  model.GetPortletPrefNames(), "Parameter names not loaded correctly in the model!");
		AssertStringArraysEqual(userParamDescs1,  model.GetPortletPrefDescriptions(), "Parameter descriptions not loaded correctly in the model!" );
		// sort both value arrays, the prefs values might get loaded in a different order since it is an enum of a hashtable
		Object[] loadedPrefs = model.GetPortletPrefValues();
		XPArray.Sort(userValues1);
		XPArray.Sort(loadedPrefs);
		AssertStringArraysEqual(userValues1, loadedPrefs, "Parameter values not loaded correctly from prefs data!" );
		
		// #test3: setup scenario for pagelet change in webservice so new set of parameters  
		SetupWSObject(wsId, 
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER_DESCS,
				userParams2, userParamDescs2, (MockEnvironment)model.m_asOwner);
		
		StartModel(model, pageId, commId, portletId, false);
		AssertStringArraysEqual(userParams2,  model.GetPortletPrefNames(), "Parameter names not loaded correctly in the model after updated mapping!");
		AssertStringArraysEqual(userParamDescs2,  model.GetPortletPrefDescriptions(), "Parameter descriptions not loaded correctly in the model after updated mapping!" );
		Object[] loadedPrefs2 = model.GetPortletPrefValues();
		Object[] checkVals   = new Object[] {"", "", userValues1[0]};
		XPArray.Sort(checkVals);
		XPArray.Sort(loadedPrefs2);
		AssertStringArraysEqual(checkVals, loadedPrefs2, "Parameter values not loaded correctly from prefs data after updated mapping!" );
		
	}
	
	public void testModelCommPrefs()
	{
		Object[] comParams1 		= new Object[] {"Comm Param 1", "Comm Param 2"};
		Object[] commParamDescs1 	= new Object[] {"Comm Param 1 Desc", "Comm Param 2 Desc"};
		Object[] commParams2 		= new Object[] {"Comm Param A", "Comm Param B", "Comm Param 1"};
		Object[] commParamDescs2 	= new Object[] {"Comm Param A Desc", "Comm Param B Desc", "Comm Param 1 Desc"};
		Object[] commValues1 		= new Object[] {"Comm Value 1", "Comm Value 2"};
		int wsId					= 300;
		int portletId				= 200;
		int commId					= 1000;
		int pageId					= 0;
		// #test1: setup scenario for first load of editor after webservice object mapping
		MockIntrinsicPrefsEditorForPageletParametersModel model = InitializeWithCommPrefs(wsId, portletId, pageId, commId, comParams1, commParamDescs1);

		// check first load model state
		AssertStringArraysEqual(comParams1,  model.GetPortletPrefNames(), "Parameter names not stored correctly in the model!");
		AssertStringArraysEqual(commParamDescs1,  model.GetPortletPrefDescriptions(), "Parameter descriptions not stored correctly in the model!" );
		AssertStringArraysEqual(new Object[] {"", ""},  model.GetPortletPrefValues(), "Parameter values not empty for first time editor!" );

		// check model values were properly updated
		UpdateParamValues(model, commValues1);
		AssertStringArraysEqual(commValues1,  model.GetPortletPrefValues(), "Parameter values not updated after updating parameter values!" );
		
		// check prefs were properly stored
		model.Finish();
		Object[][] storedPrefs = model.GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_COMMUNITYPORTLET, null);
		AssertPrefsArrayMatchParams(storedPrefs, comParams1, commValues1, "Stored preference values do not match initial parameter values!");
		
		// #test2: setup scenario for loading model with stored prefs values
		StartModel(model, pageId, commId, portletId, false);
		
		// check model names, descs and values were properly loaded
		AssertStringArraysEqual(comParams1,  model.GetPortletPrefNames(), "Parameter names not loaded correctly in the model!");
		AssertStringArraysEqual(commParamDescs1,  model.GetPortletPrefDescriptions(), "Parameter descriptions not loaded correctly in the model!" );
		// sort both value arrays, the prefs values might get loaded in a different order since it is an enum of a hashtable
		Object[] loadedPrefs = model.GetPortletPrefValues();
		XPArray.Sort(commValues1);
		XPArray.Sort(loadedPrefs);
		AssertStringArraysEqual(commValues1, loadedPrefs, "Parameter values not loaded correctly from prefs data!" );
		
		// #test3: setup scenario for pagelet change in webservice so new set of parameters  
		SetupWSObject(wsId, 
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM_DESCS,
				commParams2, commParamDescs2, (MockEnvironment)model.m_asOwner);
		
		StartModel(model, pageId, commId, portletId, false);
		AssertStringArraysEqual(commParams2,  model.GetPortletPrefNames(), "Parameter names not loaded correctly in the model after updated mapping!");
		AssertStringArraysEqual(commParamDescs2,  model.GetPortletPrefDescriptions(), "Parameter descriptions not loaded correctly in the model after updated mapping!" );
		Object[] loadedPrefs2 = model.GetPortletPrefValues();
		Object[] checkVals   = new Object[] {"", "", commValues1[0]};
		XPArray.Sort(checkVals);
		XPArray.Sort(loadedPrefs2);
		AssertStringArraysEqual(checkVals, loadedPrefs2, "Parameter values not loaded correctly from prefs data after updated mapping!" );
		
	}
	
	

	/**
	 * Setup the prefs editor model and the entire required environment for admin prefs
	 * 
	 * @param wsId
	 * @param portletId
	 * @param paramNames
	 * @param paramDescs
	 * @return
	 */
	protected MockIntrinsicPrefsEditorForPageletParametersModel 
	InitializeWithAdminPrefs(int wsId, int portletId, Object[] paramNames, Object[] paramDescs)
	{
		MockEnvironment mockEnv = new MockEnvironment();
		
		MockIntrinsicPrefsEditorForPageletParametersModel model = new MockIntrinsicPrefsEditorForPageletParametersModel();
		
		MockPTPortlet mockPortletObj = new MockPTPortlet();
		mockPortletObj.SetObjectID(portletId);
		mockPortletObj.SetWebServiceID(wsId);
		
		MockPTWebService mockWSObj = SetupWSObject(wsId, 
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN_DESCS, paramNames, paramDescs, mockEnv);
		
		MockPortletModel mockPortletModel = new MockPortletModel();
		mockPortletModel.SetPortletObject(mockPortletObj);
		((MockEnvironment)mockEnv.GetParentSpace()).m_models.PutElement(PortletModel.STR_MVC_CLASS_NAME, mockPortletModel);
		
		MockPTObjectManager mockPortletMgr = (MockPTObjectManager)((MockPTSession) mockEnv.GetUserSession()).GetGadgets();
		mockPortletMgr.m_htObjects.PutElement(new Integer(portletId), mockPortletObj);
		
		model.Init(mockEnv);
		model.m_mockPortlet = mockPortletObj;
		
		StartModel(model, 0, 0, portletId, true);
		
		return model;
	}
	
	/**
	 * Setup the prefs editor model and the entire required environment for personal prefs
	 * 
	 * @param wsId
	 * @param portletId
	 * @param paramNames
	 * @param paramDescs
	 * @return
	 */
	protected MockIntrinsicPrefsEditorForPageletParametersModel 
	InitializeWithPersonalPrefs(int wsId, int portletId, int pageId, int commId, Object[] paramNames, Object[] paramDescs)
	{
		MockEnvironment mockEnv = new MockEnvironment();
		// by default mockenv is created with parent activity space, which is interpreted by the intrinsicprefsmodel
		// as admin prefs (opened from portlet editor), clear parents space from mock environment to simulate user and 
		mockEnv.m_parentSpace = null;
		MockIntrinsicPrefsEditorForPageletParametersModel model = new MockIntrinsicPrefsEditorForPageletParametersModel();
		
		MockPTPortlet mockPortletObj = new MockPTPortlet();
		mockPortletObj.SetObjectID(portletId);
		mockPortletObj.SetWebServiceID(wsId);
		
		MockPTWebService mockWSObj = SetupWSObject(wsId, 
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER_DESCS,
				paramNames, paramDescs, mockEnv);
		
//		MockPortletModel mockPortletModel = new MockPortletModel();
//		mockPortletModel.SetPortletObject(mockPortletObj);
//		((MockEnvironment)mockEnv.GetParentSpace()).m_models.PutElement(PortletModel.STR_MVC_CLASS_NAME, mockPortletModel);
		
		MockPTObjectManager mockPortletMgr = (MockPTObjectManager)((MockPTSession) mockEnv.GetUserSession()).GetGadgets();
		mockPortletMgr.m_htObjects.PutElement(new Integer(portletId), mockPortletObj);
		
		model.Init(mockEnv);
		model.m_mockPortlet = mockPortletObj;
		
		StartModel(model, pageId, commId, portletId, false);
		return model;
	}
	
	/**
	 * Setup the prefs editor model and the entire required environment for community prefs
	 * 
	 * @param wsId
	 * @param portletId
	 * @param paramNames
	 * @param paramDescs
	 * @return
	 */
	protected MockIntrinsicPrefsEditorForPageletParametersModel 
	InitializeWithCommPrefs(int wsId, int portletId, int pageId, int commId, Object[] paramNames, Object[] paramDescs)
	{
		MockEnvironment mockEnv = new MockEnvironment();
		// by default mockenv is created with parent activity space, which is interpreted by the intrinsicprefsmodel
		// as admin prefs (opened from portlet editor), clear parents space from mock environment to simulate user and 
		mockEnv.m_parentSpace = null;
		MockIntrinsicPrefsEditorForPageletParametersModel model = new MockIntrinsicPrefsEditorForPageletParametersModel();
		
		MockPTPortlet mockPortletObj = new MockPTPortlet();
		mockPortletObj.SetObjectID(portletId);
		mockPortletObj.SetWebServiceID(wsId);
		
		MockPTWebService mockWSObj = SetupWSObject(wsId, 
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM, 
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM_DESCS,  
				paramNames, paramDescs, mockEnv);
		
//		MockPortletModel mockPortletModel = new MockPortletModel();
//		mockPortletModel.SetPortletObject(mockPortletObj);
//		((MockEnvironment)mockEnv.GetParentSpace()).m_models.PutElement(PortletModel.STR_MVC_CLASS_NAME, mockPortletModel);
		
		MockPTObjectManager mockPortletMgr = (MockPTObjectManager)((MockPTSession) mockEnv.GetUserSession()).GetGadgets();
		mockPortletMgr.m_htObjects.PutElement(new Integer(portletId), mockPortletObj);
		
		model.Init(mockEnv);
		model.m_mockPortlet = mockPortletObj;
		
		StartModel(model, pageId, commId, portletId, false);
		return model;
	}
	
	/**
	 * Helper method to setup the webservice object with the expected mapping data
	 * 
	 * @param wsId
	 * @param paramNames
	 * @param paramDescs
	 * @return
	 */
	private MockPTWebService SetupWSObject(int wsId, String nameType, String descType, Object[] paramNames, Object[] paramDescs, MockEnvironment mockEnv)
	{
		MockPTWebService mockWSObj = new MockPTWebService();
		mockWSObj.SetObjectID(wsId);
		// by default mockenv is created with parent activity space, which is interpreted by the intrinsicprefsmodel
		// as admin prefs (opened from portlet editor), clear parents space from mock environment to simulate user and 
		// comm portlet prefs editor typeIXPPropertyBag ptBag = PortalObjectsFactory.CreatePropertyBag();
		IXPPropertyBag ptBag = PortalObjectsFactory.CreatePropertyBag();
		ptBag.Write(nameType, paramNames);
		ptBag.Write(descType, paramDescs);
		
		mockWSObj.SetProviderInfo(ptBag);
		
		MockPTObjectManager mockWSMgr = ((MockPTSession) mockEnv.GetUserSession()).m_WSObjectManager;
		mockWSMgr.m_htObjects.PutElement(new Integer(wsId), mockWSObj);
		return mockWSObj;
	}
	
	/**
	 * Helper method to run the editor prefs model with the expected form data
	 * 
	 * @param model
	 * @param pageId
	 * @param commId
	 * @param portletId
	 * @param isAdmin
	 */
	protected void StartModel(MockIntrinsicPrefsEditorForPageletParametersModel model, 
			int pageId, int commId, int portletId, boolean isAdmin )
	{
		XPHashtable formData = new XPHashtable();
		formData.PutElement(IntrinsicPortletPrefsUtils.PAGEID, new String[] {pageId+""});
		formData.PutElement(IntrinsicPortletPrefsUtils.COMMUNITYID, new String[] {commId+""});
		formData.PutElement(IntrinsicPortletPrefsUtils.PORTLETID, new String[] {portletId+""});
		formData.PutElement(IntrinsicPortletPrefsUtils.ISADMINPREF, new String[] {isAdmin+""});
		
		model.CheckEditorAccessAndStart(formData);
	}
	
	/**
	 * Helper method to assert that a 2d prefs array contains the same preferences
	 * as 2 arrays with pref names and values
	 * 
	 * @param prefsArray
	 * @param paramNames
	 * @param paramVals
	 * @param errorMsg
	 */
	public void AssertPrefsArrayMatchParams(Object[][] prefsArray, Object[] paramNames, Object[] paramVals, String errorMsg)
	{
		XPHashtable paramMap = new XPHashtable();
		for ( int i = 0; i < paramNames.length; i++ ) {
			paramMap.PutElement(paramNames[i], paramVals[i]);
		}
		
		for ( int i = 0; i < prefsArray.length; i++ ) {
			String paramName = (String)prefsArray[0][i];
			String paramVal  = (String)prefsArray[1][i];
			// @TODO add cause
			Assert.assertFalse(errorMsg, paramMap.IsEmpty());
			if ( paramMap.ContainsKey(paramName) && paramVal.equals(paramMap.GetElement(paramName)) ) {
				paramMap.RemoveElement(paramName);
			} else {
				// @TODO add cause
				Assert.fail(errorMsg);
			}
		}
		// @TODO add cause
		Assert.assertTrue( errorMsg, paramMap.IsEmpty() );
	}
	
	/**
	 * Helper method to assert that two object arrays are equal
	 * 
	 * @param refArray
	 * @param compArray
	 * @param errorMsg
	 */
	public void AssertStringArraysEqual(Object[] refArray, Object[] compArray, String errorMsg)
	{
		boolean result = true;
		if ( refArray.length != compArray.length) {
			result = false;
		}
		for ( int i = 0; i < refArray.length; i++ ) {
			if ( refArray[i] == null && compArray[i] == null ) {
			  continue;	
			}
			if ( !refArray[i].equals(compArray[i]) ) 
				result =  false;
		}
		if ( !result ) {
			Assert.fail(errorMsg);
		}
	}
	
	/**
	 * Helper method to set posted form values to pass into the model 
	 * @param model
	 * @param paramValues
	 */
	protected void UpdateParamValues(MockIntrinsicPrefsEditorForPageletParametersModel model, Object[] paramValues)
	{
		XPHashtable formVals = new XPHashtable();
		for ( int i = 0; i < paramValues.length; i++ ) {
			formVals.PutElement(IntrinsicPrefsEditorForPageletParametersView.CPPREF_INPUT_NAME+i, new String[] {(String)paramValues[i]});
		}
		model.SavePage(null, formVals);
	}
	
}
