package com.plumtree.portalpages.test.browsing.sso.ensemble;

import junit.framework.Assert;
import junit.framework.TestCase;

import com.plumtree.openfoundation.mockobjects.XPSessionSimulator;
import com.plumtree.openfoundation.util.XPHashtable;
import com.plumtree.openfoundation.util.XPStringUtility;
import com.plumtree.openfoundation.util.XPSystem;
import com.plumtree.portalpages.browsing.sso.ensemble.EnsembleHandlerControl;
import com.plumtree.portaluiinfrastructure.helpers.PTConfigService;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockApplicationManager;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockConfigVarPack;
import com.plumtree.portaluiinfrastructure.mock.helper.MockPTConfigHelper;
import com.plumtree.portaluiinfrastructure.mock.tags.MockEnvironment;
import com.plumtree.server.*;
import com.plumtree.server.mock.*;
import com.plumtree.server.mock.core.MockPTSession;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.ASConstants;
import com.plumtree.uiinfrastructure.activityspace.Redirect;
import com.plumtree.uiinfrastructure.application.varpacks.AppConstants;
import com.plumtree.uiinfrastructure.application.varpacks.ConfigConstants;
import com.plumtree.uiinfrastructure.application.varpacks.ConfigVarPack;
import com.plumtree.uiinfrastructure.statichelpers.HttpUtils;
import com.plumtree.uiinfrastructure.web.Application;
import com.plumtree.uiinfrastructure.web.ApplicationManager;
import com.plumtree.uiinfrastructure.web.IApplication;
import com.plumtree.uiinfrastructure.web.ISessionManager;
import com.plumtree.uiinfrastructure.web.SessionManagerFactory;

/**
 * This class tests Ensemble SSO redirect functionality, It tests various cases of 
 * the redirect url being properly generated by WCI when Ensemble sends SSO request
 * 
 * In general, the tests will use a MockMyPortalModel for interaction between
 * the control and the model and verify the results.
 * 
 * @author Ravi Tunuguntla
 *
 */
public class EnsembleHandlerControlTest extends TestCase {

	public static final String MOCK_ENSEMBLE_TOKEN = "0|fAkEeNsEmBlEtOKeN";
	
	protected EnsembleHandlerControl testObject = null;
	protected XPHashtable testArgs = null;
	protected AActivitySpace asParent = null;
	protected MockPTSession userSession = null;
	public ISessionManager subSession = null;
	public MockPTConfigHelper m_helper;
	private String testURL;
	private MockConfigVarPack varPack;
	
	/**
	 * @param name
	 */
	public EnsembleHandlerControlTest(String name) {
		super(name);
		
	}

	/*
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() throws Exception 
	{
		IApplication application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
		
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);
		
		testObject = new EnsembleHandlerControl();
   		asParent = new MockEnvironment();
   		
   		
   		// Init Mock ConfigVarPack

   		if(XPSystem.IsRunningInDotNet()) {
   			varPack = new MockConfigVarPack(ConfigVarPack.APP_PLATFORM_DOT_NET);
		} else {
			varPack = new MockConfigVarPack(ConfigVarPack.APP_PLATFORM_JAVA);
		}
   		
   		subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
   		
   		asParent.SetPersistentSubSession(subSession);
   		userSession = new MockPTSession(); 
   		
   		String[] qsArg = new String [1];
		qsArg[0] = "http%3A//google.com/";
		
   		testURL = "http://localhost/portal/server.pt?space=" + EnsembleHandlerControl.STR_MVC_CLASS_NAME +
   						"&" + EnsembleHandlerControl.ES_POST_REDIRECT_URL + "=" + qsArg[0];
   		
   		testArgs = new XPHashtable();		
		
		testArgs.PutElement(ASConstants.SPACENAME, EnsembleHandlerControl.STR_MVC_CLASS_NAME);
		testArgs.PutElement(EnsembleHandlerControl.ES_POST_REDIRECT_URL, qsArg);
	}
	
	
	/* 
	 * @see junit.framework.TestCase#tearDown()
	 */
	public void tearDown() throws Exception 
	{
		super.tearDown();
		testObject = null;
		testArgs = null;
		asParent = null;
		userSession = null;
		subSession = null;
		m_helper = null;		
		varPack = null;
	}
	
	/**
	 * Test case when Ensemble sends SSO request for user not logged into portal
	 */
	public void testSSOLoginAsGuest() {

   		// Setting SSO LoginToken Timeout to 2 min 
   		varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT, 
   				ConfigConstants.VALUE_ATTRIBUTE, "2");
   		
   		asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);
   		
		userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_GUEST);   		
   		((MockEnvironment) asParent).m_userSession = userSession;

   		testObject.Init( null, asParent);
   		testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
   		
		Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
		
		String redirectURL = redirect.GetExternalURL();
		
		Assert.assertEquals("Could not find the expected Redirect URL!", redirectURL, "http%3A//google.com/?portal_cookie=did_not_find_cookie");
		
	}
	
	/**
	 * Testcase: Ensemble sends sso request for the already logged in user.
	 */
	public void testSSOLoginAsRealUser() {

   		// Setting SSO LoginToken Timeout to 2 min 
   		varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT, 
   				ConfigConstants.VALUE_ATTRIBUTE, "2");
   		
   		asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);

		userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_REGULAR);   		
   		((MockEnvironment) asParent).m_userSession = userSession;

   		testObject.Init( null, asParent);
		
   		testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
		Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
		
		String redirectURL = redirect.GetExternalURL();
		
   		Assert.assertEquals("Could not find the expected redirect URL!", redirectURL, "http%3A//google.com/?portal_cookie=0%7CfAkEpOrTaLtOKeN" );
		//@TODO Check Redirect URL also
	}
	
	/**
	 * Testcase: Ensemble sends sso request with Login Token when user is not logged into WCI.
	 */
	public void testSSOLoginAsGuestWithToken(){
		
		// Setting SSO LoginToken Timeout to 2 min 
   		varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT, 
   				ConfigConstants.VALUE_ATTRIBUTE, "2");
   		
   		asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);

		userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_GUEST);   		
   		((MockEnvironment) asParent).m_userSession = userSession;

   		testObject.Init( null, asParent);

		// Adding Ensemble Token to the request Args
   		testURL += "&" + EnsembleHandlerControl.WCI_TOKEN + "=" + MOCK_ENSEMBLE_TOKEN;
   		
   		testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
   		String[] tokArg = new String [1];
   		tokArg[0] = MOCK_ENSEMBLE_TOKEN; 
   		testArgs.PutElement(EnsembleHandlerControl.WCI_TOKEN, tokArg);
   		// Setting PortalObjectFactory to use MockPTSession
   		MockPortalObjectsFactory factory = new MockPortalObjectsFactory();
   		factory.m_session = userSession;
   		PortalObjectsFactoryService.setTestInstance(factory);
   		
   		Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);   		
   		String redirectURL = redirect.GetExternalURL();   		
   		Assert.assertEquals("Could not find the expected redirect URL!", redirectURL, "http%3A//google.com/?portal_cookie=0%7CfAkEpOrTaLtOKeN" );
   		
   		// Reset to null after test is done
   		PortalObjectsFactoryService.setTestInstance(null);
		
	}
	
	/**
	 * Testcase: Ensemble sends sso request with Login Token for the already logged in user.
	 */
	public void testSSOLoginAsRealUserWithToken(){

		// Setting SSO LoginToken Timeout to 2 min 
   		varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT, 
   				ConfigConstants.VALUE_ATTRIBUTE, "2");
   		
   		asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);

		userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_REGULAR);   		
   		((MockEnvironment) asParent).m_userSession = userSession;

   		testObject.Init( null, asParent);

		// Adding Ensemble Token to the request Args
   		testURL += "&" + EnsembleHandlerControl.WCI_TOKEN + "=" + MOCK_ENSEMBLE_TOKEN;
   		
   		testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);

   		String[] tokArg = new String [1];
   		tokArg[0] = MOCK_ENSEMBLE_TOKEN; 
   		testArgs.PutElement(EnsembleHandlerControl.WCI_TOKEN, tokArg);
   		
   		Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
   		
   		String redirectURL = redirect.GetExternalURL();
   		
   		Assert.assertEquals("Could not find the expected redirect URL!", redirectURL, "http%3A//google.com/?portal_cookie=0%7CfAkEpOrTaLtOKeN" );


	}
	
	/**
	 * Testcase when EnsembleSSO feature is turned off in WCI
	 */
	public void testWithSSODisabled() {
   		// Setting SSO LoginToken Timeout to 0 min 
   		varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT, 
   				ConfigConstants.VALUE_ATTRIBUTE, "0");
   		
   		asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);

		userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_REGULAR);   		
   		((MockEnvironment) asParent).m_userSession = userSession;

   		testObject.Init( null, asParent);
   		testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
		Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
		
		String redirectURL = redirect.GetExternalURL();


		Assert.assertEquals("Could not find the expected Redirect URL when SSO is disabled!", redirectURL, "http%3A//google.com/?portal_cookie=did_not_find_cookie");
	}

}
