package com.plumtree.portalpages.test.condition.conditiontypes;

import junit.framework.*;

import com.plumtree.openfoundation.mockobjects.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.mock.condition.*;
import com.plumtree.portalpages.condition.conditiontypes.*;
import com.plumtree.server.condition.*;
import com.plumtree.server.mock.condition.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;

public class ConditionTypeUserAgentTest extends TestCase
{
	private static String FIREFOX_USER_AGENT = "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14";
	private static String IE_USER_AGENT = "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; HPC Factor; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; FDM)";
	
	private ConditionTypeUserAgent testObject = null;
	
	public void setUp() throws Exception
	{
		testObject = new ConditionTypeUserAgent();
	}
	
	public void tearDown() throws Exception 
	{
		testObject = null;
	}

	public void testCompare()
	{
		IValue conditionValue = new MockConditionValue();
		conditionValue.SetType(ValueTypeEnum.STRING);
		conditionValue.SetValue(IE_USER_AGENT);
		
		XPHashtable htUserEnvironment = new XPHashtable();
		htUserEnvironment.PutElement(new Integer(testObject.GetTypeID()), IE_USER_AGENT);
		boolean result = testObject.Compare(htUserEnvironment, conditionValue, null);
		Assert.assertTrue("Exact match should return true.", result);
		
		htUserEnvironment.PutElement(new Integer(testObject.GetTypeID()), FIREFOX_USER_AGENT);
		result = testObject.Compare(htUserEnvironment, conditionValue, null);
		Assert.assertFalse("Different strings should return false.", result);
		
		conditionValue.SetValue("Firefox");
		result = testObject.Compare(htUserEnvironment, conditionValue, null);
		Assert.assertTrue("Partial match should return true.", result);
		
		conditionValue.SetValue("MSIE");
		result = testObject.Compare(htUserEnvironment, conditionValue, null);
		Assert.assertFalse("No partial match should return false.", result);
	}
	
	public void testGetCurrentValue()
	{
		MockXPLimitedRequest xpRequest = new MockXPLimitedRequest(XPRequestSimulator.CreateGetLocalhost());
		xpRequest.SetHeader("User-Agent", IE_USER_AGENT);
		XPHashtable htUserEnvironment = new XPHashtable();
		
		testObject.GetCurrentValue(xpRequest, null, htUserEnvironment);
		String userAgent = (String) htUserEnvironment.GetElement(new Integer(testObject.GetTypeID()));
		Assert.assertEquals("Should have added string: " + IE_USER_AGENT + " to environment.", userAgent, IE_USER_AGENT);
	}
	
	public void testGetConditionValue()
	{
		MockArrayWrapper saData = new MockArrayWrapper();
		Object[] row = new Object[GrowableListModel.EXPLIST_COL_MAX];
		row[GrowableListModel.EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT] = FIREFOX_USER_AGENT;
		saData.AddRow(row);
		row = new Object[GrowableListModel.EXPLIST_COL_MAX];
		row[GrowableListModel.EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT] = IE_USER_AGENT;
		saData.AddRow(row);
		
		Object result = testObject.GetConditionValue(0, saData);
		Assert.assertEquals("Should have gotten string: " + FIREFOX_USER_AGENT + " out of the list array.", result, FIREFOX_USER_AGENT);
		result = testObject.GetConditionValue(1, saData);
		Assert.assertEquals("Should have gotten string: " + IE_USER_AGENT + " out of the list array.", result, IE_USER_AGENT);
	}
	
}
