package com.plumtree.portalpages.test.rest.user;

import junit.framework.*;

import com.plumtree.portalpages.rest.user.*;
import com.plumtree.portalpages.rest.utils.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.taskapi.test.portalui.mock.*;

/**
 * Tests the UserRESTControl, as well as the UserRESTModel (which is very simple).
 */
public class UserRESTControlTest extends TestCase
{
	UserRESTControl m_control;
	UserRESTModel m_model;
	MockTaskAPIUICommunityService m_task;

	public void setUp() throws Exception
	{
		super.setUp();

		m_task = new MockTaskAPIUICommunityService();
		TaskAPIUICommunityService.SetMockInstanceForDebug(m_task);

		m_control = new UserRESTControl();
		m_model = new UserRESTModel();
		m_control.Init(m_model, null);
	}

	public void tearDown() throws Exception
	{
		super.tearDown();

		// Release the mock instance.
		TaskAPIUICommunityService.SetMockInstanceForDebug(null);

		m_control = null;
		m_model = null;
	}

	public void testJoinCommunity()
	{
		String strJSON = "{ \"" + UserRESTConstants.USER_FORMAT_NAME + "\": {" +
			"\"" + UserRESTConstants.USER_JOIN_COMMUNITIES + "\": \"534\"" +
			"} }";

		assertEquals("No community should be joined by default in Task API.", -1, m_task.m_nJoinedCommunityID);
		assertEquals("No community should be joined by default in model.", -1, m_model.GetJoinedCommunityID());

		assertEquals("No community should be left by default.", -1, m_task.m_nLeftCommunityID);
		assertEquals("No community should be left by default in model.", -1, m_model.GetLeftCommunityID());

		IJSONParser parser = JSONParser.GetInstance();
		parser.ParseJSONObject(strJSON);

		m_control.ProcessAction(parser);

		assertNull("There should not be an error after joining.", m_model.GetError());

		assertEquals("Community was not joined correctly on the Task API.", 534, m_task.m_nJoinedCommunityID);
		assertEquals("Incorrect community joined on model.", 534, m_model.GetJoinedCommunityID());

		assertEquals("No community should be left in Task API after joining.", -1, m_task.m_nLeftCommunityID);
		assertEquals("No community should be left in model after joining.", -1, m_model.GetLeftCommunityID());
	}

	public void testLeaveCommunity()
	{
		String strJSON = "{ \"" + UserRESTConstants.USER_FORMAT_NAME + "\": {" +
			"\"" + UserRESTConstants.USER_LEAVE_COMMUNITIES + "\": \"534\"" +
			"} }";

		assertEquals("No community should be joined by default in Task API.", -1, m_task.m_nJoinedCommunityID);
		assertEquals("No community should be joined by default in model.", -1, m_model.GetJoinedCommunityID());

		assertEquals("No community should be left by default.", -1, m_task.m_nLeftCommunityID);
		assertEquals("No community should be left by default in model.", -1, m_model.GetLeftCommunityID());

		IJSONParser parser = JSONParser.GetInstance();
		parser.ParseJSONObject(strJSON);

		m_control.ProcessAction(parser);

		assertNull("There should not be an error after leaving.", m_model.GetError());

		assertEquals("Community was not left correctly on the Task API.", 534, m_task.m_nLeftCommunityID);
		assertEquals("Incorrect community left on model.", 534, m_model.GetLeftCommunityID());

		assertEquals("No community should be joined in Task API after leaving.", -1, m_task.m_nJoinedCommunityID);
		assertEquals("No community should be joined in model after leaving.", -1, m_model.GetJoinedCommunityID());
	}

	public void testJoinAndLeaveCommunity()
	{
		String strJSON = "{ \"" + UserRESTConstants.USER_FORMAT_NAME + "\": {" +
			"\"" + UserRESTConstants.USER_JOIN_COMMUNITIES + "\": \"666\"," +
			"\"" + UserRESTConstants.USER_LEAVE_COMMUNITIES + "\": \"534\"" +
			"} }";

		assertEquals("No community should be joined by default in Task API.", -1, m_task.m_nJoinedCommunityID);
		assertEquals("No community should be joined by default in model.", -1, m_model.GetJoinedCommunityID());

		assertEquals("No community should be left by default.", -1, m_task.m_nLeftCommunityID);
		assertEquals("No community should be left by default in model.", -1, m_model.GetLeftCommunityID());

		IJSONParser parser = JSONParser.GetInstance();
		parser.ParseJSONObject(strJSON);

		m_control.ProcessAction(parser);

		assertNull("There should not be an error after joining and leaving.", m_model.GetError());

		assertEquals("Community was not joined correctly on the Task API.", 666, m_task.m_nJoinedCommunityID);
		assertEquals("Incorrect community joined on model.", 666, m_model.GetJoinedCommunityID());

		assertEquals("Community was not left correctly on the Task API.", 534, m_task.m_nLeftCommunityID);
		assertEquals("Incorrect community left on model.", 534, m_model.GetLeftCommunityID());
	}

	public void testError()
	{
//		String strJSON = "garbage";

		// TODO: test that this sets an error on the model and redirects to the correct page.
	}
}