package com.plumtree.portalpages.test.rest.user;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.rest.*;
import com.plumtree.portalpages.rest.user.*;
import com.plumtree.portalpages.rest.utils.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.taskapi.test.portalui.mock.*;

/**
 * Tests the display functionality of the UserRESTDP.
 * 
 * NOTE: Since this API only supports integer values (IDs), there
 * is no need to test JS escaping and javascript hacks like in the
 * DirRESTDPTest. 
 */
public class UserRESTDPTest extends TestCase
{
	public MockEnvironment m_environment = new MockEnvironment();
	public UserRESTModel m_model = new UserRESTModel();
	public UserRESTDP m_page = new UserRESTDP();
	public MockTaskAPIUICommunityService m_task;

	public void setUp() throws Exception
	{
		super.setUp();

		// This will probably log an error, but it will init what we want.
		m_environment.Init();
		m_environment.m_models.PutElement(UserRESTModel.STR_MVC_CLASS_NAME, m_model);
		m_environment.RegisterPage(m_page);

		m_task = new MockTaskAPIUICommunityService();
		TaskAPIUICommunityService.SetMockInstanceForDebug(m_task);
	}

	public void tearDown() throws Exception
	{
		super.tearDown();

		// Release the mock instance.
		TaskAPIUICommunityService.SetMockInstanceForDebug(null);
	}

	public void testSuccess()
	{
		m_model.JoinCommunity(534);
		m_model.LeaveCommunity(666);

		MockWebData output = new MockWebData();
		m_page.Display(output);

		String strOutput = output.m_strData;

		assertNotNull("Page output should be non-null.", strOutput);

		assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.StartsWith(strOutput, "/*"));
		assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.EndsWith(strOutput, "*/"));

		// The parser can handle comment-filtered JSON.
		IJSONParser parser = JSONParser.GetInstance();
		parser.ParseJSONObject(strOutput);

		assertEquals("Unexpected JSON object name.", UserRESTConstants.USER_FORMAT_NAME, parser.GetObjectName());

		assertEquals("Unexpected joined community id.", "534", parser.GetMember(UserRESTConstants.USER_JOIN_COMMUNITIES));
		assertEquals("Checking that Task API was called to join the correct community.",
			534, m_task.m_nJoinedCommunityID);

		assertEquals("Unexpected left community id.", "666", parser.GetMember(UserRESTConstants.USER_LEAVE_COMMUNITIES));
		assertEquals("Checking that Task API was called to leave the correct community.",
			666, m_task.m_nLeftCommunityID);
	}

	public void testError()
	{
		m_model.SetError(CommonRestErrors.GENERAL);

		MockWebData output = new MockWebData();
		m_page.Display(output);

		String strOutput = output.m_strData;

		assertNotNull("Page output should be non-null.", strOutput);

		assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.StartsWith(strOutput, "/*"));
		assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.EndsWith(strOutput, ""));

		// The parser can handle comment-filtered JSON.
		IJSONParser parser = JSONParser.GetInstance();
		parser.ParseJSONObject(strOutput);

		assertEquals("Unexpected JSON object name.", RESTErrorConstants.ERROR_FORMAT_NAME, parser.GetObjectName());

		assertEquals("Unexpected error text.", CommonRestErrors.GENERAL.GetMessage(), parser.GetMember(RESTErrorConstants.ERROR_TEXT));
		assertEquals("Unexpected error code.", XPConvert.ToString(CommonRestErrors.GENERAL.GetCode()), parser.GetMember(RESTErrorConstants.ERROR_CODE));
	}
}