/**
 * 
 */
package com.plumtree.portalpages.test.rest.utils;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.rest.utils.*;

/**
 * Tests the JSON generated by JSONSerializer
 * @TODO: Currently just outputting result without validation. Validate visually. Need a way to
 * enumerate hashtable content in a predictable order.
 * 
 * 
 * @author rozhang
 */
public class JSONSerializerTest extends TestCase
{
	/**
	 *
	 * @author rozhang
	 */
	public void setup()
	{
		
	}
	
	/**
	 * Tests for all the supported object types
	 */
	public void testSimpleHashtable()
	{
		XPHashtable obj = new XPHashtable();
		// try different types
		obj.PutElement("integer1", new Integer(-2));
		obj.PutElement("integer2", new Integer(0));
		obj.PutElement("integer3", new Integer(234234));
		obj.PutElement("float1", new Float(23.10));
		obj.PutElement("float2", new Float(-0.1));
		obj.PutElement("long", new Long(12345678));
		obj.PutElement("double1", new Double(234234.0));
		obj.PutElement("double2", new Double(234234234));
		obj.PutElement("char", new Character('\n'));
		obj.PutElement("char2", new Character('a'));
		obj.PutElement("char3", 'c');
		obj.PutElement("String", "teststring");
		obj.PutElement("bool1", new Boolean(true));
		obj.PutElement("bool2", new Boolean(false));
		XPDateTime dateNow = new XPDateTime();
		
		obj.PutElement("dateNow", new Long(dateNow.GetTimeInMilliSeconds()));
		
		JSONSerializer jsonOut = new JSONSerializer(obj);
		XPSystem.Out.Write( jsonOut.GenerateStringRepresentation(false) );
		
	}
	
	/**
	 * Tests an array 
	 */
	public void testSimpleHashtableWithArray()
	{
		XPHashtable obj = new XPHashtable();
		obj.PutElement("integer1", new Integer(-2));
		obj.PutElement("String", "teststring");
		XPArrayList list = new XPArrayList();
		list.Add(new Integer(-2));
		list.Add(new Integer(0));
		list.Add(new Integer(16225));
		list.Add(new Float(23.10));
		list.Add(new Float(-0.1));
		list.Add(new Double(234234.0));
		list.Add(new Double(234234234));
		list.Add(new Character('\n'));
		list.Add(new Character('a'));
		list.Add('c');
		list.Add("teststring");
		list.Add(new Boolean(true));
		list.Add(new Boolean(false));
		obj.PutElement("listproperty", list);
		
		JSONSerializer jsonOut = new JSONSerializer(obj);
		XPSystem.Out.Write( jsonOut.GenerateStringRepresentation(false) );
		
	}
	
	/**
	 * Test serial and nested arrays
	 */
	public void testSerialNestedArrays()
	{
		XPHashtable obj = new XPHashtable();
		obj.PutElement("integer1", new Integer(-2));
		obj.PutElement("String", "teststring");
		XPArrayList list = new XPArrayList();
		list.Add(new Integer(-2));
		list.Add(new Float(23.10));
		list.Add(new Double(234234.0));
		list.Add(new Character('\n'));
		
		XPArrayList list2 = new XPArrayList();
		list2.Add(new Integer(0));
		list2.Add(new Float(-0.1));
		list2.Add(new Double(234234234));
		list2.Add('c');
		list2.Add("teststring");
		list.Add(list2);
		
		XPArrayList list3 = new XPArrayList();
		list3.Add(new Integer(0));
		list3.Add(new Float(-0.1));
		list3.Add(new Double(234234234));
		list3.Add('c');
		list3.Add("teststring");
		list.Add(list3);

		
		list.Add(new Character('a'));
		list.Add('c');
		list.Add("teststring");
		obj.PutElement("listproperty", list);
		
		JSONSerializer jsonOut = new JSONSerializer(obj);
		XPSystem.Out.Write( jsonOut.GenerateStringRepresentation(false) );
		
	}
	
	/**
	 * Tests serial and nested hashtables
	 */
	public void testSerialNestedHashtables()
	{
		XPHashtable obj = new XPHashtable();
		// try different types
		obj.PutElement("integer1", new Integer(-2));
		obj.PutElement("float1", new Float(23.10));
		obj.PutElement("double1", new Double(234234.0));
		obj.PutElement("char", new Character('\n'));
		obj.PutElement("String", "teststring");
		
		XPHashtable obj2 = new XPHashtable();
		// try different types
		obj2.PutElement("l2a_integer1", new Integer(-2));
		obj2.PutElement("l2a_float1", new Float(23.10));
		obj2.PutElement("l2a_double1", new Double(234234.0));
		obj2.PutElement("l2a_char", 'c');
		obj2.PutElement("l2a_String", "teststring");
		
		obj.PutElement("nestedObj_L2A", obj2);
		
		XPHashtable obj3 = new XPHashtable();
		// try different types
		obj3.PutElement("l2g_integer1", new Integer(-2));
		obj3.PutElement("l2g_float1", new Float(23.10));
		obj3.PutElement("l2g_double1", new Double(234234.0));
		obj3.PutElement("l2g_char", 'c');
		obj3.PutElement("l2g_String", "teststring");
		
		obj.PutElement("nestedObj_L2B", obj3);
		
		JSONSerializer jsonOut = new JSONSerializer(obj);
		XPSystem.Out.Write( jsonOut.GenerateStringRepresentation(false) );
		
	}
	
	/**
	 * 
	 */
	public void testHashtableInArrayNesting()
	{
		XPHashtable obj = new XPHashtable();
		XPArrayList list = new XPArrayList();
		obj.PutElement("array1", list);
		
		XPHashtable obj1 = new XPHashtable();
		obj1.PutElement("l2_h1_string", "test string");
		obj1.PutElement("l2_h1_integer", new Integer(-234));
		obj1.PutElement("l2_h1_float", new Float(0.01));
		XPHashtable obj2 = new XPHashtable();
		obj2.PutElement("l2_h2_string", "test string");
		obj2.PutElement("l2_h2_integer", new Integer(-234));
		obj2.PutElement("l2_h2_float", new Float(0.01));
		XPHashtable obj3 = new XPHashtable();
		obj3.PutElement("l2_h3_bool", new Boolean(true));
		
		list.Add(obj1);
		list.Add(obj2);
		list.Add(obj3);
		
		JSONSerializer jsonOut = new JSONSerializer(obj);
		XPSystem.Out.Write( jsonOut.GenerateStringRepresentation(false) );
		
	}
	
	/**
	 * Test escape encoding
	 */
	public void testStringEscapeEncoding()
	{
		XPHashtable obj = new XPHashtable();
		// try different types
		obj.PutElement("singleQuote", "'");
		obj.PutElement("doubleQuote", "\"");
		obj.PutElement("backSlash", "\\");
		obj.PutElement("forwasrdSlash", "/");
		obj.PutElement("backSpace", "\b");
		obj.PutElement("formFeed", "\f");
		obj.PutElement("newLine", "\n");
		obj.PutElement("carriageReturn", "\r");
		obj.PutElement("horizontalTab", "\t");
		obj.PutElement("greaterThan", ">");
		obj.PutElement("lessThan", "<");
		
		XPArrayList list = new XPArrayList();
		list.Add("'");
		list.Add("\"");
		list.Add("\\");
		list.Add("/");
		list.Add("\b");
		list.Add("\f");
		list.Add("\n");
		list.Add("\r");
		list.Add("\t");
		list.Add("<");
		list.Add(">");
		
		obj.PutElement("arrayEncoding", list);
		
		JSONSerializer jsonOut = new JSONSerializer(obj);
		XPSystem.Out.Write( jsonOut.GenerateStringRepresentation(false) );
		
	}
	
	/**
	 * Test handling of empty and null values
	 */
	public void testEmptyValues()
	{
		XPHashtable obj = new XPHashtable();
		obj.PutElement("emptypropvalue", "");
		
		XPArrayList list1 = new XPArrayList();
		obj.PutElement("emptystring", list1);
		
		JSONSerializer jsonOut = new JSONSerializer(obj);
		XPSystem.Out.Write( jsonOut.GenerateStringRepresentation(false) );
		
	}
}
