package com.plumtree.taskapi.test.portalui;

import junit.framework.*;

import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.community.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.taskapi.portalui.*;

/**
 * This tests the new methods on the TaskAPIUICommunityService class,
 * but not the pre-existing methods on the TaskAPIUICommunity class.
 * 
 * It does not test PEIs.
 */
public class TaskAPIUICommunityServiceTest extends TestCase
{
	public static final int MEMBER_COMMUNITY_1 = 214;
	public static final int MEMBER_COMMUNITY_2 = 754;

	public static final int COMMUNITY_1 = 937;
	public static final int COMMUNITY_2 = 478;

	protected MockEnvironment m_environment;
	protected ITaskAPIUICommunity m_task;
	protected MockPTCommunityManager m_manager;

   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();

   		m_task = TaskAPIUICommunityService.GetInstance();
		m_environment = new MockEnvironment();

		MockPTSession ptSession = (MockPTSession) m_environment.GetUserSession();
		m_manager = ptSession.m_communityObjectManager;
		MockPTSessionInfo ptSessionInfo = (MockPTSessionInfo) ptSession.GetSessionInfo();

		// The community membership query only contains object IDs.
		int[] membershipColumns = {PT_PROPIDS.PT_PROPID_OBJECTID};
		Object[][] membershipData = {{new Integer(MEMBER_COMMUNITY_1), new Integer(MEMBER_COMMUNITY_2)}};

		MockPTQueryResult qrCommunityMembership = new MockPTQueryResult();
		// True means the data does not need to be flipped (I.E. It's in the right format).
		qrCommunityMembership.SetData(membershipColumns, membershipData, true);

		ptSessionInfo.m_communityMembership = qrCommunityMembership;
   	}

   	public void tearDown() throws Exception
   	{
   		super.tearDown();

   		m_task = null;
   		m_environment = null;
   	}

   	public void testMembership()
   	{
   		assertTrue("User should be a member of this community.",
   			m_task.IsCommunityMember(m_environment, MEMBER_COMMUNITY_1));

   		assertFalse("User should not be a member of this community.",
   			m_task.IsCommunityMember(m_environment, COMMUNITY_1));
   	}

   	public void testJoinCommunity()
   	{
   		assertEquals("By default should not have joined any communities.", -1, m_manager.m_nJoinedCommunityID);

   		assertFalse("Join should return false if user is already a member.", m_task.JoinCommunity(m_environment, MEMBER_COMMUNITY_1));

   		assertEquals("After skipped join, should not have joined any communities.", -1, m_manager.m_nJoinedCommunityID);

   		assertTrue("Join should return true when joining a community.", m_task.JoinCommunity(m_environment, COMMUNITY_1));

   		assertEquals("Should have joined community.", COMMUNITY_1, m_manager.m_nJoinedCommunityID);
   		assertEquals("Should have joined community with membership type.",
   			PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE, m_manager.m_nJoinedCommunityMembershipType);

   		// NOTE: Not testing PEIs
   	}

   	public void testLeaveCommunity()
   	{
   		assertEquals("By default should not have left any communities.", -1, m_manager.m_nLeftCommunityID);

   		assertFalse("Leave should return false if user is not a member.", m_task.LeaveCommunity(m_environment, COMMUNITY_1));

   		assertEquals("After skipped leave, should not have left any communities.", -1, m_manager.m_nLeftCommunityID);

   		assertTrue("Leave should return true when leaving a community.", m_task.LeaveCommunity(m_environment, MEMBER_COMMUNITY_1));

   		assertEquals("Should have left community.", MEMBER_COMMUNITY_1, m_manager.m_nLeftCommunityID);

   		// NOTE: Not testing PEIs
   	}
}