package com.plumtree.taskapi.test.portalui.mock;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;

public class MockTaskAPIUICommunityService implements ITaskAPIUICommunity
{
	/** UNIT TEST HELPERS BEGIN **/
	
	public int m_nJoinedCommunityID = -1;
	public int m_nLeftCommunityID = -1;
	
	public int m_currCommId = -1;
	public int m_currPageId = -1;
	/** Access mock Communities with MockAddCommunity, MockRemoveCommunity and MockGetCommunity methods  **/
	protected XPHashtable m_comms = new XPHashtable(); 
	/** **/
	protected XPHashtable m_pages = new XPHashtable();
	/** Each key is a community id (Integer) with value containing a list of sub community ids (Integer) **/
	protected XPHashtable m_commStructure = new XPHashtable();
	
	
	
	/**
	 * ** TEST METHOD **
	 * @param commId
	 * @param commName
	 * @param subCommIds
	 * @param pageIds
	 */
	public void MockAddCommunity(int commId, String commName, int[] subCommIds, int[] pageIds)
	{
		CommunityEntry entry = new CommunityEntry(commId, commName);
		if ( subCommIds != null ) 
			entry.SetSubCommunities(subCommIds);
		if ( pageIds != null )
			entry.SetCommPages(pageIds);
		m_comms.PutElement(new Integer(commId), entry);
	}
	
	/**
	 * ** TEST METHOD **
	 * @param commId
	 * @return
	 */
	public CommunityEntry MockGetCommunity(int commId)
	{
		return (CommunityEntry)m_comms.GetElement(new Integer(commId));
	}
	
	/**
	 * ** TEST METHOD **
	 * Adds subcommunities to specified community if the subcommunities don't already exist.
	 * Will not overwrite existing subcommunities on the parent community
	 * @param commId
	 * @param subCommIds
	 */
	public void MockAddSubCommunities(int commId, int[] subCommIds)
	{
		CommunityEntry ce = MockGetCommunity(commId);
		ce.SetSubCommunities(subCommIds);
	}
	
	/**
	 * ** TEST METHOD **
	 * Verifies passed in community structure with the mock structure configured in the current instance
	 *  
	 * @param topCommId
	 * @param depth Levels of sub communities to check
	 * @param structureMap Sub community structure data to verify with. Entry key is a comm id (Integer), with list of sub comm values (Integer)
	 * @return 0 if data is valid or the community id which test data does not correspond, or has subcommunities that does not correspond with the validation data
	 */
	public int VerifySubCommunityStructure(int topCommId, int maxDepth, XPHashtable structureMap)
	{
		return RecursiveVerifySubCommunityStructure(topCommId, maxDepth, structureMap, 0);
	}
	
	/**
	 * 
	 * @param topCommId
	 * @param maxDepth
	 * @param structureMap
	 * @param currDepth Current depth where top level community is 0, first subcommunites are 1 etc.
	 * @return
	 */
	private int RecursiveVerifySubCommunityStructure(int topCommId, int maxDepth, XPHashtable structureMap, int currDepth)
	{
		if (structureMap==null) { throw new XPIllegalArgumentException("structureMap is null");}
		
		IXPList testSubComms 	= (IXPList)structureMap.GetElement(topCommId);
		CommunityEntry ce 		= MockGetCommunity(topCommId);
		IXPList realSubComms 	= ce.m_subCommIds;
		// does community exist?
		if ( ce == null ) return topCommId; 
		
		// no sub comms?
		if ( testSubComms.IsEmpty() && realSubComms.IsEmpty() ) return 0;
		
		// contain same nr of sub comms?
		if ( ! (testSubComms == null || testSubComms.IsEmpty()) && realSubComms.IsEmpty() ) return topCommId;  
		
		// check each subcommunity id and their subcommunities
		if ( !testSubComms.ContainsAll(realSubComms) ) return topCommId;
		
		if ( currDepth < maxDepth ) {
			for ( int i = 0; i < testSubComms.GetSize(); i++ ) {
				int currCommId = ((Integer)testSubComms.GetElement(i)).intValue();
				int result = RecursiveVerifySubCommunityStructure(currCommId, maxDepth, structureMap, 1);
				if ( result != 0) return currCommId;
			}
		}
		return 0;
		
	}
	
	/**
	 * 
	 * @param pageId
	 * @param pageName
	 * @param pageType
	 */
	public void MockAddPage(int pageId, String pageName, int pageType)
	{
		PageEntry entry = new PageEntry(pageId, pageName, pageType);
		m_pages.PutElement(new Integer(pageId), entry);
	}
	
	/**
	 * ** TEST METHOD **
	 * @param commId
	 * @return
	 */
	public PageEntry MockGetPage(int pageId)
	{
		return (PageEntry)m_pages.GetElement(new Integer(pageId));
	}
	

	
	
	/** UNIT TEST HELPERS END **/
	
	public boolean CheckUserAccessLevelToCommunity(AActivitySpace owner,
			int nAccessLevel, int nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean CheckUserAccessLevelToCurrentCommunity(AActivitySpace owner,
			int nAccessLevel) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean CheckUserAccessLevelToCurrentCommunityPage(
			AActivitySpace owner, int nAccessLevel) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL CreateCommunityCommonOpenerURL(AActivitySpace owner,
			int nCommunityID, String strCommunityName) {
		return TaskAPIUICommunity.CreateCommunityCommonOpenerURL(owner, nCommunityID, strCommunityName);
	}

	public IPTURL CreateCommunityPageCommonOpenerURL(AActivitySpace owner,
			int nCommunityID, int nCommunityPageID, String strCommunityPageName) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
			int nProfileUserID, String sProfileUserName) {
		throw new XPNotImplementedException();
	}

	public IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
			int nProfileUserID, String sProfileUserName, String strURLTitle) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
			int nProfileUserID, String sProfileUserName, String strURLTitle,
			int nPageId, String strPageName) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner) {
		// TODO Auto-generated method stub
		return null;
	}

	public XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner,
			boolean bIncludeOneClick, boolean bInheritTemplate,
			int nPageTemplate) {
		// TODO Auto-generated method stub
		return null;
	}

	public int GetCommunityIDFromPTURL(IPTURL ptURL) {
		return TaskAPIUICommunity.GetCommunityIDFromPTURL(ptURL);
	}

	public String GetCommunityName(AActivitySpace owner, int nCommunityID) {
		CommunityEntry ce = MockGetCommunity(nCommunityID);
		return ce.m_commName;
	}

	public int GetCommunityPageIDFromPTURL(IPTURL ptURL) {
		// TODO Auto-generated method stub
		return 0;
	}

	public XPArrayList GetCommunityPagesAsURLs(AActivitySpace owner, int nCommunityID) {
		CommunityEntry ce = MockGetCommunity(nCommunityID);
		if ( ce == null ) {
			throw new XPIllegalStateException("No Community exists with id: "+nCommunityID);
		}
		if ( ce.m_commPageIds == null ) {
			ce.m_commPageIds = new XPArrayList(); // defensive coding
		}
		return ce.m_commPageIds;
	}

	public int GetCurrentCommunityID(AActivitySpace owner) {
		if ( m_currCommId == -1 ) {
			throw new XPIllegalStateException("No current Community set!");
		}
		CommunityEntry ce = MockGetCommunity(m_currCommId);
		return ce.m_commId;
	}

	public String GetCurrentCommunityName(AActivitySpace owner) {
		if ( m_currCommId == -1 ) {
			throw new XPIllegalStateException("No current Community set!");
		}
		CommunityEntry ce = MockGetCommunity(m_currCommId);
		if ( ce == null ) {
			throw new XPIllegalStateException("No Community with current Community id: "+m_currPageId+" was found!");
		}
		return ce.m_commName;
	}

	public int GetCurrentCommunityPageID(AActivitySpace owner)  
	{
		return m_currPageId;
	}

	public String GetCurrentCommunityPageName(AActivitySpace owner) 
	{
		if ( m_currPageId == -1 ) {
			throw new XPIllegalStateException("No current Page set!");
		}
		PageEntry pe = MockGetPage(m_currPageId);
		if ( pe == null ) {
			throw new XPIllegalStateException("No Page with current page id: "+m_currPageId+" was found!");
		}
		return pe.m_pageName;
	}

	public XPArrayList GetCurrentCommunityPagesAsURLs(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetCurrentPageAsURL(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetCurrentParentCommunityAsURL(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public int GetCurrentParentCommunityID(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetCurrentRelatedCommunitiesAsURLs(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public int[] GetCurrentRelatedCommununityIDs(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetCurrentSubCommunitiesAsURLs(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public int[] GetCurrentSubCommunityIDs(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public int GetDefaultCommunityID(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetMyCommunitiesAsURLs(AActivitySpace owner, boolean bUseCachedData) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetMyMandatoryCommunitiesWithTabsAsURLs(AActivitySpace owner, boolean bUseCachedData) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetParentCommunityAsURL(AActivitySpace owner, int nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public int GetParentCommunityID(AActivitySpace owner, int nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetRelatedCommununitiesAsURLs(AActivitySpace owner, int nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public int[] GetRelatedCommununityIDs(AActivitySpace owner, int nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetSubCommununitiesAsURLs(AActivitySpace owner, int nCommunityID) {
		CommunityEntry ce = MockGetCommunity(nCommunityID);
		XPArrayList list = new XPArrayList();
		XPArrayList subcommids = ce.m_subCommIds;
		for ( int i = 0;  subcommids != null && i < subcommids.GetSize(); i++ ) {
			Integer subCommId = (Integer)subcommids.GetElement(i);
			CommunityEntry sce = MockGetCommunity(subCommId.intValue());
			if ( sce != null ) { 
				list.Add( CreateCommunityCommonOpenerURL(owner, subCommId, sce.m_commName) );
			} else {
				XPSystem.Out.WriteLine("MockTaskAPIUICommunity.GetSubCommununitiesAsURLs: Unable to find mock Community with id: "+subCommId);
			}
		}
		
		return list;
	}

	public int[] GetSubCommununityIDs(AActivitySpace owner, int nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForAddCommunityPortletsEditor(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForAddCommunityPortletsFlyout(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForCommunityKnowledgeDirectory(AActivitySpace owner,
			int nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForCreateCommunityPage(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForCreateCommunityPageOneClick(AActivitySpace owner,
			boolean bInheritTemplate, int nPageTemplate) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public XPArrayList GetURLForCurrentCommunity(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForCurrentCommunityEditor(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForEditPortletPreferencesEditor(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForJoinCommunitiesEditor(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForJoinCurrentCommunityAction(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForUnsubscribeCommunitiesEditor(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public IPTURL GetURLForUnsubscribeCurrentCommunityAction(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean IsCommunityMember(AActivitySpace _asOwner, int _nCommunityID) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean IsCurrentCommunityUserProfileCommunity(AActivitySpace owner) 
	{
		return ( m_currCommId == PT_INTRINSICS.PT_PROFILE_COMMUNITY );
	}

	public boolean IsCurrentPageCommunityPage(AActivitySpace owner) {
		return (m_currCommId > 0);
	}

	public boolean IsCurrentPageMyPortalPage(AActivitySpace owner) {
		return ( m_currPageId != -1 );
	}

	public boolean IsCurrentUserAbleToEditCurrentCommunityPage(
			AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean IsCurrentUserCommunityOwner(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean IsUserAbleToAccessCurrentCommunity(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean IsUserAbleToJoinCurrentCommunity(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean IsUserMemberOfCurrentCommunity(AActivitySpace owner) {
		// TODO Auto-generated method stub
		throw new XPNotImplementedException();
	}

	public boolean JoinCommunity(AActivitySpace _asOwner, int _nCommunityID)
			throws XPException
	{
		m_nJoinedCommunityID = _nCommunityID;
		return true;
	}

	public boolean LeaveCommunity(AActivitySpace _asOwner, int _nCommunityID)
			throws XPException {
		m_nLeftCommunityID = _nCommunityID;
		return true;
	}
	
	public class CommunityEntry
	{
		public int m_commId;
		public String m_commName;
		
		public XPArrayList m_subCommIds = new XPArrayList();
		public XPArrayList m_commPageIds = new XPArrayList();
		
		public CommunityEntry(int commId, String commName) {
			m_commId   = commId;
			m_commName = commName;
		}
		
		public void SetSubCommunities(int[] subCommIds) {
			for ( int i = 0; i < subCommIds.length; i++ ) 
				m_subCommIds.Add(subCommIds[i]);
		}
		
		public void SetCommPages(int[] pageIds) {
			for ( int i = 0; i < pageIds.length; i++ ) {
				if ( !m_commPageIds.Contains(pageIds[i])) {
					m_commPageIds.Add(pageIds[i]);
				}
			}
		}
		
	}
	
	public class PageEntry
	{
		public static final int PAGETYPE_MYPAGE = 0;
		public static final int PAGETYPE_COMMUNITY = 1;
		
		public int m_pageId;
		public String m_pageName;
		
		public int m_pageType;
		
		public PageEntry(int pageId, String pageName, int pageType)
		{
			m_pageId = pageId;
			m_pageName = pageName;
			m_pageType = pageType;
		}
	}
}