using System;
using com.plumtree.openkernel.config;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using AppWarmUp=com.plumtree.uiinfrastructure.application.AppWarmUp;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.application.varpacks
{
  public class PTAnalyticsVarPack : BaseVarPack
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.application.varpacks.PTAnalyticsVarPack");
    
    /// <summary>
    /// The string ID of this variable package. 
    /// </summary>
    public const String VARPACK_ID = "PTAnalyticsVarPack";
    // OpenConfig component type
    public const String ANALYTICS_COMMUNICATION_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/analytics-communication";
    private XPHashtable m_mapSettings;
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()
     */
     
    public override String GetVarPackID()
    {
      return VARPACK_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()
     */
     
    public override IXPEnumerator GetVarPackKeys()
    {
      return m_mapSettings.GetKeys();
    }
    /* (non-Javadoc)
     * @see com.plumtree.xpsupport.web.BaseVarPack#Load()
     */
     
    protected override void Load()
    {
      try
      {
        m_mapSettings = LoadSettings();
      }
      catch (Exception e)
      {
        log.Warn("Loading of Analytics settings failed.");
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.xpsupport.web.BaseVarPack#Reload()
     */
     
    protected override void Reload()
    {
      Load();
    }
    /* (non-Javadoc)
     * You cannot expire the content. You can only reload it. This method does nothing.
     *
     * @see com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()
     */
     
    protected override void ExpireContent()
    {
    }
    /* (non-Javadoc)
     * @see com.plumtree.xpsupport.web.BaseVarPack#GetValue(java.lang.String)
     */
     
    protected override Object GetValue(String key)
    {
      if (null != m_mapSettings)
      {
        return m_mapSettings.GetElement(key);
      } else
      {
        return null;
      }
    }
    private XPHashtable LoadSettings()
    {
      XPHashtable mapReturn = new XPHashtable();
      // Use OpenConfig to read the settings
      IOKContext configContext = AppWarmUp.GetOKConfigContext();
      IOKComponent component = null;
      component = configContext.getComponentByType(ANALYTICS_COMMUNICATION_COMPONENT_TYPE);
      if (null == component)
      {
        log.Warn("Loading of Analytics Communication setting component failed.");
        return null;
      }
      IOKSetting[] settings = component.querySettings();
      for (int j = 0;j < settings.Length;j++)
      {
        String strName = settings[j].getName();
        String strValue = null;
        //log.Info("Setting Loaded: " + strName);		        
        //log.Info("Setting type: " + settings[j].getDataType());
        int nSettingType = settings[j].getDataType();
        switch (nSettingType){
        case OKConfigDataTypes.TYPE_BOOLEAN:
        strValue = XPConvert.ToString(settings[j].getBooleanValue());
        break;
        case OKConfigDataTypes.TYPE_STRING:
        strValue = settings[j].getStringValue();
        break;
        case OKConfigDataTypes.TYPE_INTEGER:
        strValue = XPConvert.ToString(settings[j].getIntValue());
        break;
        case OKConfigDataTypes.TYPE_FLOAT:
        strValue = XPConvert.ToString(settings[j].getFloatValue());
        break;
        case OKConfigDataTypes.TYPE_DATE:
        strValue = XPConvert.ToString(settings[j].getDateValue());
        break;
        default:
        throw new XPException("Unknown data type:" + nSettingType);
        break;
        }
        //log.Info("Setting value: " + strValue);
        if ((null != strName) && (null != strValue))
        {
          mapReturn.PutElement(strName, strValue);
        }
      }
      return mapReturn;
    }
    public virtual String GetConfigValueAsString(String key)
    {
      return (String) GetValue(key);
    }
    public virtual int GetConfigValueAsInt(String key)
    {
      String strValue = (String) GetValue(key);
      if (null == strValue)
      {
        return -1;
      } else
      {
        return XPConvert.ToInteger(strValue);
      }
    }
    public virtual bool GetConfigValueAsBoolean(String key)
    {
      String strValue = (String) GetValue(key);
      if (null == strValue)
      {
        return false;
      } else
      {
        return XPConvert.ToBoolean(strValue);
      }
    }
  }
}