using System;
using com.plumtree.openfoundation.xml.dom;
using com.plumtree.openkernel.config;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.sso;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portaluiinfrastructure.application.varpacks
{
  /// <summary>
  /// This VarPack contains the Plumtree Application data.
  /// This extends the base config var pack, and adds extra data
  /// from the ptconfig.xml file.
  /// </summary>
  /// <author>John Osborne</author>
  public class PTConfigVarPack : ConfigVarPack
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.application.varpacks.PTConfigVarPack");
    // OpenConfig component types
    public const String PORTAL_DOCUMENTS_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/documents";
    public const String PORTAL_CRAWLERS_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/crawlers";
    public const String PORTAL_SEARCH_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/search";
    public const String PORTAL_STYLE_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/style";
    public const String PORTAL_COMMUNITIES_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/communities";
    public const String PORTAL_ADMINISTRATION_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/administration";
    public const String PORTAL_FAILOVER_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/failover";
    public const String PORTAL_INVITATIONS_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/invitations";
    public const String PORTAL_GATEWAY_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/gateway";
    
    /// <summary>
    /// mj: sso login page relative URL. E.g.: SSOServlet 
    /// </summary>
    private String m_sSSORelativeURL;
    
    /// <summary>
    /// mj: sso login page base URL. E.g.: /portal/SSOServlet 
    /// </summary>
    private String m_sSSOBaseURL = "";
    //private XPDocument m_xmlPTDoc;
    
    /// <summary>
    /// Constructor for PTConfigVarPack.
    /// </summary>
    /// <param name="__strPlatform">The current platform "Java" or "DotNet")</param>
    public PTConfigVarPack(String _strPlatform) : base(_strPlatform)
    {
    }
    
    /// <summary>
    /// JF- Returns the SSO Base URL. E.g.: /portal/SSOServlet
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSSOBaseURL()
    {
      return m_sSSOBaseURL;
    }
    
    /// <summary>
    /// JF- Returns the SSO relative URL. E.g.: SSOServlet
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSSORelativeURL()
    {
      return m_sSSORelativeURL;
    }
    
    /// <summary>
    /// Returns an xml element consisting of all the XML in the  specified
    /// section and subsection. Returns null if no such section or subsection
    /// exists.
    /// It first tries to get the element from the base class file, and then
    /// from the PTConfig.xml file.
    /// WARNING: if the element exists in both the base x_config.xml file and
    /// the PTconfig.xml file, only the element from the base x_config.xml
    /// file will be returned.
    /// </summary>
    /// <param name="_strSection"></param>
    /// <param name="_strSubSection"></param>
    /// <returns></returns>
    public virtual XPElement GetXMLElement(String _strSection, String _strSubSection)
    {
      log.Error("Accessing XML document directly no longer works.");
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()"></seealso>
    public override String GetVarPackID()
    {
      return VARPACK_ID;
    }
    
    /// <summary>
    /// This method loads the PTconfig.xml file into memory.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Load()"></seealso>
    protected override void Load()
    {
      base.Load();
      /*
       String strFileSeparator = XPFileSystemObject.GetPathSeparator();
       
       log.Info("Loading PTConfig XML document.");
       
       XPDocument xmlPTDoc = XPBuilder.LoadDocument(GetConfigPath() + strFileSeparator + "PTconfig.xml");
       */
       
      BuildSSOBaseURL();
      LoadSettingsIntoHashtable();
      // mj: init sso. if this is a reload, StaticInitSSO will be called later.
      SSOIntegrator.StaticInitConfig(this);
      PTLoginHelper.StaticInit(this);
      log.Info("Finished loading portal config XML document.");
    }
    
    /// <summary>
    /// Helper method to load a number of component settings from portalconfig.xml 
    /// and put them in a XPHashtable.
    /// This Hashtable will be used for the Memory Debug page where we need to be able
    /// to iterate through the keys and display all the name/value pairs.
    /// </summary>
    private void LoadSettingsIntoHashtable()
    {
      // Use OpenConfig to read the settings
      IOKContext configContext = AppWarmUp.GetOKConfigContext();
      IOKComponent component = null;
      component = configContext.getComponentByType(PORTAL_DOCUMENTS_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.DOCUMENTS_SECTION);
      component = configContext.getComponentByType(PORTAL_CRAWLERS_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.CRAWLERS_SECTION);
      component = configContext.getComponentByType(PORTAL_SEARCH_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.SEARCH_SECTION);
      component = configContext.getComponentByType(PORTAL_STYLE_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.STYLE_SECTION);
      component = configContext.getComponentByType(PORTAL_COMMUNITIES_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.COMMUNITIES_SECTION);
      component = configContext.getComponentByType(PORTAL_ADMINISTRATION_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.ADMINISTRATION_SECTION);
      component = configContext.getComponentByType(PORTAL_FAILOVER_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.FAILOVER_SECTION);
      component = configContext.getComponentByType(PORTAL_INVITATIONS_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.INVITATIONS_SECTION);
      component = configContext.getComponentByType(PORTAL_GATEWAY_COMPONENT_TYPE);
      LoadComponentSettings(component, PTConfigConstants.GATEWAY_SECTION);
      }
    
    /// <summary>
    /// This method reloads the PTconfig.xml file into memory. It clears the
    /// current data rather than delegating to Load().
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Reload()"></seealso>
    protected override void Reload()
    {
      base.Reload();
      Load();
      try
      {
        // mj: call StaticInitSSO in case SSO settings have changed.
        IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
        PTSSOVarPack vpSSOConfig = (PTSSOVarPack) application.GetVarPackManager().GetVariablePackage(PTSSOVarPack.VARPACK_ID);
        SSOIntegrator.StaticInitSSO(vpSSOConfig);
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to initialize SSO.");
      }
    }
    
    /// <summary>
    /// Helper method to build the SSO base URL based on the values from PTconfig.xml.
    /// </summary>
    private void BuildSSOBaseURL()
    {
      m_sSSORelativeURL = GetConfigValueAsString("SystemProperties", "SSOServletName",
       "value");
      m_sSSOBaseURL = GetConfigValueAsString("SystemProperties", "SSOVirtualDirectoryPath",
       "value");
      if (!XPStringUtility.EndsWith(m_sSSOBaseURL, "/"))
      {
        m_sSSOBaseURL+="/";
      }
      m_sSSOBaseURL+=GetConfigValueAsString("SystemProperties", "SSOServletName",
       "value");
      if (XPStringUtility.EndsWith(m_sSSOBaseURL, "?"))
      {
        m_sSSOBaseURL = XPStringUtility.Substring(m_sSSOBaseURL, 0, m_sSSOBaseURL.Length - 1);
        }
      log.Info("Config value: SSO Base URL has been set to: " + m_sSSOBaseURL);
      }
  }
}