using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.application.varpacks
{
  /// <summary>
  /// This VarPack contains the localized names for all the installed locales.
  /// </summary>
  /// <author>Stephen Chang</author>
  public class PTDirPrefsVarPack : BaseVarPack
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.application.varpacks.PTDirPrefsVarPack");
    
    /// <summary>
    /// The string ID of this variable package. 
    /// </summary>
    public const String VARPACK_ID = "PTDirPrefsVarPack";
    //	private static final String POPULAR_YES = "yes";
    //	private static final String POPULAR     = "popular";
    // See DirConstants.DIR_FOLD_DESC_NONE
    // DF, DA, DN
    private String m_strDocDescriptionType = "DA";
    // FF, FA, FN
    private String m_strFolderDescriptionType = "FN";
    
    /// <summary>
    /// The path to the folder in which SearchLocales.xml resides. 
    /// </summary>
    private XPArrayList m_xpPropColumns = null;
    // 1,2  (search, db)
    private int m_nBrowseBy = 1;
    private int m_nDefaultDocType = 107;
    // 1-99999
    private int m_nNumDocsPerPage = 20;
    // 1 to 8
    private int m_nNumFolderColumns = 3;
    // 1 to 5
    private int m_nNumSubSubFolders = 5;
    // 1,2,3,4 (left, right, top, bottom)
    private int m_nRelatedResourcesPlacement = 1;
    
    /// <summary>
    /// SCC- This XPArrayList contains all server config setting ids that are stored in this varpack
    /// We need it for the Memory Debug page where we need to be able to iterate through the keys to display all the values.
    /// </summary>
    private XPArrayList m_xpKeys;
    
    /// <summary>
    /// Constructor for PTDirPrefsVarPack.
    /// </summary>
    public PTDirPrefsVarPack() : base()
    {
      CreateKeysArrayList();
    }
    protected virtual void CreateKeysArrayList()
    {
      m_xpKeys = new XPArrayList();
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE));
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS));
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS));
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE));
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE));
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE));
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY));
      m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE));
      }
    
    /// <returns></returns>
    public virtual int GetBrowseBy()
    {
      return m_nBrowseBy;
    }
    
    /// <returns></returns>
    public virtual int GetDefaultDocType()
    {
      return m_nDefaultDocType;
    }
    
    /// <returns></returns>
    public virtual String GetDocDescriptionType()
    {
      return m_strDocDescriptionType;
    }
    
    /// <returns></returns>
    public virtual String GetFolderDescriptionType()
    {
      return m_strFolderDescriptionType;
    }
    
    /// <returns></returns>
    public virtual int GetNumDocsPerPage()
    {
      return m_nNumDocsPerPage;
    }
    
    /// <returns></returns>
    public virtual int GetNumFolderColumns()
    {
      return m_nNumFolderColumns;
    }
    
    /// <returns></returns>
    public virtual int GetNumSubSubFolders()
    {
      return m_nNumSubSubFolders;
    }
    
    /// <returns></returns>
    public virtual XPArrayList GetPropColumns()
    {
      return m_xpPropColumns;
    }
    
    /// <returns></returns>
    public virtual int GetRelatedResourcesPlacement()
    {
      return m_nRelatedResourcesPlacement;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()"></seealso>
    public override String GetVarPackID()
    {
      return VARPACK_ID;
    }
    
    /// <summary>
    /// This method will return an enumeration of the top level nodes in the XML
    /// tree that is SearchLocales.xml.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()"></seealso>
    public override IXPEnumerator GetVarPackKeys()
    {
      return m_xpKeys.GetEnumerator();
    }
    
    /// <summary>
    /// You cannot expire the settings content. You can only reload it. This
    /// method does nothing.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()"></seealso>
    protected override void ExpireContent()
    {
    }
    
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#GetValue(String)"></seealso>
    protected override Object GetValue(String strServerConfigID)
    {
      if (null == strServerConfigID)
      {
        return "";
      }
      int nServerConfigID = XPConvert.ToInteger(strServerConfigID);
      switch (nServerConfigID){
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE:
      return "FolderDescriptionType: " + GetFolderDescriptionType();
      goto case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS;
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS:
      return "NumSubSubFolders: " + GetNumSubSubFolders();
      goto case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS;
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS:
      return "NumFolderColumns: " + GetNumFolderColumns();
      goto case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE;
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE:
      return "NumDocsPerPage: " + GetNumDocsPerPage();
      goto case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE;
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE:
      return "DocDescriptionType: " + GetDocDescriptionType();
      goto case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE;
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE:
      return "RelatedResourcesPlacement: " + GetRelatedResourcesPlacement();
      goto case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY;
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY:
      return "BrowseBy: " + GetBrowseBy();
      goto case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE;
      case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE:
      return "DefaultDocType: " + GetDefaultDocType();
      goto default;
      default:
      return "No value for this setting.";
      break;
      }
    }
    
    /// <summary>
    /// This method loads the DirPrefs settings from the PTServerConfig table into memory.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Load()"></seealso>
    protected override void Load()
    {
      // This is the first place during startup that uses com.plumtree.server,
      // so it can take a while for this call to return, since it has to
      // initialize the core server.
      log.Info("Initializing Core Plumtree Server.");
      IPTSession ptGuestSession = PortalObjectsFactory.CreateSession();
      log.Info("Done Initializing Core Plumtree Server.");
      // Guest login -- The guest user password check is bypassed,
      // so we don't need to pass in the password.
      ptGuestSession.Connect(PT_INTRINSICS.PT_USER_GUEST, null, null);
      IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) ptGuestSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      // Load Current Settings
      Object oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE);
      if (null != oValue)
      {
        m_strFolderDescriptionType = (String) oValue;
      } else
      {
        log.Error("Unable to retrieve folder description type.");
      }
      oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS);
      if (null != oValue)
      {
        m_nNumSubSubFolders = XPConvert.ToInteger(oValue);
      } else
      {
        log.Error("Unable to retrieve number of sub sub folders.");
      }
      oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS);
      if (null != oValue)
      {
        m_nNumFolderColumns = XPConvert.ToInteger(oValue);
      } else
      {
        log.Error("Unable to retrieve number of folder columns.");
      }
      oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE);
      if (null != oValue)
      {
        m_nNumDocsPerPage = XPConvert.ToInteger(oValue);
      } else
      {
        log.Error("Unable to retrieve number of docs per page.");
      }
      oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE);
      if (null != oValue)
      {
        m_strDocDescriptionType = (String) oValue;
      } else
      {
        log.Error("Unable to retrieve document description type.");
      }
      oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE);
      if (null != oValue)
      {
        m_nRelatedResourcesPlacement = XPConvert.ToInteger(oValue);
      } else
      {
        log.Error("Unable to retrieve related resources placement.");
      }
      oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY);
      if (null != oValue)
      {
        m_nBrowseBy = XPConvert.ToInteger(oValue);
      } else
      {
        log.Error("Unable to retrieve browse by.");
      }
      oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE);
      if (null != oValue)
      {
        m_nDefaultDocType = XPConvert.ToInteger(oValue);
      } else
      {
        log.Error("Unable to retrieve default document type.");
      }
      LoadPropColumns(ptSCS);
    }
    
    /// <summary>
    /// This method reloads the DirPrefs settings. It delegates to Load().
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Reload()"></seealso>
    protected override void Reload()
    {
      Load();
    }
    
    /// <param name="_tSCS"></param>
    private void LoadPropColumns(IPTServerConfigSettings _tSCS)
    {
      Object oValue = _tSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PROP_COLUMNS);
      m_xpPropColumns = new XPArrayList();
      if (null != oValue)
      {
        String strAllProps = (String) oValue;
        if (0 == strAllProps.Length)
        {
          return;
        }
        XPStringTokenizer st = new XPStringTokenizer(strAllProps, " ");
        try
        {
          for (int i = 0;st.HasMoreTokens();i++)
          {
            int nProp = XPConvert.ToInteger(st.GetNextToken());
            m_xpPropColumns.Add(nProp);
          }
        }
        catch (Exception e)
        {
          log.Error(e, "Unable to load property columns.");
        }
      }
    }
  }
}