using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.openkernel.config;
namespace com.plumtree.portaluiinfrastructure.application.varpacks
{
  /// <summary>
  /// Varpack to load navigation sepcific settings.
  /// </summary>
  /// <author>Robert Zhang</author>
  public class PTNavSettingsVarPack : BaseVarPack
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.application.varpacks.PTNavSettingsVarPack");
    
    /// <summary>
    /// The string ID of this variable package. 
    /// </summary>
    public const String VARPACK_ID = "NavigationSettingsVarPack";
    
    /// <summary>
    /// Constants for settings defined in the file *
    /// </summary>
    public const String INTISCDROPDOWNMENU_TRUNCATION_WIDTH = "intISCDropDownMenuTruncationWidth";
    public const String INTISCDROPDOWNMENU_WIDTH = "intISCDropDownMenuWidth";
    public const String INTHORIZONTALNAVTAB_TRUNCATION_WIDTH = "intHorizontalNavTabTruncationWidth";
    public const String INTHORIZONTALNAVTAB_WIDTH = "intHorizontalNavTabWidth";
    public const String INTMYPORTLETPREFBUTTON_IN_PORTLETHEADER = "intMyPortletPrefButtonInPortletHeader";
    public const String INTPLUMTREEDPTABLESPACING = "intPlumtreeDPTableSpacing";
    public const String INTPLUMTREEDPLEFTWIDTH = "intPlumtreeDPLeftWidth";
    public const String INTPLUMTREEDPRIGHTWIDTH = "intPlumtreeDPRightWidth";
    public const String INTPLUMTREEDPLEFTWIDTHALONE = "intPlumtreeDPLeftWidthAlone";
    public const String INTPLUMTREEDPRIGHTWIDTHALONE = "intPlumtreeDPRightWidthAlone";
    // OpenConfig component type
    public const String PORTAL_NAVIGATION_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/navigation";
    
    /// <summary>
    /// Table for storing the navigation settings *
    /// </summary>
    private XPHashtable m_htNavigationSettings = null;
    
    /// <summary>
    /// Get the varpack ID.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()"></seealso>
    public override String GetVarPackID()
    {
      return VARPACK_ID;
    }
    
    /// <summary>
    /// Returns the enumeration of the navigation setting keys. 
    /// null if nothing was loaded.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()"></seealso>
    public override IXPEnumerator GetVarPackKeys()
    {
      try
      {
        return m_htNavigationSettings.GetKeys();
      }
      catch (Exception e)
      {
        return null;
      }
    }
    
    /// <summary>
    /// Not implemented.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()"></seealso>
    protected override void ExpireContent()
    {
    }
    
    /// <summary>
    /// Get the value of the specified navigation settings.
    /// null if settings doesn't exist.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#GetValue(String)"></seealso>
    protected override Object GetValue(String strNavSetting)
    {
      try
      {
        return m_htNavigationSettings.GetElement(strNavSetting);
      }
      catch (Exception e)
      {
        log.Warn("Unable to find the following NavigationSetting: " + strNavSetting);
        return null;
      }
    }
    
    /// <summary>
    /// This method loads the NavigationSettings.xml file into memory.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Load()"></seealso>
    protected override void Load()
    {
      log.Info("Loading Navigation Settings var pack...");
      m_htNavigationSettings = new XPHashtable();
      // Use OpenConfig to read the settings
      IOKContext configContext = AppWarmUp.GetOKConfigContext();
      IOKComponent component = null;
      component = configContext.getComponentByType(PORTAL_NAVIGATION_COMPONENT_TYPE);
      if (null == component)
      {
        log.Warn("Cannot retrieve component type: {0}", PORTAL_NAVIGATION_COMPONENT_TYPE);
        return;
      }
      IOKSetting[] settings = component.querySettings();
      for (int j = 0;j < settings.Length;j++)
      {
        String strName = settings[j].getName();
        String strValue = null;
        //log.Info("Setting Loaded: " + strName);		        
        //log.Info("Setting type: " + settings[j].getDataType());
        int nSettingType = settings[j].getDataType();
        switch (nSettingType){
        case OKConfigDataTypes.TYPE_BOOLEAN:
        strValue = XPConvert.ToString(settings[j].getBooleanValue());
        break;
        case OKConfigDataTypes.TYPE_STRING:
        strValue = settings[j].getStringValue();
        break;
        case OKConfigDataTypes.TYPE_INTEGER:
        strValue = XPConvert.ToString(settings[j].getIntValue());
        break;
        case OKConfigDataTypes.TYPE_FLOAT:
        strValue = XPConvert.ToString(settings[j].getFloatValue());
        break;
        case OKConfigDataTypes.TYPE_DATE:
        strValue = XPConvert.ToString(settings[j].getDateValue());
        break;
        default:
        throw new XPException("Unknown data type:" + nSettingType);
        break;
        }
        //log.Info("Setting value: " + strValue);
        if ((null != strName) && (null != strValue))
        {
          m_htNavigationSettings.PutElement(strName, strValue);
          log.Debug("Loading Navigation Settings: " + strName + " with value: " + strValue);
          }
      }
    }
    /*
     String strFileSeparator = XPFileSystemObject.GetPathSeparator();
     
     String strNavSettingsPath = GetConfigPath() + strFileSeparator + "NavigationSettings.xml";
     strNavSettingsPath = GeneralHelpers.FormatPath(strNavSettingsPath, strFileSeparator, false);
     
     XPDocument xmlDoc = XPBuilder.LoadDocument(strNavSettingsPath);
     XPElement rootNode = xmlDoc.GetDocumentElement();
     XPNodeList nlSettings = rootNode.GetChildNodes();
     // Make the hashtable big enough
     m_htNavigationSettings = new XPHashtable(nlSettings.GetLength());
     
     for (int i = 0; i < nlSettings.GetLength(); i++)
     {
     String sKey = nlSettings.Item(i).GetNodeName();
     if (!sKey.startsWith("#"))
     {
     String sValue = ((XPElement) nlSettings.Item(i)).GetAttributeNode("value").GetNodeValue();
     m_htNavigationSettings.PutElement(sKey, sValue);
     
     
     log.Debug("Loading Navigation Settings: " + sKey + " with value: "+sValue);
     
     }
     }
     */
     
    
    /// <summary>
    /// Clears and reloads all settings from the xml fie.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Reload()"></seealso>
    protected override void Reload()
    {
      m_htNavigationSettings = null;
      Load();
    }
  }
}