/*
 * Created on Feb 13, 2003
 *
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openkernel.config;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.sso;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.application.varpacks
{
  /// <summary>
  /// VarPack for sso.xml, a file used to customize various SSO integrations.
  /// It reads in all settings in the file and stores them in a map, which
  /// is available via the GetVendorSettings method.
  /// </summary>
  /// <author>Mike Jahr</author>
  public class PTSSOVarPack : BaseVarPack
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.application.varpacks.PTSSOVarPack");
    
    /// <summary>
    /// The string ID of this variable package. 
    /// </summary>
    public const String VARPACK_ID = "PTSSOVarPack";
    // OpenConfig component type
    public const String PORTAL_SSOVENDOR_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/ssovendor";
    private XPHashtable m_mapVendorSettings;
    private bool m_bLoadSucceeded = false;
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()
     */
     
    public override String GetVarPackID()
    {
      return VARPACK_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()
     */
     
    public override IXPEnumerator GetVarPackKeys()
    {
      return m_mapVendorSettings.GetKeys();
    }
    
    /// <summary>
    /// Returns an <c>XPHashtable</c> from <c>String</c> to
    /// <c>XPArrayList</c>, containing all the settings in
    /// the <c>sso.xml</c> config file.
    /// </summary>
    /// <returns>an XPHashtable of vendor settings</returns>
    public virtual XPHashtable GetVendorSettings()
    {
      if (!m_bLoadSucceeded && log.IsErrorEnabled())
      {
        log.Error("Loading of SSO vendor settings failed.");
      }
      return m_mapVendorSettings;
    }
    /* (non-Javadoc)
     * You cannot expire the content. You can only reload it. This method does nothing.
     *
     * @see com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()
     */
     
    protected override void ExpireContent()
    {
    }
    /* (non-Javadoc)
     * @see com.plumtree.xpsupport.web.BaseVarPack#GetValue(java.lang.String)
     */
     
    protected override Object GetValue(String arg0)
    {
      return m_mapVendorSettings.GetElement(arg0);
    }
    /* (non-Javadoc)
     * @see com.plumtree.xpsupport.web.BaseVarPack#Load()
     */
     
    protected override void Load()
    {
      // String strFileSeparator = XPFileSystemObject.GetPathSeparator();
      try
      {
        /*
         XPDocument xmlDoc = XPBuilder.LoadDocument(GetConfigPath() + strFileSeparator + "sso.xml");
         
         XPElement xmlRoot = xmlDoc.GetDocumentElement();
         
         m_mapVendorSettings     = LoadSettings(xmlRoot, "value");
         */
         
        m_mapVendorSettings = LoadSettings();
        m_bLoadSucceeded = true;
        // mj: re-init sso in case settings changed.
        SSOIntegrator.StaticInitSSO(this);
      }
      catch (Exception e)
      {
        log.Warn("Loading of SSO vendor settings failed.");
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.xpsupport.web.BaseVarPack#Reload()
     */
     
    protected override void Reload()
    {
      m_bLoadSucceeded = false;
      m_mapVendorSettings = null;
      Load();
    }
    
    /// <summary>
    /// This loads all settings from the given section.  Returns an XPHashtable containing
    /// strings mapped to XPArrayLists.
    /// </summary>
    private static XPHashtable LoadSettings()
    {
      log.Info("LoadSettings() called.");
      XPHashtable mapReturn = new XPHashtable();
      // Use OpenConfig to read the settings
      IOKContext configContext = AppWarmUp.GetOKConfigContext();
      IOKComponent component = null;
      component = configContext.getComponentByType(PORTAL_SSOVENDOR_COMPONENT_TYPE);
      if (null == component)
      {
        log.Warn("Cannot retrieve component type: {0}", PORTAL_SSOVENDOR_COMPONENT_TYPE);
        return mapReturn;
      }
      IOKSetting[] settings = component.querySettings();
      for (int j = 0;j < settings.Length;j++)
      {
        String strName = settings[j].getName();
        String strValue = null;
        //log.Info("Setting Loaded: " + strName);		        
        //log.Info("Setting type: " + settings[j].getDataType());
        int nSettingType = settings[j].getDataType();
        switch (nSettingType){
        case OKConfigDataTypes.TYPE_BOOLEAN:
        strValue = XPConvert.ToString(settings[j].getBooleanValue());
        break;
        case OKConfigDataTypes.TYPE_STRING:
        strValue = settings[j].getStringValue();
        break;
        case OKConfigDataTypes.TYPE_INTEGER:
        strValue = XPConvert.ToString(settings[j].getIntValue());
        break;
        case OKConfigDataTypes.TYPE_FLOAT:
        strValue = XPConvert.ToString(settings[j].getFloatValue());
        break;
        case OKConfigDataTypes.TYPE_DATE:
        strValue = XPConvert.ToString(settings[j].getDateValue());
        break;
        default:
        throw new XPException("Unknown data type:" + nSettingType);
        break;
        }
        //log.Info("Setting value: " + strValue);
        if ((null != strName) && (null != strValue))
        {
          // mj: if this setting is already in the map, we should append the 
          //     value to the existing list
          XPArrayList list = (XPArrayList) mapReturn.GetElement(strName);
          if (list == null)
          {
            list = new XPArrayList();
          }
          XPStringTokenizer strTokenizer = new XPStringTokenizer(strValue,
           ";");
          String strToken;
          while (strTokenizer.HasMoreTokens())
          {
            strToken = XPStringUtility.Trim(strTokenizer.GetNextToken());
            list.Add(strToken);
          }
          mapReturn.PutElement(strName, list);
        } else
        {
          log.Error("LoadSettings() failed to load {0} with value {1}", strName,
           strValue);
        }
      }
      return mapReturn;
    }
  }
}