using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openkernel.config;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.application.varpacks
{
  /// <summary>
  /// This var pack contains the time zone information.
  /// </summary>
  /// <author>SudhaS</author>
  public class PTTimeZoneVarPack : BaseVarPack
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.application.varpacks.PTTimeZoneVarPack");
    
    /// <summary>
    /// The string ID of this variable package. 
    /// </summary>
    public const String VARPACK_ID = "PTTimeZoneVarPack";
    // OpenConfig component type
    public const String PORTAL_TIMEZONES_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/timezones";
    private const String TIMEZONE_ID_PREFIX = "TimezoneID";
    private XPHashtable m_htTimeZoneXMLSettings;
    
    /// <summary>
    /// This XPArrayList contains all Locales that are loaded
    /// We need it for the Memory Debug page where we need to be able to iterate through the keys to display all the values.
    /// </summary>
    private XPArrayList m_xpKeys;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()"></seealso>
    public override String GetVarPackID()
    {
      return VARPACK_ID;
    }
    
    /// <summary>
    /// This method will return an enumeration of the top level nodes in the XML
    /// tree that is x_config.xml.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()"></seealso>
    public override IXPEnumerator GetVarPackKeys()
    {
      // We need to use this array list rather than the hash table, because
      // the hash table values are stored as Integers, but GetValue takes
      // Strings.
      return m_xpKeys.GetEnumerator();
    }
    
    /// <returns></returns>
    public virtual int GetVarPackLength()
    {
      if (m_htTimeZoneXMLSettings == null)
      {
        return 0;
      }
      return m_htTimeZoneXMLSettings.GetSize();
    }
    
    /// <summary>
    /// You cannot expire the x_config.xml content. You can only reload it. This
    /// method does nothing.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()"></seealso>
    protected override void ExpireContent()
    {
    }
    
    /// <summary>
    /// This method will return a chunk of from one level under the PTConfig
    /// node.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#GetValue(String)"></seealso>
    protected override Object GetValue(String arg0)
    {
      if (m_htTimeZoneXMLSettings == null)
      {
        return null;
      }
      int index = XPConvert.ToInteger(arg0);
      return ((String) m_htTimeZoneXMLSettings.GetElement(index));
    }
    
    /// <summary>
    /// This method loads the x_config.xml file into memory.
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Load()"></seealso>
    protected override void Load()
    {
      /*
       String strFileSeparator = XPFileSystemObject.GetPathSeparator();
       
       
       XPDocument xmlDoc = XPBuilder.LoadDocument(GetConfigPath() +
       strFileSeparator + "timezones.xml");
       */
       
      LoadSettingsIntoHashtable();
    }
    private void LoadSettingsIntoHashtable()
    {
      m_htTimeZoneXMLSettings = new XPHashtable();
      m_xpKeys = new XPArrayList();
      // Use OpenConfig to read the settings
      IOKContext configContext = AppWarmUp.GetOKConfigContext();
      IOKComponent component = null;
      component = configContext.getComponentByType(PORTAL_TIMEZONES_COMPONENT_TYPE);
      if (null == component)
      {
        log.Warn("Cannot retrieve component type: {0}", PORTAL_TIMEZONES_COMPONENT_TYPE);
        return;
      }
      IOKSetting[] settings = component.querySettings();
      for (int j = 0;j < settings.Length;j++)
      {
        String strName = settings[j].getName();
        String strValue = null;
        int nSettingType = settings[j].getDataType();
        if (OKConfigDataTypes.TYPE_STRING == nSettingType)
        {
          strValue = settings[j].getStringValue();
          if (null != strValue)
          {
            // parse the ID number from the name field				
            if ((null != strName) && (strName.Length > TIMEZONE_ID_PREFIX.Length))
            {
              try
              {
                int nKey = XPConvert.ToInteger(XPStringUtility.Substring(strName,
                 TIMEZONE_ID_PREFIX.Length));
                // log.Info("Timezone: " + nKey);		        
                // log.Info("Value: " + strValue);
                m_htTimeZoneXMLSettings.PutElement(nKey, strValue);
                // Add the key as a String so MemDebug page can iterate through the
                // timezones.
                m_xpKeys.Add(XPConvert.ToString(nKey));
              }
              catch (Exception e)
              {
                log.Warn(e, "Error adding timezone: {0}", strName);
              }
            } else
            {
              log.Warn("Found invalid timezone ID: {0}", strName);
            }
          } else
          {
            log.Warn("Found null value for timezone: {0}", strName);
          }
        } else
        {
          log.Warn("Invalid data type for TimezoneID{0}", j);
        }
      }
    }
    
    /// <summary>
    /// This method reloads the x_config.xml file into memory. It clears the
    /// current data and then delegates to Load().
    /// </summary>
    /// <seealso cref="com.plumtree.xpsupport.web.BaseVarPack#Reload()"></seealso>
    protected override void Reload()
    {
      Load();
    }
  }
}