using System;
using XPResourceManager=com.plumtree.openfoundation.internationalization.XPResourceManager;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using AppConstants=com.plumtree.uiinfrastructure.application.varpacks.AppConstants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.opener.types;
using com.plumtree.uiinfrastructure.statichelpers;
using ApplicationManager=com.plumtree.uiinfrastructure.web.ApplicationManager;
using IApplication=com.plumtree.uiinfrastructure.web.IApplication;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors
{
  /// <summary>
  /// Parent implementation for PTClassTypeDesc.  This class will be extended
  /// by classes which define extensible and non-extensible PTClassTypeDescs.
  /// This class implements GetRedirectViewObjectMetaData (standard for most,
  /// to be overriden by some), GetRedirectViewObject (which defers to 
  /// GetRedirectOpenObject), and provides some helper methods for retrieving
  /// arguments.
  /// If a specific class type needs to be supported by the Object Lock Manager /
  /// "Admin UI->Release Item Locks" page, extending class should simply
  /// implement a default constructor and set the values of  hasObjectLockManager,
  /// objectLockManagerMsgID and objectLockManagerMsgFileName fields accordingly. 
  /// By default, this abstract class will set these values to not support Object Lock Manager  
  /// </summary>
  /// <author>John Osborne</author>
  public abstract class APTClassTypeDesc : IPTClassTypeDesc
  {
    protected bool hasObjectLockManager = false;
    protected int objectLockManagerMsgID = -1;
    protected String objectLockManagerMsgFileName = "ptmsgs_portaladminmsgs";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc");
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public abstract bool AppearsInMainCreateNewClassMenu();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.IPTClassTypeDesc#AppearsInGlobalObjPropMap()
     */
     
    public virtual bool AppearsInGlobalObjPropMap()
    {
      // most classes appear in the utility.
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public abstract int GetClassID();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.IClassTypeDesc#GetClassKey()
     */
     
    public virtual String GetClassKey()
    {
      return XPConvert.ToString(GetClassID());
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.IClassTypeDesc#GetClassType()
     */
     
    public virtual ClassTypeEnum GetClassType()
    {
      return ClassTypeEnum.PTCLASSTYPE;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public abstract String GetClassTypeLocalizedName(String _strLangID);
    
    /// <summary>
    /// This method returns the Activity Rights ID that the user 
    /// needs to have in order to have access to make changes to
    /// this class type.  Use the PT_ACTIVITY_RIGHTS constant to 
    /// specify/compare rights.
    /// </summary>
    /// <returns>
    /// The Activity Rights ID necessary for changes to
    /// this class type.
    /// </returns>
    public abstract int GetCreateActivityID();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public abstract HTMLImg GetDefaultIcon();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultOpenerMode()
     */
     
    public virtual int GetDefaultOpenerMode()
    {
      return IPTOpenerConstants.OPENER_MODE_EDIT;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public abstract Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession);
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectOpenObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public abstract Redirect GetRedirectOpenObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession);
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectSearchBrowse(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public virtual Redirect GetRedirectSearchBrowse(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      // by default uses the view mode.	
      return GetRedirectViewObject(_htArguments, _asParent, _userSession);
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectSearchEdit(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public virtual Redirect GetRedirectSearchEdit(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      // by default uses the view mode.	
      return GetRedirectViewObject(_htArguments, _asParent, _userSession);
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public virtual Redirect GetRedirectViewObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      // create the redirect object.
      Redirect resultingRedirect = new Redirect();
      // we want to go to the object manager space.
      // OpenSubFolderControl.STR_MVC_CLASS_NAME.
      resultingRedirect.SetLinkCreateNewSpace("ObjMgr", _asParent);
      resultingRedirect.SetControl("ObjMgrSettings");
      // pass on the subspace key if it exists.
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, null));
      if (null != strSubSpaceKey)
      {
        resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      }
      // retrieve class and object ids.
      int nObjectID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      int nClassID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_CLASSID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_CLASSID,
       -1));
      // add class and object control arguments.
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
       nObjectID);
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
       nClassID);
      IPTSession ptSession = (IPTSession) _userSession;
      // find the folder containing this object.
      IPTObject ptObj = (IPTObject) ptSession.GetAdminCatalog().GetObjectManager(nClassID).Open(nObjectID,
       false);
      int nParentFolderID = ptObj.GetAdminFolderID();
      // add folder control argument.
      resultingRedirect.AddControlArgument("FolderID", nParentFolderID);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObjectMetaData(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public virtual Redirect GetRedirectViewObjectMetaData(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      // create the redirect object.
      Redirect resultingRedirect = new Redirect();
      // we want to go to the object property editor space.
      resultingRedirect.SetLinkCreateNewSpace(ObjPropEditorAS.STR_MVC_CLASS_NAME,
       _asParent);
      resultingRedirect.SetDisplayPage(ObjPropBrowseDP.STR_MVC_CLASS_NAME);
      resultingRedirect.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      resultingRedirect.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
       XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
      // pass on the subspace key if it exists.
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, null));
      if (null != strSubSpaceKey)
      {
        resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      }
      // retrieve class and object ids.
      int nObjectID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      int nClassID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_CLASSID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_CLASSID,
       -1));
      // add class and object control arguments.
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
       nObjectID);
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
       nClassID);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public abstract int[] GetRelatedClassTypeIDs();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public virtual int[] GetDependentClassTypeIDs()
    {
      return null;
    }
    
    /// <summary>
    /// Returns a boolean indicating whether the user has enough
    /// rights to make changes to this class type.
    /// </summary>
    /// <param name="_ptSession">The current Plumtree session.</param>
    /// <returns>
    /// Boolean indicating whether the user has rights
    /// to make changes to this class type.
    /// </returns>
    public virtual bool HasCreateActivityRight(IPTSession _ptSession)
    {
      IPTSessionInfo ptSessionInfo = _ptSession.GetSessionInfo();
      int iActivityID = GetCreateActivityID();
      bool bHasRight = false;
      if (PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE != iActivityID)
      {
        bHasRight = ptSessionInfo.CheckForActivityRight(iActivityID);
      }
      return bHasRight;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public abstract bool HasGlobalClassTypeMap();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#IsExtensible()
     */
     
    public abstract bool IsExtensible();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasObjectLockManager()
     */
     
    public virtual bool HasObjectLockManager()
    {
      return hasObjectLockManager;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#getObjectLockManagerLocalizedName()
     */
     
    public virtual String GetObjectLockManagerLocalizedName(String strLangID)
    {
      if (objectLockManagerMsgID < 1)
      {
        return null;
      }
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(objectLockManagerMsgID, objectLockManagerMsgFileName,
       strLangID);
    }
    
    /// <summary>
    /// DCA - override this method if the object handles friendly URLs
    /// </summary>
    public virtual Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser,
     AActivitySpace _asParent, Object _userSession)
    {
      // DCA - this method should be overidden 
      log.Error("APTClassTypeDesc:GetRedirectViewObject Unimplemented method called.");
      throw new XPException("This class type does not support consumption of friendly URLs.");
      }
    
    /// <seealso cref="IPTClassTypeDesc#ConstructFriendlyURL(String,int,String)"></seealso>
    public virtual String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space)
    {
      throw new XPException("This class type (" + this.GetType() + ") does not support generation of friendly URLs.");
      }
  }
}