using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors
{
  /// <summary>
  /// This class provides the contract for non-extensible PTClassTypes.
  /// It provides basic implementations for GetRedirectCreateNew and
  /// GetRedirectOpenObject, two of the modes of the Common Opener.
  /// </summary>
  /// <author>John Osborne</author>
  public abstract class APTNonExtClassTypeDesc : APTClassTypeDesc
  {
    
    /// <summary>
    /// Returns the name of the Activity Space that is used 
    /// to edit this class type.
    /// </summary>
    /// <returns>
    /// The name of the Activity Space that is used 
    /// to edit this class type.
    /// </returns>
    public abstract String GetASNameForEditor();
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect resultingRedirect = new Redirect();
      // retrieve the folder id.
      int nFolderID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_FOLDERID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_FOLDERID,
       -1));
      bool bFolderNotRequired = HTTPHelpers.GetArgumentAsBoolean(_htArguments,
       IPTOpenerConstants.STR_QS_FOLDERNOTREQUIRED, false);
      // the server requires a folder id except for a special
      // case.  if we cannot get it, then throw an UI error. 
      // for the special case where it's not required.
      if ((nFolderID == -1) && (!bFolderNotRequired))
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, _asParent.GetString(481, "ptmsgs_portalinfrastructure"), null);
        UIErrorHandler.RaiseError(myError, _asParent.GetSubSession(), _asParent.GetApplication());
        throw new XPException("A folder ID argument is required in the Common" + " Opener URL for this object in create mode.");
        }
      // open the correct Activity Space in create mode. 
      resultingRedirect.SetLinkCreateNewSpace(GetASNameForEditor(), _asParent);
      resultingRedirect.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
       XPConvert.ToString(GetClassID()));
      resultingRedirect.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
       XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_CREATE));
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID,
       nFolderID);
      // pass on the subspace key if it exists.
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, ""));
      if (null != strSubSpaceKey)
      {
        resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      }
      // pass on the ForceSaveInFolder flag if it exists.
      String sForceSaveInFolder = HTTPHelpers.GetArgumentAsString(_htArguments,
       IPTOpenerConstants.STR_QS_FORCESAVEINFOLDER, null);
      if (null != sForceSaveInFolder)
      {
        resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER,
         sForceSaveInFolder);
      }
      // pass on the CloseOnDone flag if it exists.
      String strCloseOnDone = HTTPHelpers.GetArgumentAsString(_htArguments,
       IPTOpenerConstants.STR_QS_CLOSEPOPUPONDONE, null);
      if (null != strCloseOnDone)
      {
        resultingRedirect.AddControlArgument(EditorStartControl.QS_CLOSE_WINDOW_ON_DONE,
         strCloseOnDone);
      }
      String strParentSpaceName = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.PARENTSPACENAME, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.PARENTSPACENAME_INPUT, null));
      // if a parentspace doesn't exist, then we will default to the
      // MyPage AS.  this is a precaution since everyone has access 
      // to this space, so we don't get errors after creation.
      if (null == strParentSpaceName)
      {
        _htArguments.PutElement(ASConstants.PARENTSPACENAME, new String[]{"MyPage"});
        _asParent.SetCurrentFormData(_htArguments);
      }
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectOpenObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectOpenObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect resultingRedirect = new Redirect();
      // retrieve the object id.
      int nObjectID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      // open the correct Activity Space in edit mode. 
      resultingRedirect.SetLinkCreateNewSpace(GetASNameForEditor(), _asParent);
      resultingRedirect.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      resultingRedirect.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
       XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
       XPConvert.ToString(GetClassID()));
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
       XPConvert.ToString(nObjectID));
      // pass on the display page name if it exists.
      String strDPName = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.PAGE,
       HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.PAGE_INPUT,
       null));
      if (null != strDPName)
      {
        resultingRedirect.AddControlArgument(ASConstants.PAGE, strDPName);
        }
      // pass on the subspace key if it exists.
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, ""));
      if (null != strSubSpaceKey)
      {
        resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      }
      // pass on the CloseOnDone flag if it exists.
      String strCloseOnDone = HTTPHelpers.GetArgumentAsString(_htArguments,
       IPTOpenerConstants.STR_QS_CLOSEPOPUPONDONE, null);
      if (null != strCloseOnDone)
      {
        resultingRedirect.AddControlArgument(EditorStartControl.QS_CLOSE_WINDOW_ON_DONE,
         strCloseOnDone);
      }
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#IsExtensible()
     */
     
    public override bool IsExtensible()
    {
      return false;
    }
  }
}