using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener.types;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors
{
  /// <summary>
  /// Interface for PTClassTypeDesc.  
  /// </summary>
  /// <author>John Osborne</author>
  public interface IPTClassTypeDesc : IClassTypeDesc
  {
    
    /// <summary>
    /// Returns a boolean that tells the client if this class 
    /// type should appear in the main create new object menu.
    /// </summary>
    /// <returns>
    /// A boolean that tells the client if this class 
    /// type should appear in the main create new object menu.
    /// </returns>
    bool AppearsInMainCreateNewClassMenu();
    
    /// <summary>
    /// Returns a boolean that tells the client if this class 
    /// type appears in the global object property map utility.
    /// </summary>
    /// <returns>
    /// A boolean that tells the client if this class 
    /// type appears in the global object property map utility
    /// </returns>
    bool AppearsInGlobalObjPropMap();
    
    /// <summary>
    /// Returns the class ID of the class type. Use the 
    /// PT_CLASSIDS constant to determine/reference IDs.
    /// </summary>
    /// <returns>The class ID of the class type.</returns>
    int GetClassID();
    
    /// <summary>
    /// Returns the localized name for the class type. For example, 
    /// the name for users is "User" in English.
    /// </summary>
    /// <param name="_strLangID">The language to retrieve the name for.</param>
    /// <returns>The localized name for the class type.</returns>
    String GetClassTypeLocalizedName(String _strLangID);
    
    /// <summary>
    /// Returns the default icon for items of this class type.
    /// </summary>
    /// <returns>The default icon for items of this class type.</returns>
    HTMLImg GetDefaultIcon();
    
    /// <summary>
    /// This method lets you associate the class ID for this
    /// PTClassType with other class IDs.  One application 
    /// for this is at the end of the editor creation wizard,
    /// it provides shortcut links to create related objets.
    /// Return NULL if there are no related class types.
    /// </summary>
    /// <returns>An array of related class IDs. May be NULL.</returns>
    int[] GetRelatedClassTypeIDs();
    
    /// <summary>
    /// This method lets you specify what kind of PTClassTypes
    /// depend on this PTClassType.  One application 
    /// for this is to make sure to try to delete dependent
    /// items before deleting the main item, otherwise the
    /// delete may fail because there are dependent items.
    /// This method should only return class types that are
    /// directly dependent on this class type.
    /// For example, Remote Servers should return Web Services,
    /// but not Portlets.  Web Services should return Portlets.
    /// Return NULL if there are no related class types.
    /// NOTE: This does not support circular loops of dependencies
    /// (I.E. A -> B -> C -> A).  This behavior is undefined, and
    /// will mostly likely cause deletes of those objects to fail.
    /// </summary>
    /// <returns>An array of dependent class IDs. May be NULL.</returns>
    int[] GetDependentClassTypeIDs();
    
    /// <summary>
    /// Returns a boolean that tells the client if this class 
    /// type is on the global class type map.
    /// </summary>
    /// <returns>
    /// A boolean that tells the client if this class 
    /// type is on the global class type map.
    /// </returns>
    bool HasGlobalClassTypeMap();
    
    /// <summary>
    /// Returns a boolean that tells the client if this class 
    /// type is extensible.
    /// </summary>
    /// <returns>
    /// A boolean that tells the client if this class 
    /// type is extensible.
    /// </returns>
    bool IsExtensible();
    
    /// <summary>
    /// Returns a boolean that tells the client if this class 
    /// included/supported on the "Admin UI->Release Item Locks" page.
    /// </summary>
    /// <returns>
    /// A boolean that tells the client if this class 
    /// included/supported on the "Admin UI->Release Item Locks" page.
    /// </returns>
    bool HasObjectLockManager();
    
    /// <summary>
    /// Returns the localized name that will be displayed on the 
    /// left navigation menu of "Admin UI->Release Item Locks" page.
    /// </summary>
    /// <param name="_strLangID">The language to retrieve the name for.</param>
    /// <returns>The localized name for the class type.</returns>
    String GetObjectLockManagerLocalizedName(String strLangID);
    
    /// <summary>
    /// This method is called by the Common Opener in the view
    /// mode.  Depending on what class type you are dealing with,
    /// the Common Opener will invoke the correct implemented 
    /// method.  Some class types may need to override this so
    /// that they can put additional control arguments in.
    /// </summary>
    /// <param name="_fURLParser">contains the URL path.</param>
    /// <param name="_asParent">The parent activity space.</param>
    /// <param name="_userSession">The current session.</param>
    /// <returns>
    /// A redirect that will bring you to the view 
    /// activity space for the particular class/object.
    /// </returns>
    /// <exception>An exception is thrown if the object to be viewed cannot be determined.</exception>
    Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser, AActivitySpace _asParent,
     Object _userSession);
    
    /// <summary>
    /// Generates a friendly URL to the implementing class type. 
    /// Ideally the object name is provided, otherwise if only the object id is provided, the method has to look up
    /// the object name.
    /// If both are provided, both the object name and object id is used in the friendly url.
    /// </summary>
    /// <param name="url">FriendlyURL containing the information for the url</param>
    /// <returns>
    /// Returns the friendly part of the friendly Url, that is, just the part of the Url after server.pt
    /// including leading slash. 
    /// </returns>
    String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space);
  }
}