using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Admin folder editor in create mode (APTNonExtClassTypeDesc).
  /// 2) Edit - Admin folder editor in edit mode (APTNonExtClassTypeDesc).
  /// 3) View - Admin directory where folder exists (APTClassTypeDesc).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTAdminFolders : APTNonExtClassTypeDesc
  {
    public PTAdminFolders() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1994;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
     */
     
    public override String GetASNameForEditor()
    {
      return "AdminFolderEditor";
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(3, "ptmsgs_portalinfrastructure", _strLangID);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_ADMINFOLDERS;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public override Redirect GetRedirectViewObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      // create the redirect object.
      Redirect resultingRedirect = new Redirect();
      // we want to go to the object manager space.
      // Use a cached space if possible.
      resultingRedirect.SetLinkGetSpaceIfCached("ObjMgr", _asParent);
      // OpenSubFolderControl.STR_MVC_CLASS_NAME.
      resultingRedirect.SetControl("ObjMgrSettings");
      // pass on the subspace key if it exists.
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, ""));
      resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      // retrieve class and object ids.
      int nObjectID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      int nClassID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_CLASSID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_CLASSID,
       -1));
      // Retrieve currently expanded class IDs so that the Opener can be used
      // by the Admin Directory
      // TODO: don't use magic strings
      String strExpandedClassIDs = HTTPHelpers.GetArgumentAsString(_htArguments,
       "ObjectIDs", "");
      if (!strExpandedClassIDs.Equals(""))
      {
        // ObjMgrSettingsControl.OBJECT_IDS
        resultingRedirect.AddControlArgument("ObjectIDs", strExpandedClassIDs);
        }
      // add class and object control arguments.
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
       nObjectID);
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
       nClassID);
      // add folder control argument.
      resultingRedirect.AddControlArgument("FolderID", nObjectID);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
  }
}