using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.opener.plugins;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Community editor in create mode (APTNonExtClassTypeDesc).
  /// 2) Edit - Community editor in edit mode (APTNonExtClassTypeDesc).
  /// 3) View - Goes to the community (PTCommunities).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  /// <author>Dusting Ang</author>
  /// <author>Robert Zhang</author>
  public class PTCommunities : APTNonExtClassTypeDesc
  {
    private static OpenLogger fulog = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_FRIENDLYURL),
     "com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.PTCommunities");
    public const String COMMUNITY_AS_NAME = "CommunityPage";
    public const String COMMUNITY_CONTROL_NAME = "SetCommunity";
    public const String STR_COMMUNITY_ID = "CommunityID";
    public const String STR_PAGE_ID = "PageID";
    public const String STR_QS_PAGEID = "PageID";
    public const String COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID = "ctID";
    public const String COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT = "inherit";
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTCommunities() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1525;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_COMMUNITIES;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
     */
     
    public override String GetASNameForEditor()
    {
      return "CommunityEditor";
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_COMMUNITY_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(5, "ptmsgs_portalinfrastructure", _strLangID);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
     */
     
    public override Redirect GetRedirectViewObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect resultingRedirect = new Redirect();
      int nCommunityID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      int nPageID = HTTPHelpers.GetArgumentAsInt(_htArguments, STR_QS_PAGEID,
       0);
      // in view mode, we go to the community.
      resultingRedirect.SetLinkCreateNewSpace(COMMUNITY_AS_NAME, _asParent);
      resultingRedirect.SetControl(COMMUNITY_CONTROL_NAME);
      resultingRedirect.AddControlArgument(STR_COMMUNITY_ID, nCommunityID);
      resultingRedirect.AddControlArgument(STR_PAGE_ID, nPageID);
      // no parent space or parent ID
      resultingRedirect.SetStripParentSpace(true);
      return resultingRedirect;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.classtypedescriptors.IClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable,com.plumtree.uiinfrastructure.activityspace.AActivitySpace,com.plumtree.server.IPTSession)"></seealso>
    public override Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect result = base.GetRedirectCreateNew(_htArguments, _asParent,
       _userSession);
      int nCommTemplateID = HTTPHelpers.GetArgumentAsInt(_htArguments, COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID,
       0);
      if (0 != nCommTemplateID)
      {
        result.AddControlArgument(COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID,
         nCommTemplateID);
        result.AddControlArgument(COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT,
         HTTPHelpers.GetArgumentAsBoolean(_htArguments, COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT,
         (0 != nCommTemplateID)));
      }
      return result;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject()
     *
     * CR rob - why isn't this a proper javadoc comment? Should start with /** instead of /*
     * CR rob - what happens if there is excetions in any of the code? for example if there is an invalid friendly url
     * DCA - There is proper javadoc comment in the Interface: IPTClassTypeDesc
     */
     
    public override Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser,
     AActivitySpace _asParent, Object _userSession)
    {
      if (null == _fURLParser || null == _asParent || null == _userSession)
      {
        throw new PTException("Parameters cannot be null.", PT_RESULTCODES.PT_E_INVALIDARGUMENT);
        }
      Redirect resultingRedirect = new Redirect();
      //  DCA - used cached version if available in case it's a repost
      resultingRedirect.SetLinkGetSpaceIfCached(COMMUNITY_AS_NAME, _asParent);
      resultingRedirect.SetControl(COMMUNITY_CONTROL_NAME);
      String strCommunityName = _fURLParser.GetObjectName(true);
      int nCommunityId = _fURLParser.GetObjectId();
      String strPageName = _fURLParser.GetChildName(true);
      int nPageId = _fURLParser.GetChildId();
      IPTObjectManager ptCommunityManager = (IPTObjectManager) ((IPTSession) _userSession).GetCommunities();
      // DCA - figure out the community Id if we don't have it
      int[] arrCommunityIds = null;
      if (nCommunityId < 1)
      {
        arrCommunityIds = ptCommunityManager.LookupObjectIdFromName(strCommunityName);
        if (arrCommunityIds.Length == 1)
        {
          nCommunityId = arrCommunityIds[0];
        }
      }
      if (nPageId == 0)
      {
        // DCA - figure out page id
        if (null != strPageName && nCommunityId > 0)
        {
          // DCA - map page name to page Id
          try
          {
            nPageId = ((IPTCommunityManager) ptCommunityManager).LookupPageIdFromCommunityPageName(nCommunityId,
             strPageName);
          }
          catch (XPException e)
          {
            // redirect to community home page
            fulog.Debug(e, "Could not find page with name: " + strPageName);
            }
        } else
        // look it up from the list of possible communities
        if (null != strPageName && null != arrCommunityIds)
        {
          nCommunityId = 0;
          int nTempPageId = 0;
          for (int i = 0;i < arrCommunityIds.Length;i++)
          {
            try
            {
              nTempPageId = ((IPTCommunityManager) ptCommunityManager).LookupPageIdFromCommunityPageName(arrCommunityIds[i],
               strPageName);
            }
            catch (Exception e)
            {
              // DCA - page was not found in this community
              nTempPageId = 0;
            }
            if (nTempPageId > 0 && nCommunityId <= 0)
            {
              // DCA - this may be the community they are talking about
              nCommunityId = arrCommunityIds[i];
              nPageId = nTempPageId;
            } else
            if (nTempPageId > 0 && nCommunityId > 0)
            {
              // DCA - we have 2 communities with the same page name specified
              // we're no longer sure which community they want
              nCommunityId = 0;
              break;
            }
          }
        }
      }
      // else we will go to the search result page
      // 3 different possible routes from here:
      // 1. We have community and page id - success! Create and redirect
      // 2. We have community id but no page id, just go to the community home page (they'll be able to go to the right page from there)
      // 3. No community id, go to the search result page 
      if (nCommunityId > 0)
      {
        // case 1 and 2
        resultingRedirect.AddControlArgument(STR_COMMUNITY_ID, nCommunityId);
        fulog.Debug("PTCommunities:GetRedirectViewObject Redirecting to community with Id: " + nCommunityId + " and page Id: " + nPageId);
        resultingRedirect.AddControlArgument(STR_PAGE_ID, nPageId);
      } else
      {
        // case 3
        // DCA - nCommunityId <= 0 means there was more than one community w/ the same name
        // redirect to a search results querying for the community name
        fulog.Debug("PTCommunities:GetRedirectViewObject More than one community found. Redirecting to search.");
        resultingRedirect = new Redirect();
        resultingRedirect.SetLinkCreateNewSpace("SearchResult", _asParent);
        resultingRedirect.SetControl("advancedstart");
        resultingRedirect.AddControlArgument(SearchResultControl.USER_QUERY,
         strCommunityName);
        resultingRedirect.AddControlArgument("in_hi_req_objtype", PT_CLASSIDS.PT_COMMUNITY_ID);
        }
      return resultingRedirect;
    }
    
    /// <seealso cref="IPTClassTypeDesc#ConstructFriendlyURL(String,int,String)">Generates a friendly Url for Community or Community page</seealso>
    public override String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space)
    {
      String objectName = url.GetOjectName();
      String pageName = url.GetChildName();
      int pageId = url.GetChildId();
      int objectId = url.GetObjectId();
      if (("".Equals(objectName) || objectName == null) && objectId <= 0)
      {
        throw new PTException("Both object name and id are missing. At leaset one needs to be specified to create a friendly Url.",
         PT_RESULTCODES.PT_E_INVALIDARGUMENT);
      }
      XPStringBuilder buf = new XPStringBuilder(200);
      // Lookup the keyword for communities
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      IFriendlyURLManager ptFriendlyURLMgr = (IFriendlyURLManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
      String commKeyword = ptFriendlyURLMgr.LookupFriendlyURLKeyFromClassId(PT_CLASSIDS.PT_COMMUNITY_ID + "");
      if (commKeyword == null)
      {
        throw new PTException("No Friendly URL keyword was found for Communities. " + "Verify that a mapping entry exists in FriendlyURL.xml.",
         PT_RESULTCODES.PT_E_FAIL);
      }
      buf.Append("/").Append(commKeyword);
      IPTSession session = (IPTSession) space.GetUserSession();
      // need to lookup object name from object id. Use the community object cache
      if ("".Equals(objectName) || objectName == null)
      {
        IPTCommunityInfo comm = null;
        try
        {
          comm = ((IPTCommunityManager) session.GetCommunities()).CachedOpenCommunityInfo(objectId,
           false);
        }
        catch (PTException e)
        {
          throw new PTException(e, "Invalid community id provided: " + objectId + " . The community does not exist or the user does not have access to it.",
           PT_RESULTCODES.PT_E_INVALIDARGUMENT);
        }
        objectName = comm.GetPrimaryName();
      }
      // Add the community name to the url but massage the name first
      String normObjectName = FriendlyURL.NormalizeObjectName(objectName);
      // DCA - we're encoding in case it has non-ASCII chars
      normObjectName = XPHttpUtility.UrlEncode(normObjectName, LinkConstants.UTF_8_ENCODING);
      buf.Append("/").Append(normObjectName);
      // Add object id if there are more than one community with the same name
      // to dis-ambiguate
      // To handle special charactres in urls, always add object id and encode all special characters to underscores
      // we want to change any underscores to spaces so that search can find any ambigous entries 
      //objectName = FriendlyURL.DeNormalizeObjectName(objectName); 
      //int ids[] = session.GetCommunities().LookupObjectIdFromName(objectName);
      //if ( url.GetUseIdIfAvailable() || ids.length > 1) {
      //	buf.Append("/").Append(objectId);
      //}
      if (FriendlyURLPlugin.UseObjectId())
      {
        buf.Append("/").Append(objectId);
      }
      // Do we need to add page to the url?
      if (pageId != 0)
      {
        // we don't have page name so look it up from the id
        if (pageName == null)
        {
          IPTPageInfo page = null;
          try
          {
            page = ((IPTPageManager) session.GetPages()).CachedOpenPageInfo(pageId,
             false, false);
          }
          catch (PTException e)
          {
            throw new PTException(e, "Invalid page id provided: " + pageId + " . The community page does not exist or the user does not have access to it.",
             PT_RESULTCODES.PT_E_INVALIDARGUMENT);
          }
          pageName = page.GetName();
        }
        // normalize page name
        pageName = FriendlyURL.NormalizeObjectName(pageName);
        // DCA - we're encoding in case it has non-ASCII chars
        pageName = XPHttpUtility.UrlEncode(pageName, LinkConstants.UTF_8_ENCODING);
        buf.Append("/").Append(pageName);
        // check if we should add page id to disambiguate page names
        if (FriendlyURLPlugin.UseObjectId())
        {
          buf.Append("/").Append(pageId);
        }
      }
      return buf.ToString();
    }
  }
}