using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Crawler editor in create mode (PTCrawlers).
  /// 2) Edit - Crawler editor in edit mode (APTExtClassTypeDesc).
  /// 3) View - Redirect to Edit (APTClassTypeDesc).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTCrawlers : APTExtClassTypeDesc
  {
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTCrawlers() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1526;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTExtClassTypeDesc#GetASNameForEditor(java.lang.String)
     */
     
    public override String GetASNameForEditor(String _strProvEnglishName)
    {
      String strBaseEditorASName = "CrawlerEditor";
      return _strProvEnglishName + strBaseEditorASName;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_CRAWLER_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(7, "ptmsgs_portalinfrastructure", _strLangID);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTExtClassTypeDesc#GetCLSIDForExistingObject(int, com.plumtree.server.IPTSession)
     */
     
    public sealed override String GetCLSIDForExistingObject(int _nObjectID,
     IPTSession _ptSession)
    {
      IPTCrawler ptCrawler = (IPTCrawler) _ptSession.GetCrawlers().Open(_nObjectID,
       false);
      int nDataSourceID = ptCrawler.GetDataSourceID();
      IPTDataSource ptDataSource = (IPTDataSource) _ptSession.GetDataSources().Open(nDataSourceID,
       false);
      String sProviderCLSID = ptDataSource.GetDataSourceProviderCLSID();
      return sProviderCLSID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_CRAWLERS;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_CRAWLER).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect resultingRedirect = base.GetRedirectCreateNew(_htArguments,
       _asParent, _userSession);
      // retrieve the provider english name and provInfo object.						
      String strProvEngName = HTTPHelpers.GetArgumentAsString(_htArguments,
       IPTOpenerConstants.QS_PROV_ENG_NAME, HTTPHelpers.GetArgumentAsString(_htArguments,
       IPTOpenerConstants.STR_QS_PROVIDER_ENG_NAME, null));
      IProvInfo myProv = PTConfigHelper.GetPTClassTypeDescrManager().GetRegisteredProvInfoGivenEnglishName(strProvEngName);
      ClassIDProvCLSIDPair myClassIDProvCLSIDPair = myProv.RequiresObjectChoiceOnStart(GetClassID());
      // if the provider requires a object choice on start,
      // we can check that it it's in our arguments list.
      if (null != myClassIDProvCLSIDPair)
      {
        // crawlers will only require datasource, 
        // so we will only check for that argument.
        if (myClassIDProvCLSIDPair.GetClassID() == PT_CLASSIDS.PT_DATASOURCE_ID)
        {
          String strXUIDataSourceID = HTTPHelpers.GetArgumentAsString(_htArguments,
           XUIHelperMethods.QS_XUI_DATASOURCE_ID, null);
          if (null == strXUIDataSourceID)
          {
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, _asParent.GetString(484, "ptmsgs_portalinfrastructure"),
             null);
            UIErrorHandler.RaiseError(myError, _asParent.GetSubSession(),
             _asParent.GetApplication());
            throw new XPException("A datasource ID argument is required in the Common Opener URL for this object in create mode.");
            }
        }
      }
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return new int[]{PT_CLASSIDS.PT_JOB_ID, PT_CLASSIDS.PT_DATASOURCE_ID};
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
  }
}