using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.opener.plugins;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Folder editor in create mode. (PTDocFolders).
  /// 2) Edit - Folder editor in edit mode (APTExtClassTypeDesc).
  /// 3) View - Directory where folder exists (PTDocFolders).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTDocFolders : APTNonExtClassTypeDesc
  {
    public const String DIRECTORY_PARAM_FOLDERID = "subfolderID";
    public const String DIRECTORY_ASNAME = "Dir";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.PTDocFolders");
    private static OpenLogger fulog = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_FRIENDLYURL),
     "com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.PTDocFolders");
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTDocFolders() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1524;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
     */
     
    public override String GetASNameForEditor()
    {
      return "FolderEditor";
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_CATALOGFOLDER_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_FOLDERS;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(9, "ptmsgs_portalinfrastructure", _strLangID);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectViewObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect resultingRedirect = new Redirect();
      // Get a cached copy of the Directory space, if possible.
      resultingRedirect.SetLinkGetSpaceIfCached("Dir", _asParent);
      // Spoof the sub-space key
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, ""));
      if (!strSubSpaceKey.Equals(""))
      {
        resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      }
      // OpenSubFolderControl.STR_MVC_CLASS_NAME
      resultingRedirect.SetControl("OpenSubFolder");
      // @TODO: don't use magic strings, probably need to refactor these classes to portalpages
      // Retrieve current directory mode (browse / edit) so that the Opener can be used
      // by the Document Directory
      String strDirMode = HTTPHelpers.GetArgumentAsString(_htArguments, "DirMode",
       "");
      if (strDirMode.Equals(""))
      {
        // DirConstants.QS_DIRECTORY_MODE and DirConstants.BROWSE_MODE
        resultingRedirect.AddControlArgument("DirMode", 1);
      } else
      {
        // DirConstants.QS_DIRECTORY_MODE and QS supplied mode
        resultingRedirect.AddControlArgument("DirMode", strDirMode);
      }
      int nSubFolderID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      // OpenDirFolderControl.m_SubFolderID
      resultingRedirect.AddControlArgument(DIRECTORY_PARAM_FOLDERID, nSubFolderID);
      // no parent space or parent ID
      resultingRedirect.SetStripParentSpace(true);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return new int[]{PT_CLASSIDS.PT_FILTER_ID};
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
    
    /// <summary>
    /// Create a redirect object to a knowledge directory folder page from a friendly URL
    /// Current format is [directory keyword]/[directory name]/[directory id] where the 
    /// directory id is optional. This method will lookup the id if one isn't provided
    /// </summary>
    public override Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser,
     AActivitySpace asParent, Object userSession)
    {
      if (null == _fURLParser || null == asParent || null == userSession)
      {
        throw new PTException("Parameters cannot be null.", PT_RESULTCODES.PT_E_INVALIDARGUMENT);
        }
      int[] folderIds = null;
      int singleFolderId = _fURLParser.GetObjectId();
      String folderName = _fURLParser.GetObjectName(true);
      // @TODO For now just support folder name with id, will add some sort of support for folder path
      // when search API adds support for it, Bug #63548
      if (true)
      {
        // either single dir name with or without object id
        if (null == folderName)
        {
          // CR DLH: Maybe include the URL or token thing in this error for debugging?
          // ROB: We don't have anything at this point so there is no further data to include
          // DLH: We could just display the original full URL for debugging purposes.
          throw new XPIllegalArgumentException("Invalid friendly Url provided. Expected folder name but none was supplied.");
          }
      } else
      {
        }
      // code for parsing out the folder path from url
      // will use later when we can search for folder paths with search api
      //		XPStringBuilder buf = new XPStringBuilder(50);
      //		while ( stURLTokens.HasMoreTokens() ) {
      //			String folderName = stURLTokens.GetNextToken();
      //			if ( !"".equals(folderName) /** @TOOD any other validation necessary here? **/ ) {
      //				buf.Append(folderName).Append("/");
      //			}
      //		}
      //		folderName = buf.ToString();
      Redirect resultingRedirect = new Redirect();
      // Lookup id for the directory if none was provided
      if (singleFolderId == 0)
      {
        IPTCatalog ptCatalog = ((IPTSession) userSession).GetCatalog();
        // Let exception bubble up if we encounter any problems here.
        // This would happen if they provided an invalid folder name or if they don't have access to it
        folderIds = ptCatalog.LookupObjectIdFromName(folderName, PT_CLASSIDS.PT_CATALOGFOLDER_ID);
        if (folderIds == null)
        {
          // not supposed to happen
          throw new XPIllegalStateException("Object id lookup result returned null.");
          }
        // Determine if we need to redirect to search result page or not
        if (folderIds.Length == 1)
        {
          // Only one directory folder with the name exists,just get the object id 
          singleFolderId = folderIds[0];
        } else
        {
          // more than one result means there was more than one document folder w/ the same name
          // redirect to a search results querying for the folder name to let the user choose which
          // directory to go to
          fulog.Debug("PTDocFolders:GetRedirectViewObject More than one knowledge directory found with name " + folderName + ". Redirecting to search.");
          // CR DLH: Ideally this shouldn't use magic strings.  Can we make these strings come from a common
          // place for both here and the activity space?  Maybe we should refactor these class type
          // descriptors so their in the portal pages project if they need to link to that.  Do they all need
          // to be in this project for some reason?
          // ROB these constants are defined in portalpages, the class hierarchy is messed up so we have to hardcode the strings
          // in this project. Moving these strings into another class doesn't really solve that much, it will still be a hardcoded
          // constant
          // DLH: Does this class need to be in portaluiinf?  Aren't these object dynamically discovered,
          // meaning we can just move them into portalpages and solve this problem?
          resultingRedirect.SetLinkCreateNewSpace("SearchResult", asParent);
          resultingRedirect.SetControl("advancedstart");
          resultingRedirect.AddControlArgument(SearchResultControl.USER_QUERY,
           folderName);
          resultingRedirect.AddControlArgument("in_hi_req_objtype", PT_CLASSIDS.PT_CATALOGFOLDER_ID);
          return resultingRedirect;
        }
      }
      // CR DLH: Same comment as above re: magic strings
      // ROB these constants are defined in portalpages, the class hierarchy is messed up so we have to hardcode the strings
      // in this project. Moving these strings into another class doesn't really solve that much, it will still be a hardcoded
      // constant
      // Create redirect object to the directory page
      // DCA - used cached version if available in case it's a repost
      resultingRedirect.SetLinkGetSpaceIfCached(DIRECTORY_ASNAME, asParent);
      resultingRedirect.SetControl("OpenSubFolder");
      // DirConstants.QS_DIRECTORY_MODE and DirConstants.BROWSE_MODE
      resultingRedirect.AddControlArgument("DirMode", 1);
      // OpenDirFolderControl.m_SubFolderID
      resultingRedirect.AddControlArgument(DIRECTORY_PARAM_FOLDERID, singleFolderId);
      return resultingRedirect;
    }
    
    /// <summary>
    /// Creates a friendly Url to a Knowledge Directory folder.
    /// Current format is [directory keyword]/[directory name]/[directory id] where the 
    /// directory id is optional. This method will lookup the id if one isn't provided
    /// </summary>
    /// <param name="url">
    /// Container with necessary information to create a friendly Url. Object id
    /// of the folder is required.
    /// </param>
    public override String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space)
    {
      int folderId = url.GetObjectId();
      String folderName = url.GetOjectName();
      XPStringBuilder buf = new XPStringBuilder(50);
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      IFriendlyURLManager ptFriendlyURLMgr = (IFriendlyURLManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
      // CR DLH: Can't we use String.valueof instead of ""?  "" seems cryptic and nonintuitive.  I'm sure the jvm
      // optimizes them both the same.
      // ROB: This makes the clearer to see what gets passed in rather than nesting it in 2 levels of function calls
      // would have to use XPConvert
      String dirFolderKeyword = ptFriendlyURLMgr.LookupFriendlyURLKeyFromClassId(PT_CLASSIDS.PT_CATALOGFOLDER_ID + "");
      if (dirFolderKeyword == null)
      {
        throw new PTException("No Friendly URL keyword was found for Directory Folders. " + "Verify that a mapping entry exists in FriendlyURL.xml.",
         PT_RESULTCODES.PT_E_FAIL);
      }
      buf.Append("/").Append(dirFolderKeyword).Append("/");
      IPTSession session = (IPTSession) space.GetUserSession();
      IPTCatalog ptCatalog = session.GetCatalog();
      if (folderId < 0)
      {
        // TODO: This should just set id to intrinsic root folder and lookup from cache
        folderName = null;
        folderId = PT_INTRINSICS.PT_FOLDER_ROOTFOLDER;
      }
      // CR DLH: Shouldn't we just say folderName.length == 0 or something like that?
      // ROB: The standard way is to check for empty string and not 0 length
      if (null == folderName || "".Equals(folderName))
      {
        folderName = ptCatalog.LookupNameFromObjectId(folderId, PT_CLASSIDS.PT_CATALOGFOLDER_ID);
        }
      // code for parsing through a folder path, might need later
      //IPTFolder folder = ptCatalog.OpenFolder(folderId, false);
      // doesnt work now
      //		String folderPath = folder.GetPath();
      //		
      //		String friendlyUrlPath = FriendlyURL.NormalizeObjectName(folderPath);
      //		buf.Append(friendlyUrlPath);
      String normalizedFolderName = FriendlyURL.NormalizeObjectName(folderName);
      // DCA - we're encoding in case it has non-ASCII chars
      normalizedFolderName = XPHttpUtility.UrlEncode(normalizedFolderName,
       LinkConstants.UTF_8_ENCODING);
      buf.Append(normalizedFolderName);
      if (FriendlyURLPlugin.UseObjectId())
      {
        buf.Append("/").Append(folderId + "");
      }
      return buf.ToString();
    }
  }
}