using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Show error. (PTDocuments).
  /// 2) Edit - Document editor in edit mode (APTExtClassTypeDesc).
  /// 3) View - Clickthrough to document (PTDocuments).
  /// 4) Meta - View object properties page (PTDocuments).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTDocuments : APTExtClassTypeDesc
  {
    public const String DOCUMENT_AS_NAME = "OpenDoc";
    public const String DOCUMENT_DP_NAME = "OpenDoc";
    public const String DOCUMENT_CONTROL_NAME = "OpenDoc";
    public const String STR_CARD_ID = "cardID";
    public const String SEARCH_AS_NAME = "SearchResult";
    public const String SEARCH_CONTROL_NAME = "advancedstart";
    public const String STR_OBJTYPE = "in_hi_req_objtype";
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTDocuments() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1523;
    }
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.IPTClassTypeDesc#AppearsInGlobalObjPropMap()
     */
     
    public override bool AppearsInGlobalObjPropMap()
    {
      return false;
    }
    public override String GetASNameForEditor(String _strProvEnglishName)
    {
      return GetASNameForEditor();
    }
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE;
    }
    public virtual String GetASNameForEditor()
    {
      return "CardEditor";
    }
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_CATALOGCARD_ID;
    }
    public sealed override String GetCLSIDForExistingObject(int _nObjectID,
     IPTSession _ptSession)
    {
      IPTCard ptDocument = (IPTCard) _ptSession.GetCatalog().OpenCard(_nObjectID,
       false);
      int nDataSourceID = ptDocument.GetDataSourceID();
      IPTDataSource ptDataSource = (IPTDataSource) _ptSession.GetDataSources().Open(nDataSourceID,
       false);
      String sProviderCLSID = ptDataSource.GetDataSourceProviderCLSID();
      return sProviderCLSID;
    }
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(11, "ptmsgs_portalinfrastructure", _strLangID);
      }
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
       null, _asParent.GetString(486, "ptmsgs_portalinfrastructure"), null);
      UIErrorHandler.RaiseError(myError, _asParent.GetSubSession(), _asParent.GetApplication());
      throw new XPException("The Common Opener does not support create mode for this class type.");
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectViewObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      int nCardID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      IPTSession ptSession = (IPTSession) _userSession;
      try
      {
        IPTCatalogStatistics ptCatalogStatistics = ptSession.GetCatalog().GetStatistics();
        ptCatalogStatistics.ReportCardAccess(nCardID);
      }
      catch (Exception e)
      {
      }
      // Don't prevent the opening of the card just because 
      // of an exception in the card popularity reporting.
      Redirect resultingRedirect = new Redirect();
      resultingRedirect.SetLinkCreateNewSpace(DOCUMENT_AS_NAME, _asParent);
      // Spoof the sub-space key
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, ""));
      if (!strSubSpaceKey.Equals(""))
      {
        resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      }
      // STR_MVC_CLASS_NAME
      resultingRedirect.SetDisplayPage(DOCUMENT_DP_NAME);
      // DirConstants.QS_CARDID
      resultingRedirect.AddControlArgument(STR_CARD_ID, nCardID);
      resultingRedirect.SetControl(DOCUMENT_CONTROL_NAME);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObjectMetaData(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectViewObjectMetaData(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      // Create the Redirect Object
      Redirect resultingRedirect = new Redirect();
      resultingRedirect.SetLinkGetSpaceIfCached("Dir", _asParent);
      // Spoof the sub-space key
      String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE, HTTPHelpers.GetArgumentAsString(_htArguments,
       ASConstants.SUBSPACE_INPUT, ""));
      if (!strSubSpaceKey.Equals(""))
      {
        resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
      }
      if (AccessStyles.STANDARD == _asParent.GetAccessStyle())
      {
        // DirCardPropertiesDP.STR_MVC_CLASS_NAME
        resultingRedirect.SetDisplayPage("DirCardProperties");
      } else
      {
        // DirCardPropertiesDP_D.STR_MVC_CLASS_NAME
        resultingRedirect.SetDisplayPage("DirCardPropertiesDP_D");
      }
      // DirRepostControl.STR_MVC_CLASS_NAME
      resultingRedirect.SetControl("DirRepost");
      int nCardID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      // DirConstants.QS_CARDID
      resultingRedirect.AddControlArgument(STR_CARD_ID, nCardID);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject()
     */
     
    public override Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser,
     AActivitySpace _asParent, Object _userSession)
    {
      if (null == _fURLParser || null == _asParent || null == _userSession)
      {
        throw new PTException("Parameters cannot be null.", PT_RESULTCODES.PT_E_INVALIDARGUMENT);
        }
      Redirect resultingRedirect = new Redirect();
      IPTCatalog ptCatalog = (IPTCatalog) ((IPTSession) _userSession).GetCatalog();
      int nDocumentId = _fURLParser.GetObjectId();
      String strDocumentName = _fURLParser.GetObjectName(true);
      try
      {
        if (nDocumentId < 1)
        {
          // DCA - try to figure out document Id
          int[] arrDocumentIds = ptCatalog.LookupObjectIdFromName(strDocumentName,
           PT_CLASSIDS.PT_CATALOGCARD_ID);
          if (arrDocumentIds.Length == 1)
          {
            nDocumentId = arrDocumentIds[0];
          } else
          {
            throw new PTException("More than one document found, returning search result.",
             PT_RESULTCODES.PT_E_FAIL);
          }
        }
        // TODO CR DLH: No magic strings - at least make them statics at the top of the file. (for all of them)
        // Or, are these magic strings cuz you don't have access to the opendoc space from here?
        // If so, I'd make them statics here, and then have the opendoc space use the ones from
        // here.  That way if you make a change it will be correctly propagated.
        // DCA - Changing the OpenDoc space to use the static strings here would be a pretty big change.
        //  DCA - used cached version if available in case it's a repost
        resultingRedirect.SetLinkGetSpaceIfCached(DOCUMENT_AS_NAME, _asParent);
        // STR_MVC_CLASS_NAME
        resultingRedirect.SetDisplayPage(DOCUMENT_DP_NAME);
        resultingRedirect.SetControl(DOCUMENT_CONTROL_NAME);
        // DirConstants.QS_CARDID
        resultingRedirect.AddControlArgument(STR_CARD_ID, nDocumentId);
      }
      catch (Exception e)
      {
        // DCA - no document with the exact name was found. Perhaps it was misspelled. Perform search.
        resultingRedirect.SetLinkCreateNewSpace(SEARCH_AS_NAME, _asParent);
        resultingRedirect.SetControl(SEARCH_CONTROL_NAME);
        resultingRedirect.AddControlArgument(SearchResultControl.USER_QUERY,
         strDocumentName);
        resultingRedirect.AddControlArgument(STR_OBJTYPE, PT_CLASSIDS.PT_CATALOGCARD_ID);
        }
      return resultingRedirect;
    }
    
    /// <seealso cref="IPTClassTypeDesc#ConstructFriendlyURL(String,int,String)">Generates a friendly Url for Documents</seealso>
    public override String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space)
    {
      String objectName = url.GetOjectName();
      int objectId = url.GetObjectId();
      if (("".Equals(objectName) || objectName == null) && objectId <= 0)
      {
        throw new PTException("Both object name and id are missing. At least one needs to be specified to create a friendly Url.",
         PT_RESULTCODES.PT_E_INVALIDARGUMENT);
      }
      // TODO CR DLH: Should this length be shared by default by all friendly URLs?  Maybe
      // stored in a common base class or something?
      XPStringBuilder buf = new XPStringBuilder(200);
      // DCA - get keyword mapping 
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      IFriendlyURLManager ptFriendlyURLMgr = (IFriendlyURLManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
      String docKeyword = ptFriendlyURLMgr.LookupFriendlyURLKeyFromClassId(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
      if (docKeyword == null)
      {
        throw new PTException("No Friendly URL keyword was found for Documents. " + "Verify that a mapping entry exists in FriendlyURL.xml.",
         PT_RESULTCODES.PT_E_FAIL);
      }
      buf.Append("/").Append(docKeyword);
      buf.Append("/").Append(objectId);
      // need to lookup object name from object id. Use the card object cache
      if ("".Equals(objectName) || objectName == null)
      {
        IPTSession session = (IPTSession) space.GetUserSession();
        try
        {
          objectName = ((IPTCatalog) session.GetCatalog()).LookupNameFromObjectId(objectId,
           PT_CLASSIDS.PT_CATALOGCARD_ID);
        }
        catch (PTException e)
        {
          throw new PTException(e, "Invalid document id provided: " + objectId + " . The document does not exists or the user does not have access to it.",
           PT_RESULTCODES.PT_E_INVALIDARGUMENT);
        }
      }
      String normalizedObjectName = FriendlyURL.NormalizeObjectName(objectName);
      // DCA - we're encoding in case it has non-ASCII chars
      objectName = XPHttpUtility.UrlEncode(normalizedObjectName, LinkConstants.UTF_8_ENCODING);
      // Add the name
      buf.Append("/").Append(objectName);
      // DCA - that's all we need to construct document URLs
      return buf.ToString();
    }
  }
}