using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Invitation editor in create mode (APTNonExtClassTypeDesc).
  /// 2) Edit - Invitation editor in edit mode (APTNonExtClassTypeDesc).
  /// 3) View - Redirect to Edit (APTClassTypeDesc).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTInvitations : APTNonExtClassTypeDesc
  {
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTInvitations() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1532;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
     */
     
    public override String GetASNameForEditor()
    {
      return "InvitationEditor";
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_INVITATION_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(15, "ptmsgs_portalinfrastructure", _strLangID);
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_INVITATIONS;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_INVITATION).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
  }
}