using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Portlet editor in create mode (PTPortlets).
  /// 2) Edit - Portlet editor in edit mode (APTNonExtClassTypeDesc).
  /// 3) View - Portlet preview page (PTPortlets).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// This ClassType supports implements several extensible 
  /// methods so that it can bring up the required objects
  /// tree before opening the editor in the admin page. 
  /// Since it doesn't need a provider, we treat it as non
  /// extensible.  
  /// </summary>
  /// <author>John Osborne</author>
  public class PTPortlets : APTNonExtClassTypeDesc
  {
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTPortlets() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1564;
    }
    
    /// <summary>
    /// Statics used to pass information to the 
    /// editor through Query String arguments.
    /// </summary>
    public const String PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY = "forcomm";
    public const String PORTLET_EDITOR_QS_INT_CREATOR_CLASSID = "creatorCLASSID";
    public const String PORTLET_EDITOR_QS_INT_CREATOR_ID = "creatorID";
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
     */
     
    public override String GetASNameForEditor()
    {
      return "PortMainPortletEditor";
    }
    
    /// <summary>
    /// Returns the name of the Activity Space that is used 
    /// to edit this class type.
    /// </summary>
    /// <param name="_strProvEnglishName">
    /// The english name of the 
    /// provider that is being used for this class type.
    /// </param>
    /// <returns>
    /// The name of the Activity Space that is used 
    /// to edit this class type.
    /// </returns>
    public virtual String GetASNameForEditor(String _strProvEnglishName)
    {
      return GetASNameForEditor();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_GADGET_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(20, "ptmsgs_portalinfrastructure", _strLangID);
      }
    
    /// <summary>
    /// Returns the CLSID for this object. 
    /// </summary>
    /// <param name="_nObjectID">The object ID.</param>
    /// <param name="_ptSession">The current session.</param>
    /// <returns>The CLSID for this object.</returns>
    public virtual String GetCLSIDForExistingObject(int _nObjectID, IPTSession _ptSession)
    {
      IPTGadget ptGadget = (IPTGadget) _ptSession.GetGadgets().Open(_nObjectID,
       false);
      String sProviderCLSID = ptGadget.GetGadgetProviderCLSID();
      return sProviderCLSID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_PORTLETS;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_PORTLET).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect rCreateNew = base.GetRedirectCreateNew(_htArguments, _asParent,
       _userSession);
      bool bForCommunity = HTTPHelpers.GetArgumentAsBoolean(_htArguments,
       PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY, false);
      int nCreatorCLASSID = HTTPHelpers.GetArgumentAsInt(_htArguments, PORTLET_EDITOR_QS_INT_CREATOR_CLASSID,
       -1);
      int nCreatorID = HTTPHelpers.GetArgumentAsInt(_htArguments, PORTLET_EDITOR_QS_INT_CREATOR_ID,
       -1);
      //AGC- Pass along the arguments we may have gotten from the opening tree / editor.
      rCreateNew.AddControlArgument(PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY,
       bForCommunity);
      rCreateNew.AddControlArgument(PORTLET_EDITOR_QS_INT_CREATOR_CLASSID,
       nCreatorCLASSID);
      rCreateNew.AddControlArgument(PORTLET_EDITOR_QS_INT_CREATOR_ID, nCreatorID);
      // if the provider requires a object choice on start,
      // we can check that it it's in our arguments list.
      // nCommunityID is not required.
      if ((-1 == nCreatorCLASSID) || (-1 == nCreatorID))
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, _asParent.GetString(490, "ptmsgs_portalinfrastructure"), null);
        UIErrorHandler.RaiseError(myError, _asParent.GetSubSession(), _asParent.GetApplication());
        throw new XPException("Creator, and creator class ID arguments are required in the Common Opener URL for this object in create mode.");
        }
      // if creator class ID is not either web service  
      // or portlet template, we show a UI error.
      if ((nCreatorCLASSID != PT_CLASSIDS.PT_GADGETTEMPLATE_ID) && (nCreatorCLASSID != PT_CLASSIDS.PT_WEBSERVICE_ID))
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, _asParent.GetString(491, "ptmsgs_portalinfrastructure"), null);
        UIErrorHandler.RaiseError(myError, _asParent.GetSubSession(), _asParent.GetApplication());
        throw new XPException("The creator class ID argument must refer to either the Web Service or Portlet Template class types.");
        }
      return rCreateNew;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectViewObject(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      int nGadgetID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
       HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID,
       -1));
      // AGC- Generate an URL to the preview page for gadgets.
      // We are re-using the URL generated for use in invitations for this purpose.
      // See Naveen for details.
      Redirect rPreview = new Redirect();
      /*PreviewGadgetAS.STR_MVC_CLASS_NAME*/
      rPreview.SetLinkCreateNewSpace("PreviewGadget", _asParent);
      rPreview.SetControl(/*PreviewGadgetControl.STR_MVC_CLASS_NAME*/
      "PreviewGadget");
      rPreview.SetDisplayPage(/*PreviewGadgetDP.STR_MVC_CLASS_NAME*/
      "PreviewGadget");
      /*PreviewGadgetControl.m_PreviewType*/
      rPreview.AddControlArgument("PreviewType", /*PreviewGadgetModel.SEARCHHEADER*/
      "4");
      /*PreviewGadgetControl.m_strGadgetParam*/
      rPreview.AddControlArgument("GadgetID", nGadgetID);
      return rPreview;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
  }
}