using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Snapshot query editor in create mode (APTNonExtClassTypeDesc).
  /// 2) Edit - Snapshot query editor in edit mode (APTNonExtClassTypeDesc).
  /// 3) View - Redirect to Edit (APTClassTypeDesc).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTSavedSearches : APTNonExtClassTypeDesc
  {
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTSavedSearches() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 2002;
    }
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return true;
    }
    public override String GetASNameForEditor()
    {
      return "SavedSearchEditor";
    }
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_SAVEDSEARCH_ID;
    }
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(25, "ptmsgs_portalinfrastructure", _strLangID);
      }
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_SAVEDSEARCHES;
    }
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_SAVED_SEARCH).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    public override int[] GetRelatedClassTypeIDs()
    {
      return new int[]{PT_CLASSIDS.PT_GADGET_ID};
    }
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
  }
}