using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Taxonomist utility in create mode (PTTaxonomist).
  /// 2) Edit - Taxonomist utility in edit mode (APTNonExtClassTypeDesc).
  /// 3) View - Redirect to Edit (APTClassTypeDesc).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTTaxonomist : APTNonExtClassTypeDesc
  {
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTTaxonomist() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 1567;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
     */
     
    public override String GetASNameForEditor()
    {
      return "SmartSortEditor";
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_TAXONOMIST_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(29, "ptmsgs_portalinfrastructure", _strLangID);
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_TAXONOMISTS;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_SMART_SORT).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      // override the requirement of having a folder id.
      _htArguments.PutElement(IPTOpenerConstants.STR_QS_FOLDERNOTREQUIRED,
       new String[]{"true"});
      Redirect resultingRedirect = base.GetRedirectCreateNew(_htArguments,
       _asParent, _userSession);
      // must be saved in the intrinsic folders.
      resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID,
       PT_INTRINSICS.PT_ADMIN_FOLDER_INTRINSICOPS);
      resultingRedirect.AddControlArgument(IPTOpenerConstants.STR_QS_FORCESAVEINFOLDER,
       true);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
  }
}