using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes
{
  /// <summary>
  /// Common Opener Mode Description:
  /// 1) Create - Web services editor in create mode (PTWebServices).
  /// 2) Edit - Web services editor in edit mode (APTExtClassTypeDesc).
  /// 3) View - Redirect to Edit (APTClassTypeDesc).
  /// 4) Meta - View object properties page (APTClassTypeDesc).
  /// </summary>
  /// <author>John Osborne</author>
  public class PTWebServices : APTExtClassTypeDesc
  {
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */
     
    public PTWebServices() : base()
    {
      hasObjectLockManager = true;
      objectLockManagerMsgID = 2003;
    }
    public const String QS_WS_REMOTE_SERVER = "remoteServer";
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
     */
     
    public override bool AppearsInMainCreateNewClassMenu()
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTExtClassTypeDesc#GetASNameForEditor(java.lang.String)
     */
     
    public override String GetASNameForEditor(String _strProvEnglishName)
    {
      String strBaseEditorASName = "WebServiceEditor";
      return _strProvEnglishName + strBaseEditorASName;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
     */
     
    public override int GetClassID()
    {
      return PT_CLASSIDS.PT_WEBSERVICE_ID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
     */
     
    public override int GetCreateActivityID()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_WEBSERVICE_INFRASTRUCTURE;
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
     */
     
    public override String GetClassTypeLocalizedName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(31, "ptmsgs_portalinfrastructure", _strLangID);
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTExtClassTypeDesc#GetCLSIDForExistingObject(int, com.plumtree.server.IPTSession)
     */
     
    public sealed override String GetCLSIDForExistingObject(int _nObjectID,
     IPTSession _ptSession)
    {
      IPTWebService ptWebService = (IPTWebService) _ptSession.GetWebServices().Open(_nObjectID,
       false);
      String sProviderCLSID = ptWebService.GetProviderCLSID();
      return sProviderCLSID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
     */
     
    public override HTMLImg GetDefaultIcon()
    {
      try
      {
        HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_WEB_SERVICE).GetHTMLElement();
        return imgIcon;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
     */
     
    public override Redirect GetRedirectCreateNew(XPHashtable _htArguments,
     AActivitySpace _asParent, Object _userSession)
    {
      Redirect resultingRedirect = base.GetRedirectCreateNew(_htArguments,
       _asParent, _userSession);
      // Pass on the Remote Server ID, if it exists
      String strRemoteServerID = HTTPHelpers.GetArgumentAsString(_htArguments,
       QS_WS_REMOTE_SERVER, "");
      resultingRedirect.AddControlArgument(QS_WS_REMOTE_SERVER, strRemoteServerID);
      return resultingRedirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetRelatedClassTypeIDs()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
     */
     
    public override int[] GetDependentClassTypeIDs()
    {
      // Technically, only certain kinds of web services can have
      // certain kinds of dependent objects, but it doesn't hurt
      // to try to delete all of these objects before any Web
      // Service.
      return new int[]{PT_CLASSIDS.PT_GADGET_ID, PT_CLASSIDS.PT_GADGETTEMPLATE_ID,
       PT_CLASSIDS.PT_DATASOURCE_ID, PT_CLASSIDS.PT_AUTHSOURCE_ID, PT_CLASSIDS.PT_PROFILESOURCE_ID,
       PT_CLASSIDS.PT_FEDERATEDPORTAL_ID};
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
     */
     
    public override bool HasGlobalClassTypeMap()
    {
      return false;
    }
  }
}