using System;
namespace com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework
{
  /// <summary>
  /// This interface contains general extensibility constants used with extensible components.
  /// </summary>
  public abstract class AExtensibilityConstants
  {
    ///////////////////////////////////////////////////////////////////////
    //  General
    ///////////////////////////////////////////////////////////////////////
    // PT_PROPBAG_FORMAT will be used by ALL extensibility PropertyBags,
    //   and contains the format identifier. This lets the propbags be
    //   self describing, to an extent.
    public const String PT_PROPBAG_FORMAT = "PTC_PBAGFORMAT";
    ///////////////////////////////////////////////////////////////////////
    //  DataSource Provider
    ///////////////////////////////////////////////////////////////////////
    // *** "Document Location" PropertyBag Required Fields ***
    // The Doc Type Map Category is used to know which part of the Document Type Map to use to do lookups of the value stored in PT_PROPBAG_DOC_IDENTIFIER
    public const String PT_PROPBAG_DOC_TYPE_MAP_SECTION_ID = "PTC_DTM_SECT";
    // The Document Identifier is used to look in the Document Type Map.  For example, for file PropertyBags, this will store the file short name
    public const String PT_PROPBAG_DOC_IDENTIFIER = "PTC_DOC_ID";
    // The Unique Identifier is used to uniquely identify the location of the document or container.  This will be used by crawlers to guarantee that they do not crawl the same document or container multiple times.  It should be a string.  It may also be used internally by the Accessor or Provider, at their discretion.
    public const String PT_PROPBAG_UNIQUE_ID = "PTC_UNIQUE";
    // *** "Crawler Node" PropertyBag Required Fields ***
    // The human readable name of the folder (e.g. "Downloads", used to recreate the folder hierarchy in Plumtree)
    public const String PT_PROPBAG_CONTAINER_NODE_FOLDER_NAME = "PTC_FOLDER_NAME";
    public const int PT_PROPBAG_FORMAT_FEDSEARCH_SIMPLEREQUEST = 8000;
    public const int PT_PROPBAG_FORMAT_FEDSEARCH_SEARCHRESULT = 8001;
    public const int PT_PROPBAG_FORMAT_FEDSEARCH_OPENDOCTOKEN = 8002;
    // *** Federated Search Simple Search Request Required Fields ***
    // properties for a federated search simple search request
    public const String PT_PROPBAG_FEDSEARCH_SIMPLEREQUEST_REQUESTINGPORTAL = "PTC_FEDSEARCH_REQUESTINGPORTAL";
    public const String PT_PROPBAG_FEDSEARCH_SIMPLEREQUEST_ENCRYPTEDINNERBAG = "PTC_FEDSEARCH_ENCRYPTEDINNERBAG";
    //	BJF- PT_PROPBAG_FORMAT is required, as described above
    // the Plumtree federated search request's ENCRYPTEDINNERBAG property is actually an encrypted property bag;
    // the federated search agent will decrypt it, load it into a property bag, and then read out the following
    // properties:
    public const String PT_PROPBAG_FEDSEARCH_SIMPLEREQUEST_INNERBAG_SKIP = "PTC_FEDSEARCH_SKIP";
    public const String PT_PROPBAG_FEDSEARCH_SIMPLEREQUEST_INNERBAG_MAX = "PTC_FEDSEARCH_MAX";
    public const String PT_PROPBAG_FEDSEARCH_SIMPLEREQUEST_INNERBAG_REQUESTSTRING = "PTC_FEDSEARCH_REQUESTSTRING";
    public const String PT_PROPBAG_FEDSEARCH_SIMPLEREQUEST_INNERBAG_REQUESTINGUSER = "PTC_FEDSEARCH_REQUESTINGUSER";
    public const String PT_PROPBAG_FEDSEARCH_SIMPLEREQUEST_INNERBAG_TIMESTAMP = "PTC_FEDSEARCH_TIMESTAMP";
    // ***Federated Search Result Required Fields ***
    // properties for a federated search result
    public const String PT_PROPBAG_FEDSEARCH_RESULT_MATCHESRETURNED = "PTC_FEDSEARCH_MATCHESRETURNED";
    public const String PT_PROPBAG_FEDSEARCH_RESULT_SKIPPED = "PTC_FEDSEARCH_SKIPPED";
    public const String PT_PROPBAG_FEDSEARCH_RESULT_TOTALMATCHES = "PTC_FEDSEARCH_TOTALMATCHES";
    public const String PT_PROPBAG_FEDSEARCH_RESULT_CARDPROPERTYIDS = "PTC_FEDSEARCH_CARDPROPERTYIDS";
    // this is set ONLY if the search fails
    public const String PT_PROPBAG_FEDSEARCH_RESULT_FAILEDMESSAGE = "PTC_FEDSEARCH_FAILEDMESSAGE";
    // CardPropertyValues will be appended with the ID of a card property; the value of
    // PTC_FEDSEARCH_CARDPROPERTYVALUES1 will then contain an array of PT_PROPERTY_CARDNAME values for
    // each row returned.
    public const String PT_PROPBAG_FEDSEARCH_RESULT_CARDPROPERTYVALUES = "PTC_FEDSEARCH_CARDPROPERTYVALUES";
    //	BJF- PT_PROPBAG_FORMAT is required, as described above
    // ***Federated Search -- Property Bag that is encrypted as a token in the returned open document URLs ***
    // properties for a federated search result
    public const String PT_PROPBAG_FEDSEARCH_OPENDOC_REQUESTINGPORTAL = "PTC_FEDSEARCH_REQUESTINGPORTAL";
    public const String PT_PROPBAG_FEDSEARCH_OPENDOC_INNERBAG = "PTC_FEDSEARCH_INNERBAG";
    // the inner, encrypted portion of the open doc bag
    public const String PT_PROPBAG_FEDSEARCH_OPENDOC_INNERBAG_CARDID = "PTC_FEDSEARCH_CARDID";
    public const String PT_PROPBAG_FEDSEARCH_OPENDOC_INNERBAG_EXPIRES = "PTC_FEDSEARCH_EXPIRES";
    public const String PT_PROPBAG_FEDSEARCH_OPENDOC_INNERBAG_REQUESTINGPORTAL = "PTC_FEDSEARCH_INNERBAG_REQUESTINGPORTAL";
    public const String PT_PROPBAG_FEDSEARCH_OPENDOC_INNERBAG_REQUESTINGUSER = "PTC_FEDSEARCH_REQUESTINGUSER";
    //	BJF- PT_PROPBAG_FORMAT is required, as described above
    // the name of the form variable set in the form post made by the requesting portal that contains the search request
    public const String PT_FEDERATEDSEARCH_SEARCHREQUEST_FORMVARIABLENAME = "SearchRequest";
    ///////////////////////////////////////////////////////////////////////////
    // Transformer constants
    ////////////////////////////////////////////////////////////////////
    public const int PT_PROPBAG_FORMAT_ADMINGADGETSETTINGS = 9000;
    public const String PT_PROPBAG_ADMINGADGETSETTINGS_NUMPREFS = "PTC_ADMINGADGETSETTINGS_NUMPREFS";
    ///////////////////////////////////////////////////////////////////////////
    // Transformer constants
    ////////////////////////////////////////////////////////////////////
    // Transformer PropBags are created by clients and passed to Transformers
    public const int PT_PROPBAG_FORMAT_XML_TRANSFORMER_INIT = 7000;
    public const int PT_PROPBAG_FORMAT_HTML_TRANSFORMER_INIT = 7001;
    public const String PT_PROPBAG_TRANSFORMER_CLASSID = "TRANSCLASSID";
    // syndicated Publickatons
    public const String PT_SYNDPUB_IMPERSONATINGUSER = "IMPERSONATEUSER";
    ///////////////////////////////////////////////////////////////////////////
    // GCS constants
    ////////////////////////////////////////////////////////////////////
    public const String PT_PROPBAG_GCS_GADGET_LIST = "GCS_GADGET_LIST";
    public const String PT_GPAPPDATA_ON_STATE = "PlumtreeCSP";
    ///////////////////////////////////////////////////////////////////////////
    // Authentication Source Provider constants
    ////////////////////////////////////////////////////////////////////
    public const int PT_AUTHSOURCEPROV_CONFIG_CATEGORY = 0;
    public const int PT_AUTHSOURCEPROV_CONFIG_NTDOMAIN = 1;
    //////////////////////////////////////////////////////////////////////////////////////////////
    //////////////		Property Bag Formats		//////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////////////
    //	These constants will identify the "format" of the propertybag, which allows consumers of
    //	a propertybag to assure that they are receiving the correct type of stuff.  The value
    //	will be stored in the PT_PROPBAG_FORMAT field.
    // Provider Initialization PropBags are stored in Data Sources, and are used to connect a Provider to a Repository
    public const int PT_PROPBAG_FORMAT_FILE_PROVIDER_INIT = 1000;
    public const int PT_PROPBAG_FORMAT_NOTES_PROVIDER_INIT = 1001;
    public const int PT_PROPBAG_FORMAT_WEB_PROVIDER_INIT = 1002;
    public const int PT_PROPBAG_FORMAT_EXCHANGE_PROVIDER_INIT = 1003;
    public const int PT_PROPBAG_FORMAT_DOCS_PROVIDER_INIT = 1004;
    public const int PT_PROPBAG_FORMAT_NOTES_PROVIDER_INIT_2 = 1005;
    public const int PT_PROPBAG_FORMAT_DOCUMENTUM_PROVIDER_INIT = 1006;
    // Provider Document PropBags are stored in Cards, and are used to find a particular document in a repository
    public const int PT_PROPBAG_FORMAT_FILE_PROVIDER_DOC = 2000;
    public const int PT_PROPBAG_FORMAT_NOTES_PROVIDER_DOC = 2001;
    public const int PT_PROPBAG_FORMAT_WEB_PROVIDER_DOC = 2002;
    public const int PT_PROPBAG_FORMAT_EXCHANGE_PROVIDER_DOC = 2003;
    public const int PT_PROPBAG_FORMAT_DOCS_PROVIDER_DOC = 2004;
    public const int PT_PROPBAG_FORMAT_NOTES_PROVIDER_DOC_2 = 2005;
    public const int PT_PROPBAG_FORMAT_DOCUMENTUM_PROVIDER_DOC = 2006;
    // Crawler Init PropBags are stored in Crawlers, and are used to configure the crawler and provide a start location
    public const int PT_PROPBAG_FORMAT_FILE_CRAWLER_INIT = 3000;
    public const int PT_PROPBAG_FORMAT_NOTES_CRAWLER_INIT = 3001;
    public const int PT_PROPBAG_FORMAT_WEB_CRAWLER_INIT = 3002;
    public const int PT_PROPBAG_FORMAT_EXCHANGE_CRAWLER_INIT = 3003;
    public const int PT_PROPBAG_FORMAT_DOCS_CRAWLER_INIT = 3004;
    public const int PT_PROPBAG_FORMAT_NOTES_CRAWLER_INIT_2 = 3005;
    public const int PT_PROPBAG_FORMAT_DOCUMENTUM_CRAWLER_INIT = 3006;
    // Accessor Document PropBags are created by Providers and handed to Accessors.  They are not stored.
    public const int PT_PROPBAG_FORMAT_FILE_ACCESSOR_DOC = 4000;
    public const int PT_PROPBAG_FORMAT_NOTES_ACCESSOR_DOC = 4001;
    public const int PT_PROPBAG_FORMAT_EXCHANGE_ACCESSOR_DOC = 4002;
    // Delivery Method Provider PropBags are created by Delivery Method Browsers and are stored by Delivery Methods
    public const int PT_PROPBAG_FORMAT_SIMPLEEMAIL_DMPROVIDER_INIT = 5000;
    public const int PT_PROPBAG_FORMAT_FILE_DMPROVIDER_INIT = 5001;
    // Portlet Provider PropBags are created by Portlet Browsers and are stored by Gadgets
    public const int PT_PROPBAG_FORMAT_ASPGADGET_INIT = 6000;
    public const int PT_PROPBAG_FORMAT_HTTPGADGET_INIT = 6001;
    public const int PT_PROPBAG_FORMAT_INTRINSICGADGET_INIT = 6002;
    //////////////////////////////////////////////////////////////////////////////////////////////
    //////////////		Document Type Map Category IDs			//////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////////////
    // There is one Document Type Category for each type identifier.  For example, the
    //	File section will store file names with wildcard ("*.doc"), while the Mime
    //	section will store Mime types ("Application/MSWord")
    // Associated with PT_PROPBAG_FORMAT_FILE_ACCESSOR
    public const int PT_DOC_IDENTIFIER_TYPE_FILE = 1000;
    // Associated with PT_PROPBAG_FORMAT_FILE_ACCESSOR
    public const int PT_DOC_IDENTIFIER_TYPE_MIME = 1001;
    // Associated with PT_PROPBAG_FORMAT_NOTES_ACCESSOR
    public const int PT_DOC_IDENTIFIER_TYPE_NOTES = 1002;
    // Associated with PT_PROPBAG_FORMAT_EXCHANGE_ACCESSOR
    public const int PT_DOC_IDENTIFIER_TYPE_EXCHANGE = 1003;
    // JAS- information needed to connect to a particular data repository.
    public const String PT_PROPBAG_REPOSITORY_INFO = "PTC_REPOSITORY_INFO";
    // JAS- information needed to connect to a particular document within a data repository.
    public const String PT_PROPBAG_DOCUMENT_INFO = "PTC_DOCUMENT_INFO";
    // JAS- configuration information for a specific crawl within a data repository.
    public const String PT_PROPBAG_CRAWLER_INFO = "PTC_CRAWLER_INFO";
    // AGC- configuration information for a delivery method.
    public const String PT_PROPBAG_DELIVERYMETHOD_INFO = "PTC_DELIVERYMETHOD_INFO";
    // configuration information for a gadget. -sra.
    public const String PT_PROPBAG_GADGET_INFO = "PTC_GADGET_INFO";
    // A description to go with the above name (e.g. "\Ithaca\Downloads")
    public const String PT_PROPBAG_CONTAINER_NODE_FOLDER_DESCRIPTION = "PTC_FOLDER_DESC";
    public const String PT_PROPBAG_PERFORM_MIRROR_CRAWL = "PTC_MIRROR";
    /////////////////////////////////////////////////////////////////////////////
    //////////////	File Accessor Required Fields	/////////////////////////////
    /////////////////////////////////////////////////////////////////////////////
    //MS- The following fields are REQUIRED in the Accessor Document Location PropertyBags
    //	that will be used to initialize FILE Accessors
    //MS- The full name of the file, including path
    public const String PT_PROPBAG_FILE_NAME = "PTC_FILE";
    //MS- The name of the Notes server, e.g. qa6/plumtree
    public const String PT_PROPBAG_NOTES_SERVER_NAME = "PTC_NOTES_SERVER_NAME";
    //MS- The relative path to the Notes database, e.g. MichaelT.nsf
    public const String PT_PROPBAG_NOTES_DATABASE_FILE = "PTC_NOTES_DB_FILE";
    //MS- The UserID file, e.g. C:\Notes\Data\msmedber.id
    public const String PT_PROPBAG_NOTES_USERID = "PTC_NOTES_USER";
    //MS- The Password for the user, e.g. plumtree
    public const String PT_PROPBAG_NOTES_PASSWORD = "PTC_NOTES_PASS";
    //MS- The name of the machine running PlumNotes, or empty if local
    public const String PT_PROPBAG_NOTES_REMOTEMACHINENAME = "PTC_NOTES_MACH";
    //MS- The UNC name of the folder to be used for temp files, or empty if local
    public const String PT_PROPBAG_NOTES_SHARED_FOLDER = "PTC_NOTES_SHARE";
    //MS- The internal NoteID of the Note to be accessed, e.g. 8466
    public const String PT_PROPBAG_NOTES_NOTEID = "PTC_NOTES_NOTEID";
    //MS- The suggested name for the Note (derived from PT_PROPBAG_NOTES_CARDNAMECOLUMN)
    public const String PT_PROPBAG_NOTES_SUGGESTEDNAME = "PTC_NOTES_SUGGNAME";
    //MS- Does the card represent an Attachment to the Note?  (Boolean stored as long)
    public const String PT_PROPBAG_NOTES_ISATTACHMENT = "PTC_NOTES_ISATTACH";
    //MS- If the card represents an Attachment, which Attachment is it, e.g. folder.gif
    public const String PT_PROPBAG_NOTES_ATTACHMENTNAME = "PTC_NOTES_ATTACHNAME";
    //MS- The Domino URL to the Notes server, e.g. http://qa6:8080
    public const String PT_PROPBAG_NOTES_DOMINOSERVERURL = "PTC_NOTES_DOMURL";
    //MS- A text representation of the UNID of the view/folder from which the Note came (used to create the Domino URL), e.g. e50fdc93a13b676f8825664e006c157d
    public const String PT_PROPBAG_NOTES_VIEWFOLDER_UNID = "PTC_NOTES_VF_UNID";
    public const String PT_PROPBAG_NOTES_VIEWFOLDER_ID = 
    //MS- Notes internal ID of the view/folder to crawl, e.g. 274
    "PTC_NOTES_VF_ID";
    public const String PT_PROPBAG_NOTES_CRAWL_TEXTCONSTRAINT = 
    //MS- If there is a text constraint, the text of the constraint
    "PTC_NOTES_SEARCH";
    public const String PT_PROPBAG_NOTES_CRAWL_THROTTLE = 
    //MS- If the crawl is throttled, the milliseconds to wait between nodes
    "PTC_NOTES_THROTTLE";
    public const String PT_PROPBAG_NOTES_CRAWL_CREATE_CARDS_FOR_NOTES = 
    //MS- Should cards be created for Notes?  (Boolean stored as long)
    "PTC_NOTES_CRAWL_NOTES";
    public const String PT_PROPBAG_NOTES_CRAWL_CREATE_CARDS_FOR_ATTACHMENTS = 
    //MS- Should cards be created for Attachments?  (Boolean stored as long)
    "PTC_NOTES_CRAWL_ATTACH";
    //MS- A boolean indicating if PT_PROPBAG_NOTES_CRAWL_STARTLOC is set
    public const String PT_PROPBAG_NOTES_CRAWL_STARTLOC_CONSTRAINED = "PTC_NOTES_START_CONSTRAINED";
    //MS- The start location for a crawl- may be the zero length string
    public const String PT_PROPBAG_NOTES_CRAWL_STARTLOC = "PTC_NOTES_START";
    //MS- The name associated with PT_PROPBAG_NOTES_CRAWL_STARTLOC
    public const String PT_PROPBAG_NOTES_CRAWL_STARTLOC_NAME = "PTC_NOTES_START_NAME";
    //MS- Name of the view/folder to crawl (used to create a text description of the crawl), e.g. TestView
    public const String PT_PROPBAG_NOTES_VIEWFOLDER_NAME = "PTC_NOTES_VF_NAME";
    //MS- The name of the Notes database, e.g. Michael Test
    public const String PT_PROPBAG_NOTES_DATABASE_NAME = "PTC_NOTES_DB_NAME";
    public const String PT_PROPBAG_EXCHANGE_DOCUMENT_ID_ARRAY = "PTC_EXCHANGE_DOCUMENT_ID_ARRAY";
    //	AGC- An array of PR_ENTRYIDs that identify the children of a MAPI document. Each of the IDs in this array must be added to the end of
    //	a PTC_EXCHANGE_DOCUMENT_ID_ARRAY in order to create a set of PT_PROPBAG_EXCHANGE_DOCUMENT_ID_ARRAYs
    //	that each uniquely identify a MAPI document. The Propertybag could store each full Exchange Document ID Array, however,
    //	the resulting propertybag would be quite large and would contain anywhere from 66% to 90+% duplicate information.
    public const String PT_PROPBAG_EXCHANGE_DISPLAY_PATH = "PTC_PROPBAG_EXCHANGE_DISPLAY_PATH";
    // A LONG that is used as an input to ExchangeExternal::ExchangeDocument->GetChildren that masks out certain
    // child return values. This is optional and only valid in a Crawler bag.
    public const String PT_PROPBAG_EXCHANGE_FILTER_MASK = "PTC_PROPBAG_EXCHANGE_FILTER_MASK";
    //	AGC- PT_PROPBAG_FORMAT is required, as described above
    /////////////////////////////////////////////////////////////////////////////
    //////////////	Documentum  Fields	/////////////////////////////////////////
    /////////////////////////////////////////////////////////////////////////////
    //JD- The following fields appear in the Provider Initialization PropertyBags
    //JD- Name of the documentum domain, e.g. Documentum1
    public const String PT_PROPBAG_DOCUMENTUM_DOMAIN = "PTC_DOCUMENTUM_DOMAIN";
    //JD- Name of the docbase in the domain, e.g. Documentum1
    public const String PT_PROPBAG_DOCUMENTUM_DOCBASE = "PTC_DOCUMENTUM_DOCBASE";
    //JD- Username for Documentum, e.g. DMAdmin
    public const String PT_PROPBAG_DOCUMENTUM_USER = "PTC_DOCUMENTUM_USER";
    //JD- Password for user, e.g. plumtree
    public const String PT_PROPBAG_DOCUMENTUM_PASSWORD = "PTC_DOCUMENTUM_PASS";
    public const String PT_PROPBAG_THREADS = "PTC_NUM_THREADS";
    //MS- Crawlers may (optionally) store the crawl depth in PT_PROPBAG_DEPTH.
    //	Alternately, they may have their own, proprietary way of recording depth.
    public const String PT_PROPBAG_DEPTH = "PTC_CRAWL_DEPTH";
    //MS- PT_DOCUMENT_FORMAT_NAME and PT_DOCUMENT_FORMAT_DESC are used to add an accessor-specific
    //	field to each card.  This field can be used by end users to search for documents of a
    //	particular type (e.g. to search for all PowerPoint presentations.)
    // JF- These are constants and should NOT be String extracted.
    public const String PT_DOCUMENT_FORMAT_NAME = "Plumtree Document Format";
    public const String PT_DOCUMENT_FORMAT_DESC = "The Plumtree Document Format represents the format of the source document (e.g. Microsoft Word or Lotus Notes)";
    public const String DUMMY_PASSWORD = "********";
    public const int DSP_CAP_DEPTH_UNLIMITED = -1;
    public const int DSP_CAP_THREADS_UNLIMITED = -1;
    //////////////////////////////////////////////////////////////////////////////////////////////
    //////////////		Web Session State constants			//////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////////////
    //amcd - constants used to key items in the UserSessionState dictionary in the web UI.
    public const int PT_WEBSTATE_USER_NAME = 1;
    public const int PT_WEBSTATE_STYLE_SHEET_URI = 2;
    public const int PT_WEBSTATE_HOST_PAGE_URI = 3;
    public const int PT_WEBSTATE_COMMUNITY_ID = 4;
    public const int PT_WEBSTATE_GATEWAY_MAJOR_VERSION = 5;
    public const int PT_WEBSTATE_GATEWAY_MINOR_VERSION = 6;
    public const int PT_WEBSTATE_BANNER_URI = 7;
    //////////////////////////////////////////////////////////////////////////////////////////////
    //////////////  Portlet object - Names of Property Bags passed to ProviderInfo   //////////////
    //////////////////////////////////////////////////////////////////////////////////////////////
    //JF- Portlet url
    public const String PT_PROPBAG_HTTPGADGET_URL = "PTC_HTTPGADGET_URL";
    //JF- Portlet Summary url
    public const String PT_PROPBAG_HTTPGADGET_SUMMARYURL = "PTC_HTTPGADGET_SUMMARYURL";
    //JF- Portlet preferences url
    public const String PT_PROPBAG_HTTPGADGET_PREFSURL = "PTC_HTTPGADGET_PREFSURL";
    //JF- Portlet admin preferences url
    public const String PT_PROPBAG_HTTPGADGET_ADMINPREFSURL = "PTC_HTTPGADGET_ADMINPREFSURL";
    //JF- Community preferences url.
    public const String PT_PROPBAG_HTTPGADGET_COMMUNITYPREFSURL = "PTC_HTTPGADGET_COMMUNITYPREFSURL";
    //JF- Portlet Authentication type
    public const String PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION = "PTC_HTTPGADGET_SENDUSERBASICAUTHENTICATION";
    //JF- Basic Authentication User Name
    public const String PT_PROPBAG_HTTPGADGET_BASICAUTHNAME = "PTC_HTTPGADGET_BASICAUTHNAME";
    //JF- Basic Authentication Password
    public const String PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD = "PTC_HTTPGADGET_BASICAUTHPASSWORD";
    //JF- Portlet Timeout
    public const String PT_PROPBAG_HTTPGADGET_TIMEOUT = "PTC_HTTPGADGET_TIMEOUT";
    // DLH - String specifying the pagelet library to append to the GCS URL (for Ensemble pagelet web services only)
    public const String PT_PROPBAG_HTTPGADGET_PAGELET_LIBRARY = "PTC_HTTPGADGET_PAGELET_LIBRARY";
    // DLH - String specifying the pagelet name to append to the GCS URL (for Ensemble pagelet web services only)
    public const String PT_PROPBAG_HTTPGADGET_PAGELET_NAME = "PTC_HTTPGADGET_PAGELET_NAME";
    //JF- Gateway URL Prefixes growable table
    public const String PT_PROPBAG_HTTPGADGET_PROXYSPACE = "PTC_HTTPGADGET_PROXYSPACE";
    //JF- Send all User preferences to the Portlet server
    public const String PT_PROPBAG_HTTPGADGET_SENDALLUSERPREFS = "PTC_HTTPGADGET_SENDALLUSERPREFS";
    //JF- Send all Community preferences to the Portlet server.
    public const String PT_PROPBAG_HTTPGADGET_SENDALLCOMMUNITYPREFS = "PTC_HTTPGADGET_SENDALLCOMMUNITYPREFS";
    //JF- User Preferences List growable table
    public const String PT_PROPBAG_HTTPGADGET_USERPREFS = "PTC_HTTPGADGET_USERPREFS";
    //JF- User Info List growable table
    public const String PT_PROPBAG_HTTPGADGET_USERINFO = "PTC_HTTPGADGET_USERINFOSETTINGS";
    //JF- Community Preferences List growable table
    public const String PT_PROPBAG_HTTPGADGET_COMMUNITYPREFS = "PTC_HTTPGADGET_COMMUNITYPREFS";
    //JF- UNC Path to XSL File
    public const String PT_PROPBAG_HTTPGADGET_XSLFILEPATH = "PTC_HTTPGADGET_XSLFILEPATH";
    //JF- Minimum Cache Time
    public const String PT_PROPBAG_HTTPGADGET_MINC = "PTC_HTTPGADGET_MINC";
    //JF- Maximum Cache Time
    public const String PT_PROPBAG_HTTPGADGET_MAXC = "PTC_HTTPGADGET_MAXC";
    //JF- When Portlet download errors out, use cached content
    public const String PT_PROPBAG_HTTPGADGET_HIDEERR = "PTC_HTTPGADGET_HIDEERR";
    
    /// <summary>
    /// Parameter mapping to preference types for pagelet portlets
    /// </summary>
    public const String PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER = "PTC_HTTPGADGET_PARAMMAP_USER";
    public const String PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM = "PTC_HTTPGADGET_PARAMMAP_COMM";
    public const String PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN = "PTC_HTTPGADGET_PARAMMAP_ADMIN";
    
    /// <summary>
    /// descriptions for maped pagelets parameters *
    /// </summary>
    public const String PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER_DESCS = "PTC_HTTPGADGET_PARAMMAP_USER_DESCS";
    public const String PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM_DESCS = "PTC_HTTPGADGET_PARAMMAP_COMM_DESCS";
    public const String PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN_DESCS = "PTC_HTTPGADGET_PARAMMAP_ADMIN_DESCS";
    public const String PT_USERINFO_FULLNAME = "FullName";
    public const String PT_USERINFO_EMAIL = "Email";
    public const String PT_USERINFO_PHONE = "Phone";
    public const String PT_USERINFO_EMPLOYEEID = "EmployeeID";
    public const String PT_USERINFO_DEPARTMENT = "Department";
    public const String PT_USERINFO_TITLE = "Title";
    public const String PT_USERINFO_ZIPCODE = "ZipCode";
    public const String PT_USERINFO_MANAGER = "Manager";
    public const String PT_USERINFO_ACCESSINGFROMINTRANET = "AccessingFromIntranet";
    /////////////////////////////////////////////////////////////////////////
    // AGC- Recent additions for 5.0
    /////////////////////////////////////////////////////////////////////////
    public const String PTC_HTTPSOAP_TIMEOUT = "PTC_HTTPSOAP_TIMEOUT";
    public const String PTC_HTTPAWS_AUTH_TIMEOUT = "PTC_HTTPAWS_AUTH_TIMEOUT";
    public const String PTC_HTTPSOAP_ENCODED = "PTC_HTTPSOAP_ENCODED";
    public const String PTC_HTTPAWS_AUTHURL = "PTC_HTTPAWS_AUTHURL";
    public const String PTC_HTTPAWS_SYNCURL = "PTC_HTTPAWS_SYNCURL";
    public const String PTC_HTTPPWS_SYNCURL = "PTC_HTTPPWS_SYNCURL";
    public const String PTC_HTTPMWS_MWSURL = "PTC_HTTPMWS_MWSURL";
    public const String PTC_HTTPCWS_CONTAINERURL = "PTC_HTTPCWS_CONTAINERURL";
    public const String PTC_HTTPCWS_DOCUMENTURL = "PTC_HTTPCWS_DOCUMENTURL";
    public const String PTC_HTTPCWS_UPLOADURL = "PTC_HTTPCWS_UPLOADURL";
    public const String PTC_HTTPSWS_SEARCHURL = "PTC_HTTPSWS_SEARCHURL";
    public const String PTC_HTTPGADGET_ACTIVITYRIGHTS = "PTC_HTTPGADGET_ACTIVITYRIGHTS";
    public const String PTC_HTTPGADGET_ADMINPREFSURL_TEMPLT = "PTC_HTTPGADGET_ADMINPREFSURL_TEMPLT";
    public const String PTC_HTTPGADGET_CONFIGURL_ADMIN = "PTC_HTTPGADGET_CONFIGURL_ADMIN";
    public const String PTC_HTTPGADGET_CONFIGURL_COMMUNITY = "PTC_HTTPGADGET_CONFIGURL_COMMUNITY";
    public const String PTC_HTTPGADGET_CONFIGURL_USER = "PTC_HTTPGADGET_CONFIGURL_USER";
    public const String PTC_HTTPGADGET_GATEWAYTIMEOUT = "PTC_HTTPGADGET_GATEWAYTIMEOUT";
    public const String PTC_HTTPGADGET_HELPURL = "PTC_HTTPGADGET_HELPURL";
    public const String PTC_HTTPGADGET_LOGINTOKENVALID = "PTC_HTTPGADGET_LOGINTOKENVALID";
    public const String PTC_HTTPGADGET_MIGRATIONURL = "PTC_HTTPGADGET_MIGRATIONURL";
    public const String PTC_HTTPGADGET_SENDALLUSERINFOSETTINGS = "PTC_HTTPGADGET_SENDALLUSERINFOSETTINGS";
    public const String PTC_HTTPGADGET_SENDCOMMUNITYACL = "PTC_HTTPGADGET_SENDCOMMUNITYACL";
    public const String PTC_HTTPGADGET_SENDLOGINTOKEN = "PTC_HTTPGADGET_SENDLOGINTOKEN";
    public const String PTC_HTTPGADGET_SENDPAGEID = "PTC_HTTPGADGET_SENDPAGEID";
    public const String PTC_HTTPGADGET_SENDTIMEZONE = "PTC_HTTPGADGET_SENDTIMEZONE";
    public const String PTC_HTTPGADGET_XUIURL = "PTC_HTTPGADGET_XUIURL";
    public const String PTC_I_GADGET_CLASSID = "PTC_I_GADGET_CLASSID";
    public const String PTC_I_GADGET_ADMINPREFS_SPACE = "PTC_I_GADGET_ADMINPREFS_SPACE";
    public const String PTC_I_GADGET_ADMINPREFS_TEMPLT_SPACE = "PTC_I_GADGET_ADMINPREFS_TEMPLT_SPACE";
    public const String PTC_I_GADGET_COMMUNITYPREFS_SPACE = "PTC_I_GADGET_COMMUNITYPREFS_SPACE";
    public const String PTC_I_GADGET_HELP_URL = "PTC_I_GADGET_HELP_URL";
    public const String PTC_I_GADGET_PREFS_SPACE = "PTC_I_GADGET_PREFS_SPACE";
    
    /// <summary>
    /// strLocale is the user pref that tells the HTTPGP to send the locale to a Search Web Service 
    /// </summary>
    public const String PTC_STRLOCALE = "strLocale";
    public const String PTC_HTTPCWS_SUPPORTSMIRRORING = "PTC_HTTPCWS_SUPPORTSMIRRORING";
    public const String PTC_HTTPCWS_SUPPORTSACLIMPORT = "PTC_HTTPCWS_SUPPORTSACLIMPORT";
    }
}