using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.compoundlist
{
  /// <summary>
  /// Class to hold components of an URL. Used by ASCompoundLists
  /// </summary>
  /// <author>robertz</author>
  public class ListEntry
  {
    protected PTImageType Image;
    protected PTImageType Image2;
    protected String Control;
    protected String EditorAS;
    protected String EditorPage;
    // Editor params
    protected String EditorType;
    // Misc params
    protected String FullURL;
    protected String ImageAltText;
    //	protected String ImageHeight;
    //	protected String ImageWidth;
    // Common params
    protected String Label;
    protected String m_strDescription;
    protected String[] m_paramNames;
    protected String[] m_paramValues;
    // MyPage/Community params
    protected int CommunityID;
    protected int FolderID;
    protected int m_nProfileID;
    // for site map in community preview
    protected bool m_bIsPreview;
    // Directory params
    protected int Mode;
    protected int NewASType;
    protected int PageID;
    protected int Type;
    protected int m_nTruncateLength = 20;
    
    /// <summary>
    /// Creates a new ListEntry object.
    /// </summary>
    /// <param name="nType">Link type</param>
    public ListEntry(int nType)
    {
      Type = nType;
    }
    
    /// <summary>
    /// Gets the Community ID.
    /// </summary>
    /// <returns>Community integer ID</returns>
    public virtual int GetCommunityID()
    {
      return CommunityID;
    }
    
    /// <summary>
    /// Gets the Control ID.
    /// </summary>
    /// <returns>Control String ID</returns>
    public virtual String GetControl()
    {
      return Control;
    }
    
    /// <summary>
    /// Gets the Description
    /// </summary>
    /// <returns>Description String, empty String if none exists</returns>
    public virtual String GetDescription()
    {
      if (m_strDescription == null)
      {
        return "";
      }
      return XPHttpUtility.HtmlEncode(m_strDescription);
    }
    
    /// <summary>
    /// Gets the Editor Activityspace ID
    /// </summary>
    /// <returns>Activityspace String ID</returns>
    public virtual String GetEditorAS()
    {
      return EditorAS;
    }
    
    /// <summary>
    /// Gets the editorType.
    /// </summary>
    /// <returns>Editor int type</returns>
    public virtual String GetEditorType()
    {
      return EditorType;
    }
    
    /// <summary>
    /// Gets the FolderID for Directory
    /// </summary>
    /// <returns>Folder int ID</returns>
    public virtual int GetFolderID()
    {
      return FolderID;
    }
    
    /// <summary>
    /// Gets the Full URL
    /// </summary>
    /// <returns>Full URL String</returns>
    public virtual String GetFullURL()
    {
      return FullURL;
    }
    
    /// <summary>
    /// Gets the image.
    /// </summary>
    /// <returns>Image construct</returns>
    public virtual PTImageType GetImage()
    {
      return Image;
    }
    
    /// <summary>
    /// Gets the second image.
    /// </summary>
    /// <returns>Image construct</returns>
    public virtual PTImageType GetImage2()
    {
      return Image2;
    }
    
    /// <summary>
    /// Gets the imageAltText.
    /// </summary>
    /// <returns>Image Alt String</returns>
    public virtual String GetImageAltTextEncoded()
    {
      return XPHttpUtility.HtmlEncode(ImageAltText);
    }
    
    /// <summary>
    /// Gets the encoded and truncated label.
    /// </summary>
    /// <returns>Truncated and HTML encoded String</returns>
    public virtual String GetLabel()
    {
      String formatLabel = GeneralHelpers.TruncateLongString(Label, m_nTruncateLength,
       false);
      // bjf -- fixed bug here, it was calling HtmlEncode on Label rather than formatLabel.
      formatLabel = XPHttpUtility.HtmlEncode(formatLabel);
      return formatLabel;
    }
    
    /// <summary>
    /// Gets the encoded but untruncated label.
    /// </summary>
    /// <returns>HTML encoded String</returns>
    public virtual String GetOrigLabel()
    {
      String formatLabel = XPHttpUtility.HtmlEncode(Label);
      return formatLabel;
    }
    
    /// <summary>
    /// Gets the Mode
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetMode()
    {
      return Mode;
    }
    
    /// <summary>
    /// Gets the newASType.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetNewASType()
    {
      return NewASType;
    }
    
    /// <summary>
    /// Gets the Editor Page
    /// </summary>
    /// <returns>Editor String Page</returns>
    public virtual String GetPage()
    {
      return EditorPage;
    }
    
    /// <summary>
    /// Gets the Page ID.
    /// </summary>
    /// <returns>Page integer ID</returns>
    public virtual int GetPageID()
    {
      return PageID;
    }
    
    /// <summary>
    /// Gets the parameter names array
    /// </summary>
    /// <returns>Array of parameter names</returns>
    public virtual String[] GetParamNames()
    {
      return m_paramNames;
    }
    
    /// <summary>
    /// Gets the parameter value array
    /// </summary>
    /// <returns>Array of parameter values</returns>
    public virtual String[] GetParamValues()
    {
      return m_paramValues;
    }
    
    /// <summary>
    /// Gets the editor type.
    /// </summary>
    /// <returns>integer type</returns>
    public virtual int GetType()
    {
      return Type;
    }
    public virtual bool GetIsPreview()
    {
      return m_bIsPreview;
    }
    
    /// <summary>
    /// Sets the communityID.
    /// </summary>
    /// <param name="communityID">The community ID</param>
    public virtual void SetCommunityID(int communityID)
    {
      CommunityID = communityID;
    }
    
    /// <summary>
    /// Sets the control.
    /// </summary>
    /// <param name="control">The String Control</param>
    public virtual void SetControl(String control)
    {
      Control = control;
    }
    
    /// <summary>
    /// Sets the description.
    /// </summary>
    /// <param name="strDescription">The description</param>
    public virtual void SetDescription(String strDescription)
    {
      m_strDescription = strDescription;
    }
    
    /// <summary>
    /// Sets the editorAS.
    /// </summary>
    /// <param name="editorAS">The Editor Activityspace</param>
    public virtual void SetEditorAS(String editorAS)
    {
      EditorAS = editorAS;
    }
    
    /// <summary>
    /// Sets the editorType.
    /// </summary>
    /// <param name="editorType">The editorType</param>
    public virtual void SetEditorType(int editorType)
    {
      EditorType = XPConvert.ToString(editorType);
    }
    
    /// <summary>
    /// Set additional parameters
    /// </summary>
    /// <param name="paramNames">Array of additional parameter names</param>
    /// <param name="paramValues">Array of additional parameter values</param>
    public virtual void SetExtraParams(String[] paramNames, String[] paramValues)
    {
      m_paramNames = paramNames;
      m_paramValues = paramValues;
    }
    
    /// <summary>
    /// Sets the folderID for directory
    /// </summary>
    /// <param name="folderID">The Folder ID</param>
    public virtual void SetFolderID(int folderID)
    {
      FolderID = folderID;
    }
    
    /// <summary>
    /// Sets the fullURL.
    /// </summary>
    /// <param name="fullURL">The fullURL</param>
    public virtual void SetFullURL(String fullURL)
    {
      FullURL = fullURL;
    }
    
    /// <summary>
    /// Sets the image.
    /// </summary>
    /// <param name="image">The image to set</param>
    public virtual void SetImage(PTImageType image)
    {
      Image = image;
    }
    
    /// <summary>
    /// Sets the image.
    /// </summary>
    /// <param name="image">The second image to set</param>
    public virtual void SetImage2(PTImageType image)
    {
      Image2 = image;
    }
    
    /// <summary>
    /// Sets the imageAltText.
    /// </summary>
    /// <param name="imageAltText">The imageAltText to set</param>
    public virtual void SetImageAltText(String imageAltText)
    {
      ImageAltText = imageAltText;
    }
    
    /// <summary>
    /// Sets the label.
    /// </summary>
    /// <param name="label">The label to set</param>
    public virtual void SetLabel(String label)
    {
      Label = label;
    }
    
    /// <summary>
    /// Sets the Mode for directory
    /// </summary>
    /// <param name="mode">The mode to set</param>
    public virtual void SetMode(int mode)
    {
      Mode = mode;
    }
    
    /// <summary>
    /// Sets the newASType.
    /// </summary>
    /// <param name="newASType">The new activityspace type to set</param>
    public virtual void SetNewASType(int newASType)
    {
      NewASType = newASType;
    }
    
    /// <summary>
    /// Sets the editorPage.
    /// </summary>
    /// <param name="editorPage">The editor page to set</param>
    public virtual void SetPage(String editorPage)
    {
      EditorPage = editorPage;
    }
    
    /// <summary>
    /// Sets the pageID.
    /// </summary>
    /// <param name="pageID">The page ID to set</param>
    public virtual void SetPageID(int pageID)
    {
      PageID = pageID;
    }
    
    /// <summary>
    /// Sets the label truncation width
    /// </summary>
    /// <param name="nMax">Character position to truncate at</param>
    public virtual void SetTruncationLength(int nMax)
    {
      m_nTruncateLength = nMax;
    }
    
    /// <summary>
    /// Sets the type.
    /// </summary>
    /// <param name="type">The type to set</param>
    public virtual void SetType(int type)
    {
      Type = type;
    }
    
    /// <summary>
    /// Sets if the current page is a preview
    /// </summary>
    /// <param name="bIsPreview">Is the page a preview page</param>
    public virtual void SetIsPreview(bool bIsPreview)
    {
      m_bIsPreview = bIsPreview;
    }
    
    /// <summary>
    /// Gets the profile ID
    /// </summary>
    /// <returns>					The profile ID</returns>
    public virtual int GetProfileID()
    {
      return m_nProfileID;
    }
    
    /// <summary>
    /// Sets the profile ID
    /// </summary>
    /// <param name="Sets">profile ID</param>
    public virtual void SetProfileID(int i)
    {
      m_nProfileID = i;
    }
  }
}