using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
namespace com.plumtree.portaluiinfrastructure.condition
{
  /// <summary>
  /// Wrapper class for the XPRequest in the openfoundation jar. This class does everything
  /// except for certain methods which reads the body of the request and causes the
  /// gateway to fail.
  /// </summary>
  public class XPLimitedRequest
  {
    private XPRequest m_xpRealRequest;
    
    /// <summary>
    /// Constructor - Creates an XPLimitedRequest wrapper object around xpRealRequest which
    /// must implement the IXPRequest Interface.
    /// </summary>
    /// <param name="xpRealRequest"></param>
    public XPLimitedRequest(IXPRequest xpRealRequest)
    {
      m_xpRealRequest = (XPRequest) xpRealRequest;
    }
    
    /// <summary>
    /// Returns the named attribute
    /// </summary>
    /// <param name="name">Name of the attribute</param>
    /// <returns>        Object value of the attribute</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetAttribute(java.lang.String)"></seealso>
    public virtual Object GetAttribute(String name)
    {
      return m_xpRealRequest.GetAttribute(name);
    }
    
    /// <summary>
    /// Returns the length of the content sent by the client in bytes
    /// </summary>
    /// <returns>     Length of the content sent by the client in bytes</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetContentLength()"></seealso>
    public virtual int GetContentLength()
    {
      return m_xpRealRequest.GetContentLength();
    }
    
    /// <summary>
    /// Returns the name of the authentication scheme used.
    /// </summary>
    /// <returns>
    ///      string indicating the authentication scheme,
    /// or null if no authentication is being used.	
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetAuthType()"></seealso>
    public virtual String GetAuthType()
    {
      return m_xpRealRequest.GetAuthType();
    }
    
    /// <summary>
    /// Returns the user name being used for basic authentication.
    /// </summary>
    /// <returns>
    ///      The user name being used for basic authentication,
    /// empty string if basic authentication is not being used.	
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetBasicAuthUserName()"></seealso>
    public virtual String GetBasicAuthUserName()
    {
      return m_xpRealRequest.GetBasicAuthUserName();
    }
    
    /// <summary>
    /// Returns the password being used for basic authentication.\u0009
    /// </summary>
    /// <returns>
    ///      The password being used for basic authentication,
    /// empty string if basic authentication is not being used.	
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetBasicAuthPassword()"></seealso>
    public virtual String GetBasicAuthPassword()
    {
      return m_xpRealRequest.GetBasicAuthPassword();
    }
    
    /// <summary>
    /// Returns the IP address of the client as a String in dotted quad form.
    /// </summary>
    /// <returns>     the IP address of the client in dotted quad form.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetClientAddress()"></seealso>
    public virtual String GetClientAddress()
    {
      return m_xpRealRequest.GetClientAddress();
    }
    
    /// <summary>
    /// Returns the MIME type of the content sent by the client
    /// </summary>
    /// <returns>
    ///     MIME type of the content sent by the client. For e.g. text/html
    /// null if type is not known.
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetContentType()"></seealso>
    public virtual String GetContentType()
    {
      return m_xpRealRequest.GetContentType();
    }
    
    /// <summary>
    /// Returns the value of the given HTTP header 
    /// </summary>
    /// <param name="name">Name of the HTTP header. For e.g. HTTP_USER_AGENT</param>
    /// <returns>			The given HTTP header as a String, null if not found.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetHeader(java.lang.String)"></seealso>
    public virtual String GetHeader(String name)
    {
      return m_xpRealRequest.GetHeader(name);
    }
    
    /// <summary>
    /// Returns an Enumeration of names of all HTTP headers in the HTTP request
    /// </summary>
    /// <returns>     Enumeration of names of all HTTP headers in the HTTP request</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetHeaderNames()"></seealso>
    public virtual IXPEnumerator GetHeaderNames()
    {
      return m_xpRealRequest.GetHeaderNames();
    }
    
    /// <summary>
    /// Returns an Enumeration of XPLocale that the client will accept content in, 
    /// based on the Accept-Language header. 
    /// </summary>
    /// <returns>     Enumeration of XPLocale objects.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetLocales()"></seealso>
    public virtual IXPEnumerator GetLocales()
    {
      return m_xpRealRequest.GetLocales();
    }
    
    /// <summary>
    /// Returns the HTTP data transfer method used by the client
    /// </summary>
    /// <returns>
    ///      String value that specifies the HTTP data transfer method used
    /// by the client. For e.g., GET, POST, HEAD etc.
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetMethod()"></seealso>
    public virtual String GetMethod()
    {
      return m_xpRealRequest.GetMethod();
    }
    
    /// <summary>
    /// Returns a boolean indicating whether this request was
    /// made using a secure channel, such as HTTPS.
    /// </summary>
    /// <returns>
    ///      a boolean indicating whether this request was
    /// made using a secure channel, such as HTTPS.
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#IsSecureConnection()"></seealso>
    public virtual bool IsSecureConnection()
    {
      return m_xpRealRequest.IsSecureConnection();
    }
    
    /// <summary>
    /// Returns the query string
    /// </summary>
    /// <returns>
    ///      a String that is the query string, null if no
    /// query string present.
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetQueryString()"></seealso>
    public virtual String GetQueryString()
    {
      return m_xpRealRequest.GetQueryString();
    }
    
    /// <summary>
    /// Returns the session ID specified by the client
    /// </summary>
    /// <returns>     a String that is the session ID, null if not specified.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetRequestedSessionId()"></seealso>
    public virtual String GetRequestedSessionId()
    {
      return m_xpRealRequest.GetRequestedSessionId();
    }
    
    /// <summary>
    /// Returns the section of the URL between the protocol and the query string.
    /// </summary>
    /// <returns>     A String for the URI.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetRequestURI()"></seealso>
    public virtual String GetRequestURI()
    {
      return m_xpRealRequest.GetRequestURI();
    }
    
    /// <summary>
    /// Returns the full URL, without the query string.
    /// </summary>
    /// <returns>     A String for the full URL, without query string.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetRequestURL()"></seealso>
    public virtual String GetRequestURL()
    {
      return m_xpRealRequest.GetRequestURL();
    }
    
    /// <summary>
    /// Returns the name of the remote user, if present; otherwise empty string.
    /// </summary>
    /// <returns>     The remote user name.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetRemoteUser()"></seealso>
    public virtual String GetRemoteUser()
    {
      return m_xpRealRequest.GetRemoteUser();
    }
    
    /// <summary>
    /// Returns a String containing the name of the scheme used to make this request
    /// (such as http, https, or ftp).
    /// </summary>
    /// <returns>     a String containing the name of the scheme used to make this request</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetScheme()"></seealso>
    public virtual String GetScheme()
    {
      return m_xpRealRequest.GetScheme();
    }
    
    /// <summary>
    /// Returns the host name of the server.
    /// </summary>
    /// <returns>     A String containing the host name of the server</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetServerName()"></seealso>
    public virtual String GetServerName()
    {
      return m_xpRealRequest.GetServerName();
    }
    
    /// <summary>
    /// Returns the server port.
    /// </summary>
    /// <returns>     The integer value of the server port.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetServerPort()"></seealso>
    public virtual int GetServerPort()
    {
      return m_xpRealRequest.GetServerPort();
    }
    
    /// <summary>
    /// Returns the XPSession for this request.
    /// </summary>
    /// <returns>     the XPSession for this request.</returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetSession()"></seealso>
    public virtual XPSession GetSession()
    {
      return m_xpRealRequest.GetSession();
    }
    
    /// <summary>
    /// Returns the complete path to the uploaded file.  This method is only
    /// valid after XPRequest.Save() has been called.  It will return null
    /// until then.
    /// </summary>
    /// <returns>
    ///      a String containing the complete path to the uploaded file,
    /// null if no file was uploaded.
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetCompletePath()"></seealso>
    public virtual String GetCompletePath()
    {
      return m_xpRealRequest.GetCompletePath();
    }
    
    /// <summary>
    /// Returns the path to the remote file to be uploaded.  This is the last
    /// file to be uploaded in a multi-part MIME request.
    /// </summary>
    /// <returns>
    ///      a String containing the path to the remote file to be uploaded,
    /// null if no file was uploaded.
    /// </returns>
    /// <seealso cref="com.plumtree.openfoundation.web.IXPRequest#GetRemoteFilePath()"></seealso>
    public virtual String GetRemoteFilePath()
    {
      return m_xpRealRequest.GetRemoteFilePath();
    }
  }
}