using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.condition;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.condition;
using com.plumtree.uiinfrastructure.interpreter;
using com.plumtree.uiinfrastructure.interpreter.filter;
using com.plumtree.uiinfrastructure.login;
namespace com.plumtree.portaluiinfrastructure.condition.interpreterfilter
{
  /// <summary>
  /// A filter to run the Expression Engine for set-GuestLogin action.
  /// </summary>
  /// <author>WilliamA (Writing this new class)</author>
  public class PTExpressionEngineFilter : BaseInterpreterFilter
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.login.GuestLoginInterpreterFilter");
    // TODO: Need to define portal-wide constant for this?
    private const int PT_SUBPORTAL_DEFAULT = 100;
    
    /// <summary>
    /// This method load the necessary environment data and run the 
    /// Expression Engine for set-GuestLogin action. 
    /// </summary>
    public override bool PreFilter(RequestData requestData)
    {
      bool validUserSession = false;
      // Comment it out (see optimization note below):
      // String str = (String)requestData.m_smPersistentSandbox.GetAttribute("RULE_BASED_SUBPORTALID");
      // int currentSessionSubportalID = PT_INTRINSICS.PT_NULL_OBJECTID;
      // if (null != str) 
      //	currentSessionSubportalID = XPConvert.ToInteger(str);
      // Check valid session
      if (null != requestData.GetUserSession())
      {
        validUserSession = XPConvert.ToBoolean(requestData.m_smSandbox.GetAttribute(Interpreter.USERSESSIONVALID));
        }
      if (!validUserSession)
      {
        // DCA - execute expression engine for the guest settings
        int result = ConditionTypeManager.GetInstance().EvaluateExpressionForGuestLoginPhase(requestData.m_asSpace,
         requestData.m_Application, requestData.m_xpRequest, (IPTSession) requestData.GetUserSession());
        int nSubportalID = PT_INTRINSICS.PT_NULL_OBJECTID;
        if (-1 != result)
        {
          nSubportalID = result;
          // store in the persistent subsession
          requestData.m_smPersistentSandbox.SetAttribute("RULE_BASED_SUBPORTALID",
           XPConvert.ToString(nSubportalID));
        } else
        {
          // WilliamA - no match on the guest rules. 
          // TODO: In this case, should we just use the default subportal, or
          // we want to query which subportal the default guest belongs to
          // since default guest can be in any folder now?
          // if we want the latter (query):
          //IPTSubPortalInfo ptSPI = PTSession.GetGuestReadOnlySession().GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
          //if (null != ptSPI) {
          //	nSubportalID = ptSPI.GetObjectID();
          //}
          // if we want just using the default subportal: 
          nSubportalID = PT_SUBPORTAL_DEFAULT;
        }
        bool anyMatchForGuestLogin = false;
        // WilliamA - the following optimization (currentSessionSubportalID comparison)
        // is good, but can cause 'stale' data, i.e., when settings in the GuestLogin 
        // are updated, the new settings won't take effect until the next HTTPSession.
        // So, comment out the following optimization for now for better change propagation: 
        // -- if ((currentSessionSubportalID != nSubportalID) && (PT_INTRINSICS.PT_NULL_OBJECTID != nSubportalID)) 
        if (PT_INTRINSICS.PT_NULL_OBJECTID != nSubportalID)
        {
          IPTGuestLoginInfo guestLoginInfo = null;
          try
          {
            guestLoginInfo = PortalObjectsFactory.CreateGuestLoginInfo(nSubportalID);
            }
          catch (Exception e)
          {
            log.Error(e, "Cannot get the guest login object of subportal ID " + nSubportalID);
            }
          // Extract fields of GuestLogin and put them in the session
          // for the Interpreter / Authenticator to use.						
          if (null != guestLoginInfo)
          {
            requestData.m_SessionManager.SetAttribute(Authenticator.GUESTLOGIN_GUESTUSERNAME,
             guestLoginInfo.GetGuestUserName());
            requestData.m_SessionManager.SetAttribute(Authenticator.GUESTLOGIN_GUESTUSERID,
             XPConvert.ToString(guestLoginInfo.GetGuestUserID()));
            requestData.m_SessionManager.SetAttribute(Authenticator.GUESTLOGIN_REDIRECTTOLOGIN,
             XPConvert.ToString(guestLoginInfo.GetGuestRedirectToLogin()));
            requestData.m_SessionManager.SetAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT,
             XPConvert.ToString(guestLoginInfo.GetRedirectOnLogout()));
            requestData.m_SessionManager.SetAttribute(Authenticator.GUESTLOGIN_SSOVENDOR,
             XPConvert.ToString(guestLoginInfo.GetSSOVendor()));
            // Put redirectOnLogout and redirectOnLogin in sandbox session as well
            requestData.m_smSandbox.SetAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT,
             XPConvert.ToString(guestLoginInfo.GetRedirectOnLogout()));
            // Bug 41762 - Failed login should redirect based on the subportal's login page setting.
            // Bug 46109 - SSO always clears the sandbox regardless of whether the pending
            // login will be sucessful or not - store in the persistent sandbox instead. 
            requestData.m_smPersistentSandbox.SetAttribute(Authenticator.GUESTLOGIN_REDIRECTTOLOGIN,
             XPConvert.ToString(guestLoginInfo.GetGuestRedirectToLogin()));
            anyMatchForGuestLogin = true;
          } else
          {
            anyMatchForGuestLogin = false;
          }
        } else
        {
          anyMatchForGuestLogin = false;
        }
        if (!anyMatchForGuestLogin)
        {
          // no match for guest login overrides
          // remove any login-setting overrides
          requestData.m_SessionManager.RemoveAttribute(Authenticator.GUESTLOGIN_GUESTUSERNAME);
          requestData.m_SessionManager.RemoveAttribute(Authenticator.GUESTLOGIN_GUESTUSERID);
          requestData.m_SessionManager.RemoveAttribute(Authenticator.GUESTLOGIN_REDIRECTTOLOGIN);
          requestData.m_SessionManager.RemoveAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT);
          requestData.m_SessionManager.RemoveAttribute(Authenticator.GUESTLOGIN_SSOVENDOR);
          requestData.m_smSandbox.RemoveAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT);
          requestData.m_smPersistentSandbox.RemoveAttribute(Authenticator.GUESTLOGIN_REDIRECTTOLOGIN);
          }
      } else
      {
        // Make sure the RedirectOnLogout info is in the sandbox session
        // since LoginControl needs to access this info
        String redirectOnLogout = (String) (requestData.m_smSandbox.GetAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT));
        if (null == redirectOnLogout)
        {
          String str = (String) requestData.m_SessionManager.GetAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT);
          if (null != str)
          {
            requestData.m_smSandbox.SetAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT,
             str);
          }
        }
        // Bug 41762 - Failed login should redirect based on the subportal's login page setting.
        // Make sure the GUESTLOGIN_REDIRECTTOLOGIN info is in the persistent sandbox session
        // since LoginModel needs to access this info (on failed login)
        // Bug 46109 - Failed SSO needs to access this info as well.			
        String redirectToLogin = (String) (requestData.m_smPersistentSandbox.GetAttribute(Authenticator.GUESTLOGIN_REDIRECTTOLOGIN));
        if (null == redirectToLogin)
        {
          String str = (String) requestData.m_SessionManager.GetAttribute(Authenticator.GUESTLOGIN_REDIRECTTOLOGIN);
          if (null != str)
          {
            requestData.m_smPersistentSandbox.SetAttribute(Authenticator.GUESTLOGIN_REDIRECTTOLOGIN,
             str);
          }
        }
      }
      return false;
    }
  }
}