using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.keywords
{
  /// <summary>
  /// This is the implementation of the Expandable List  framework for the
  /// Keywords on an object.  Add will not be allowed at this time.
  /// </summary>
  /// <author>michaeld</author>
  public class KeywordsModel : ExpListModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.commonpages.keywords.KeywordsModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "Keywords";
    
    /// <summary>
    /// Max number of columns 
    /// </summary>
    public const int KEYWORDSMODEL_COL_MAX = 3;
    
    /// <summary>
    /// First column: an index to keep the list sorted.
    /// </summary>
    public const int KEYWORDSMODEL_COL_INDEX = 0;
    
    /// <summary>
    /// Second column: name. 
    /// </summary>
    public const int KEYWORDSMODEL_COL_KEYWORD = 1;
    
    /// <summary>
    /// Fourth column: language. 
    /// </summary>
    public const int KEYWORDSMODEL_COL_URL = 2;
    private int m_nClassID;
    private int m_nObjectID;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
    }
    // Currently we do not allow rows to be added on repost for keywords
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)  with a column
    /// mapping and an array of sort. The growable array will always be sorted
    /// by the 1st  column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper)"></seealso>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{KEYWORDSMODEL_COL_INDEX, KEYWORDSMODEL_COL_KEYWORD,
       KEYWORDSMODEL_COL_URL};
      // MJD- Sort array
      // The growable array will be sorted by the 1st column.
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = KEYWORDSMODEL_COL_KEYWORD;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      SearchKeywordHelper kwHelper = new SearchKeywordHelper(m_asOwner);
      IXPList listKeywords = kwHelper.getPortalObjectKeywords(m_nClassID,
       m_nObjectID);
      Object[][] arrAllData = null;
      if (null != listKeywords && !listKeywords.IsEmpty())
      {
        //MJD- Create the data array
        arrAllData = new Object[KEYWORDSMODEL_COL_MAX][];
        for (int j2c_index = 0;j2c_index < KEYWORDSMODEL_COL_MAX;j2c_index++)
        {
          arrAllData[j2c_index] = new Object[listKeywords.GetSize()];
        }
        //MJD- Add the keywords
        IXPEnumerator keywords = listKeywords.GetEnumerator();
        int i = 0;
        while (keywords.MoveNext())
        {
          String keyword = (String) keywords.GetCurrent();
          arrAllData[KEYWORDSMODEL_COL_INDEX][i] = i;
          arrAllData[KEYWORDSMODEL_COL_KEYWORD][i] = keyword;
          keyword = XPHttpUtility.UrlEncode(keyword, LinkConstants.UTF_8_ENCODING);
          arrAllData[KEYWORDSMODEL_COL_URL][i] = m_asOwner.GetCurrentNormalizedBaseURL() + IPTOpenerConstants.QS_KEYWORD + "=" + keyword;
          i++;
        }
      }
      //MJD- We set up the data, initialize the list.
      _saData.Initialize(arrColumns, arrAllData, arrSort, false);
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="objToEdit">is the IPTObject to be edited</param>
    public virtual void InitializeKeywords(IPTObject objToEdit, int _nListKey)
    {
      m_nClassID = objToEdit.GetClassID();
      m_nObjectID = objToEdit.GetObjectID();
      Object[][] arrExpListColInfo = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[EXPLIST_COLUMN_INVALID];
        }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = KEYWORDSMODEL_COL_KEYWORD;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(507,
       "ptmsgs_portalinfrastructure");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "20%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = KEYWORDSMODEL_COL_URL;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(508,
       "ptmsgs_portalinfrastructure");
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "80%";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      //MJD- Record the object we're editing
      //m_objEditing = objToEdit;
      base.InitializeExpandableList(m_asOwner.GetString(509, "ptmsgs_portalinfrastructure"),
       arrExpListColInfo, PTImageType.ACTION_ADD, "", _nListKey);
      base.DisableAddButton();
      base.DisableCheckBoxes();
      base.SetEmptyListMessages(m_asOwner.GetString(510, "ptmsgs_portalinfrastructure"),
       m_asOwner.GetString(511, "ptmsgs_portalinfrastructure"));
    }
    
    /// <summary>
    /// Saves the data when a repost occurs. Editors using this framework need
    /// to call that method from  the savePage method of the main Model.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Status for server side validation</returns>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int intStatus = base.SaveSection(_htFormData);
      //MJD- Let the superclass do it's thing
      return intStatus;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#SaveRow(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper,int,com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      //MJD- Nothing to do to save a row- it's handled in SaveSection
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new KeywordsModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}