using System;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames
{
  /// <summary>
  /// LocNamesDP is the DisplayPage for Localized Names and Descriptions
  /// </summary>
  /// <version>1.0</version>
  /// <author>MichaelS</author>
  public class LocNamesDP : EditorDP
  {
    
    /// <summary>
    /// The name of this object 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "LocNames";
    
    /// <summary>
    /// Flag used to update mandatory page status only the first time the left nav string is retrieved 
    /// </summary>
    protected bool bFirstTimeOnPage = true;
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      // Update mandatory page status the first time left nav string is retrieved.
      UpdateMandatoryPageStatus();
      IObjPropModelRO objPropModel = (IObjPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);
      if (objPropModel.CheckObjectSupportsEOD())
      {
        return m_asOwner.GetString(46, "ptmsgs_portalinfrastructure");
      } else
      {
        return m_asOwner.GetString(0, "ptmsgs_portalinfrastructure");
      }
    }
    
    /// <summary>
    /// Dynamically update mandatory page ststua. In this case, we check the object properties
    /// model to see if it contains any mandatory properties.
    /// </summary>
    public virtual void UpdateMandatoryPageStatus()
    {
      if (bFirstTimeOnPage)
      {
        IObjPropModelRO objPropModel = (IObjPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);
        bool bPageIsMandatory = objPropModel.CheckDisplayPageIsMandatory();
        ((EditorAS) m_asOwner).GetLeftMenu().SetMandatoryPage(bPageIsMandatory,
         GetName());
        bFirstTimeOnPage = false;
      }
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(268, "ptmsgs_portalinfrastructure"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// The date-picker needs to print some stuff before the form.
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLBeforeForm()"></seealso>
    public override HTMLElementCollection DisplayHTMLBeforeForm()
    {
      IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);
      return iModelRO.GetDateTimePickerControlManager().GetPagePreFormContent();
      }
    
    /// <summary>
    /// Returns the HTML that is placed in the HEAD section of this HTML page.
    /// Add date picker HTML in head.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLinHEAD()"></seealso>
    public override HTMLElementCollection DisplayHTMLinHEAD()
    {
      IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);
      return iModelRO.GetDateTimePickerControlManager().GetJSIncludes();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.form.AFormDP#PartialContentDisplay()
     */
     
    public override HTMLElement PartialContentDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      //MES- Add the list of languages we're localized into, IF we support localization AND we're localized!
      ILocNamesModelRO locNamesModel = (ILocNamesModelRO) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);
      if (locNamesModel.SupportsLocalization() && locNamesModel.GetIsLocalized())
      {
        //result.AddInnerHTMLElement(new HTMLBr());
        result.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME)).Display());
        }
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException on error</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      //MES- Add the primary name/desc
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME)).Display());
      //MES- Add the list of languages we're localized into, IF we support localization AND we're localized!
      ILocNamesModelRO locNamesModel = (ILocNamesModelRO) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);
      if (locNamesModel.SupportsLocalization() && locNamesModel.GetIsLocalized())
      {
        views.AddInnerHTMLElement(new HTMLBr());
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME)).Display());
        }
      //JIC- Add object properties view only if it is supported.
      IObjPropModelRO objPropModel = (IObjPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);
      if (objPropModel.CheckObjectSupportsEOD())
      {
        //Add a space
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        //Add the Object Properties view
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjPropEditView.STR_MVC_CLASS_NAME)).Display());
        }
      //Add a space
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      //Add the Object Properties view
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_KEYWORDS)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection scripts = base.DisplayJavaScriptFromChild();
      scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME).DisplayJavascript());
      //MES- Add the JavaScript for the list of languages we're localized into, IF we support localization!
      ILocNamesModelRO model = (ILocNamesModelRO) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);
      if (model.GetIsLocalized())
      {
        scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME).DisplayJavascript());
        }
      scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjPropEditView.STR_MVC_CLASS_NAME).DisplayJavascript());
      scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_KEYWORDS).DisplayJavascript());
      return scripts;
    }
  }
}