using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames
{
  /// <summary>
  /// LocNamesPopUpView creates the HTML for the "popup" for editing
  /// name, description, and language for a given object.
  /// </summary>
  /// <version>1.0</version>
  /// <author>MichaelS</author>
  public class LocNamesPopUpView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.LocNamesPopUpView");
    
    /// <summary>
    /// MES- The name of this object 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "LocNamesPopUp";
    
    /// <summary>
    /// MES- The names of various HTML elements, such as inputs 
    /// </summary>
    public const String HTMLINPUT_NAME = "in_tx_Name";
    public const String HTMLINPUT_DESCRIPTION = "in_ta_Description";
    public const String HTMLINPUT_LANG = "in_se_Lang";
    public const String HTMLBUTTON_DONE = "in_bu_done";
    public const String HTMLBUTTON_CANCEL = "in_bu_cancel";
    
    /// <summary>
    /// MES- Store the arguments to Init so we can use them later 
    /// </summary>
    private ILocNamesModelRO m_model;
    private AActivitySpace m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new LocNamesPopUpView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (ILocNamesModel) model;
      m_asOwner = parent;
    }
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>XPException </throws>
    public virtual HTMLElement Display()
    {
      //MES- Get the initial values from the Model if we're editing a row.
      //	If we're NOT editing a row (i.e. we're adding a new one), then
      //	we need to set good defaults.
      String sInitialName;
      String sInitialDescription;
      String sInitialLang;
      ILocNamesModelRO model = (ILocNamesModelRO) m_model;
      IPTGrowableSortedArrayWrapperRO data = model.GetReadOnlyItems();
      int iRowToEdit = model.GetRowToEdit();
      // RWW - Figure out the max length for the "Name" field 
      // for client side validation.  Normally, this is set to
      // a default value of 255, but for Admin Folders for  
      // example, we use a limit of 63 (community reasons).
      int iClientValidationMaxName;
      if (model.IsUsingMaxNameOverride())
      {
        iClientValidationMaxName = model.GetMaxNameOverride();
      } else
      {
        iClientValidationMaxName = LocNamesModel.CLIENT_VALIDATION_MAX_NAME;
        }
      //MES- Is it a legit row?
      if ((LocNamesView.EDIT_ROW_NEWROW != iRowToEdit) && ((iRowToEdit < 0) || (iRowToEdit >= data.GetCount())))
      {
        //MES-0 Invalid row number!
        throw new XPException("ERROR in LocNamesPopUpView::Display, row number " + XPConvert.ToString(iRowToEdit) + " is not in the allowed range.");
        }
      //MES- It's a legit row, or the "NEW ROW" value
      if (LocNamesView.EDIT_ROW_NEWROW == iRowToEdit)
      {
        //MES- New row
        sInitialName = m_asOwner.GetString(58, "ptmsgs_portalinfrastructure");
        sInitialDescription = m_asOwner.GetString(59, "ptmsgs_portalinfrastructure");
        sInitialLang = null;
      } else
      {
        //MES- The user is editing an existing row, get the data for the row
        sInitialName = (String) data.GetItem(iRowToEdit, LocNamesModel.LOCNAMEMODEL_COL_NAME);
        sInitialDescription = (String) data.GetItem(iRowToEdit, LocNamesModel.LOCNAMEMODEL_COL_DESCRIPTION);
        sInitialLang = (String) data.GetItem(iRowToEdit, LocNamesModel.LOCNAMEMODEL_COL_LANG);
        }
      // WRAP VIEW W/ ID FOR IPR
      HTMLElementCollection resultWrapper = new HTMLElementCollection();
      HTMLSpan result = new HTMLSpan();
      result.SetID(((IExpListModelRO) m_model).GetUniqueString(STR_MVC_CLASS_NAME));
      resultWrapper.AddInnerHTMLElement(result);
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      HTMLTextArea myTextArea;
      try
      {
        result.AddInnerHTMLElement(new HTMLComment("Begin: Display LocNamesPopUpView"));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myTable.SetWidth("100%");
        myTable.SetHeight("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("10");
        myTable.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        //MES- First row: a header
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetColSpan("2");
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(57, "ptmsgs_portalinfrastructure"));
        //MES- Second row, labels for some inputs
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        //MES- The Name label
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(55, "ptmsgs_portalinfrastructure"));
        //MES- The Language label
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(54, "ptmsgs_portalinfrastructure"));
        //MES- Third row, the inputs corresponding to the labels
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        //MES- The Name input
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, ((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_NAME),
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(sInitialName);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetMaxLength(iClientValidationMaxName);
        //MES- The Language input
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        //MES- Make a map of the existing languages (including primary), so that a new item can't 
        //	duplicate the language of an existing item.
        XPHashtable mapUsedLangs = new XPHashtable();
        mapUsedLangs.PutElement(model.GetPrimaryLang(), model.GetPrimaryLang());
        for (int iLangIndex = 0;iLangIndex < data.GetCount();++iLangIndex)
        {
          String strDisallowedLang = (String) data.GetItem(iLangIndex, LocNamesModel.LOCNAMEMODEL_COL_LANG);
          strDisallowedLang = XPStringUtility.ToLowerCase(strDisallowedLang);
          mapUsedLangs.PutElement(strDisallowedLang, strDisallowedLang);
        }
        //MES- Get the current language	
        String sLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();
        //MES- Use a helper function to write the control
        myCell.AddInnerHTMLElement(LocNamesView.GetLangChoicesControl(sLang,
         ((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_LANG), sInitialLang,
         m_asOwner.GetResourceManager(), mapUsedLangs));
        //MES- A spacer			
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetColSpan("2");
        myCell.SetNoWrap(true);
        myCell.SetAutoFit(true);
        myCell.SetHeight("3");
        if (!m_model.IsNoDescriptions())
        {
          //MES- Fourth row, more labels (for description)
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          //MES- The Description label
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetColSpan("2");
          myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
          myCell.AddInnerHTMLString(m_asOwner.GetString(56, "ptmsgs_portalinfrastructure"));
          //MES- Fifth row, the description input
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          //MES- The Description input
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetColSpan("2");
          myTextArea = new HTMLTextArea("50", "3");
          myCell.AddInnerHTMLElement(myTextArea);
          myTextArea.AddInnerHTMLString(sInitialDescription);
          myTextArea.SetName(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_DESCRIPTION));
          myTextArea.SetStyleClass(PTStyleClass.FORM_TEXTBOX_TEXT);
        }
        //MES- Sixth row, the action buttons
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetColSpan("2");
        // ***Done Action*** begins here
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, ((IExpListModelRO) m_model).GetUniqueString(HTMLBUTTON_DONE),
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(53, "ptmsgs_portalinfrastructure"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        // mj: removed 'Javascript:' from function name
        myInput.SetOnClick("OnDone(window.opener.document);");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // ***Done Action*** ends here
        // ***Cancel Action*** begins here
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(51, "ptmsgs_portalinfrastructure"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        // mj: removed 'Javascript:' from function name
        myInput.SetOnClick("window.close();");
        // PAI - this is a hack to extend the table beyond the bottom border, so the table fills in the window
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetHeight("100");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // ***Cancel Action*** ends here
        result.AddInnerHTMLElement(new HTMLComment("End: Display LocNamesPopUpView"));
        }
      catch (Exception e)
      {
        log.Error(e, "LocNamesPopUpView::Display An error occured when trying to display the HTML.");
        throw new XPException(m_asOwner.GetString(52, "ptmsgs_portalinfrastructure"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on
    /// the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        // JF- OnDone JavaScript function
        sb = new XPStringBuilder(400);
        sb.Append("function OnDone()\n");
        sb.Append("{\n");
        //MES- Validate the client side data, the validation function will display any error messages needed
        //	NOTE: We can't easily use the framework for validation, since it occurs in
        //	PostToSelf, which runs in the PARENT window!
        sb.Append("  if (!ValidateNameDesc())\n");
        sb.Append("    return;\n");
        //MES- If our opener is not ready to get data, then we can't set it!
        //	This could happen if the user unchecked the "Supports Localization"
        //	checkbox on our opener- this window is meant to add or edit an entry
        //	in the localization list, but the localization list has gone away!
        sb.Append("  if (null != window.opener.document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(LocNamesView.HTML_INPUT_NEW_NAME)).Append(")\n");
        sb.Append("  {\n");
        // MES- Store the name, description, and language into our opener
        sb.Append("    window.opener.document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(LocNamesView.HTML_INPUT_NEW_NAME)).Append(".value = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_NAME)).Append(".value;\n");
        if (!m_model.IsNoDescriptions())
        {
          sb.Append("    window.opener.document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(LocNamesView.HTML_INPUT_NEW_DESCRIPTION)).Append(".value = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_DESCRIPTION)).Append(".value;\n");
          }
        sb.Append("    window.opener.document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(LocNamesView.HTML_INPUT_NEW_LANG)).Append(".value = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_LANG)).Append(".value;\n");
        if (m_asOwner.GetIsInPlaceRefreshEnabled())
        {
          sb.Append(InPlaceRefreshHelper.GetJSSendPOSTOnAFormDP(m_asOwner.GetCurrentNormalizedBaseURL(),
           "LOC_NAME_WRAPPER_ID", ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD_IPR),
           "window.opener.document")).Append("\n");
        } else
        {
          // JF- Then we repost the main form
          sb.Append("  window.opener.postToSelf(").Append(((ILocNamesModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD)).Append(")\n");
          }
        //MES- Close the "if" check for existence of controls on our opener
        sb.Append("  }\n");
        // JF- Finally we close the pop-up window
        sb.Append("  window.close();\n");
        sb.Append("}\n");
        //MES- See note above about PostToSelf.            
        sb.Append("function ValidateNameDesc()\n");
        sb.Append("{\n");
        //MES- Validate the name.  It must not be blank.
        sb.Append("\t\tsName = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_NAME)).Append(".value;\n");
        //MES- Trim the name
        sb.Append("\t\tsTrimmedName = sName.replace(/^\\s+/g, \'\').replace(/\\s+$/g, \'\');\n");
        sb.Append("\t\tif (sTrimmedName.length <= 0)\n");
        sb.Append("\t\t{\n");
        sb.Append("\t\t\talert(\"").Append(m_asOwner.GetString(60, "ptmsgs_portalinfrastructure")).Append("\");\n");
        sb.Append("\t\t\treturn false;\n");
        sb.Append("\t\t}\n");
        //MES- If we changed the name, store the modified name
        sb.Append("\t\tif (sTrimmedName != sName)\n");
        sb.Append("\t\t{\n");
        sb.Append("\t\t\tdocument.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_NAME)).Append(".value = sTrimmedName;\n");
        sb.Append("\t\t}\n");
        if (!m_model.IsNoDescriptions())
        {
          //MES- Validate the description- it can be blank but cannot be over 255 characters.
          sb.Append("\t\tsDesc = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_DESCRIPTION)).Append(".value;\n");
          sb.Append("\t\tif (sDesc.length > ").Append(LocNamesModel.CLIENT_VALIDATION_MAX_DESCRIPTION).Append(")\n");
          sb.Append("\t\t{\n");
          sb.Append("\t\t\talert(\"").Append(XPResourceManager.FormatMessage(m_asOwner.GetString(61,
           "ptmsgs_portalinfrastructure"), LocNamesModel.CLIENT_VALIDATION_MAX_DESCRIPTION + 1)).Append("\");\n");
          sb.Append("\t\t\treturn false;\n");
          sb.Append("\t\t}\n");
        }
        sb.Append("\t\treturn true;\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "PopUpView::DisplayJavascript An error occured when trying to display the JavaScript.");
        }
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}