using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames
{
  /// <summary>
  /// MES- LocNamesRepostControl is the repost control for the Localized Names and Descriptions
  /// page.  It controls what happens when the form posts to itself.
  /// </summary>
  /// <version>1.0</version>
  /// <author>MichaelS</author>
  public class LocNamesRepostControl : ExpListControl
  {
    
    /// <summary>
    /// MES- The name of this object 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "LocNamesRepost";
    
    /// <summary>
    /// MES- Custom post actions that we post to ourself- we don't want to conflict
    /// with a superclass! 
    /// </summary>
    public const int POSTTOSELF_ACTION_NAMEDESC_POPUP = 60;
    public const int POSTTOSELF_ACTION_CHANGE_ISLOCALIZED = 61;
    public const int POSTTOSELF_ACTION_CHANGE_PRIMARYLANG = 62;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LocNamesRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call  the associated method for each
    /// action.
    /// </summary>
    /// <param name="_nAction">is the action to take</param>
    /// <param name="_htFormData">
    /// is a hashtable that stores the posted form data and querystring
    /// arguments
    /// </param>
    public override void PerformRepostAction(int _nAction, XPHashtable _htFormData)
    {
      ExpListModel myExpListModel = (ExpListModel) m_model;
      //MES- Is this an action we know about?
      if (_nAction == myExpListModel.GetUniqueInt(POSTTOSELF_ACTION_NAMEDESC_POPUP))
      {
        //MES- This is our "own" action, we know how to deal with it
        PerformNameDescPopupAction(_htFormData);
      } else
      if (_nAction == myExpListModel.GetUniqueInt(POSTTOSELF_ACTION_CHANGE_ISLOCALIZED))
      {
        //MES- The user changed the IsLocalized checkbox, reset the member data
        //	and reshow the form
        PerformIsLocalizedChangeAction(_htFormData);
      } else
      if (_nAction == myExpListModel.GetUniqueInt(POSTTOSELF_ACTION_CHANGE_PRIMARYLANG))
      {
        //MES- The user changed the IsLocalized checkbox, reset the member data
        //	and reshow the form
        PerformChangePrimaryLangAction(_htFormData);
      } else
      {
        //MES- We don't know what this is, pass it to our parent
        base.PerformRepostAction(_nAction, _htFormData);
      }
    }
    
    /// <summary>
    /// MES- PerformChangePrimaryLangAction reacts to the user changing the
    /// Primary Language dropdown by updating model variables
    /// </summary>
    /// <param name="_htFormData">is a hashtable that stores the form post data and querystring</param>
    private void PerformChangePrimaryLangAction(XPHashtable _htFormData)
    {
      ((ILocNamesModel) m_model).SetPrimaryLang(((String[]) _htFormData.GetElement(((ExpListModel) m_model).GetUniqueString(LocNamesPrimaryNameView.PRIMARY_LANG_DROPDOWN)))[0]);
      }
    
    /// <summary>
    /// MES- PerformIsLocalizedChangeAction reacts to the user changing the
    /// "Is Localized" checkbox by updating model variables
    /// </summary>
    /// <param name="_htFormData">is a hashtable that stores the form post data and querystring</param>
    private void PerformIsLocalizedChangeAction(XPHashtable _htFormData)
    {
      ((ILocNamesModel) m_model).SetIsLocalized(_htFormData.ContainsKey(((ExpListModel) m_model).GetUniqueString(LocNamesPrimaryNameView.LOCNAME_CHK_SUPPORTS_LOC)));
      }
    
    /// <summary>
    /// MES- PerformNameDescPopupAction handles the case where a popup is being displayed
    /// </summary>
    /// <param name="_htFormData">is a hashtable that stores the form post data and querystring</param>
    private void PerformNameDescPopupAction(XPHashtable _htFormData)
    {
      //MES- Get the row number of the item we're editing and store it in the Model, where
      //	the Form can get to it.  The Model will also use this info later, when storing
      //	the data from the popup.
      ((ILocNamesModel) m_model).SetRowToEdit(XPConvert.ToInteger(((String[]) _htFormData.GetElement(((ExpListModel) m_model).GetUniqueString(LocNamesView.POPUP_CONTROL_ARG_ROWTOEDIT)))[0]));
      }
  }
}