using System;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory
{
  /// <summary>
  /// Interface used to set and retrieve migration status of an object
  /// in an editor.
  /// </summary>
  /// <version>$Revision$</version>
  /// <author>ArvindS</author>
  public interface IMigrationHistoryModel : IModel
  {
    
    /// <summary>
    /// Retrieves the current migration status of the underlying PTObject.
    /// </summary>
    int GetCurrentMigrationStatus();
    
    /// <summary>
    /// Retrieves the history item at the index specified by _nIndex
    /// </summary>
    MigrationHistoryItem GetHistoryItem(int _nIndex);
    
    /// <summary>
    /// Returns the number of items in the history for the underlying PTObject.
    /// </summary>
    int GetNumHistoryItems();
    
    /// <summary>
    /// Retrieves the flag indicating whether or not we are being
    /// hosted by another activity space, or our own.
    /// </summary>
    bool IsStandalone();
    
    /// <summary>
    /// Retrieves the flag indicating whether or not to display
    /// the approval checkbox (currently only for full sysadmins)
    /// </summary>
    bool ShouldDisplayApproval();
    
    /// <summary>
    /// Sets the flag indicating this object has been approved for migration
    /// </summary>
    void SetApprovedForMigration(bool bApproved);
    
    /// <summary>
    /// Helper method to Save the migration status on the object.
    /// </summary>
    void StoreMigrationStatus(int nClassID, int nObjectID);
  }
}