using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory
{
  /// <summary>
  /// Helper class that contains the items in a single migration history entry.
  /// </summary>
  /// <version>$Revision$</version>
  /// <author>ArvindS</author>
  public class MigrationHistoryItem
  {
    private String m_strMigrationComment;
    private String m_strMigrationSourcePortalUUID;
    private XPDateTime m_xpdtMigrationDate;
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Creates a new MigrationHistoryItem object.
    /// </summary>
    /// <param name="_xpdtMigrationDate">- Date retrieved from the server for this history item.</param>
    /// <param name="_strMigrationComment">- Migration comment retrieved from the server for this history item.</param>
    /// <param name="_strMigrationSourcePortalUUID">- Portal UUID retrieved from the server for this history item.</param>
    public MigrationHistoryItem(XPDateTime _xpdtMigrationDate, String _strMigrationComment,
     String _strMigrationSourcePortalUUID, AActivitySpace _asOwner)
    {
      m_xpdtMigrationDate = _xpdtMigrationDate;
      m_strMigrationComment = _strMigrationComment;
      m_strMigrationSourcePortalUUID = _strMigrationSourcePortalUUID;
      m_asOwner = _asOwner;
    }
    
    /// <summary>
    /// Retrieves the migration comment portion of this history item.
    /// </summary>
    /// <returns>The migration comment.</returns>
    public virtual String GetMigrationComment()
    {
      return m_strMigrationComment;
    }
    
    /// <summary>
    /// Retrieves the migration status date for this history item.
    /// </summary>
    /// <returns>The migration status date.</returns>
    public virtual String GetMigrationDate()
    {
      XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT,
       XPDateFormat.SHORT, PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
       PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner));
      return xpDateTimeFormat.Format(m_xpdtMigrationDate);
    }
    
    /// <summary>
    /// Retrieves the source portal uuid for this history item.
    /// </summary>
    /// <returns>The source portal uuid.</returns>
    public virtual String GetMigrationSourcePortalUUID()
    {
      return m_strMigrationSourcePortalUUID;
    }
  }
}