using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory
{
  /// <version>$Revision$</version>
  /// <author>ArvindS</author>
  public class MigrationHistoryView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.MigrationHistoryView");
    
    /// <summary>
    /// The class name for this view 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MigrationHistory";
    
    /// <summary>
    /// HTML Object name: checkbox to approve migration 
    /// </summary>
    public const String HTMLCHECKBOX_MIGRATION = "in_cb_Migration";
    
    /// <summary>
    /// HTML Object name: done button 
    /// </summary>
    public const String HTMLBUTTON_DONE = "in_bu_done";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MigrationHistoryView();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        result.AddInnerHTMLString("\n<!-- Begin: Display MigrationHistoryView -->\n");
        if (((IMigrationHistoryModelRO) m_model).IsStandalone())
        {
          HTMLTable doneButton = RenderDoneButton();
          result.AddInnerHTMLElement(doneButton);
        }
        // Display current migration status
        HTMLElement migrationStatus = RenderCurrentMigrationStatus();
        result.AddInnerHTMLElement(migrationStatus);
        result.AddInnerHTMLElement(GetSpacerTable());
        // Display migration history			
        HTMLElement migrationHistory = RenderMigrationHistory();
        result.AddInnerHTMLElement(migrationHistory);
      }
      catch (HTMLException e)
      {
        log.Error(e, "MigrationHistoryView: Unable to generate HTML. The following exception occured: " + e.Message);
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns HTML for the current migration status of the object
    /// </summary>
    private HTMLElement RenderCurrentMigrationStatus()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLElement header = base.GetHeaderView(m_asOwner.GetString(73, "ptmsgs_portalinfrastructure"));
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        result.AddInnerHTMLElement(header);
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetCellPadding(CommonHTMLStrings.FIVE);
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        // Display the migration status
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetNoWrap(true);
        myCell.SetHeight("25");
        int nMigrationStatus = ((IMigrationHistoryModelRO) m_model).GetCurrentMigrationStatus();
        myCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(74,
         "ptmsgs_portalinfrastructure"), ""));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetNoWrap(true);
        myCell.SetHeight("25");
        myCell.SetWidth("100%");
        String strMigrationStatus = StringFromMigrationStatus(nMigrationStatus);
        myCell.AddInnerHTMLString(strMigrationStatus);
        if (((IMigrationHistoryModelRO) m_model).ShouldDisplayApproval())
        {
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetColSpan("2");
          myCell.SetNoWrap(true);
          myCell.SetHeight("25");
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell.SetAlign(CommonHTMLStrings.LEFT);
          HTMLInput myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_MIGRATION,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
          myInput.SetChecked(((IMigrationHistoryModelRO) m_model).IsMigrationCheckboxChecked());
          myCell.AddInnerHTMLString(m_asOwner.GetString(278, "ptmsgs_portalinfrastructure"));
          }
      }
      catch (HTMLException e)
      {
        log.Error(e, "MigrationHistoryView: Unable to generate HTML for current migration status. The following exception occured: " + e.Message);
        }
      return result;
    }
    
    /// <summary>
    /// Returns HTML for the done button.
    /// </summary>
    private HTMLTable RenderDoneButton()
    {
      HTMLTable myTable = new HTMLTable();
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        myTable.SetCellPadding(CommonHTMLStrings.FIVE);
        myTable.SetCellSpacing(CommonHTMLStrings.TWO);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        HTMLInput myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_DONE,
         EditorRepostControl.STR_MVC_CLASS_NAME);
        myInput.SetValue(m_asOwner.GetString(84, "ptmsgs_portalinfrastructure"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        myInput.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + EditorRepostControl.POSTTOSELF_ACTION_FINISH + "); return false;");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLElement(myInput);
      }
      catch (HTMLException e)
      {
        log.Error(e, "MigrationHistoryView: Unable to generate HTML for done button. The following exception occured: " + e.Message);
        }
      return myTable;
    }
    
    /// <summary>
    /// Returns HTML for the migration history.
    /// </summary>
    private HTMLElement RenderMigrationHistory()
    {
      int nNumHistoryItems = ((IMigrationHistoryModelRO) m_model).GetNumHistoryItems();
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLElement header = base.GetHeaderView(m_asOwner.GetString(72, "ptmsgs_portalinfrastructure"));
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        result.AddInnerHTMLElement(header);
        result.AddInnerHTMLElement(GetShortSpacerTable());
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetCellPadding(CommonHTMLStrings.FIVE);
        myTable.SetCellSpacing(CommonHTMLStrings.TWO);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        if (nNumHistoryItems > 0)
        {
          // Display the header
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(m_asOwner.GetString(76, "ptmsgs_portalinfrastructure"));
          myCell.SetHeight("25");
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(m_asOwner.GetString(75, "ptmsgs_portalinfrastructure"));
          myCell.SetHeight("25");
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(m_asOwner.GetString(77, "ptmsgs_portalinfrastructure"));
          myCell.SetHeight("25");
          // Loop through and display each entry
          for (int i = 0;i < nNumHistoryItems;i++)
          {
            MigrationHistoryItem mhi = ((IMigrationHistoryModelRO) m_model).GetHistoryItem(i);
            String strMigrationDate = mhi.GetMigrationDate();
            String strMigrationComment = mhi.GetMigrationComment();
            String strMigrationSourcePortalUUID = mhi.GetMigrationSourcePortalUUID();
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            //Alternate styles by row number
            if ((i % 2) == 1)
            {
              myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
            } else
            {
              myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
            }
            // Display the migration date
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myCell.SetWidth("25%");
            myCell.AddInnerHTMLEncodedString(strMigrationDate);
            myCell.SetHeight("30");
            // Display the migration comment
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myCell.SetWidth("100%");
            myCell.AddInnerHTMLEncodedString(strMigrationComment);
            myCell.SetHeight("30");
            // Display the source portal uuid
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myCell.SetWidth("30%");
            myCell.AddInnerHTMLEncodedString(strMigrationSourcePortalUUID);
            myCell.SetHeight("30");
          }
        } else
        {
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myRow.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myCell.SetAlign(CommonHTMLStrings.CENTER);
          myCell.AddInnerHTMLString(m_asOwner.GetString(85, "ptmsgs_portalinfrastructure"));
          myCell.SetHeight("30");
        }
      }
      catch (HTMLException e)
      {
        log.Error(e, "MigrationHistoryView: Unable to generate HTML for migration history. The following exception occured.");
        }
      return result;
    }
    
    /// <param name="nMigrationStatus"></param>
    /// <returns></returns>
    private String StringFromMigrationStatus(int nMigrationStatus)
    {
      String strReturn;
      switch (nMigrationStatus){
      case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_NONE:
      strReturn = m_asOwner.GetString(78, "ptmsgs_portalinfrastructure");
      break;
      case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED:
      strReturn = m_asOwner.GetString(79, "ptmsgs_portalinfrastructure");
      break;
      case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED:
      strReturn = m_asOwner.GetString(80, "ptmsgs_portalinfrastructure");
      break;
      case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_DENIED:
      strReturn = m_asOwner.GetString(81, "ptmsgs_portalinfrastructure");
      break;
      case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_MIGRATED:
      strReturn = m_asOwner.GetString(82, "ptmsgs_portalinfrastructure");
      break;
      default:
      strReturn = m_asOwner.GetString(83, "ptmsgs_portalinfrastructure");
      break;
      }
      return strReturn;
    }
  }
}