using System;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties
{
  /// <summary>
  /// This interface contains all of the methods for accessing object property
  /// information in the model.
  /// </summary>
  /// <author>josephc</author>
  public interface IObjPropModelRO : IExpListPropModelRO
  {
    
    /// <summary>
    /// Checks to see if the object supports EOD
    /// </summary>
    /// <returns>Returns true if object supports EOD.  Otherwise returns false.</returns>
    bool CheckObjectSupportsEOD();
    
    /// <summary>
    /// Checks to see if the property is an HREF
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if HREF. Otherwise returns false.</returns>
    bool CheckRowIsHREF(int _nRowIndex);
    
    /// <summary>
    /// Checks to see if the property is mandatory
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if mandatory. Otherwise returns false.</returns>
    bool CheckRowIsMandatory(int _nRowIndex);
    
    /// <summary>
    /// Checks to see if the property is multivalued
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if multivalued. Otherwise returns false.</returns>
    bool CheckRowIsMultiValued(int _nRowIndex);
    
    /// <summary>
    /// Checks to see if the property is read-only
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if read-only. Otherwise returns false.</returns>
    bool CheckRowIsReadOnly(int _nRowIndex);
    
    /// <summary>
    /// Checks to see if the property is visible
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if visible. Otherwise returns false.</returns>
    bool CheckRowIsVisible(int _nRowIndex);
    
    /// <summary>
    /// Returns true if the display page is mandatory because it contains
    /// mandatory properties.
    /// </summary>
    /// <returns>True if page contains mandatory properties that user must enter values for.</returns>
    bool CheckDisplayPageIsMandatory();
    
    /// <summary>
    /// Return pick list values for the property
    /// </summary>
    /// <param name="_nPropertyID">Property ID</param>
    /// <returns>Pick list values</returns>
    Object[][] GetPickListValues(int _nPropertyID);
    
    /// <summary>
    /// Returns the value of the requested PROPID from the EOD query result.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="nPropID">PT_PROPID</param>
    /// <returns>Value of requested PROPID</returns>
    Object GetRowPropertyInfo(int _nRowIndex, int nPropID);
    
    /// <summary>
    /// Returns the reference value name
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Reference value name</returns>
    String GetRowRefValueName(int _nRowIndex);
    
    /// <summary>
    /// Returns string representation of property value
    /// </summary>
    /// <param name="oValue">Property value as Object</param>
    /// <param name="nPropertyType">Property type</param>
    /// <returns>Property value as string</returns>
    String GetStringFromObjectValue(Object oValue, int nPropertyType);
    
    /// <summary>
    /// Returns any previously selected reference
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Value of property</returns>
    String GetSelectedReference(int _nRowIndex);
    
    /// <summary>
    /// Returns true if current user has access to global object property map.
    /// In order to access this editor, the user must be a member of the administrators
    /// group and must have the right to access the Plumtree utilities.
    /// </summary>
    /// <returns>True if user has access. False otherwise.</returns>
    bool HasAccessToGlobalObjectPropMapEditor();
    
    /// <summary>
    /// If a property has a pick tree or pick list, check that the pick values
    /// can be successfully retrieved.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>True if pick values can be successfully retrieved.</returns>
    bool CheckPickValuesAreValid(int _nRowIndex);
  }
}