using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties
{
  /// <summary>
  /// Display page for browse view of object properties
  /// </summary>
  /// <author>josephc</author>
  public class ObjPropBrowseDP : AFormDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.ObjPropBrowseDP");
    
    /// <summary>
    /// Class name for ObjPropBrowseDP 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjPropBrowse";
    
    /// <summary>
    /// HTML button for closing editor / going back (508) 
    /// </summary>
    public const String HTMLBUTTON_EDITOR_CLOSE = "in_bu_Close";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()"></seealso>
    public override String GetFormTitle()
    {
      String strObjectName = ((ObjPropEditorModel) m_asOwner.GetModel(ObjPropEditorModel.STR_MVC_CLASS_NAME)).GetObjectName();
      return XPResourceManager.FormatMessage(m_asOwner.GetString(279, "ptmsgs_portalinfrastructure"),
       XPHttpUtility.HtmlEncode(strObjectName));
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the object properties page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException </throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection myResult = new HTMLElementCollection();
      myResult.AddInnerHTMLElement(GetHeader());
      myResult.AddInnerHTMLElement(m_asOwner.GetView(ObjPropBrowseView.STR_MVC_CLASS_NAME).Display());
      return myResult;
    }
    public virtual HTMLTable GetHeader()
    {
      HTMLTable mainTable = null;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLH1 headerH1;
      try
      {
        mainTable = new HTMLTable();
        mainTable.SetBorder("0");
        mainTable.SetWidth("100%");
        mainTable.SetCellPadding("5");
        mainTable.SetCellSpacing("0");
        // BEGIN Banner and Edit and Close buttons
        myRow = new HTMLTableRow();
        mainTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        headerH1 = new HTMLH1();
        myCell.AddInnerHTMLElement(headerH1);
        myCell.SetHeight("30");
        // Title
        String strObjectName = ((ObjPropEditorModel) m_asOwner.GetModel(ObjPropEditorModel.STR_MVC_CLASS_NAME)).GetObjectName();
        headerH1.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(86,
         "ptmsgs_portalinfrastructure"), XPHttpUtility.HtmlEncode(strObjectName)));
        headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);
        // buttons
        myCell = new HTMLTableCell();
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetWidth("300");
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        if (GetOwner().GetAccessStyle() == AccessStyles.STANDARD)
        {
          // Close button
          myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_EDITOR_CLOSE,
           "");
          myCell.AddInnerHTMLElement(myInput);
          // TODO: Create a "close" button in portaluiinfrastructure
          myInput.SetValue(m_asOwner.GetString(118, "ptmsgs_portalbrowsingmsgs"));
          myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
          myInput.SetOnClick("self.close(); return false;");
        } else
        {
          // Finish button (in 508 mode it's not a popup, 
          // so we just want to go back to previous page.
          // "Finish"
          String strFinish = m_asOwner.GetString(147, ResourceConstants.INFRASTRUCTURE);
          myInput = new HTMLInput(HTMLInputTypes.SUBMIT, RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_CANCEL,
           "");
          myCell.AddInnerHTMLElement(myInput);
          // "Finish"
          myInput.SetValue(strFinish);
          // "Finish"
          myInput.SetAlt(strFinish);
          myInput.SetAccessKey(m_asOwner.GetString(26, "ptmsgs_portal508quickkeymsgs"));
          myInput.SetTitle(m_asOwner.GetString(28, "ptmsgs_portal508quickkeymsgs"));
          myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "The following error occured when trying to display the HTML: " + e.Message);
        }
      return mainTable;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      if (GetOwner().GetAccessStyle() == AccessStyles.STANDARD)
      {
        HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
        myScripts.AddInnerHTMLElement(m_asOwner.GetView(ObjPropBrowseView.STR_MVC_CLASS_NAME).DisplayJavascript());
        return myScripts;
      } else
      {
        return null;
      }
    }
  }
}