using System;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties
{
  /// <summary>
  /// This is the implementation of the Expandable List for object properties
  /// </summary>
  /// <author>josephc</author>
  public class ObjPropBrowseView : ExpListPropBrowseView
  {
    
    /// <summary>
    /// Class name for the ObjPropBrowseView 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjPropBrowse";
    
    /// <summary>
    /// Height of rows in list 
    /// </summary>
    protected String m_strRowHeight = "20";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjPropBrowseView();
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>HTML for row</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Get cell containing class name
      result.AddInnerHTMLElement(GetHTMLForName(_nRowIndex));
      // Get cell containing property value
      result.AddInnerHTMLElement(GetHTMLForPropertyValue(_nRowIndex));
      // Get cell containing row action (add, remove, or nothing)
      HTMLTableCell cellAction = GetHTMLForRowAction(_nRowIndex);
      if (null != cellAction)
      {
        result.AddInnerHTMLElement(cellAction);
      }
      return result;
    }
    
    /// <summary>
    /// Returns null because rows are read-only in browse-mode.
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Table cell for action</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForRowAction(int _nRowIndex)
    {
      return null;
    }
    
    /// <summary>
    /// Returns table cell for property value
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Table cell for property value</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForPropertyValue(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetWidth("80%");
      myCell.SetHeight(m_strRowHeight);
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      Object oValue = iOPModel.GetRowValue(_nRowIndex);
      int nPropertyType = iOPModel.GetRowType(_nRowIndex);
      String strValue = iOPModel.GetStringFromObjectValue(oValue, nPropertyType);
      if (null != oValue)
      {
        if (iOPModel.CheckRowIsHREF(_nRowIndex))
        {
          HTMLAnchor myAnchor = new HTMLAnchor(strValue);
          myCell.AddInnerHTMLElement(myAnchor);
          myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strValue));
          } else
        {
          myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strValue));
        }
      }
      return myCell;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Helper method to determine whether or not row is visible.  This method
    /// is used by Display().  This method overrides the default behavior of
    /// the ExpListView, where all rows are visible.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>True if row should be displayed, otherwise false.</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#CheckRowIsVisible(int)"></seealso>
    protected override bool CheckRowIsVisible(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      // Display the row if the property is visible and the row has not been deleted.
      if ((iOPModel.CheckRowIsVisible(_nRowIndex)) && (ObjPropModel.ROW_STATUS_DELETED != iOPModel.GetRowStatus(_nRowIndex)))
      {
        return true;
      } else
      {
        return false;
      }
    }
    
    /// <summary>
    /// Returns HTML for name of property. If the row is a new property then
    /// display name.  If the row is another value in a multi-valued property,
    /// then don't display name.  Distinguish mandatory properties from
    /// optional properties.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>HTML table cell for name</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTableCell GetHTMLForName(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetWidth("20%");
      myCell.SetHeight(m_strRowHeight);
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      // Get current row's name and propertyID
      String strName = iOPModel.GetRowName(_nRowIndex);
      // If we have a new property, then display name
      if (CheckRowIsFirstForProperty(_nRowIndex))
      {
        HTMLSpan spanSubTitle = new HTMLSpan();
        myCell.AddInnerHTMLElement(spanSubTitle);
        spanSubTitle.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        spanSubTitle.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strName));
        }
      return myCell;
    }
  }
}