using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.server.treeiterator;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties
{
  /// <summary>
  /// This is the implementation of the Expandable List for object properties
  /// </summary>
  /// <author>josephc</author>
  public class ObjPropEditView : ExpListPropEditView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.ObjPropEditView");
    
    /// <summary>
    /// Class name for the ObjPropEditView 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjPropEdit";
    
    /// <summary>
    /// Prefix for picklist input 
    /// </summary>
    public const String HTMLINPUT_SELECT_PICKLIST_PREFIX = "in_se_PickList";
    
    /// <summary>
    /// TagID for picklist 
    /// </summary>
    public const String HTMLINPUT_SELECT_PICKLIST_TAGID = "PickListTagID";
    
    /// <summary>
    /// HTML Object name: clear value (set to true to clear the property value) 
    /// </summary>
    public const String HTMLHIDDEN_CLEARVALUE = "in_hi_clearvalue";
    
    /// <summary>
    /// JavaScript function to open pick tree. 
    /// </summary>
    private const String JAVASCRIPT_PICKTREE_OPEN = "pickTreeOpen";
    
    /// <summary>
    /// JavaScript function to get pick tree value. 
    /// </summary>
    private const String JAVASCRIPT_PICKTREE_GETVALUE = "pickTreeGetValue";
    
    /// <summary>
    /// JavaScript function to open reference tree. 
    /// </summary>
    private const String JAVASCRIPT_REFTREE_OPEN = "referenceTreeOpen";
    
    /// <summary>
    /// JavaScript function to get reference tree value. 
    /// </summary>
    private const String JAVASCRIPT_REFTREE_GETVALUE = "referenceTreeGetValue";
    
    /// <summary>
    /// JavaScript function to add or remove a property value. 
    /// </summary>
    private const String JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE = "addRemovePropertyValue";
    
    /// <summary>
    /// JavaScript function to clear a property value. 
    /// </summary>
    private const String JAVASCRIPT_CLEAR_PROPERTY_VALUE = "clearPropertyValue";
    
    /// <summary>
    /// JavaScript function to open Global Object Properties Editor. 
    /// </summary>
    private const String JAVASCRIPT_OBJ_PROP_EDITOR_OPEN = "objPropEditorOpen";
    
    /// <summary>
    /// Height of rows in list 
    /// </summary>
    protected String m_strRowHeight = "30";
    
    /// <summary>
    /// Helper method to determine whether or not row is visible.  This method
    /// is used by Display().  This method overrides the default behavior of
    /// the ExpListView, where all rows are visible.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>True if row should be displayed, otherwise false.</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#CheckRowIsVisible(int)"></seealso>
    protected override bool CheckRowIsVisible(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      // Display the row if the property is visible and the row has not been deleted.
      if ((iOPModel.CheckRowIsVisible(_nRowIndex)) && (ObjPropModel.ROW_STATUS_DELETED != iOPModel.GetRowStatus(_nRowIndex)))
      {
        // Special case for name and description properties. They shouldn't show up in the edit view.
        if (ObjPropModel.PROP_OBJECTID_NAME == iOPModel.GetRowPropertyID(_nRowIndex) || ObjPropModel.PROP_OBJECTID_DESCRIPTION == iOPModel.GetRowPropertyID(_nRowIndex))
        {
          return false;
        } else
        {
          return true;
        }
      } else
      {
        return false;
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjPropEditView();
    }
    
    /// <summary>
    /// Returns the HTML for the View.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      // Override this method so that we can add a hidden form input for use in
      // clearing property values.
      HTMLElement result = base.Display();
      // Hidden input for the clear property value functionality
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ((IObjPropModelRO) m_model).GetUniqueString(HTMLHIDDEN_CLEARVALUE),
       "");
      myInput.SetValue(XPConvert.ToString(false));
      result.AddInnerHTMLElement(myInput);
      return result;
    }
    
    /// <summary>
    /// JavaScript for opening tree selectors and retrieving values on return
    /// from tree.
    /// </summary>
    /// <returns>JavaScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLScript result = base.DisplayJavascript();
      XPStringBuilder sb;
      try
      {
        // The URL to open a pick tree
        ASURL asURLPickTree = GetPickTreeURL();
        // JavaScript fucntion to open pick tree
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_OPEN)).Append("(varPropertyID, varRowIndex)\n");
        sb.Append("{\n");
        sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
        sb.Append("  window.open(\'").Append(asURLPickTree.GetURLAsString());
        sb.Append("&").Append(ServerStartTreeControl.INIT_DATA).Append("=\' + varPropertyID");
        sb.Append(", \'PickTreeWindow\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // JavaScript function to get pick tree value on return
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_GETVALUE)).Append("()\n");
        sb.Append("{\n");
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MODIFYROW)).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // The URL to open a reference tree
        ASURL asURLRefTree = GetRefTreeURL();
        // JavaScript function to open reference tree
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_OPEN)).Append("(varClassID, varRowIndex, varTreeSelectMode, varSelectedRef)\n");
        sb.Append("{\n");
        sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
        sb.Append("  window.open(\'").Append(asURLRefTree.GetURLAsString());
        sb.Append("&").Append(StartTreeControl.CLASS_IDS_TO_DISPLAY).Append("=\' + varClassID");
        sb.Append(" + \'&").Append(StartTreeControl.SELECT_MODE).Append("=\' + varTreeSelectMode");
        sb.Append(" + \'&").Append(StartTreeControl.SELECTED_ITEMS).Append("=\' + varSelectedRef");
        sb.Append(", \'ReferenceTreeWindow\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // JavaScript function to open Global Object Properties Map
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_OBJ_PROP_EDITOR_OPEN)).Append("()\n");
        sb.Append("{\n");
        sb.Append("  window.open(\'").Append(GetASURLToObjPropMap(null).GetURLAsString());
        sb.Append("\', \'ObjPropWindow\', \'location=no,menubar=no,resizable=yes,scrollbars=yes\');\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // JavaScript function to get reference object on return from reference tree
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_GETVALUE)).Append("()\n");
        sb.Append("{\n");
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MODIFYROW)).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // JavaScript to add or remove property values
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE)).Append("(varAction, varRowIndex)\n");
        sb.Append("{\n");
        sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append("varAction").Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // JavaScript to clear property values
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_CLEAR_PROPERTY_VALUE)).Append("(varRowIndex)\n");
        sb.Append("{\n");
        sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
        sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_CLEARVALUE)).Append(".value = true;\n");
        // Since we are using the base ExpListControl, we just use the MODIFY_ROW action to clear
        // a value.  Our model has special code in the ModifyRow method to handle this case.
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MODIFYROW)).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element.");
        }
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>HTML for row</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Get cell containing class name
      result.AddInnerHTMLElement(GetHTMLForName(_nRowIndex));
      // Get cell containing property value
      result.AddInnerHTMLElement(GetHTMLForPropertyValue(_nRowIndex));
      // Get cell containing row action (add, remove, or nothing)
      HTMLTableCell cellAction = GetHTMLForRowAction(_nRowIndex);
      if (null != cellAction)
      {
        result.AddInnerHTMLElement(cellAction);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Displays HTML below action bar. If the table contained any mandatory
    /// properties, then we want to display "*RequiredText".
    /// </summary>
    /// <returns>HTML below action bar</returns>
    /// <throws>Exception</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLBelowMainTable()"></seealso>
    protected override HTMLTable GetHTMLBelowMainTable()
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      if (iOPModel.CheckDisplayPageIsMandatory())
      {
        HTMLTable myTable;
        HTMLTableRow myRow;
        HTMLTableCell myCell;
        HTMLSpan mySpan;
        myTable = new HTMLTable();
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding(CommonHTMLStrings.FIVE);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("150");
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetColSpan(CommonHTMLStrings.THREE);
        myCell.SetNoWrap(true);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
        mySpan.AddInnerHTMLString("*");
        mySpan.AddInnerHTMLString(m_asOwner.GetString(267, "ptmsgs_portalinfrastructure"));
        return myTable;
      } else
      {
        return null;
      }
    }
    
    /// <summary>
    /// Returns HTML for pick list
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_strValue">Property value as string</param>
    /// <returns>HTML for pick list</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLElementCollection GetHTMLForPickList(int _nRowIndex,
     String _strValue)
    {
      HTMLElementCollection myCollection = new HTMLElementCollection();
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      if (iOPModel.CheckPickValuesAreValid(_nRowIndex))
      {
        HTMLSelect mySelect = new HTMLSelect(iOPModel.GetUniqueString(HTMLINPUT_SELECT_PICKLIST_PREFIX) + _nRowIndex,
         iOPModel.GetUniqueString(HTMLINPUT_SELECT_PICKLIST_TAGID) + _nRowIndex);
        myCollection.AddInnerHTMLElement(mySelect);
        // Add the first option, which is empty value
        HTMLOption optionEmpty = new HTMLOption("");
        mySelect.AddInnerHTMLElement(optionEmpty);
        mySelect.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        // Open the property ObjectManager in order to open property.
        Object[][] arPickListValues = iOPModel.GetPickListValues(iOPModel.GetRowPropertyID(_nRowIndex));
        bool bValueInList = false;
        // Add drop down
        if (null != arPickListValues)
        {
          for (int nOption = 0;nOption < arPickListValues[0].Length;nOption++)
          {
            String strPickListVal = (String) arPickListValues[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME][nOption];
            String strEncodedString = XPHttpUtility.HtmlEncode(strPickListVal);
            HTMLOption optionPickListVal = new HTMLOption(strEncodedString);
            optionPickListVal.AddInnerHTMLString(strEncodedString);
            mySelect.AddInnerHTMLElement(optionPickListVal);
            if (strPickListVal.Equals(_strValue))
            {
              bValueInList = true;
            }
          }
        }
        if (null != _strValue && 0 < _strValue.Length)
        {
          // If the option doesn't exist as a valid pick list value, then display alert message.		
          if (!bValueInList)
          {
            // Display alert message indicating that value is no longer valid
            HTMLSpan mySpan = new HTMLSpan();
            myCollection.AddInnerHTMLElement(mySpan);
            mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
            mySpan.AddInnerHTMLEncodedString(XPResourceManager.FormatMessage(m_asOwner.GetString(469,
             "ptmsgs_portalinfrastructure"), _strValue));
          } else
          {
            // Set the selected value
            mySelect.SetValue(XPHttpUtility.HtmlEncode(_strValue));
          }
        }
      } else
      {
        myCollection.AddInnerHTMLEncodedString(_strValue);
        myCollection.AddInnerHTMLString(" ");
        HTMLSpan mySpan = new HTMLSpan();
        myCollection.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
        mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(471, "ptmsgs_portalinfrastructure"));
        }
      return myCollection;
    }
    
    /// <summary>
    /// Returns HTML for pick tree
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_strValue">Property value as string</param>
    /// <returns>HTML for pick tree</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLElement GetHTMLForPickTree(int _nRowIndex, String _strValue)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLAnchor myAnchor;
      HTMLImg myImage;
      PTConstruct myConstruct;
      XPStringBuilder sbJavascriptOpenPickTree;
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLEncodedString(_strValue);
      if (iOPModel.CheckPickValuesAreValid(_nRowIndex))
      {
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        result.AddInnerHTMLElement(myAnchor);
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT,
         true, this.m_asOwner);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myAnchor.AddInnerHTMLElement(myImage);
        myImage.SetAlt(m_asOwner.GetString(89, "ptmsgs_portalinfrastructure"));
        myImage.SetWidth("25");
        myImage.SetHeight("25");
        myImage.SetBorder(CommonHTMLStrings.ZERO);
        myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        sbJavascriptOpenPickTree = new XPStringBuilder(100);
        sbJavascriptOpenPickTree.Append(iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_OPEN)).Append("(");
        // Append property ID
        sbJavascriptOpenPickTree.Append(iOPModel.GetRowPropertyID(_nRowIndex));
        sbJavascriptOpenPickTree.Append(", ");
        // Append current row to modify
        sbJavascriptOpenPickTree.Append(_nRowIndex);
        sbJavascriptOpenPickTree.Append("); return false;");
        myAnchor.SetOnClick(sbJavascriptOpenPickTree.ToString());
      } else
      {
        result.AddInnerHTMLString(" ");
        HTMLSpan mySpan = new HTMLSpan();
        result.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
        mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(472, "ptmsgs_portalinfrastructure"));
        }
      return result;
    }
    
    /// <summary>
    /// Returns HTML for reference tree
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_strValue">Reference value as string</param>
    /// <returns>HTML for pick tree</returns>
    /// <throws>Exception</throws>
    protected override HTMLElement GetHTMLForReferenceTree(int _nRowIndex,
     String _strValue)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLAnchor myAnchor;
      HTMLImg myImage;
      PTConstruct myConstruct;
      XPStringBuilder sbOpenRefTree;
      HTMLElementCollection result = new HTMLElementCollection();
      // Reference value
      String strRefObjectName = iOPModel.GetRowRefValueName(_nRowIndex);
      if (null != strRefObjectName)
      {
        result.AddInnerHTMLEncodedString(iOPModel.GetRowRefValueName(_nRowIndex));
        result.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      // Edit link
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      result.AddInnerHTMLElement(myAnchor);
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT,
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myAnchor.AddInnerHTMLElement(myImage);
      // Reference Tree
      myImage.SetAlt(m_asOwner.GetString(266, "ptmsgs_portalinfrastructure"));
      myImage.SetWidth("25");
      myImage.SetHeight("25");
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      // Get reference class ID
      int nReferenceClassID = XPConvert.ToInteger(iOPModel.GetRowPropertyInfo(_nRowIndex,
       PT_PROPIDS.PT_PROPID_PROP_REFCLASS));
      sbOpenRefTree = new XPStringBuilder(100);
      sbOpenRefTree.Append(iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_OPEN)).Append("(");
      // Append ref class ID
      sbOpenRefTree.Append(nReferenceClassID);
      sbOpenRefTree.Append(", ");
      // Append current row to modify
      sbOpenRefTree.Append(_nRowIndex);
      sbOpenRefTree.Append(", ");
      if ((PT_CLASSIDS.PT_ADMIN_FOLDER_ID == nReferenceClassID) || (PT_CLASSIDS.PT_CATALOGFOLDER_ID == nReferenceClassID))
      {
        sbOpenRefTree.Append(TreeConstants.N_COMPOSITESELECT);
      } else
      {
        sbOpenRefTree.Append(TreeConstants.N_LEAFSELECT);
      }
      sbOpenRefTree.Append(", \'");
      sbOpenRefTree.Append(iOPModel.GetSelectedReference(_nRowIndex));
      sbOpenRefTree.Append("\'); return false;");
      myAnchor.SetOnClick(sbOpenRefTree.ToString());
      // Only add the clear link if there is a value to clear
      if (null != strRefObjectName)
      {
        // Clear link
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        result.AddInnerHTMLElement(myAnchor);
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_REMOVE,
         true, this.m_asOwner);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myAnchor.AddInnerHTMLElement(myImage);
        // Clear Value
        myImage.SetAlt(m_asOwner.GetString(545, "ptmsgs_portalinfrastructure"));
        myImage.SetWidth("25");
        myImage.SetHeight("25");
        myImage.SetBorder(CommonHTMLStrings.ZERO);
        myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        XPStringBuilder sbClearValue = new XPStringBuilder(100);
        sbClearValue.Append(iOPModel.GetUniqueString(JAVASCRIPT_CLEAR_PROPERTY_VALUE)).Append("(");
        // Append current row to modify
        sbClearValue.Append(_nRowIndex);
        sbClearValue.Append("); return false;");
        myAnchor.SetOnClick(sbClearValue.ToString());
      }
      return result;
    }
    
    /// <summary>
    /// Checks to see if the row can be removed.
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if row can be removed. Otherwise returns false.</returns>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.IObjPropModelRO#CheckRowIsRemovable(int,boolean)"></seealso>
    protected virtual bool CheckRowIsRemovable(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      // If read-only, cannot remove row
      if (iOPModel.CheckRowIsReadOnly(_nRowIndex))
      {
        return false;
      }
      // If first row for property, then cannot remove row
      if (CheckRowIsFirstForProperty(_nRowIndex))
      {
        return false;
      }
      return true;
    }
    
    /// <summary>
    /// Returns anchor for add button
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Anchor for add button</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLAnchor GetAddAnchor(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myAnchor.AddInnerHTMLElement(myImage);
      myAnchor.AddInnerHTMLString(m_asOwner.GetString(366, "ptmsgs_portalinfrastructure"));
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append(iOPModel.GetUniqueString(JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE));
      sb.Append("(\'");
      sb.Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD));
      sb.Append("\', \'");
      sb.Append(_nRowIndex);
      sb.Append("\'); return false;");
      myAnchor.SetOnClick(sb.ToString());
      return myAnchor;
    }
    
    /// <summary>
    /// Returns anchor for delete button
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Anchor for delete button</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLAnchor GetDeleteAnchor(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      // Delete icon
      myConstruct = UIConstructFactory.GetConstruct(iOPModel.GetDeleteIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myAnchor.AddInnerHTMLElement(myImage);
      myImage.SetAlt(iOPModel.GetDeleteIconAlt());
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append(iOPModel.GetUniqueString(JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE));
      sb.Append("(\'");
      sb.Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE));
      sb.Append("\', \'");
      sb.Append(_nRowIndex);
      sb.Append("\'); return false;");
      myAnchor.SetOnClick(sb.ToString());
      return myAnchor;
    }
    
    /// <summary>
    /// Returns HTML for name of property. If the row is a new property then
    /// display name.  If the row is another value in a multi-valued property,
    /// then don't display name.  Distinguish mandatory properties from
    /// optional properties.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>HTML table cell for name</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTableCell GetHTMLForName(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetWidth("20%");
      myCell.SetHeight(m_strRowHeight);
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      // Get current row's name and propertyID
      String strName = iOPModel.GetRowName(_nRowIndex);
      // If we have a new property, then display name
      if (CheckRowIsFirstForProperty(_nRowIndex) || (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD))
      {
        HTMLSpan spanSubTitle = new HTMLSpan();
        myCell.AddInnerHTMLElement(spanSubTitle);
        spanSubTitle.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        spanSubTitle.AddInnerHTMLEncodedString(strName);
        if (iOPModel.CheckRowIsMandatory(_nRowIndex) && !iOPModel.CheckRowIsReadOnly(_nRowIndex))
        {
          HTMLSpan mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
          mySpan.AddInnerHTMLString("*");
        }
      }
      return myCell;
    }
    
    /// <summary>
    /// Returns table cell for property value
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Table cell for property value</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForPropertyValue(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetWidth("80%");
      myCell.SetHeight(m_strRowHeight);
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      Object oValue = iOPModel.GetRowValue(_nRowIndex);
      int nPropertyType = iOPModel.GetRowType(_nRowIndex);
      String strValue = iOPModel.GetStringFromObjectValue(oValue, nPropertyType);
      // If the property is read-only, then just display the value.  Else display display the input text box for the value.
      if (iOPModel.CheckRowIsReadOnly(_nRowIndex))
      {
        if (null != oValue)
        {
          if (iOPModel.CheckRowIsHREF(_nRowIndex))
          {
            HTMLAnchor myAnchor = new HTMLAnchor(strValue);
            myCell.AddInnerHTMLElement(myAnchor);
            myAnchor.AddInnerHTMLEncodedString(strValue);
          } else
          {
            if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == nPropertyType)
            {
              strValue = iOPModel.GetRowRefValueName(_nRowIndex);
            }
            myCell.AddInnerHTMLEncodedString(strValue);
          }
        }
      } else
      {
        // Determine what kind of form element to display
        int nPickType = XPConvert.ToInteger(iOPModel.GetRowPropertyInfo(_nRowIndex,
         PT_PROPIDS.PT_PROPID_PROP_PICKTYPE));
        switch (nPickType){
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST:
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
        // Get drop down menu for picklist
        myCell.AddInnerHTMLElement(GetHTMLForPickList(_nRowIndex, strValue));
        break;
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
        // Get picktree link
        myCell.AddInnerHTMLElement(GetHTMLForPickTree(_nRowIndex, strValue));
        break;
        default:
        myCell.AddInnerHTMLElement(GetHTMLElementForRow(_nRowIndex, oValue));
        break;
        }
      }
      return myCell;
    }
    
    /// <summary>
    /// Returns table cell for adding a value or deleting a value.
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Table cell for action</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForRowAction(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      myCell = new HTMLTableCell();
      myCell.SetHeight(m_strRowHeight);
      myCell.SetWidth("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      // Get cell containing add or remove button
      if (!iOPModel.CheckRowIsReadOnly(_nRowIndex))
      {
        if (CheckRowIsFirstForProperty(_nRowIndex) && iOPModel.CheckRowIsMultiValued(_nRowIndex))
        {
          myAnchor = GetAddAnchor(_nRowIndex);
          myCell.AddInnerHTMLElement(myAnchor);
        } else
        if (CheckRowIsRemovable(_nRowIndex))
        {
          myAnchor = GetDeleteAnchor(_nRowIndex);
          myCell.AddInnerHTMLElement(myAnchor);
        }
      }
      return myCell;
    }
    
    /// <summary>
    /// Return ASURL for pick tree
    /// </summary>
    /// <returns>ASURL for pick tree</returns>
    private ASURL GetPickTreeURL()
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      // The URL to open a pick tree as a subspace.  We want to use the same pick tree each time.
      ASURL asURLPickTree = new ASURL(m_asOwner);
      asURLPickTree.SetLinkCreateNewSpace(ServerTreeAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      asURLPickTree.SetSubSpaceKey(iOPModel.GetUniqueString(ObjPropModel.SUBSPACE_KEY_PICKTREE));
      asURLPickTree.SetControl(ServerStartTreeControl.STR_MVC_CLASS_NAME);
      asURLPickTree.AddControlArgument(ServerStartTreeControl.INTERFACE_TYPE,
       XPConvert.ToString(ServerTreeModel.m_nPROP_PICK_TREE));
      asURLPickTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      asURLPickTree.AddControlArgument(AStartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      asURLPickTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      asURLPickTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
       AFormDP.HTMLFORM_NAME);
      asURLPickTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL,
       iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_GETVALUE));
      asURLPickTree.AddControlArgument(AStartTreeControl.TITLE, m_asOwner.GetString(91,
       "ptmsgs_portalinfrastructure"));
      asURLPickTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(90,
       "ptmsgs_portalinfrastructure"));
      asURLPickTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
      return asURLPickTree;
    }
    
    /// <summary>
    /// Return ASURL for reference tree
    /// </summary>
    /// <returns>ASURL for reference tree</returns>
    private ASURL GetRefTreeURL()
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      // The URL to open a new tree to select reference objects
      ASURL asURLRefTree = new ASURL(m_asOwner);
      asURLRefTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      asURLRefTree.SetSubSpaceKey(iOPModel.GetUniqueString(ObjPropModel.SUBSPACE_KEY_REFTREE));
      asURLRefTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      asURLRefTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
      asURLRefTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      asURLRefTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      asURLRefTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
      asURLRefTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_GETVALUE));
      asURLRefTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(92,
       "ptmsgs_portalinfrastructure"));
      asURLRefTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(93,
       "ptmsgs_portalinfrastructure"));
      asURLRefTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, XPConvert.ToString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT));
      return asURLRefTree;
    }
    
    /// <summary>
    /// Return the ASURL object going to the global object properties map.
    /// </summary>
    /// <param name="_sSubSpaceKey">
    /// Key for the sub Editor.
    /// If we are going to a new sub Editor, the key can be null and
    /// we will just pass in the default key. If we are going back to an
    /// existing sub Editor, it should be the sub Editor key.
    /// </param>
    /// <returns>ASURL</returns>
    private ASURL GetASURLToObjPropMap(String _sSubSpaceKey)
    {
      if (null == _sSubSpaceKey)
      {
        _sSubSpaceKey = "ObjPropMapEditor";
      }
      ASURL myURL = ((EditorAS) m_asOwner).GoToSubEditor("ObjPropMapEditor",
       _sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_MISC, null, null);
      return myURL;
    }
    
    /// <summary>
    /// Returns the HTML for the editing mappings
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForEditMappings()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      myAddIcon.SetAlt("");
      myAddIcon.SetAlign("absmiddle");
      // Object icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_PROPERTY,
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString(JAVASCRIPT_OBJ_PROP_EDITOR_OPEN) + "(); return false;");
      myAnchor.AddInnerHTMLString(SPACE);
      myAnchor.AddInnerHTMLElement(myAddIcon);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(m_asOwner.GetString(155, "ptmsgs_portalinfrastructure"));
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      return myCell;
    }
    
    /// <summary>
    /// We don't have an action bar in our edit mode, but we will display a button to link to the
    /// global object properties map below where the action bar would have been.
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLTable myTable = null;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      if (iOPModel.HasAccessToGlobalObjectPropMapEditor())
      {
        myTable = new HTMLTable();
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        // 1st Row begin (there is only one row)
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
        // Add icon cell
        myRow.AddInnerHTMLElement(GetHTMLForEditMappings());
        // Last Empty Cell
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetHeight("25");
        myCell.AddInnerHTMLString(SPACE);
      }
      return myTable;
    }
  }
}