using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties
{
  /// <summary>
  /// Editor model for browsing object properties.
  /// </summary>
  /// <author>josephc</author>
  public class ObjPropEditorModel : ObjEditorModel,IObjEditorModelRO
  {
    
    /// <summary>
    /// Class name for ObjPropEditorModel 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjPropEditorModel";
    
    /// <summary>
    /// That method is called by the EditorStartControl. It retrieves the existing IPTObject
    /// in edit mode.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    /// <throws>XPException</throws>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      // Set class ID and object ID with values from QS.
      SetMemberVariablesFromQS(_htFormData);
      if (!CheckEditorAccess(_htFormData))
      {
        return false;
      }
      // Initialize m_ptObject
      InitPTObject(_htFormData);
      StartObjectProp();
      // Perform Editor specific tasks
      DoTaskOnStartEditor(_htFormData);
      return true;
    }
    
    /// <summary>
    /// Helper method to check the current user rights to this Object Editor.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    /// <returns>boolean</returns>
    protected override bool CheckEditorAccess(XPHashtable _htFormData)
    {
      // JIC- In edit mode, we need to check the object ACL.
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == m_nEditorType)
      {
        bool bObjectIsAccessible = false;
        // JIC- We check read-only access.
        switch (m_nClassID){
        case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
        case PT_CLASSIDS.PT_CATALOGCARD_ID:
        bObjectIsAccessible = m_Session.GetCatalog().IsCatalogObjectAccessible(m_nClassID,
         m_nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
        break;
        case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
        bObjectIsAccessible = m_Session.GetAdminCatalog().IsAdminFolderAccessible(m_nObjectID,
         PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
        break;
        default:
        bObjectIsAccessible = m_Session.GetAdminCatalog().GetObjectManager(m_nClassID).IsObjectAccessible(m_nObjectID,
         m_Session.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
        break;
        }
        if (bObjectIsAccessible)
        {
          // JIC- The user has access but only in read-only mode.
          m_bIsEditorReadOnly = true;
          return true;
        }
      }
      return false;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjPropEditorModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}