using System;
// Framework Imports
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity
{
  /// <summary>
  /// Displays the Views for the common security page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class ObjectSecurityDP : EditorDP
  {
    
    /// <summary>
    /// Activity Space class name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjectSecurity";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      // JF- We get the String from the Model so Editors can customize it.
      String sPageTitle;
      sPageTitle = ((IObjectSecurityModelRO) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).GetLeftNavString();
      return (sPageTitle);
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(270, "ptmsgs_portalinfrastructure"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      if (((IObjectSecurityModelRO) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).GetShowHeaderAndLeftNav())
      {
        // Insert super class HTML
        result.AddInnerHTMLElement(base.PageDisplay());
        HTMLElementCollection views = new HTMLElementCollection();
        //JF- Add the Security Section.
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).Display());
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        // JF- Add the Priority drop-down Section.
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN)).Display());
        result.AddInnerHTMLElement(CreateLeftNavBar(views));
      } else
      {
        result.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).Display());
        result.AddInnerHTMLElement(EditorView.GetSpacerTable());
        result.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN)).Display());
        }
      return result;
    }
    
    /// <summary>
    /// Returns JavaScript for all the Views displayed by this DP.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection scripts = base.DisplayJavaScriptFromChild();
      scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB).DisplayJavascript());
      return scripts;
    }
  }
}