using System;
// Framework imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.saveobject
{
  /// <summary>
  /// This Section contains the HTML for the name and description.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SaveObjectCantChangeFolderView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectCantChangeFolderView");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SaveObjectCantChangeFolder";
    
    /// <summary>
    /// Associated read-only Model.
    /// </summary>
    private ISaveObjectModelRO m_model;
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    private SaveObjectAS m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SaveObjectCantChangeFolderView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLB myBold;
      try
      {
        // Content table
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("10");
        // Row 1 - begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(125, "ptmsgs_portalinfrastructure"));
        // Row 1 - end
        // Row 2 - begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myBold = new HTMLB();
        myCell.AddInnerHTMLElement(myBold);
        myBold.AddInnerHTMLString(XPHttpUtility.HtmlEncode(((ISaveObjectModelRO) m_model).GetFolderName()));
        }
      // Row 2 - end
      catch (HTMLException e)
      {
        log.Error(e, "SaveObjectCantChangeFolderView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(126, "ptmsgs_portalinfrastructure"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (ISaveObjectModelRO) model;
      m_asOwner = (SaveObjectAS) parent;
    }
  }
}