using System;
// Framework imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.saveobject
{
  /// <summary>
  /// This DP is used to close the save pop-up and refresh the Editor.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SaveObjectClosePopUpDP : IDisplayPage
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectClosePopUpDP");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SaveObjectClosePopUp";
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Construct the HTMLPage for Display.
    /// </summary>
    /// <param name="IWebData">
    /// The HTMLPage for display to the browser should be set on this
    /// object.  This object should not be stored anywhere.
    /// </param>
    public virtual void Display(IWebData webData)
    {
      HTMLPage myPage = new HTMLPage();
      // Set the HTMLPage as the data to be sent to the browser.
      webData.SetData(myPage);
      HTMLHead myHead = new HTMLHead();
      myPage.SetHead(myHead);
      HTMLBody myBody = new HTMLBody();
      myPage.SetBody(myBody);
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      // JF- Create the ASURL going to the Dependencies page.
      ASURL nextPage = new ASURL(m_asOwner);
      nextPage.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
      nextPage.SetDisplayPage(ObjDependenciesDP.STR_MVC_CLASS_NAME);
      try
      {
        sb = new XPStringBuilder(200);
        // JF- redirect the main window
        sb.Append("  parent.parent.window.opener.postToSelf(\'" + ObjEditorRepostControl.POSTTOSELF_ACTION_APPLY_CHANGES + "\'); \n");
        sb.Append("  parent.parent.window.close(); \n");
        myScript.AddInnerHTMLString(sb.ToString());
        myHead.AddInnerHTMLElement(myScript);
      }
      catch (HTMLException he)
      {
        log.Error(he, "SaveObjectClosePopUpDP::Display The following error occured" + " when trying to generate the JavaScript to close the pop up: " + he.Message);
        throw new XPException(m_asOwner.GetString(146, "ptmsgs_portalinfrastructure"),
         he);
      }
    }
    
    /// <summary>
    /// Return the name of the MVC object.
    /// </summary>
    /// <returns>the name of the object.</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Return the parent Activity Space.
    /// </summary>
    /// <returns>AActivitySpace</returns>
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    
    /// <summary>
    /// Initialize the Display Page.
    /// </summary>
    /// <param name="AActivitySpace">the parent AActivitySpace of this IDisplayPage.</param>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
    }
  }
}