using System;
// Server imports
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.common;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portaluiinfrastructure.editor.saveobject
{
  /// <summary>
  /// Display Page for the save pop-up main frame.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SaveObjectFoldersFrameDP : FrameSetDP
  {
    
    /// <summary>
    /// Frameset object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SaveObjectPopUpFrameFolders";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.dialogheader.FrameSetDialog#GetFrameSetTitle()"></seealso>
    public override String GetFrameSetTitle()
    {
      // JF- This is a frame inside another frame, no need to set the title here.
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameScrollTop()"></seealso>
    public override bool GetFrameScrollTop()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameScrollBody()"></seealso>
    public override bool GetFrameScrollBody()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameSetAttributes()"></seealso>
    public override String GetFrameSetAttributes()
    {
      ISaveObjectModelRO myModel = (ISaveObjectModelRO) m_asOwner.GetModel(SaveObjectModel.STR_MVC_CLASS_NAME);
      if (0 == myModel.GetRecentlyUsedFolders().Length)
      {
        return "100%,0px";
      } else
      {
        return "80%,70px";
      }
    }
    
    /// <summary>
    /// Returns the URL for the body frame.
    /// </summary>
    /// <returns>ASURL</returns>
    public override ASURL GetFrameURLBody()
    {
      ASURL myBodyFrame = new ASURL(m_asOwner);
      myBodyFrame.SetLinkGetCachedSpace(m_asOwner);
      myBodyFrame.SetDisplayPage(SaveObjectRecentFoldersDP.STR_MVC_CLASS_NAME);
      return myBodyFrame;
    }
    
    /// <summary>
    /// Returns the URL to go to the Top Frame.
    /// </summary>
    /// <returns>ASURL</returns>
    public override ASURL GetFrameURLTop()
    {
      ASURL myTopFrame = new ASURL(m_asOwner);
      ISaveObjectModelRO myModel = (ISaveObjectModelRO) m_asOwner.GetModel(SaveObjectModel.STR_MVC_CLASS_NAME);
      int nFolderID = myModel.GetAdminFolderID();
      // JF- Get the cached folder tree.
      if (m_asOwner.GetSubSpaceExists(SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY))
      {
        myTopFrame.SetLinkGetCachedSpace(m_asOwner.GetSubSpace(SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY));
        myTopFrame.SetDisplayPage(TreeDP.STR_MVC_CLASS_NAME);
        if (!myModel.IsAdminFolderInRecentFolders(nFolderID))
        {
          myTopFrame.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
          myTopFrame.AddControlArgument(StartTreeControl.SELECTED_ITEMS, PT_CLASSIDS.PT_ADMIN_FOLDER_ID + "," + nFolderID);
          }
      } else
      // JF- This is the first time, create a new one.
      {
        myTopFrame.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
        myTopFrame.SetSubSpaceKey(SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY);
        myTopFrame.SetDisplayPage(TreeDP.STR_MVC_CLASS_NAME);
        myTopFrame.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        myTopFrame.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
        myTopFrame.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
        myTopFrame.AddControlArgument(StartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
        myTopFrame.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
        myTopFrame.AddControlArgument(StartTreeControl.ONCLICK_CALL, "parent." + BODY_FRAME + ".UnSelectFromRecentFolders");
        myTopFrame.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(133,
         "ptmsgs_portalinfrastructure"));
        if (!myModel.IsAdminFolderInRecentFolders(nFolderID))
        {
          myTopFrame.AddControlArgument(StartTreeControl.SELECTED_ITEMS, PT_CLASSIDS.PT_ADMIN_FOLDER_ID + "," + nFolderID);
          }
      }
      return myTopFrame;
    }
  }
}