using System;
// Framework imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.saveobject
{
  /// <summary>
  /// This DP is used to redirect to the dependencies page.
  /// Because we are going from a page with 3 frames to a page with
  /// no frame, it has to be done by a JavaScript.
  /// The body frame will redirect to this DP and this DP is just a
  /// JavaScript that will do the real redirection to the dependencies page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SaveObjectGoToSecurityTabDP : IDisplayPage
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectGoToSecurityTabDP");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SaveObjectGoToSecurityTab";
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Construct the HTMLPage for Display.
    /// </summary>
    /// <param name="IWebData">
    /// The HTMLPage for display to the browser should be set on this
    /// object.  This object should not be stored anywhere.
    /// </param>
    public virtual void Display(IWebData webData)
    {
      HTMLPage myPage = new HTMLPage();
      // Set the HTMLPage as the data to be sent to the browser.
      webData.SetData(myPage);
      HTMLHead myHead = new HTMLHead();
      myPage.SetHead(myHead);
      HTMLBody myBody = new HTMLBody();
      myPage.SetBody(myBody);
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      // JF- Create the ASURL going to the Dependencies page.
      ASURL securityTab = new ASURL(m_asOwner);
      securityTab.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
      securityTab.SetDisplayPage(ObjectSecurityDP.STR_MVC_CLASS_NAME);
      try
      {
        sb = new XPStringBuilder(200);
        // JF- Add the ASURL to the JavaScript.
        sb.Append("parent.location = \'" + securityTab.GetURLAsString() + "\';\n");
        myScript.AddInnerHTMLString(sb.ToString());
        myHead.AddInnerHTMLElement(myScript);
      }
      catch (HTMLException he)
      {
        log.Error(he, "SaveObjectGoToSecurityTabDP::Display An error occured" + " when trying to generate the JavaScript to redirect to the dependencies page.");
        throw new XPException(m_asOwner.GetString(146, "ptmsgs_portalinfrastructure"));
        }
    }
    
    /// <summary>
    /// Return the name of the MVC object.
    /// </summary>
    /// <returns>the name of the object.</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Return the parent Activity Space.
    /// </summary>
    /// <returns>AActivitySpace</returns>
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    
    /// <summary>
    /// Initialize the Display Page.
    /// </summary>
    /// <param name="AActivitySpace">the parent AActivitySpace of this IDisplayPage.</param>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
    }
  }
}