using System;
// Framework imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.editor.saveobject
{
  /// <summary>
  /// This Section contains the HTML for the tabs "save in" and "security".
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SaveObjectMenuView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectMenuView");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SaveObjectPopUpMenu";
    
    /// <summary>
    /// HTML Object name: hidden input for the new tab to select 
    /// </summary>
    public const String HTMLHIDDEN_NEWTAB = "in_hi_NewTab";
    
    /// <summary>
    /// Flag to display a one time alert when going from Security tab to Folder tab. 
    /// </summary>
    private bool m_bIsFirstTime;
    
    /// <summary>
    /// Associated read-only Model.
    /// </summary>
    private ISaveObjectModelRO m_model;
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    private SaveObjectAS m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SaveObjectMenuView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      HTMLInput myInput;
      try
      {
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        // 1st Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetColSpan("3");
        myCell.SetNoWrap(true);
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER,
         true, m_asOwner);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetWidth("1");
        myImage.SetHeight("15");
        myImage.SetBorder("0");
        myImage.SetAlign("absmiddle");
        myCell.AddInnerHTMLElement(myImage);
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_NEWTAB,
         "");
        myCell.AddInnerHTMLElement(myInput);
        // 2nd Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        // Cell 1 - Save In
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100");
        myCell.SetAlign("center");
        myCell.SetNoWrap(true);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TAB_TEXT);
        if (SaveObjectModel.SAVEOBJECT_TAB_FOLDERTREE == m_model.GetCurrentTab())
        {
          myCell.SetStyleClass(PTStyleClass.DIALOGUE_TAB_ON_BG);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(134, "ptmsgs_portalinfrastructure"));
          } else
        {
          myCell.SetStyleClass(PTStyleClass.DIALOGUE_TAB_OFF_BG);
          myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick("ChangeTab(\'" + SaveObjectModel.SAVEOBJECT_TAB_FOLDERTREE + "\'); return false;");
          mySpan.AddInnerHTMLElement(myAnchor);
          myAnchor.AddInnerHTMLString(m_asOwner.GetString(134, "ptmsgs_portalinfrastructure"));
          }
        if (!m_model.HideSecurityTab())
        {
          // Cell 2 - Security
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("100");
          myCell.SetAlign("center");
          myCell.SetNoWrap(true);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TAB_TEXT);
          if (SaveObjectModel.SAVEOBJECT_TAB_SECURITY == m_model.GetCurrentTab())
          {
            myCell.SetStyleClass(PTStyleClass.DIALOGUE_TAB_ON_BG);
            mySpan.AddInnerHTMLString(m_asOwner.GetString(135, "ptmsgs_portalinfrastructure"));
            } else
          {
            myCell.SetStyleClass(PTStyleClass.DIALOGUE_TAB_OFF_BG);
            myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick("ChangeTab(\'" + SaveObjectModel.SAVEOBJECT_TAB_SECURITY + "\'); return false;");
            myAnchor.AddInnerHTMLString(m_asOwner.GetString(135, "ptmsgs_portalinfrastructure"));
            mySpan.AddInnerHTMLElement(myAnchor);
          }
        }
        // Cell 3 - Empty
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetHeight("15");
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      catch (Exception e)
      {
        log.Error(e, "SaveObjectMenuView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(137, "ptmsgs_portalinfrastructure"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        sb = new XPStringBuilder(200);
        sb.Append("function ChangeTab(varNewTab)\n");
        sb.Append("{\n");
        if ((!m_model.ForceSaveInFolder()) && m_bIsFirstTime && (m_model.GetCurrentTab() == SaveObjectModel.SAVEOBJECT_TAB_SECURITY))
        {
          sb.Append("    alert(\'" + m_asOwner.GetString(437, "ptmsgs_portalinfrastructure") + "\'); \n");
          m_bIsFirstTime = false;
        }
        sb.Append("   if (ValidateTree()) \n");
        sb.Append("   {\n");
        sb.Append("     document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_NEWTAB + ".value = varNewTab;\n");
        // JF- We also need to pass in the DP name, usually the AS does it for us but in this case we have 
        // a frame and the AS thinks we are on SaveObjectMainFrameDP
        sb.Append("     document." + AFormDP.HTMLFORM_NAME + "." + ASConstants.PAGE_INPUT + ".value = \'" + SaveObjectTopFrameDP.STR_MVC_CLASS_NAME + "\' ;\n");
        sb.Append("     postToSelf(\'" + SaveObjectRepostControl.POSTTOSELF_ACTION_CHANGETAB + "\');");
        sb.Append("   }\n");
        sb.Append("}\n");
        sb.Append("function ValidateTree()\n");
        sb.Append("{\n");
        sb.Append("  if (null != parent." + SaveObjectMainFrameDP.BODY_FRAME + "." + SaveObjectFoldersFrameDP.TOP_FRAME + ")\n");
        sb.Append("  {\n");
        sb.Append("    varFolderTree = parent." + SaveObjectMainFrameDP.BODY_FRAME + "." + SaveObjectFoldersFrameDP.TOP_FRAME + ".document." + AFormDP.HTMLFORM_NAME + "." + TreeView.HTMLBUTTON_RADIO + ";\n");
        //sb.Append("    varFolderID = parent." + SaveObjectMainFrameDP.BODY_FRAME + "." 
        //			+ SaveObjectFoldersFrameDP.BODY_FRAME + ".document." 
        //			+ AFormDP.HTMLFORM_NAME + "." + SaveObjectRecentFoldersView.HTMLHIDDEN_SELECTED_FOLDER + ";\n");
        sb.Append("    varRecentFolders = parent." + SaveObjectMainFrameDP.BODY_FRAME + "." + SaveObjectFoldersFrameDP.BODY_FRAME + ".document." + AFormDP.HTMLFORM_NAME + "." + SaveObjectRecentFoldersView.HTMLINPUT_RECENT_FOLDERS + ";\n");
        sb.Append("    if (varFolderTree)\n");
        sb.Append("    { \n");
        sb.Append("      if (varFolderTree.length)\n");
        sb.Append("      { \n");
        sb.Append("        for ( var i = 0; i < varFolderTree.length; i++ ) \n");
        sb.Append("        {\n");
        sb.Append("          if ( varFolderTree[i].checked == true ) \n");
        sb.Append("          {\n");
        //sb.Append("             varFolderID.value =  varFolderTree.value ;\n");
        sb.Append("             return true;\n");
        sb.Append("          }\n");
        sb.Append("        }\n");
        sb.Append("      } \n");
        sb.Append("      else if (varFolderTree.checked == true) \n");
        sb.Append("      {\n");
        //sb.Append("        varFolderID.value =  varFolderTree.value ;\n");
        sb.Append("        return true;\n");
        sb.Append("      }\n");
        sb.Append("    }\n");
        sb.Append("    if (varRecentFolders)\n");
        sb.Append("    { \n");
        sb.Append("      if (varRecentFolders.length)\n");
        sb.Append("      { \n");
        sb.Append("        for ( var i = 0; i < varRecentFolders.length; i++ ) \n");
        sb.Append("        {\n");
        sb.Append("          if ( varRecentFolders[i].checked == true ) \n");
        sb.Append("          {\n");
        //sb.Append("             varFolderID.value =  varRecentFolders.value ;\n");
        sb.Append("             return true;\n");
        sb.Append("          }\n");
        sb.Append("        }\n");
        sb.Append("      } \n");
        sb.Append("      else if (varRecentFolders.checked == true) \n");
        sb.Append("      {\n");
        //sb.Append("        varFolderID.value =  varRecentFolders.value ;\n");
        sb.Append("        return true;\n");
        sb.Append("      }\n");
        sb.Append("    }\n");
        sb.Append("  } \n");
        sb.Append("  else \n");
        sb.Append("  { \n");
        sb.Append("    return true; \n");
        sb.Append("  } \n");
        sb.Append("  alert(\'" + m_asOwner.GetString(136, "ptmsgs_portalinfrastructure") + "\');\n");
        sb.Append("  return false;\n");
        sb.Append("}\n");
        if (m_model.GetRepostBodyFromTopFrame())
        {
          // JF- We just reposted this frame to change the selected tab.
          // Now we are going to repost the body tab and update the content of it, 
          // according to the new selected tab.
          int nRepostAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
          if (SaveObjectModel.SAVEOBJECT_TAB_FOLDERTREE == m_model.GetCurrentTab())
          {
            nRepostAction = SaveObjectRepostControl.POSTTOSELF_ACTION_GOTO_FOLDERTREETAB;
            sb.Append(" varForm = parent." + SaveObjectMainFrameDP.BODY_FRAME + ".document." + AFormDP.HTMLFORM_NAME + "; \n");
            } else
          if (SaveObjectModel.SAVEOBJECT_TAB_SECURITY == m_model.GetCurrentTab())
          {
            if (m_model.ForceSaveInFolder())
            {
              nRepostAction = SaveObjectRepostControl.POSTTOSELF_ACTION_GOTO_SECURITYTAB;
              sb.Append(" varForm = parent." + SaveObjectMainFrameDP.BODY_FRAME + ".document." + AFormDP.HTMLFORM_NAME + "; \n");
              } else
            {
              nRepostAction = SaveObjectRepostControl.POSTTOSELF_ACTION_REPOST_TREE;
              sb.Append(" varForm = parent." + SaveObjectMainFrameDP.BODY_FRAME + "." + SaveObjectFoldersFrameDP.BODY_FRAME + ".document." + AFormDP.HTMLFORM_NAME + "; \n");
              sb.Append(" varForm." + ASConstants.PAGE_INPUT + ".value = \'" + SaveObjectRecentFoldersDP.STR_MVC_CLASS_NAME + "\' ;\n");
              }
          }
          sb.Append(" varForm." + ASConstants.SPACENAME_INPUT + ".value = \'" + SaveObjectAS.STR_MVC_CLASS_NAME + "\' ;\n");
          sb.Append(" varForm." + ASConstants.CONTROL_INPUT + ".value = \'" + SaveObjectRepostControl.STR_MVC_CLASS_NAME + "\' ;\n");
          sb.Append(" varForm." + ASConstants.SPACEID_INPUT + ".value = \'" + m_asOwner.GetSpaceID() + "\' ;\n");
          sb.Append(" varForm." + RepostControl.HTMLINPUT_POSTTOSELF + ".value =  \'" + nRepostAction + "\';\n");
          sb.Append(" varForm.submit();\n");
        }
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "SaveObjectMenuView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (ISaveObjectModelRO) model;
      m_asOwner = (SaveObjectAS) parent;
      m_bIsFirstTime = true;
    }
  }
}