using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portaluiinfrastructure.editor.saveobject
{
  /// <author>Julie Fournier</author>
  public class SaveObjectRepostControl : RepostControl,IHTTPControl
  {
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SaveObjectPopUpRepost";
    
    /// <summary>
    /// Repost Action: To save the object.
    /// </summary>
    public const int POSTTOSELF_ACTION_SAVEOBJECT = 400;
    
    /// <summary>
    /// Repost Action: To redirect the body frame to the security page.
    /// </summary>
    public const int POSTTOSELF_ACTION_GOTO_SECURITYTAB = 401;
    
    /// <summary>
    /// Repost Action: To redirect the body frame to the folder tree.
    /// </summary>
    public const int POSTTOSELF_ACTION_GOTO_FOLDERTREETAB = 402;
    
    /// <summary>
    /// Repost Action: Simple repost to sasve the name and description frame.
    /// </summary>
    public const int POSTTOSELF_ACTION_SAVENAME_AND_DESCRIPTION = 403;
    
    /// <summary>
    /// Repost Action: To change tab.
    /// </summary>
    public const int POSTTOSELF_ACTION_CHANGETAB = 404;
    
    /// <summary>
    /// Repost Action: Repost tree frame
    /// </summary>
    public const int POSTTOSELF_ACTION_REPOST_TREE = 405;
    
    /// <summary>
    /// Repost Action: Repost tree frame and save object
    /// </summary>
    public const int POSTTOSELF_ACTION_REPOST_TREE_AND_SAVE = 406;
    
    /// <summary>
    /// Web Data Object (needs to be nulled out after execution to prevent leaks) 
    /// </summary>
    private IWebData m_WebData;
    
    /// <summary>
    /// HTTP Request (needs to be nulled out after execution to prevent leaks) 
    /// </summary>
    private IXPRequest m_xpRequest;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SaveObjectRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits this Control with the HTTP Request and the Web Data object.
    /// </summary>
    /// <param name="_xpRequest"></param>
    /// <param name="_webdata"></param>
    public virtual void SetHTTPItems(IXPRequest _xpRequest, IWebData _webdata)
    {
      m_xpRequest = _xpRequest;
      m_WebData = _webdata;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      Redirect result;
      switch (_nAction){
      case POSTTOSELF_ACTION_SAVEOBJECT:
      if (!((SaveObjectModel) m_model).ForceSaveInFolder())
      {
        ((SaveObjectModel) m_model).AddAdminFolderIDToCookie(m_xpRequest,
         m_WebData);
      }
      try
      {
        m_model.Finish();
        // JF- We are done with the Editor, we call finish on the parent AS, 
        // which will take care of storing the Object.
        EditorAS parentSpace = (EditorAS) m_asOwner.GetParentSpace();
        ObjEditorModel parentModel = (ObjEditorModel) parentSpace.GetModel(parentSpace.m_strModelName);
        // The parent space is not initialized, which means it can't be used normally in
        // the INewEditObjectActions PEI when that is triggered.  So we initialize it here.
        parentSpace.SetCurrentHTTPRequestResponseObjects(m_asOwner.GetCurrentHTTPRequest(),
         m_asOwner.GetCurrentHTTPResponse());
        parentSpace.SetCurrentRequestURL(m_asOwner.GetCurrentRequestURL());
        parentModel.Finish();
        // JF- Then we redirect to the dependencies page.
        // We are in the bottom frame and we want to redirect the entire window. 
        // We redirect to a DP that will take care of redirecting the frame.
        result = new Redirect();
        result.SetLinkGetCachedSpace(m_asOwner);
        result.SetDisplayPage(SaveObjectRedirectDP.STR_MVC_CLASS_NAME);
        SetRedirect(result);
        break;
      }
      catch (Exception e)
      {
        IXPEnumerator arrErrors = UIErrorHandler.GetErrors(m_asOwner.GetSubSession(),
         m_asOwner.GetApplication(), m_asOwner, true, true);
        if (!arrErrors.MoveNext())
        {
          UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
           null, m_asOwner.GetString(445, "ptmsgs_portalinfrastructure"),
           null);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
        result = new Redirect();
        result.SetLinkGetCachedSpace(m_asOwner);
        result.SetDisplayPage(SaveObjectClosePopUpDP.STR_MVC_CLASS_NAME);
        SetRedirect(result);
        return;
      }
      goto case POSTTOSELF_ACTION_SAVENAME_AND_DESCRIPTION;
      case POSTTOSELF_ACTION_SAVENAME_AND_DESCRIPTION:
      // JF- We saved the name and description, but we also want to save the body frame.
      // With the flag below, when the name and description Section is displayed, it will 
      // have a JS to repost the body Section.
      ((SaveObjectModel) m_model).SetRepostBodyFromBottomFrame(true);
      break;
      case POSTTOSELF_ACTION_CHANGETAB:
      if (!((SaveObjectModel) m_model).HideSecurityTab())
      {
        // JF- We saved the new tab ID, but we also want to save the body frame and redirect it 
        // according to the new tab ID.
        // With the flag below, when the tab Section is displayed, it will 
        // have a JS to repost the body Section.
        ((SaveObjectModel) m_model).SetRepostBodyFromTopFrame(true);
      }
      break;
      case POSTTOSELF_ACTION_GOTO_SECURITYTAB:
      if (!((SaveObjectModel) m_model).HideSecurityTab())
      {
        // JF- We redirect to the Security page. We get it from our parent Space.
        result = new Redirect();
        if (((SaveObjectModel) m_model).ForceSaveInFolder())
        {
          result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
          result.SetDisplayPage(ObjectSecurityDP.STR_MVC_CLASS_NAME);
        } else
        {
          result.SetLinkGetCachedSpace(m_asOwner);
          result.SetDisplayPage(SaveObjectGoToSecurityTabDP.STR_MVC_CLASS_NAME);
          }
        SetRedirect(result);
      }
      break;
      case POSTTOSELF_ACTION_GOTO_FOLDERTREETAB:
      if (!((SaveObjectModel) m_model).HideSecurityTab())
      {
        result = new Redirect();
        if (((SaveObjectModel) m_model).ForceSaveInFolder())
        {
          result.SetLinkGetCachedSpace(m_asOwner);
          result.SetDisplayPage(SaveObjectCantChangeFolderDP.STR_MVC_CLASS_NAME);
          } else
        {
          // JF- We redirect to the folder tree. (It's a sub space.)
          //result.SetSpaceGetCached(m_asOwner.GetSubSpace(SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY));
          result.SetLinkGetCachedSpace(m_asOwner);
          result.SetDisplayPage(SaveObjectFoldersFrameDP.STR_MVC_CLASS_NAME);
          }
        SetRedirect(result);
      }
      break;
      case POSTTOSELF_ACTION_REPOST_TREE:
      ((SaveObjectModel) m_model).SetRepostTreeRecentFoldersFrame(true);
      break;
      case POSTTOSELF_ACTION_REPOST_TREE_AND_SAVE:
      ((SaveObjectModel) m_model).SetRepostTreeAndSave(true);
      break;
      }
      // null out these so we don't leak them.
      m_xpRequest = null;
      m_WebData = null;
    }
  }
}