using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.editor.saveobject
{
  /// <summary>
  /// This control is used to initalize the save object pop-up.
  /// It has to be called the first time the pop-up is displayed.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SaveObjectStartControl : IControl,IHTTPControl
  {
    
    /// <summary>
    /// Object Name for AS 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SaveObjectPopUpStart";
    
    /// <summary>
    /// Associated Activity Space 
    /// </summary>
    protected SaveObjectAS m_asOwner;
    
    /// <summary>
    /// Associated Model 
    /// </summary>
    protected SaveObjectModel m_model;
    
    /// <summary>
    /// HTTP Request (needs to be nulled out after execution to prevent leaks) 
    /// </summary>
    private IXPRequest m_xpRequest;
    
    /// <summary>
    /// Intializes the Model.
    /// </summary>
    /// <returns>Redirect</returns>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      m_model.InitializeSaveObjectPopUp(m_xpRequest);
      // null out request so we don't leak it.
      m_xpRequest = null;
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SaveObjectStartControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the class with the associated model and activity space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="space"></param>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_model = (SaveObjectModel) model;
      m_asOwner = (SaveObjectAS) space;
    }
    
    /// <summary>
    /// Inits this Control with the HTTP Request.
    /// (Will be used to retrieve most recently used folders.)
    /// </summary>
    /// <param name="_xpRequest"></param>
    /// <param name="_webdata"></param>
    public virtual void SetHTTPItems(IXPRequest _xpRequest, IWebData _webdata)
    {
      m_xpRequest = _xpRequest;
    }
  }
}