using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portaluiinfrastructure.error
{
  /// <author>
  /// Ben Geislinger
  /// This helper class is used to determine whether or not to display admin
  /// errors.  The UIErrorHandler should be initialized by the AppStartUp code
  /// to use this helper class.
  /// </author>
  public class PTErrorHandler : IAdminUIErrorHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.error.PTErrorHandler");
    
    /// <summary>
    /// Call this method to obtain a boolean value indicating whether or not
    /// the current user should see errors intended for administrators.
    /// <br /><br />
    /// </summary>
    /// <param name="ptSession">IPTSession</param>
    /// <returns>boolean value</returns>
    public virtual bool GetDisplayAdminErrors(Object session)
    {
      log.Debug("GetDisplayAdminErrors()");
      // This can happen on a failed login attempt.
      if (session == null)
      {
        return false;
      }
      IPTSessionInfo info = ((IPTSession) session).GetSessionInfo();
      bool bUserIsAdmin = false;
      try
      {
        bUserIsAdmin = PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) session);
        }
      catch (Exception ex)
      {
        log.Error(ex, "Error while checking if user is in the Administrators group.");
        }
      log.Debug("GetDisplayAdminErrors() - bUserIsAdmin: " + XPConvert.ToString(bUserIsAdmin));
      log.Debug("userid: " + info.GetCurrentUserID());
      return bUserIsAdmin;
    }
    
    /// <summary>
    /// Call this method to obtain a boolean value indicating whether or not
    /// the current user should see errors intended for administrators.
    /// <br /><br />
    /// </summary>
    /// <param name="AActivitySpace"></param>
    /// <returns>boolean value</returns>
    public virtual bool GetDisplayAdminErrors(AActivitySpace space)
    {
      log.Debug("GetDisplayAdminErrors()");
      return UIErrorHandler.GetDisplayAdminErrors(space.GetUserSession());
      }
  }
}