using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
namespace com.plumtree.portaluiinfrastructure.expandablelist.inherit
{
  /// <author>michaeld</author>
  public class InheritListModel : SelectPTObjectModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.expandablelist.inherit.InheritListModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "InheritList";
    public const int EXPLIST_COL_MAX = 5;
    public const int EXPLIST_COL_INHERITS = 4;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new InheritListModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initializes the read only inherit list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_nDisplayClassID">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public virtual void InitializeInheritList(String _sSectionTitle, int _nDisplayClassID,
     int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      // Name column
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_STRING;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(3046,
       ResourceConstants.PORTALADMINMSGS);
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      // Inherits Template Column
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_INHERITS;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(3047,
       ResourceConstants.PORTALADMINMSGS);
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "20";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeReadOnlyExpandableList(_sSectionTitle, arrExpListColInfo,
       _nListKey);
      base.InitializeListClassIDs(new int[]{_nDisplayClassID});
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
       EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING, EXPLIST_COL_INHERITS};
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_STRING;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, false, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    
    /// <summary>
    /// Uses the passed in parameters to query which objects use the passed in template
    /// and which inherit it then adds those as the default objects.
    /// </summary>
    /// <param name="_Session"></param>
    /// <param name="_nDisplayClassID"></param>
    /// <param name="_nTemplateObjectID"></param>
    /// <param name="_nTemplateColumnPropID"></param>
    /// <param name="_nInheritTemplateColumnPropID"></param>
    public virtual void SetDefaultObjects(IPTSession _Session, int _nDisplayClassID,
     int _nTemplateObjectID, int _nTemplateColumnPropID, int _nInheritTemplateColumnPropID)
    {
      int[][] aOrderBy = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        aOrderBy[j2c_index] = new int[2];
      }
      aOrderBy[0][0] = PT_PROPIDS.PT_PROPID_NAME;
      aOrderBy[0][1] = PT_ORDERBY_SETTINGS.PT_ORDERBY_ASCENDING;
      Object[][] aQueryFilter = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        aQueryFilter[j2c_index] = new Object[1];
      }
      aQueryFilter[0][0] = _nTemplateColumnPropID;
      aQueryFilter[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      aQueryFilter[2][0] = _nTemplateObjectID;
      IPTQueryResult ptqrObjects = _Session.GetObjectManagers(_nDisplayClassID).Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_DESCRIPTION | _nTemplateColumnPropID | _nInheritTemplateColumnPropID,
       -1, aOrderBy, 0, -1, aQueryFilter);
      Object[][] arrObjects = SetupInheritedObjects(ptqrObjects, _nDisplayClassID,
       _nInheritTemplateColumnPropID);
      base.SetDefaultObjects(arrObjects);
    }
    
    /// <summary>
    /// Takes a query result of objects and sets up the member variables from
    /// it.
    /// </summary>
    /// <param name="IPTQueryResult">ptqrObjects</param>
    /// <param name="_nDisplayClassID"></param>
    /// <param name="_nInheritTemplateColumnPropID"></param>
    /// <returns>Object[][]</returns>
    private Object[][] SetupInheritedObjects(IPTQueryResult ptqrObjects, int _nDisplayClassID,
     int _nInheritTemplateColumnPropID)
    {
      int nObjectCount;
      if (null == ptqrObjects)
      {
        nObjectCount = 0;
      } else
      {
        nObjectCount = ptqrObjects.RowCount();
      }
      Object[][] arrReturn = new Object[nObjectCount][];
      for (int j2c_index = 0;j2c_index < nObjectCount;j2c_index++)
      {
        arrReturn[j2c_index] = new Object[EXPLIST_COL_MAX];
      }
      for (int i = 0;i < nObjectCount;i++)
      {
        arrReturn[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = this.m_nNextIndex;
        this.m_nNextIndex++;
        arrReturn[i][EXPLIST_COL_CLASSID] = _nDisplayClassID;
        arrReturn[i][EXPLIST_COL_OBJECTID] = ptqrObjects.ItemAsObject(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        arrReturn[i][EXPLIST_COL_STRING] = (String) ptqrObjects.ItemAsObject(i,
         PT_PROPIDS.PT_PROPID_NAME);
        arrReturn[i][EXPLIST_COL_INHERITS] = ptqrObjects.ItemAsObject(i, _nInheritTemplateColumnPropID);
        }
      return arrReturn;
    }
  }
}