using System;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.expandablelist.properties
{
  /// <summary>
  /// Browse view for expandable list of properties. 
  /// </summary>
  /// <author>josephc</author>
  public abstract class ExpListPropBrowseView : ExpListView
  {
    
    /// <summary>
    /// Used to set the style of the row 
    /// </summary>
    protected PTStyleClass m_rowStyleClass;
    
    /// <summary>
    /// Compares the property ID of the row to the previous row's property ID to
    /// determine whether or not the row is a new property or not.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>True if new property, False otherwise.</returns>
    protected virtual bool CheckRowIsFirstForProperty(int _nRowIndex)
    {
      IExpListPropModelRO iOPModel = (IExpListPropModelRO) m_model;
      if (-1 == m_nLastVisibleRow)
      {
        return true;
      } else
      {
        int nPropertyID = iOPModel.GetRowPropertyID(_nRowIndex);
        // Get last visible row's name and propertyID
        int nLastPropertyID = iOPModel.GetRowPropertyID(m_nLastVisibleRow);
        // If the current propertyID not equal to the previous propertyID
        // then we know that the row contains a new property.
        return nPropertyID != nLastPropertyID;
      }
    }
    
    /// <summary>
    /// Helper method to set the style of a row.  This method is used by
    /// Display(). Overrides the ExpListView::SetExpListRowStyle().
    /// </summary>
    /// <param name="_myRow"></param>
    /// <param name="_nRowIndex"></param>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#SetExpListRowStyle(HTMLTableRow,int)"></seealso>
    protected override void SetRowStyle(HTMLTableRow _myRow, int _nRowIndex)
    {
      // If we're on the first row, then reset the style
      if (0 == _nRowIndex)
      {
        m_rowStyleClass = PTStyleClass.LIST_ITEM_ONE_BG;
      }
      // If the row is the first for the property
      if (CheckRowIsFirstForProperty(_nRowIndex))
      {
        // Toggle style index if we have a new property
        if (PTStyleClass.LIST_ITEM_ONE_BG == m_rowStyleClass)
        {
          m_rowStyleClass = PTStyleClass.LIST_ITEM_TWO_BG;
        } else
        {
          m_rowStyleClass = PTStyleClass.LIST_ITEM_ONE_BG;
        }
      }
      _myRow.SetStyleClass(m_rowStyleClass);
    }
  }
}