using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.expandablelist.properties
{
  /// <summary>
  /// Edit view for expandable list of properties. 
  /// </summary>
  /// <author>josephc</author>
  public abstract class ExpListPropEditView : ExpListPropBrowseView
  {
    
    /// <summary>
    /// Input for input text box 
    /// </summary>
    public const String HTMLINPUT_ITEM = "in_tx_Item";
    
    /// <summary>
    /// Input for input password box 
    /// </summary>
    public const String HTMLINPUT_PASSWORD = "in_pw_Item";
    
    /// <summary>
    /// Max size for input that contains a long 
    /// </summary>
    public const int INPUT_MAXSIZE_LONG = 10;
    
    /// <summary>
    /// Max size for input that contains a double 
    /// </summary>
    public const int INPUT_MAXSIZE_DOUBLE = 30;
    
    /// <summary>
    /// Max size for input that contains a String 
    /// </summary>
    public const int INPUT_MAXSIZE_STRING = 80;
    
    /// <summary>
    /// Max length for String. 
    /// </summary>
    public const int INPUT_MAXLENGTH_STRING = 1333;
    
    /// <summary>
    /// Return HTML for text input box
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_strValue">Property value as string</param>
    /// <param name="_nInputMaxLength"></param>
    /// <param name="_nInputSize"></param>
    /// <returns>Input for text value</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLInput GetHTMLTextInput(int _nRowIndex, String _strValue,
     int _nInputMaxLength, int _nInputSize)
    {
      IExpListPropModelRO iModel = (IExpListPropModelRO) m_model;
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.TEXT, iModel.GetUniqueString(HTMLINPUT_ITEM) + _nRowIndex,
       "");
      myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      myInput.SetMaxLength(_nInputMaxLength);
      myInput.SetSize(_nInputSize);
      if (null != _strValue)
      {
        myInput.SetValue(_strValue);
      }
      return myInput;
    }
    
    /// <summary>
    /// Return HTML for text input box
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_strValue">Property value as string</param>
    /// <param name="_nInputMaxLength"></param>
    /// <param name="_nInputSize"></param>
    /// <returns>Input for text value</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLInput GetHTMLEncryptedInput(int _nRowIndex, String _strValue,
     int _nInputMaxLength, int _nInputSize)
    {
      IExpListPropModelRO iModel = (IExpListPropModelRO) m_model;
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.PASSWORD, iModel.GetUniqueString(HTMLINPUT_PASSWORD) + _nRowIndex,
       "");
      myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      myInput.SetMaxLength(_nInputMaxLength);
      myInput.SetSize(_nInputSize);
      if (null != _strValue)
      {
        myInput.SetValue(_strValue);
      }
      return myInput;
    }
    
    /// <summary>
    /// Returns HTML for display date/time value
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTML for date value</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLElement GetHTMLForDate(int _nRowIndex)
    {
      IExpListPropModelRO iModel = (IExpListPropModelRO) m_model;
      HTMLElementCollection result = new HTMLElementCollection();
      // Unique key for date/time picker
      String strUniqueKey = iModel.GetUniqueDateTimePickerKey(_nRowIndex);
      result.AddInnerHTMLElement(iModel.GetDateTimePickerControlManager().GetComponentHTML(strUniqueKey));
      return result;
    }
    
    /// <summary>
    /// Returns HTML for reference value
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTML for date value</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLElement GetHTMLForReferenceTree(int _nRowIndex,
     String strValue)
    {
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for a row in the list.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="oValue">Row value</param>
    /// <returns>HTML for row</returns>
    protected virtual HTMLElement GetHTMLElementForRow(int _nRowIndex, Object oValue)
    {
      IExpListPropModelRO iOPModel = (IExpListPropModelRO) m_model;
      int nValueType = iOPModel.GetRowType(_nRowIndex);
      switch (nValueType){
      case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
      // Date picker
      return GetHTMLForDate(_nRowIndex);
      goto case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE;
      case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
      // Input text box
      return GetHTMLTextInput(_nRowIndex, XPConvert.ToString(oValue), INPUT_MAXSIZE_DOUBLE,
       INPUT_MAXSIZE_DOUBLE);
      goto case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG;
      case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
      // Input text box
      return GetHTMLTextInput(_nRowIndex, XPConvert.ToString(oValue), INPUT_MAXSIZE_LONG,
       INPUT_MAXSIZE_LONG);
      goto case PT_PROPERTY_TYPES.PT_PROPTYPE_REF;
      case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
      // Reference tree
      return GetHTMLForReferenceTree(_nRowIndex, XPConvert.ToString(oValue));
      goto case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED;
      case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED:
      // Password box
      return GetHTMLEncryptedInput(_nRowIndex, XPConvert.ToString(oValue),
       INPUT_MAXLENGTH_STRING, INPUT_MAXSIZE_STRING);
      goto case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING;
      case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
      // Input text box
      return GetHTMLTextInput(_nRowIndex, XPConvert.ToString(oValue), INPUT_MAXLENGTH_STRING,
       INPUT_MAXSIZE_STRING);
      break;
      }
      return null;
    }
  }
}