using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.datepicker;
using com.plumtree.uiinfrastructure.pagecontrols.framework;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.jsutil;
namespace com.plumtree.portaluiinfrastructure.expandablelist.properties
{
  /// <summary>
  /// Expandable list model for properties
  /// </summary>
  /// <author>josephc</author>
  public abstract class ExpListPropModel : ExpListModel,IExpListPropModelRO
  {
    
    /// <summary>
    /// Prefix for unique ID of row containing datetime picker 
    /// </summary>
    public const String STR_ROW_PROPERTY_DATE_PICKER_UNIQUE_ID_PREFIX = "RowPropertyDP";
    
    /// <summary>
    /// Expandable list column for property ID 
    /// </summary>
    public const int EXPLIST_COL_PROPID = 0;
    
    /// <summary>
    /// Expandable list column for property value 
    /// </summary>
    public const int EXPLIST_COL_VALUE = 1;
    
    /// <summary>
    /// Expandable list column for property name 
    /// </summary>
    public const int EXPLIST_COL_NAME = 2;
    
    /// <summary>
    /// Expandable list column for property type 
    /// </summary>
    public const int EXPLIST_COL_TYPE = 3;
    
    /// <summary>
    /// Expandable list column for row status (no change, added, deleted, edited) 
    /// </summary>
    public const int EXPLIST_COL_STATUS = 4;
    
    /// <summary>
    /// Status of unchanged row 
    /// </summary>
    public const int ROW_STATUS_NO_CHANGE = 0;
    
    /// <summary>
    /// Status of newly added row 
    /// </summary>
    public const int ROW_STATUS_ADDED = 1;
    
    /// <summary>
    /// Status of modified row 
    /// </summary>
    public const int ROW_STATUS_MODIFIED = 2;
    
    /// <summary>
    /// DateTime picker control 
    /// </summary>
    protected JSDateTimePickerMgr m_ptJSDateTimePickerMgr;
    
    /// <summary>
    /// Page manager 
    /// </summary>
    protected PageMgr m_ptPageMgr;
    
    /// <summary>
    /// Inits the Model with the Activity Space.  Initializes date/time picker and page manager
    /// for date/time picker.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      // Deal with the page manager
      String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(parent.GetIsSecuredSpace());
      m_ptPageMgr = new PageMgr(m_asOwner.GetAccessStyle(), PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
       PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner),
       strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL,
       ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      JSDatePickerVersionMgr ptDatePickerVersionMgr = new JSDatePickerVersionMgr();
      // Deal with the date/time-picker
      m_ptJSDateTimePickerMgr = new JSDateTimePickerMgr(ptJSRegistry, ptDatePickerVersionMgr,
       m_ptPageMgr);
      m_ptPageMgr.RegisterComponentMgr(m_ptJSDateTimePickerMgr);
    }
    
    /// <summary>
    /// Returns the datetime-picker control manager.
    /// </summary>
    /// <returns>The datetime-picker control manager.</returns>
    public virtual JSDateTimePickerMgr GetDateTimePickerControlManager()
    {
      return m_ptJSDateTimePickerMgr;
    }
    
    /// <summary>
    /// Helper method to return XPDateTime from datetime picker, using the unique instance ID.
    /// </summary>
    /// <param name="_strUniqueInstanceID">The unique instance ID is the special prefix plus the row number.</param>
    /// <returns></returns>
    protected virtual XPDateTime GetDateTimeFromDatePicker(String _strUniqueInstanceID)
    {
      ADatePickerComponent ptJSDateTimePicker = (ADatePickerComponent) m_ptJSDateTimePickerMgr.GetComponent(_strUniqueInstanceID);
      if (null != ptJSDateTimePicker)
      {
        return ptJSDateTimePicker.GetDateTimeAsDateTime();
      } else
      {
        return null;
      }
    }
    
    /// <summary>
    /// Converts a property value from its string representation to the
    /// appropriate type.
    /// </summary>
    /// <param name="strValue">String value</param>
    /// <param name="nPropertyType">Property type</param>
    /// <returns>Property value as an Object</returns>
    /// <throws>Exception</throws>
    public static Object GetPropValueFromString(String strValue, int nPropertyType)
    {
      // Convert string value to object type
      Object oValue = null;
      if ((null != strValue) && (strValue.Length > 0))
      {
        switch (nPropertyType){
        case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
        oValue = XPConvert.ToDouble(strValue);
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
        case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
        oValue = XPConvert.ToInteger(strValue);
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
        case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED:
        oValue = strValue;
        break;
        default:
        break;
        }
      }
      return oValue;
    }
    
    /// <summary>
    /// Returns the name of the property in the indicated row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Name of property</returns>
    public virtual String GetRowName(int _nRowIndex)
    {
      return (String) m_saData.GetItem(_nRowIndex, EXPLIST_COL_NAME);
    }
    
    /// <summary>
    /// Returns the property ID of the property in the indicated row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Property ID</returns>
    public virtual int GetRowPropertyID(int _nRowIndex)
    {
      return XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, EXPLIST_COL_PROPID));
      }
    
    /// <summary>
    /// Returns the status of the row (added, deleted, edited, modified)
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Row status</returns>
    public virtual int GetRowStatus(int _nRowIndex)
    {
      return XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, EXPLIST_COL_STATUS));
      }
    
    /// <summary>
    /// Returns the value type of the property
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Value type of property</returns>
    public virtual int GetRowType(int _nRowIndex)
    {
      return XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, EXPLIST_COL_TYPE));
      }
    
    /// <summary>
    /// Returns the value of the property
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Value of property</returns>
    public virtual Object GetRowValue(int _nRowIndex)
    {
      return m_saData.GetItem(_nRowIndex, EXPLIST_COL_VALUE);
    }
    
    /// <summary>
    /// Returns the unique date/time picker string ID for the row.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    public virtual String GetUniqueDateTimePickerKey(int _nRowIndex)
    {
      return STR_ROW_PROPERTY_DATE_PICKER_UNIQUE_ID_PREFIX + _nRowIndex;
    }
    
    /// <summary>
    /// Set the row status
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_nStatus">Status of row</param>
    protected virtual void SetRowStatus(int _nRowIndex, int _nStatus)
    {
      m_saData.SetItem(_nRowIndex, EXPLIST_COL_STATUS, _nStatus);
    }
    
    /// <summary>
    /// Set the row value
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_oValue">Value of property in row</param>
    protected virtual void SetRowValue(int _nRowIndex, Object _oValue)
    {
      m_saData.SetItem(_nRowIndex, EXPLIST_COL_VALUE, _oValue);
    }
    
    /// <summary>
    /// Updates a row in the list with new values
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_oValue">Value of property in row</param>
    protected virtual void UpdateRowInList(int _nRowIndex, Object _oValue)
    {
      bool bUpdateRow = false;
      Object oPreviousValue = GetRowValue(_nRowIndex);
      if (null == _oValue)
      {
        // If the value is null and the previous value is not null, then update.
        if (null != oPreviousValue)
        {
          bUpdateRow = true;
        }
      } else
      {
        // If the value is not null and not equal to the previous value, then update.
        if (!_oValue.Equals(oPreviousValue))
        {
          bUpdateRow = true;
        }
      }
      if (bUpdateRow)
      {
        SetRowValue(_nRowIndex, _oValue);
        if (ROW_STATUS_NO_CHANGE == GetRowStatus(_nRowIndex))
        {
          SetRowStatus(_nRowIndex, ROW_STATUS_MODIFIED);
        }
      }
    }
    
    /// <summary>
    /// Saves the date/time value
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_htFormData">Form data</param>
    /// <returns>Valid if row is saved successfully. Invalid if mandatory and value is null.</returns>
    protected virtual int SaveDateTimeRow(int _nRowIndex, XPHashtable _htFormData)
    {
      UIError myError;
      int nStatus = RepostControl.PAGE_STATUS_VALID;
      nStatus = m_ptPageMgr.StoreAllUserInput(_htFormData);
      // if the status is invalid, print out error msgs stored in the page manager
      // page mgr holds errors msgs generated from storing all the inputs
      if (nStatus == RepostControl.PAGE_STATUS_INVALID)
      {
        myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_ptPageMgr.GetErrorMessages(m_asOwner), m_ptPageMgr.GetErrorMessages(m_asOwner));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      String strUniqueKey = GetUniqueDateTimePickerKey(_nRowIndex);
      XPDateTime myDateTime = GetDateTimeFromDatePicker(strUniqueKey);
      if (null != myDateTime)
      {
        UpdateRowInList(_nRowIndex, myDateTime);
      } else
      if (CheckRowIsMandatory(_nRowIndex))
      {
        // raise error to display to user
        String strErrorMsg = GetRowErrorMessage(_nRowIndex, m_asOwner.GetString(99,
         "ptmsgs_portalinfrastructure"));
        myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         strErrorMsg, strErrorMsg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
      return nStatus;
    }
    
    /// <summary>
    /// Returns data key for a row.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_htFormData">Form data</param>
    /// <returns>Data key for row</returns>
    protected virtual String GetDataKey(int _nRowIndex, XPHashtable _htFormData)
    {
      return GetUniqueString(ExpListPropEditView.HTMLINPUT_ITEM) + _nRowIndex;
      }
    
    /// <summary>
    /// Returns data key for a row.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_htFormData">Form data</param>
    /// <returns>Data key for row</returns>
    protected virtual String GetPasswordKey(int _nRowIndex, XPHashtable _htFormData)
    {
      return GetUniqueString(ExpListPropEditView.HTMLINPUT_PASSWORD) + _nRowIndex;
      }
    
    /// <summary>
    /// Check that a mandatory row does not have a null string value or empty string.
    /// Raise error if string value is null or empty string. 
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="strValue">String value</param>
    /// <returns>Valid if row is not mandatory or if it is mandatory and has non-empty value.</returns>
    protected virtual int ValidateMandatoryDataValue(int _nRowIndex, String strValue)
    {
      // Validate mandatory row
      if (CheckRowIsMandatory(_nRowIndex))
      {
        if ((null == strValue) || (0 == strValue.Length))
        {
          // raise error to display to user
          String strErrorMsg = GetRowErrorMessage(_nRowIndex, m_asOwner.GetString(99,
           "ptmsgs_portalinfrastructure"));
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           strErrorMsg, strErrorMsg);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          return RepostControl.PAGE_STATUS_INVALID;
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Saves the data value for the row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_htFormData">Form data</param>
    /// <returns>Valid if row was saved successfully.</returns>
    protected virtual int SaveDataValue(int _nRowIndex, XPHashtable _htFormData)
    {
      String sDataKey = GetDataKey(_nRowIndex, _htFormData);
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
        if (aDataValues.Length > 0)
        {
          Object oValue = null;
          String strValue = aDataValues[0];
          int nPropertyType = GetRowType(_nRowIndex);
          int nStatus = ValidateMandatoryDataValue(_nRowIndex, strValue);
          if (RepostControl.PAGE_STATUS_INVALID == nStatus)
          {
            return nStatus;
          }
          try
          {
            // Convert string to object
            oValue = GetPropValueFromString(strValue, nPropertyType);
          }
          catch (Exception e)
          {
            // There was a problem converting the string value to the object value.
            String strErrorMsg = GetRowErrorMessage(_nRowIndex, m_asOwner.GetString(98,
             "ptmsgs_portalinfrastructure"));
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             e, strErrorMsg, strErrorMsg);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            return RepostControl.PAGE_STATUS_INVALID;
          }
          // Update the value
          UpdateRowInList(_nRowIndex, oValue);
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Saves the data value for the row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_htFormData">Form data</param>
    /// <returns>Valid if row was saved successfully.</returns>
    protected virtual int SavePasswordValue(int _nRowIndex, XPHashtable _htFormData)
    {
      String sDataKey = GetPasswordKey(_nRowIndex, _htFormData);
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
        if (aDataValues.Length > 0)
        {
          Object oValue = null;
          String strValue = aDataValues[0];
          int nPropertyType = GetRowType(_nRowIndex);
          int nStatus = ValidateMandatoryDataValue(_nRowIndex, strValue);
          if (RepostControl.PAGE_STATUS_INVALID == nStatus)
          {
            return nStatus;
          }
          try
          {
            // Convert string to object
            oValue = GetPropValueFromString(strValue, nPropertyType);
          }
          catch (Exception e)
          {
            // There was a problem converting the string value to the object value.
            String strErrorMsg = GetRowErrorMessage(_nRowIndex, m_asOwner.GetString(98,
             "ptmsgs_portalinfrastructure"));
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             e, strErrorMsg, strErrorMsg);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            return RepostControl.PAGE_STATUS_INVALID;
          }
          // Update the value
          if (oValue != null)
          {
            // Should we update the row with null if it does equal NULL_PASSWORD?
            if (!(oValue.Equals(PlumtreeExtensibility.STR_NULL_PASSWORD)))
            {
              UpdateRowInList(_nRowIndex, oValue);
            }
          } else
          {
            // Do we want to be updating this with null here?
            UpdateRowInList(_nRowIndex, null);
          }
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Return an error message for row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="strMessage">Message</param>
    /// <returns>Error message for row</returns>
    protected virtual String GetRowErrorMessage(int _nRowIndex, String strMessage)
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      String strPropertyName = GetRowName(_nRowIndex);
      sb.Append(strPropertyName).Append(": ");
      sb.Append(strMessage);
      return sb.ToString();
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      int nPropertyType = GetRowType(_nRowIndex);
      try
      {
        switch (nPropertyType){
        case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
        return SaveDateTimeRow(_nRowIndex, _htFormData);
        goto case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
        case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
        case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
        return SaveDataValue(_nRowIndex, _htFormData);
        goto case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED:
        return SavePasswordValue(_nRowIndex, _htFormData);
        goto case PT_PROPERTY_TYPES.PT_PROPTYPE_REF;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
        return RepostControl.PAGE_STATUS_VALID;
        goto default;
        default:
        return RepostControl.PAGE_STATUS_INVALID;
        break;
        }
      }
      catch (Exception e)
      {
        return RepostControl.PAGE_STATUS_INVALID;
      }
    }
    
    /// <summary>
    /// Remove all existing datetime components from the datetime picker manager, and
    /// re-register all datetime pickers.  This method must be called whenever the expandable
    /// list is modified (whenever rows are added or deleted) because the row numbers, which
    /// are used to construct the unique key, are changed.
    /// </summary>
    protected virtual void UpdateDateTimeUniqueKeys()
    {
      // Remove first component in the list until no more components
      while (0 < m_ptJSDateTimePickerMgr.GetNumComponents())
      {
        AComponent ptJSComponent = m_ptJSDateTimePickerMgr.GetComponent(0);
        m_ptJSDateTimePickerMgr.UnRegisterComponent(ptJSComponent.GetUniqueInstanceID());
        }
      // Iterate through all rows and re-register all date-time pickers
      for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
      {
        Object oValue = GetRowValue(nRowIndex);
        if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == GetRowType(nRowIndex))
        {
          String strUniqueKey = GetUniqueDateTimePickerKey(nRowIndex);
          ADatePickerComponent ptJSDateTimePicker;
          if ((null == oValue) || oValue.Equals(""))
          {
            ptJSDateTimePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DateTimePicker");
            ptJSDateTimePicker.Init(AFormDP.HTMLFORM_NAME, m_ptPageMgr, strUniqueKey);
            } else
          {
            ptJSDateTimePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DateTimePicker");
            ptJSDateTimePicker.Init(AFormDP.HTMLFORM_NAME, (XPDateTime) oValue,
             m_ptPageMgr, strUniqueKey);
          }
          m_ptJSDateTimePickerMgr.RegisterComponent(ptJSDateTimePicker);
        }
      }
    }
    
    /// <summary>
    /// Implemented by the child class in order to load the properties.
    /// </summary>
    protected abstract void LoadProperties();
    
    /// <summary>
    /// Implemented by the child class in order to save the properties.
    /// </summary>
    public abstract void Finish();
    
    /// <summary>
    /// Check whether row is mandatory
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>True if row is mandatory</returns>
    public abstract bool CheckRowIsMandatory(int _nRowIndex);
    
    /// <summary>
    /// Must update date/time picker rows when sorting by column.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void SortByColumn(XPHashtable _htFormData)
    {
      base.SortByColumn(_htFormData);
      UpdateDateTimeUniqueKeys();
    }
    
    /// <summary>
    /// Must update date/time picker rows when sorting by column.
    /// </summary>
    public override void ReverseCurrentSort()
    {
      base.ReverseCurrentSort();
      UpdateDateTimeUniqueKeys();
    }
  }
}