using System;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
namespace com.plumtree.portaluiinfrastructure.expandablelist.properties
{
  /// <summary>
  /// Read-only interface for expandable list of properties model.
  /// </summary>
  /// <author>josephc</author>
  public interface IExpListPropModelRO : IExpListModelRO
  {
    
    /// <summary>
    /// Returns the name of the property in the indicated row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Name of property</returns>
    String GetRowName(int _nRowIndex);
    
    /// <summary>
    /// Returns the property ID of the property in the indicated row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Property ID</returns>
    int GetRowPropertyID(int _nRowIndex);
    
    /// <summary>
    /// Returns the status of the row (added, deleted, edited, modified)
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Row status</returns>
    int GetRowStatus(int _nRowIndex);
    
    /// <summary>
    /// Returns the value type of the property
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Value type of property</returns>
    int GetRowType(int _nRowIndex);
    
    /// <summary>
    /// Returns the value of the property
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Value of property</returns>
    Object GetRowValue(int _nRowIndex);
    
    /// <summary>
    /// Returns the datetime-picker control manager.
    /// </summary>
    /// <returns>The datetime-picker control manager.</returns>
    JSDateTimePickerMgr GetDateTimePickerControlManager();
    
    /// <summary>
    /// Returns the unique date/time picker string ID for the row.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    String GetUniqueDateTimePickerKey(int _nRowIndex);
  }
}