using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.expandablelist.selectptobject
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the Select PTObject list.
  /// Is constains the HTML to display the object Array.
  /// It gets the data to display from SelectPTObjectModel.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SelectPTObjectView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.SelectPTObjectView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SelectPTObject";
    
    /// <summary>
    /// HTML Object names 
    /// </summary>
    public const String HTMLINPUT_TREEASID = "in_hi_TreeSpaceID";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SelectPTObjectView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      //SE: logging
      log.FunctionBegin("SelectPTObjectView::DisplayJavascript");
      HTMLScript myScript = base.DisplayJavascript();
      // The URL to open a new tree
      ASURL myNewTree = new ASURL(m_asOwner);
      myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myNewTree.SetSubSpaceKey(((ISelectPTObjectModelRO) m_model).GetUniqueString(SelectPTObjectModel.SUBSPACE_KEY_SELECTTREE));
      myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
      myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, ((ISelectPTObjectModelRO) m_model).GetTreeMultiSelect());
      myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetTreeLeafType()));
      myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       ((ISelectPTObjectModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID));
      myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, ((ISelectPTObjectModelRO) m_model).GetUniqueString("OnReturnFromTree"));
      myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       ((ISelectPTObjectModelRO) m_model).GetObjectClassIDs());
      myNewTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetAccessLevel()));
      String strSelectedItems = ((ISelectPTObjectModelRO) m_model).GetSelectedItems();
      if (strSelectedItems.Length < 100)
      {
        myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, strSelectedItems);
        } else
      {
        // This list can be quite long for users, so we need to pass
        // it by reference.
        myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, strSelectedItems,
         m_asOwner);
      }
      if (null != ((ISelectPTObjectModelRO) m_model).GetTreeTitle())
      {
        myNewTree.AddControlArgument(StartTreeControl.TITLE, ((ISelectPTObjectModelRO) m_model).GetTreeTitle());
        }
      if (null != ((ISelectPTObjectModelRO) m_model).GetTreeSubTitle())
      {
        myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, ((ISelectPTObjectModelRO) m_model).GetTreeSubTitle());
        }
      if (null != ((ISelectPTObjectModelRO) m_model).GetDisplayObjects())
      {
        myNewTree.AddControlArgument(StartTreeControl.DISPLAYED_ITEMS, ((ISelectPTObjectModelRO) m_model).GetDisplayObjects());
        }
      if (!("").Equals(((ISelectPTObjectModelRO) m_model).GetHiddenObjects()))
      {
        myNewTree.AddControlArgument(StartTreeControl.HIDDEN_ITEMS, ((ISelectPTObjectModelRO) m_model).GetHiddenObjects());
        }
      if (!("").Equals(((ISelectPTObjectModelRO) m_model).GetTreeQueryFilter()))
      {
        myNewTree.AddControlArgument(StartTreeControl.QUERY_FILTER, ((ISelectPTObjectModelRO) m_model).GetTreeQueryFilter());
        }
      // Default (no mode set) returns 0.
      int nCommunityMode = ((ISelectPTObjectModelRO) m_model).GetCommunityMode();
      if (0 < ((ISelectPTObjectModelRO) m_model).GetCommunityFolderID())
      {
        nCommunityMode = AObjectTreeModel.THISCOMMUNITY;
        myNewTree.AddControlArgument(StartTreeControl.COMMUNITY_FOLDER_ID,
         ((ISelectPTObjectModelRO) m_model).GetCommunityFolderID());
      }
      if (0 < nCommunityMode)
      {
        myNewTree.AddControlArgument(StartTreeControl.COMMUNITY_MODE, nCommunityMode);
        }
      // The url to open a previously opened server user tree
      // This needs to have the SpaceID added to it.
      ASURL myOldTree = new ASURL(m_asOwner);
      myOldTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myOldTree.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
      myOldTree.IsSubSpace();
      if (strSelectedItems.Length < 100)
      {
        myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, strSelectedItems);
        } else
      {
        // This list can be quite long for users, so we need to pass
        // it by reference.
        myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, strSelectedItems,
         m_asOwner);
      }
      if (!("").Equals(((ISelectPTObjectModelRO) m_model).GetHiddenObjects()))
      {
        myOldTree.AddControlArgument(StartTreeControl.HIDDEN_ITEMS, ((ISelectPTObjectModelRO) m_model).GetHiddenObjects());
        }
      XPStringBuilder sb;
      try
      {
        // Open Tree function
        sb = new XPStringBuilder(200);
        sb.Append("function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("OpenTree") + "(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(myNewTree.GetURLAsString()).Append("\', \'_SelectPTObjectTree\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(myOldTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_SelectPTObjectTree\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // On return from Tree function
        sb = new XPStringBuilder(200);
        sb.Append(" function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("OnReturnFromTree") + "()");
        sb.Append(" {");
        sb.Append(" \tpostToSelf(\'" + ((ISelectPTObjectModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "\');");
        sb.Append(" }");
        myScript.AddInnerHTMLString(sb.ToString());
        // Create new object
        sb = new XPStringBuilder(200);
        sb.Append(" function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("CreateNew") + "(varURL)");
        sb.Append(" {");
        sb.Append("    window.open(varURL,\'");
        sb.Append(((ISelectPTObjectModelRO) m_model).GetUniquePopUpName("PopUpCreateMode"));
        sb.Append("\',\'location=no,menubar=no,scrollbars,resizable,height=600,width=800\');\n");
        sb.Append(" }");
        myScript.AddInnerHTMLString(sb.ToString());
        // Edit object
        sb = new XPStringBuilder(200);
        sb.Append(" function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("EditObject") + "(varURL,varIndex)");
        sb.Append(" {");
        sb.Append("    window.open(varURL,\'");
        sb.Append(((ISelectPTObjectModelRO) m_model).GetUniquePopUpName("PopUpEditMode"));
        sb.Append("\' + varIndex,\'location=no,menubar=no,scrollbars,resizable,height=600,width=800\');\n");
        sb.Append(" }");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "SelectPTObjectView::DisplayJavascript An error occured when trying to display the JavaScript.");
        }
      //SE: logging
      log.FunctionEnd("SelectPTObjectView::DisplayJavascript");
      return myScript;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      //SE: logging
      log.FunctionBegin("SelectPTObjectView::GetHTMLForRow");
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      if (((ISelectPTObjectModelRO) m_model).GetEnableMoveRowActions())
      {
        result.AddInnerHTMLElement(base.GetHTMLForMoveRowActions(_nRowIndex));
        }
      //SE: logging
      log.FunctionEnd("SelectPTObjectView::GetHTMLForRow");
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Empty method that sub classes can averride to add
    /// actions to the action bar (like a create object action).
    /// </summary>
    /// <param name="_myRow">Action bar row object.</param>
    /// <throws>Exception</throws>
    protected override void AddHTMLToActionBar(HTMLTableRow _myRow)
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myCreateIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      //SE: logging
      log.FunctionBegin("SelectPTObjectView::AddHTMLToActionBar");
      ISelectPTObjectModelRO myROModel = (ISelectPTObjectModelRO) m_model;
      Object[][] arrCreateNewInfo = (Object[][]) myROModel.GetCreateNewInfo();
      // JF- We are only displaying the create new buttons if we have all the required info 
      // and also if the tree is single select, we only display it if the list is empty.
      if ((null != arrCreateNewInfo) && (XPConvert.ToBoolean(myROModel.GetTreeMultiSelect()) || (0 == myROModel.GetReadOnlyItems().GetCount())))
      {
        for (int i = 0;i < arrCreateNewInfo.Length;i++)
        {
          int nClassID = XPConvert.ToInteger(arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_CLASSID]);
          String sEditorASName = (String) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_ASNAME];
          ASURL myURL = ((ISelectPTObjectModelRO) m_model).GetCreateNewURL(nClassID,
           sEditorASName);
          myCell = new HTMLTableCell();
          _myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("25");
          myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
          myCell.SetNoWrap(true);
          // Create new icon
          myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
           true, this.m_asOwner);
          myCreateIcon = (HTMLImg) myConstruct.GetHTMLElement();
          myCreateIcon.SetAlt("");
          myCreateIcon.SetAlign("absmiddle");
          // object icon
          myConstruct = UIConstructFactory.GetConstruct((PTImageType) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_ICON],
           true, this.m_asOwner);
          myImage = (HTMLImg) myConstruct.GetHTMLElement();
          myImage.SetAlt("");
          myImage.SetAlign("absmiddle");
          myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          myAnchor.AddInnerHTMLString(SPACE);
          myAnchor.SetOnClick(((ISelectPTObjectModelRO) m_model).GetUniqueString("CreateNew") + "(\'" + myURL.GetURLAsString() + "\'); return false;");
          myAnchor.AddInnerHTMLElement(myCreateIcon);
          myAnchor.AddInnerHTMLElement(myImage);
          mySpan = new HTMLSpan();
          myAnchor.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
          // Create label
          mySpan.AddInnerHTMLString((String) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_LABEL]);
          mySpan.AddInnerHTMLString(SPACE);
          mySpan.AddInnerHTMLString(SPACE);
          myCell.AddInnerHTMLElement(myAnchor);
        }
      }
      //SE: logging
      log.FunctionEnd("SelectPTObjectView::AddHTMLToActionBar");
    }
    
    /// <summary>
    /// Helper method to return the add action link.
    /// </summary>
    /// <returns>HTMLAnchor</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLAnchor GetAnchorForAddAction()
    {
      HTMLAnchor myAnchor;
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(((ISelectPTObjectModelRO) m_model).GetUniqueString("OpenTree") + "(document." + AFormDP.HTMLFORM_NAME + "." + ((ISelectPTObjectModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID) + "); return false;");
      return myAnchor;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      //SE: logging
      log.FunctionBegin("SelectPTObjectView::GetHTMLForAddAction");
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      myAddIcon.SetAlt("");
      myAddIcon.SetAlign("absmiddle");
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(((ISelectPTObjectModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      myAnchor = GetAnchorForAddAction();
      myAnchor.AddInnerHTMLString(SPACE);
      myAnchor.AddInnerHTMLElement(myAddIcon);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(((ISelectPTObjectModelRO) m_model).GetAddLabel());
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      // hidden input with the tree space ID
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ((ISelectPTObjectModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID),
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((ISelectPTObjectModelRO) m_model).GetTreeSpaceID());
      //SE: logging
      log.FunctionEnd("SelectPTObjectView::GetHTMLForAddAction");
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      //SE: logging
      log.FunctionBegin("SelectPTObjectView::GetHTMLForNameColumn");
      myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // RWW: we modify to get the class id first, then 
      // try to associate a row icon with the class id.
      // this way we can have different row icons dep.
      // on what the class of the object is.
      // RWW: Retrieve object name and class id.
      String sPTObjectName = (String) _saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_STRING);
      int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_CLASSID));
      // RWW: Retrieve icon based on class id (note that we are now using
      // the "GetRowIconByClassID" method. If there is no specific
      // image assigned to this class id, then it will use the default
      // class id. if that is null, then there will be no image).
      if (false == ((ISelectPTObjectModelRO) m_model).GetNoRowIcons())
      {
        PTImageType imgRowIcon = ((ISelectPTObjectModelRO) m_model).GetRowIconByClassID(nClassID);
        if (null != imgRowIcon)
        {
          myCell.AddInnerHTMLElement(GetIcon(imgRowIcon));
          myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        } else
        {
          //Use the ClassDescriptor framework to attempt to get the icon for the class.
          //Do this only as a last resort so we don't change existing peoples' functionality
          ClassTypeDescManager ptObjDescMgr = PTConfigHelper.GetPTClassTypeDescrManager();
          String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
           m_asOwner);
          HTMLImg iconImage = ptObjDescMgr.GetDefaultIconForClassType(nClassID,
           strLangID);
          if (null != iconImage)
          {
            myCell.AddInnerHTMLElement(iconImage);
          }
        }
      }
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      HTMLImg spacerImage = (HTMLImg) myConstruct.GetHTMLElement();
      spacerImage.SetAlt("---");
      spacerImage.SetWidth(CommonHTMLStrings.FIVE);
      spacerImage.SetBorder("0");
      myCell.AddInnerHTMLElement(spacerImage);
      if (((ISelectPTObjectModelRO) m_model).IsEditLinkEnabled(nClassID))
      {
        // JF- We are displaying the link to Edit the object
        int nObjectID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
        ASURL myURL = ((ISelectPTObjectModelRO) m_model).GetEditObjectURL(nClassID,
         nObjectID);
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(((ISelectPTObjectModelRO) m_model).GetUniqueString("EditObject") + "(\'" + myURL.GetURLAsString() + "\',\'" + _nRowIndex + "\'); return false;");
        myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sPTObjectName));
        myCell.AddInnerHTMLElement(myAnchor);
      } else
      {
        // JF- We are just displaying the object name
        myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sPTObjectName));
        }
      //SE: logging
      log.FunctionEnd("SelectPTObjectView::GetHTMLForNameColumn");
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the checkbox on row _nRowIndex.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)
    {
      HTMLTableCell myCell;
      ISelectPTObjectModelRO myROModel = (ISelectPTObjectModelRO) m_model;
      IPTGrowableSortedArrayWrapperRO saData = myROModel.GetReadOnlyItems();
      int nClassID = XPConvert.ToInteger(saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_CLASSID));
      int nObjectID = XPConvert.ToInteger(saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
      bool bIsObjectReadOnly = ((ISelectPTObjectModelRO) m_model).IsObjectReadOnly(nClassID,
       nObjectID);
      if (bIsObjectReadOnly)
      {
        myCell = new HTMLTableCell();
        myCell.SetWidth("20");
        myCell.SetHeight("30");
        myCell.SetAlign("center");
        myCell.SetVAlign("middle");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      } else
      {
        myCell = base.GetHTMLForCheckBox(_nRowIndex);
      }
      return myCell;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      return (myImage);
    }
  }
}