using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.portaluiinfrastructure.tree.template;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.expandablelist.template
{
  /// <author>michaeld</author>
  public class TemplateListView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.expandablelist.template.TemplateListView");
    public const String STR_MVC_CLASS_NAME = "TemplateList";
    
    /// <summary>
    /// Template Tree Space ID 
    /// </summary>
    public const String HTMLINPUT_TEMPLATETREEASID = "in_hi_TemplateTreeSpaceID";
    
    /// <summary>
    /// Javascript function names - do not need to localize *
    /// </summary>
    private const String JAVASCRIPT_SELECT_TEMPLATE = "selectTemplate";
    private const String JAVASCRIPT_ONRETURN_SELECT_TEMPLATE = "onReturnSelectTemplate";
    
    /// <summary>
    /// Returns the HTML for the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    protected override HTMLTable GetHTMLForActionBar()
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myTable = new HTMLTable();
      myTable.SetBorder("0");
      myTable.SetCellPadding("0");
      myTable.SetCellSpacing("0");
      // 1st Row begin (there is only one row)
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      // Add icon cell
      myRow.AddInnerHTMLElement(GetHTMLForAddAction());
      // Empty Cell
      myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
      // Last Empty Cell
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetHeight("25");
      myCell.AddInnerHTMLString(SPACE);
      // 1st Row ends
      return myTable;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      myAnchor = ConstructStaticHelpers.GetJavascriptAnchor("", JAVASCRIPT_SELECT_TEMPLATE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_TEMPLATETREEASID + ")");
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(SPACE);
      // Hidden input for space of community template selection tree control
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_TEMPLATETREEASID,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((ITemplateListModelRO) m_model).GetInputValue(HTMLINPUT_TEMPLATETREEASID));
      return myCell;
    }
    
    /// <summary>
    /// Helper method for empty cell between actions
    /// in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    protected override HTMLTableCell GetHTMLForEmptyCellInActionBar()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER, true,
       this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetWidth("1");
      myImage.SetHeight("1");
      myImage.SetBorder("0");
      myCell.AddInnerHTMLElement(myImage);
      return myCell;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO,int)"></seealso>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // Object Name
      String strTemplateName = XPConvert.ToString(_saData.GetItem(_nRowIndex,
       TemplateListModel.EXPLIST_COL_TEMPLATE_NAME));
      // tiny space between document and name of page
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetWidth(CommonHTMLStrings.FIVE);
      myImage.SetBorder("0");
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
       m_asOwner);
      if (null == strTemplateName || "".Equals(strTemplateName))
      {
        // row icon
        myCell.AddInnerHTMLElement(ptClassTypeDescManager.GetDefaultIconForClassType(((ITemplateListModelRO) m_model).GetTemplateClassID(),
         strLangID));
        myCell.AddInnerHTMLElement(myImage);
        myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(535, "ptmsgs_portalinfrastructure"));
        } else
      {
        /*
         * TODO - MJD : turn this in to a link to a read only editor at some point
         * HTMLAnchor myAnchor = ConstructStaticHelpers.GetJavascriptAnchor(
         PTOpenerLinks.GetJSOpenInNewWindow(
         PTOpenerLinks.GetOpenerJSURLOpenObjID(
         ((ITemplateListModelRO) m_model).GetTemplateClassID(),
         XPConvert.ToInteger(_saData.GetItem(_nRowIndex, TemplateListModel.EXPLIST_COL_TEMPLATE_ID)),
         "&"+ASConstants.SUBSPACE+"="+TemplateListModel.SUBSPACE_NAME_COMMTEMP,
         IPTOpenerConstants.OPENER_MODE_EDIT),
         PTOpenerLinks.GetWindowName("" + ((ITemplateListModelRO) m_model).GetTemplateClassID()
         + "_" + XPConvert.ToInteger(_saData.GetItem(_nRowIndex, TemplateListModel.EXPLIST_COL_TEMPLATE_ID)))
         , "800", "800", false));
         myCell.AddInnerHTMLElement(myAnchor);
         
         // row icon
         myAnchor.AddInnerHTMLElement(
         ptClassTypeDescManager.GetDefaultIconForClassType(
         ((ITemplateListModelRO) m_model).GetTemplateClassID(), strLangID));
         
         myAnchor.AddInnerHTMLElement(myImage);
         
         myAnchor.AddInnerHTMLEncodedString(strTemplateName);
         */
         
        // row icon
        myCell.AddInnerHTMLElement(ptClassTypeDescManager.GetDefaultIconForClassType(((ITemplateListModelRO) m_model).GetTemplateClassID(),
         strLangID));
        myCell.AddInnerHTMLElement(myImage);
        myCell.AddInnerHTMLEncodedString(strTemplateName);
      }
      return myCell;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      ASURL myNewTree;
      ASURL myOldTree;
      XPStringBuilder sb;
      HTMLScript script = base.DisplayJavascript();
      if (null == script)
      {
        script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      }
      // The url to open a previously opened tree
      // This needs to have the SpaceID added to it within the javascript function
      myOldTree = new ASURL(m_asOwner);
      myOldTree.SetLinkCreateNewSpace(TemplateTreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myOldTree.IsSubSpace();
      // The URL to open a new tree to select a community template
      myNewTree = new ASURL(m_asOwner);
      myNewTree.SetLinkCreateNewSpace(TemplateTreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myNewTree.SetSubSpaceKey(TemplateListModel.SUBSPACE_NAME_SELECTTEMPLATETREE);
      myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
      myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
      myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, TreeConstants.N_SERVERSUBMIT);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       HTMLINPUT_TEMPLATETREEASID);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, JAVASCRIPT_ONRETURN_SELECT_TEMPLATE);
      myNewTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(311,
       "ptmsgs_portalbrowsingmsgs"));
      myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(312,
       "ptmsgs_portalbrowsingmsgs"));
      myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       ((ITemplateListModelRO) m_model).GetTemplateClassID());
      IPTGrowableSortedArrayWrapperRO saData = ((IExpListModelRO) m_model).GetReadOnlyItems();
      if (0 < saData.GetCount())
      {
        myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, ((ITemplateListModelRO) m_model).GetTemplateClassID() + "," + XPConvert.ToInteger(saData.GetItem(0,
         TemplateListModel.EXPLIST_COL_TEMPLATE_ID)));
      }
      try
      {
        // Open Tree function
        sb = new XPStringBuilder(200);
        sb.Append("\n" + "function ").Append(JAVASCRIPT_SELECT_TEMPLATE).Append("(myInput)\n").Append("{\n").Append("  if (myInput.value == \'\') {\n").Append("    window.open(\'").Append(myNewTree.GetURLAsString()).Append("\', \'Templates\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n").Append("  } else {\n").Append("    window.open(\'").Append(myOldTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'Templates\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n").Append("  }\n").Append("}\n");
        script.AddInnerHTMLString(sb.ToString());
        // On return from Tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JAVASCRIPT_ONRETURN_SELECT_TEMPLATE).Append("()\n").Append("{\n").Append("\tpostToSelf(\'").Append(((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD)).Append("\');\n").Append("}\n");
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "CommunityTemplateSelectorView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return script;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      return (myImage);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TemplateListView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}