using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openkernel.sharedcache;
namespace com.plumtree.portaluiinfrastructure.failover
{
  /// <summary>
  /// This class stores info about a cookie.
  /// </summary>
  /// <author>ErickS, JosephC </author>
  public class CookieInfo
  {
    private static String STR_NAME = "NAME";
    private static String STR_VALUE = "VALUE";
    private static String STR_DOMAIN = "DOMAIN";
    private static String STR_PATH = "PATH";
    private static String STR_SECURE = "SECURE";
    private static String STR_EXPIRE = "EXPIRE";
    private String m_strName;
    private String m_strValue;
    private String m_strDomain;
    private String m_strPath;
    private bool m_bSecure;
    private XPDateTime m_dtExpire;
    
    /// <summary>
    /// Creates a new CookieInfo object.
    /// </summary>
    /// <param name="strName">DOCUMENT_ME</param>
    /// <param name="strVal">DOCUMENT_ME</param>
    /// <param name="strDomain">DOCUMENT_ME</param>
    /// <param name="strPath">DOCUMENT_ME</param>
    /// <param name="bSecure">DOCUMENT_ME</param>
    /// <param name="dtExpire">DOCUMENT_ME</param>
    public CookieInfo(String strName, String strVal, String strDomain, String strPath,
     bool bSecure, XPDateTime dtExpire)
    {
      m_strName = strName;
      m_strValue = strVal;
      m_strDomain = strDomain;
      m_strPath = strPath;
      m_bSecure = bSecure;
      m_dtExpire = dtExpire;
    }
    
    /// <summary>
    /// Creates a new CookieInfo object.
    /// </summary>
    /// <param name="cacheNode">DOCUMENT_ME</param>
    public CookieInfo(IOKSharedCacheNode cacheNode)
    {
      m_strName = (String) cacheNode.GetElement(STR_NAME);
      m_strValue = (String) cacheNode.GetElement(STR_VALUE);
      m_strDomain = (String) cacheNode.GetElement(STR_DOMAIN);
      m_strPath = (String) cacheNode.GetElement(STR_PATH);
      int iSecure = XPConvert.ToInteger(cacheNode.GetElement(STR_SECURE));
      if (1 == iSecure)
      {
        m_bSecure = true;
      } else
      {
        m_bSecure = false;
      }
      m_dtExpire = (XPDateTime) cacheNode.GetElement(STR_EXPIRE);
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual String GetName()
    {
      return m_strName;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual String GetValue()
    {
      return m_strValue;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual String GetDomain()
    {
      return m_strDomain;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual String GetPath()
    {
      return m_strPath;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual bool GetSecure()
    {
      return m_bSecure;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual XPDateTime GetDateExpire()
    {
      return m_dtExpire;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual IOKSharedCacheNode GetCacheNode()
    {
      IOKSharedCacheNode spBag = ReplicationCache.GetSharedCache().CreateNode();
      spBag.PutElement(STR_NAME, m_strName);
      spBag.PutElement(STR_VALUE, m_strValue);
      spBag.PutElement(STR_DOMAIN, m_strDomain);
      spBag.PutElement(STR_PATH, m_strPath);
      if (m_bSecure)
      {
        spBag.PutElement(STR_SECURE, 1);
      } else
      {
        spBag.PutElement(STR_SECURE, 0);
      }
      if (null != m_dtExpire)
      {
        spBag.PutElement(STR_EXPIRE, m_dtExpire);
      }
      return spBag;
    }
  }
}