using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openkernel.config;
using com.plumtree.openkernel.factory;
using com.plumtree.openkernel.http;
using com.plumtree.openkernel.sharedcache;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.xpshared.config;
namespace com.plumtree.portaluiinfrastructure.failover
{
  /// <summary>
  /// This class handles the ReplicationCache
  /// </summary>
  /// <author>ErickS, JosephC</author>
  public class ReplicationCache
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.failover.ReplicationCache");
    
    /// <summary>
    /// DOCUMENT ME!
    /// </summary>
    public static int CLEANUP_MINUTES = 30;
    
    /// <summary>
    /// DOCUMENT ME!
    /// </summary>
    public const String DATE_EXPIRED = "DATE_EXPIRED";
    
    /// <summary>
    /// DOCUMENT ME!
    /// </summary>
    public const String COOKIES = "COOKIES";
    
    /// <summary>
    /// DOCUMENT ME!
    /// </summary>
    public const String SESSION_PREFS = "SESSION_PREFS";
    
    /// <summary>
    /// whether or not the replication cache has already been initialized. 
    /// </summary>
    private static bool m_initialized = false;
    private static bool m_enabled = false;
    private static IOKSharedCache m_sharedCache;
    private static XPDateTime m_lastCleanupDate;
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public static IOKSharedCache GetSharedCache()
    {
      return m_sharedCache;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    /// <returns>DOCUMENT_ME</returns>
    public static IOKSharedCacheNode GetCookies(String replicationToken)
    {
      String[] key = new String[]{replicationToken, ReplicationCache.COOKIES};
      return (IOKSharedCacheNode) ReplicationCache.GetSharedCache().GetElement(key);
      }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    /// <param name="segment">DOCUMENT_ME</param>
    /// <param name="cookie">DOCUMENT_ME</param>
    public static void SetCookie(String replicationToken, String segment,
     IOKHttpCookie cookie)
    {
      CookieInfo cookieInfo = new CookieInfo(cookie.Name(), cookie.Value(),
       cookie.Domain(), cookie.Path(), cookie.Secure(), cookie.DateExpire());
      String[] cookieKey = new String[]{replicationToken, ReplicationCache.COOKIES,
       segment};
      lock (ReplicationCache.GetSharedCache()) {
        ReplicationCache.GetSharedCache().PutElement(cookieKey, cookieInfo.GetCacheNode());
        }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    /// <returns>DOCUMENT_ME</returns>
    public static IOKSharedCacheNode GetSessionPrefs(String replicationToken)
    {
      String[] key = new String[]{replicationToken, ReplicationCache.SESSION_PREFS};
      return (IOKSharedCacheNode) ReplicationCache.GetSharedCache().GetElement(key);
      }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    /// <param name="sessionPref">DOCUMENT_ME</param>
    /// <param name="prefValue">DOCUMENT_ME</param>
    public static void SetSessionPref(String replicationToken, String sessionPref,
     String prefValue)
    {
      String[] key = new String[]{replicationToken, ReplicationCache.SESSION_PREFS,
       sessionPref};
      lock (ReplicationCache.GetSharedCache()) {
        ReplicationCache.GetSharedCache().PutElement(key, prefValue);
      }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    /// <param name="sessionPref">DOCUMENT_ME</param>
    public static void RemoveSessionPref(String replicationToken, String sessionPref)
    {
      String[] key = new String[]{replicationToken, ReplicationCache.SESSION_PREFS,
       sessionPref};
      ReplicationCache.GetSharedCache().RemoveElement(key);
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    /// <returns>DOCUMENT_ME</returns>
    public static XPDateTime GetLastModified(String replicationToken)
    {
      String[] key = new String[]{replicationToken, ReplicationCache.DATE_EXPIRED};
      return (XPDateTime) ReplicationCache.GetSharedCache().GetElement(key);
      }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    /// <param name="lastModified">DOCUMENT_ME</param>
    public static void SetLastModified(String replicationToken, XPDateTime lastModified)
    {
      String[] dateKey = new String[]{replicationToken, ReplicationCache.DATE_EXPIRED};
      lock (m_sharedCache) {
        ReplicationCache.GetSharedCache().PutElement(dateKey, lastModified);
        }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    public static void Remove(String replicationToken)
    {
      lock (m_sharedCache) {
        m_sharedCache.RemoveElement(replicationToken);
      }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="vpConfig">DOCUMENT_ME</param>
    public static void StaticInit(PTConfigVarPack vpConfig)
    {
      if (m_initialized)
      {
        log.Error("ReplicationCache StaticInit attempted twice.  Ignoring second attempt.");
        return;
      }
      m_initialized = true;
      m_lastCleanupDate = new XPDateTime();
      try
      {
        String sReplicationCacheName;
        if (null != vpConfig)
        {
          sReplicationCacheName = vpConfig.GetConfigValueAsString("Failover",
           "ClusterName", "value");
        } else
        {
          sReplicationCacheName = "MyTestRC";
        }
        String configpath = ConfigPathResolver.GetOpenConfigPath();
        IOKContext myConfigContext = OKConfigFactory.createInstance(configpath,
         "portal");
        IOKSharedCachingService factory = OKSharedCacheFactory.getInstance(myConfigContext);
        m_sharedCache = factory.CreateCache(sReplicationCacheName);
        log.Info("Finished initializing ReplicationCache");
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to init replication cache");
      }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="enabled">DOCUMENT_ME</param>
    public static void SetEnabled(bool enabled)
    {
      lock (typeof(ReplicationCache)) {
        m_enabled = enabled;
      }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public static bool GetEnabled()
    {
      lock (typeof(ReplicationCache)) {
        return m_enabled;
      }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="dt">DOCUMENT_ME</param>
    /// <param name="expireMinutes">DOCUMENT_ME</param>
    /// <returns>DOCUMENT_ME</returns>
    public static bool IsExpired(XPDateTime dt, int expireMinutes)
    {
      long elapsedTime = XPSystem.GetCurrentTimeMilliSec() - dt.GetTimeInMilliSeconds();
      /*milliseconds in a second*/
      long expireMilliseconds = expireMinutes * 60 * 1000;
      return (expireMilliseconds <= elapsedTime);
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="numMinutes">DOCUMENT_ME</param>
    public static void SetCleanUpMinutes(int numMinutes)
    {
      lock (typeof(ReplicationCache)) {
        CLEANUP_MINUTES = numMinutes;
      }
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    public static void CleanupIfExpired()
    {
      lock (typeof(ReplicationCache)) {
        // check if it's been more than CLEANUP_MINUTES when we last checked.
        // if so, trigger a cleanup thread.
        if (IsExpired(m_lastCleanupDate, CLEANUP_MINUTES))
        {
          // spawn a cleanup thread
          log.Info("ReplicationCache needs purging.  Spawning cleanup thread.");
          // set it to the current time
          m_lastCleanupDate = new XPDateTime();
          XPThread cleanupThread = new XPThread(new CleanupCache(m_sharedCache));
          cleanupThread.SetBackground(true);
          cleanupThread.Start();
        }
      }
    }
  }
}