using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openkernel.http;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.failover
{
  /// <summary>
  /// This class handles the ReplicationCacheEntry.
  /// </summary>
  /// <author>ErickS, JosephC</author>
  public class ReplicationCacheEntry : IOKSessionStateNotification,IPTSessionPrefChangeNotification
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.failover.ReplicationCacheEntry");
    private String m_replicationToken;
    
    /// <summary>
    /// Creates a new ReplicationCacheEntry object.
    /// </summary>
    /// <param name="replicationToken">DOCUMENT_ME</param>
    public ReplicationCacheEntry(String replicationToken)
    {
      m_replicationToken = replicationToken;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="segment">DOCUMENT_ME</param>
    /// <param name="cookie">DOCUMENT_ME</param>
    public virtual void OnSetCookie(String segment, IOKHttpCookie cookie)
    {
      log.Info("Adding cookie to the replication cache.");
      ReplicationCache.SetCookie(m_replicationToken, segment, cookie);
      log.Info("Cookie name: " + cookie.Name() + ", value: " + cookie.Value() + " added to the replication cache.");
      ReplicationCache.SetLastModified(m_replicationToken, new XPDateTime());
      ReplicationCache.CleanupIfExpired();
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="host">DOCUMENT_ME</param>
    /// <param name="address">DOCUMENT_ME</param>
    public virtual void OnPreferedHostChange(String host, OKIPAddress address)
    {
    }
    //TODO: ES - take this whole method out once IOKSessionStateNotification
    // interface has been changed in OpenKernel.
    /*
     byte[] bt_address = address.GetAddress();
     m_htPreferredHosts.PutElement(strHost, bt_address);
     ReplicationCache.UpdateLastModified(m_replicationToken);
     */
     
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="sessionPref">DOCUMENT_ME</param>
    /// <param name="prefValue">DOCUMENT_ME</param>
    public virtual void OnSessionPrefAdd(String sessionPref, String prefValue)
    {
      log.Info("Adding session pref to replication cache.");
      ReplicationCache.SetSessionPref(m_replicationToken, sessionPref, prefValue);
      log.Info("Session pref key: " + sessionPref + ", value: " + prefValue + " added to replication cache.");
      ReplicationCache.SetLastModified(m_replicationToken, new XPDateTime());
      ReplicationCache.CleanupIfExpired();
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="sessionPref">DOCUMENT_ME</param>
    public virtual void OnSessionPrefRemove(String sessionPref)
    {
      log.Info("Removing session pref from replication cache.");
      ReplicationCache.RemoveSessionPref(m_replicationToken, sessionPref);
      log.Info("Session pref key: " + sessionPref + " removed from replication cache.");
      ReplicationCache.CleanupIfExpired();
    }
  }
}