using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.interpreter;
using com.plumtree.uiinfrastructure.interpreter.filter;
using com.plumtree.uiinfrastructure.interpreter.filter.utils;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.friendlyurl
{
  /// <summary>
  /// A filter to handle friendly gateway url request.
  /// </summary>
  /// <author>RobertZ</author>
  public class GatewayFriendlyURLFilter : BaseInterpreterFilter
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent("UI_Infrastructure"),
     "com.plumtree.portaluiinfrastructure.friendlyurl.GatewayFriendlyURLFilter");
    
    /// <summary>
    /// This method detects if the incoming request is a gateway request.
    /// If it is, it will take over the processing of the request, and return
    /// a boolean true to indicate that Interpreter shall not process the
    /// request further. 
    /// NOTE: No exceptions should bubble up from this method. Let the gateway handler take care of any errors.
    /// </summary>
    public override bool PreFilter(RequestData requestData)
    {
      IXPRequest request = requestData.m_xpRequest;
      String strURL = request.GetRequestURL();
      String queryString = request.GetQueryString();
      queryString = (null == queryString) ? "" : "?" + queryString;
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      IFriendlyURLManager ptFriendlyURLMgr = (IFriendlyURLManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
      String keyword = ptFriendlyURLMgr.LookupFriendlyURLKeyFromClassId(FriendlyURLConstants.FRIENDLY_GATEWAY_URL);
      if (keyword == null || "".Equals(keyword))
      {
        log.Debug("No keyword defined for friendly gateway url in FriendlyURLs.xml. Friendly Gateway URLs disabled");
        return false;
      }
      // Use the gateway handle request if this is a gateway url
      if (GatewayHelpers.IsFriendlyGatewayURL(strURL, keyword))
      {
        // convert the friendly gateway url to a regular gatewayurl
        String convertedUrl = GatewayHelpers.ConvertToRegularGatewayURL(strURL,
         keyword) + queryString;
        requestData.SetRequestURL(convertedUrl);
        requestData.SetRequestFullURL(convertedUrl);
        log.Debug("Calling HandleGatewayRequest(...) for URL [" + request.GetRequestURL() + "] from friendly Gateway URL [" + strURL + "]");
        // If we need to login from the gateway, we let the
        // interpreter handle that.			
        return GatewayHandlers.HandleGatewayRequest(requestData);
      }
      /*
       * ================================================================================================
       * END OF SPECIAL PROCESSING FOR THE GATEWAY REQUESTS
       * ================================================================================================
       */
       
      return false;
    }
  }
}