using System;
namespace com.plumtree.portaluiinfrastructure.friendlyurl
{
  /// <summary>
  /// This class is responsible for parsing friendly URLs and populating the different
  /// variables (ie name of object, id of object, ...)
  /// </summary>
  /// <author>duang</author>
  public interface IFriendlyURLParser
  {
    
    /// <summary>
    /// Returns the child Id if one was parsed from the URL, 0 otherwise.
    /// </summary>
    /// <returns></returns>
    int GetChildId();
    
    /// <summary>
    /// Returns the class Id mapped to the keyword parsed from the URL.
    /// </summary>
    /// <returns></returns>
    String GetClassId();
    
    /// <summary>
    /// Sets the class Id mapped to the keyword parsed from the URL.
    /// </summary>
    /// <returns></returns>
    void SetClassId(String strClassId);
    
    /// <summary>
    /// Returns the object Id if one was parsed from the URL, 0 otherwise.
    /// </summary>
    /// <returns></returns>
    int GetObjectId();
    
    /// <summary>
    /// Returns the child name if one was parsed from the URL, null otherwise.
    /// </summary>
    /// <param name="bDeNormalize">Indicates whether the name should be denormalized before being returned</param>
    /// <returns></returns>
    String GetChildName(bool bDeNormalize);
    
    /// <summary>
    /// Returns the keyword if one was parsed from the URL, null otherwise.
    /// </summary>
    /// <returns></returns>
    String GetKeyword();
    
    /// <summary>
    /// Returns the object name if one was parsed from the URL, null otherwise.
    /// </summary>
    /// <param name="bDeNormalize">Indicates whether the name should be denormalized before being returned</param>
    /// <returns></returns>
    String GetObjectName(bool bDeNormalize);
  }
}