using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portaluiinfrastructure.friendlyurl
{
  /// <summary>
  /// A manager class in charge of retrieving the correct friendly URL parser
  /// given a URL path.
  /// </summary>
  /// <author>duang</author>
  public interface IFriendlyURLParserManager
  {
    
    /// <summary>
    /// Stores the map of keywords to class Ids.
    /// </summary>
    /// <param name="htKeyToClassIdLookup">Map of keywords to class ids taken from FriendlyURLS.xml</param>
    void SetKeyToClassIdLookupTable(XPHashtable htKeyToClassIdLookup);
    
    /// <summary>
    /// Returns an IFriendlyURLParser based on the URL path given.
    /// </summary>
    /// <param name="stURLTokens">URL path</param>
    /// <returns>	</returns>
    IFriendlyURLParser GetParser(XPStringTokenizer stURLTokens);
    
    /// <summary>
    /// Looks up the friendly url keyword for the specified type.
    /// </summary>
    /// <param name="typeId">Class id or type id</param>
    /// <returns>The friendly url keyword or null if typeid was not defined</returns>
    String FindKeywordForType(String typeId);
  }
}