using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.helpers
{
  public class AppDataObjectFactory : IAppDataObjectFactory
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.helpers.AppDataObjectFactory");
    //the singleton instance
    private static IAppDataObjectFactory m_FactoryInstance;
    // This stores whether or not the factory is in test mode.
    private static bool m_bIsProduction = false;
    // Private constructor to ensure controlled access to the singleton.
    private AppDataObjectFactory()
    {
    }
    
    /// <returns>The singleton config helper.</returns>
    public static IAppDataObjectFactory GetInstance()
    {
      if (m_FactoryInstance == null)
      {
        m_bIsProduction = true;
        m_FactoryInstance = new AppDataObjectFactory();
      }
      return m_FactoryInstance;
    }
    
    /// <summary>
    /// Unit tests should use this method to overwrite/teardown existing helper singleton.
    /// DO NOT USE for production code. 
    /// </summary>
    public static void SetTestInstance(IAppDataObjectFactory testHelper)
    {
      if (m_bIsProduction)
      {
        String strMessage = "Can\'t override AppDataObjectFactory instance for testing... AppDataObjectFactory has already been initialized.";
        log.Error(strMessage);
        throw new XPException(strMessage);
      }
      m_FactoryInstance = testHelper;
    }
    public virtual IPTState GetAppDataObject(int iCommunityID, int iPageID,
     String strHostPageURI, AActivitySpace asOwner)
    {
      return AppDataObject.GetAppDataObject(iCommunityID, iPageID, strHostPageURI,
       asOwner);
    }
    public virtual IPTState GetAppDataObject(int iCommunityID, int iPageID,
     String strHostPageURI, AActivitySpace asOwner, bool bResolveSecureBase)
    {
      return AppDataObject.GetAppDataObject(iCommunityID, iPageID, strHostPageURI,
       asOwner, bResolveSecureBase);
    }
    public virtual IPTState GetAppDataObject(int iCommunityID, int iPageID,
     int iGWParams, String strHostPageURI, AActivitySpace asOwner)
    {
      return AppDataObject.GetAppDataObject(iCommunityID, iPageID, iGWParams,
       strHostPageURI, asOwner);
    }
    public virtual IPTState GetAppDataObject(int iCommunityID, int iPageID,
     int iGWParams, String strHostPageURI, AActivitySpace asOwner, bool bResolveSecureBase)
    {
      return AppDataObject.GetAppDataObject(iCommunityID, iPageID, iGWParams,
       strHostPageURI, asOwner, bResolveSecureBase);
    }
    public virtual PTStyleSheetLink GetStyleSheet(int iCommunityID, IPTSession ptSession,
     AActivitySpace asOwner)
    {
      return AppDataObject.GetStyleSheet(iCommunityID, ptSession, asOwner);
      }
  }
}