using System;
using IPTSession=com.plumtree.server.IPTSession;
namespace com.plumtree.portaluiinfrastructure.helpers
{
  /// <summary>
  /// The IPathwaysHelper handles common functionality related to
  /// Pathways integrations.
  /// </summary>
  public interface IPathwaysHelper
  {
    
    /// <param name="_session">the current user session.</param>
    /// <returns>whether or not Ensemble is installed.</returns>
    bool IsPathwaysInstalled(IPTSession _session);
    
    /// <param name="_session">the current user session.</param>
    /// <returns>
    /// the ID of the Pathways API web service. -1 if it
    /// is not installed.
    /// </returns>
    int GetAPIWebServiceID(IPTSession _session);
    
    /// <summary>
    /// When a Pathways search server issue occurs, this sets timeout value for when to use Pathways again
    /// </summary>
    void StartErrorState();
    
    /// <returns>
    /// whether or not Pathways timeout has expired.  Returns true if the time out still occurs and false if 
    /// the timeout expired and we can try Pathways again.
    /// </returns>
    bool IsErrorState();
    
    /// <param name="value">the boolean value representing if the search is in fall back to legacy mode</param>
    void SetLegacySearchMode(bool value);
    
    /// <summary>
    /// This is for advanced search, since it will fall back to legacy search if a search request is not valid for a 
    /// pathways search even though it's enabled and without error
    /// </summary>
    /// <returns>the boolean value if the search is currently defaulting to legacy mode</returns>
    bool GetLegacySearchMode();
  }
}