using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.helpers
{
  /// <summary>
  /// A service that provides access to the pt config helper object.
  /// </summary>
  public class PTConfigService : ConfigService,IPTConfigHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.helpers.PTConfigService");
    //the singleton instance
    private static IPTConfigHelper m_PTHelperInstance;
    // This stores whether or not the factory is in test mode.
    private static bool m_bIsPTHelperProduction = false;
    // Private constructor to ensure controlled access to the singleton.
    private PTConfigService() : base()
    {
    }
    
    /// <returns>The singleton PT config helper.</returns>
    public static IPTConfigHelper getPTInstance()
    {
      if (m_PTHelperInstance == null)
      {
        m_bIsPTHelperProduction = true;
        m_PTHelperInstance = new PTConfigService();
      }
      return m_PTHelperInstance;
    }
    
    /// <summary>
    /// Unit tests should use this method to overwrite/teardown existing helper singleton.
    /// DO NOT USE for production code.
    /// NOTE: When finished with a unit test, this should be set back to null so as not
    /// to interfere with other tests.
    /// </summary>
    public static void setTestPTInstance(IPTConfigHelper testHelper)
    {
      if (m_bIsPTHelperProduction)
      {
        String strMessage = "Can\'t override PTConfigHelper instance for testing... PTConfigService has already been initialized.";
        log.Error(strMessage);
        throw new XPException(strMessage);
      }
      m_PTHelperInstance = testHelper;
    }
    public virtual int GetConfigVariableAsInt(String strSection, String strSubSection,
     String strAttribute, AActivitySpace space)
    {
      return ((PTConfigVarPack) space.GetApplication().GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsInt(strSection,
       strSubSection, strAttribute);
    }
    public virtual String GetConfigVariableAsString(String strSection, String strSubSection,
     String strAttribute, AActivitySpace space)
    {
      return ((PTConfigVarPack) space.GetApplication().GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsString(strSection,
       strSubSection, strAttribute);
    }
    public virtual String GetConfigVariableAsString(String strSection, String strSubSection,
     String strAttribute, IApplication app)
    {
      return ((PTConfigVarPack) app.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsString(strSection,
       strSubSection, strAttribute);
    }
    public virtual Object[] GetConfigVariables(String strSection, String strSubSection,
     String strAttribute, AActivitySpace space)
    {
      return ((PTConfigVarPack) space.GetApplication().GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValues(strSection,
       strSubSection, strAttribute);
    }
    public virtual Object[] GetConfigVariables(String strSection, String strSubSection,
     String strAttribute, IApplication application)
    {
      return ((PTConfigVarPack) application.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValues(strSection,
       strSubSection, strAttribute);
    }
    public virtual IPTClassTypeDescManager GetPTClassTypeDescrManager()
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      return (IPTClassTypeDescManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
      }
    public virtual String GetAbsoluteImageServerBaseURL(AActivitySpace _space,
     String _strRequestURL)
    {
      String strImgSvrBaseURL = PTConfigHelper.GetImageServerBaseURL(_space);
      return MakeAbsolute(strImgSvrBaseURL, _space, _strRequestURL);
    }
    public virtual String GetAbsoluteImageServerRootURL(AActivitySpace _space,
     String _strRequestURL)
    {
      String strImgSvrRootURL = PTConfigHelper.GetImageServerRootURL(_space);
      return MakeAbsolute(strImgSvrRootURL, _space, _strRequestURL);
    }
    private String MakeAbsolute(String strURL, AActivitySpace _space, String _strRequestURL)
    {
      // if the imageserverurl configured in xml is relative, calculate based on
      // user's base url pref
      if (!XPStringUtility.StartsWith(strURL, "http://") && !XPStringUtility.StartsWith(strURL,
       "https://"))
      {
        log.Debug("Image Server URL in config is relative.  Calculating absolute URL based on user preference...");
        // it's relative, so look up the user's base url pref
        XPStringBuilder sbImageServerURL = new XPStringBuilder();
        String appBaseURL = XPConvert.ToString(PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.BASE_URL,
         _space.GetSubSession(), _space.GetApplication(), (IPTSession) _space.GetUserSession()));
        if (null == appBaseURL || appBaseURL.Length < 1)
        {
          appBaseURL = ConfigHelper.GetApplicationBaseURL(ConfigHelper.GetNormalizedBaseURL(_strRequestURL));
          int indProtocol = XPStringUtility.IndexOf(appBaseURL, "://") + 3;
          appBaseURL = XPStringUtility.Substring(appBaseURL, 0, XPStringUtility.IndexOf(appBaseURL,
           "/", indProtocol));
        }
        sbImageServerURL.Append(appBaseURL);
        // make sure there is always a single slash between the strBaseURL
        // and rest of image server URL.
        if (!XPStringUtility.StartsWith(strURL, "/"))
        {
          sbImageServerURL.Append("/");
        }
        sbImageServerURL.Append(strURL);
        strURL = sbImageServerURL.ToString();
        log.Debug("Passing absolute image server URL in AppDataObject: " + strURL);
        }
      return strURL;
    }
    public virtual bool UseFriendlyURLS(int classId, String queryStringArgs)
    {
      return PTConfigHelper.UseFriendlyURLS(classId, queryStringArgs);
    }
  }
}