using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.helpers
{
  /// <summary>
  /// This helper class provides methods to check markup
  /// information for errors.
  /// </summary>
  public class PortletErrorHelper
  {
    
    /// <summary>
    /// Check if there was an HTTP error in the markup information.
    /// </summary>
    /// <param name="objArrMarkup">the markup array to check for errors.</param>
    /// <returns>true if the markup array has error information in it.</returns>
    public virtual bool IsErrorContentArray(Object[][] objArrMarkup)
    {
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_ERRORCODE)
      {
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// Get the error code from the markup information.
    /// </summary>
    /// <param name="objArrMarkup">the markup array used to get the error code.</param>
    /// <returns>the error code from the markup array.</returns>
    public virtual int GetErrorCode(Object[][] objArrMarkup)
    {
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_ERRORCODE)
      {
        int iErrorCode = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0]);
        return iErrorCode;
      }
      return 0;
    }
    
    /// <summary>
    /// Get the error message from the markup information.
    /// </summary>
    /// <param name="objArrMarkup">the markup array used to get the error message.</param>
    /// <returns>the error message from the markup array.</returns>
    public virtual String GetErrorMessage(Object[][] objArrMarkup)
    {
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_ERRORMESSAGE)
      {
        String strErrorMessage = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1];
        return strErrorMessage;
      }
      return null;
    }
  }
}