using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.htmlconstructs
{
  /// <deprecated>
  /// com.plumtree.portaluiinfrastructure.htmlconstructs.PTPortletTitleBar has 
  /// been replaced by overridable methods in com.plumtree.portalpages.browsing.myportal.MyPortalContentView.
  /// To customize the portlet headers override MyPortalContentView through dynamic discovery
  /// and override the functions PortletHeader, GetPortletButtonsCell, and/or GetPortletNameCell.
  /// </deprecated>
  /// <author>MichaelD</author>
  public class PTPortletTitleBar
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.htmlconstructs.PTPortletTitleBar");
    private AActivitySpace m_asOwner;
    private HTMLAnchor[] m_arActions = null;
    private String m_strPortletName = "";
    private String m_strHelpURL;
    private bool m_bHasHelpURL;
    private bool m_bIsMandatory;
    private int m_nColumnID;
    
    /// <summary>
    /// Creates a new PTPortletTitleBar object.
    /// </summary>
    /// <param name="strPortletName"></param>
    /// <param name="bIsCollapsed"></param>
    /// <param name="nColumnID"></param>
    /// <param name="asurlAction"></param>
    /// <param name="rowPortletHeader"></param>
    public PTPortletTitleBar(String strPortletName, int nPortletID, bool bIsCollapsed,
     bool bIsMandatory, bool bHasHelpURL, String strHelpURL, int nColumnID,
     HTMLAnchor[] arActions, AActivitySpace asOwner)
    {
      m_strPortletName = strPortletName;
      m_nColumnID = nColumnID;
      m_arActions = arActions;
      m_bIsMandatory = bIsMandatory;
      m_bHasHelpURL = bHasHelpURL;
      m_strHelpURL = strHelpURL;
      m_asOwner = asOwner;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    public virtual HTMLTable GetPortletTitleBar()
    {
      HTMLTable table = new HTMLTable();
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetBorder(CommonHTMLStrings.ZERO);
      table.SetCellPadding(CommonHTMLStrings.ZERO);
      table.SetCellSpacing(CommonHTMLStrings.ZERO);
      table.SetSummary(XPResourceManager.FormatMessage("{0} Header", XPHttpUtility.HtmlEncode(m_strPortletName)));
      HTMLTableRow row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      row.SetStyleClass(PTStyleClass.PLATPORTLET_HEADER_BG);
      row.AddInnerHTMLElement(GetPortletNameCell());
      row.AddInnerHTMLElement(GetPortletButtonsCell());
      return table;
    }
    
    /// <throws>HTMLException </throws>
    private HTMLTableCell GetPortletButtonsCell()
    {
      PTConstruct myConstruct = null;
      HTMLTableCell cell = new HTMLTableCell();
      cell.SetHeight("18");
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetStyleClass(PTStyleClass.CUSTOMAPP_TEXT);
      cell.SetNoWrap(true);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Put help button in title bar first, or a spacer cell if there is none
      try
      {
        if (m_bHasHelpURL)
        {
          // Add icon
          myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_HELP);
          HTMLImg myImage;
          myImage = (HTMLImg) myConstruct.GetHTMLElement();
          myImage.SetAlt(m_asOwner.GetString(162, "ptmsgs_portalinfrastructure"));
          myImage.SetBorder(CommonHTMLStrings.ZERO);
          myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
          HTMLAnchor myAnchor;
          if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
          {
            String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
            myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
            myAnchor.SetOnClick(strJSUtilVersionPrefix + "PTWindowUtil.openHelpWindow(\'" + m_strHelpURL + "\', \'600\', \'600\', true);return false;");
            } else
          {
            myAnchor = new HTMLAnchor(m_strHelpURL);
          }
          myAnchor.AddInnerHTMLElement(myImage);
          cell.AddInnerHTMLElement(myAnchor);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Failed getting gadget help button.");
      }
      // Put collapse/expand action button in title bar, or a spacer cell if the portlet is mandatory
      try
      {
        for (int i = 0;i < m_arActions.Length;i++)
        {
          if (null != m_arActions[i])
          {
            cell.AddInnerHTMLElement(m_arActions[i]);
            cell.AddInnerHTMLElement(PlumtreeHelpers.GetSpacerImage("2", "1"));
            }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Failed getting gadget expand/collapse button.");
      }
      // if it's mandatory and there's no help button, then we need to add a space, or there's going to be
      // nothing else in here
      if (!m_bHasHelpURL && m_bIsMandatory)
      {
        try
        {
          HTMLImg spaceImg = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER,
           true, m_asOwner).GetHTMLElement();
          cell.AddInnerHTMLElement(spaceImg);
          spaceImg.SetWidth(CommonHTMLStrings.TWO);
          spaceImg.SetHeight(CommonHTMLStrings.ONE);
          spaceImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
          spaceImg.SetBorder(CommonHTMLStrings.ZERO);
        }
        catch (Exception e)
        {
          log.Warn("PTPortletTitleBar::AddPortletButtonsToTitleBar --  Unable to make a spacer gif.");
          }
      }
      // if it's not mandatory and there's a help button, then we need to add a space, to divide
      // the two buttons
      if (m_bHasHelpURL && !m_bIsMandatory)
      {
        try
        {
          HTMLImg spaceImg = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER).GetHTMLElement();
          cell.AddInnerHTMLElement(spaceImg);
          spaceImg.SetWidth(CommonHTMLStrings.TWO);
          spaceImg.SetHeight(CommonHTMLStrings.ONE);
          spaceImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
          spaceImg.SetBorder(CommonHTMLStrings.ZERO);
        }
        catch (Exception e)
        {
          log.Warn("PTPortletTitleBar::AddPortletButtonsToTitleBar --  Unable to make a spacer gif.");
          }
      }
      return cell;
    }
    
    /// <throws>HTMLException </throws>
    private HTMLTableCell GetPortletNameCell()
    {
      // Put gadget name in title bar
      HTMLTableCell cell = new HTMLTableCell();
      cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      cell.SetHeight("18");
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetStyleClass(PTStyleClass.CUSTOMAPP_TEXT);
      cell.SetNoWrap(true);
      HTMLSpan span = new HTMLSpan();
      cell.AddInnerHTMLElement(span);
      if (1 == m_nColumnID)
      {
        span.SetStyleClass(PTStyleClass.PLATPORTLET_WIDE_HEADER);
      } else
      {
        span.SetStyleClass(PTStyleClass.PLATPORTLET_NARROW_HEADER);
      }
      span.AddInnerHTMLEncodedString(m_strPortletName);
      return cell;
    }
  }
}