using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portaluiinfrastructure.htmlconstructs
{
  /// <author>
  /// patrickc
  /// This class holds CSS id attribute constants which are 
  /// used by discreet objects within the portal user interface.
  /// </author>
  public sealed class PTStyleID
  {
    /* Public Constants */
    // Used in PlumtreeTopBarView.java
    public const String PT_ADVANCED_SEARCH_BUTTON = "pt-advanced-search-button";
    public const String PT_FEDERATED_SEARCH_BUTTON = "pt-federated-search-button";
    public const String PT_HELP_BUTTON = "pt-help-button";
    public const String PT_LOGIN_AUTH_SELECT = "pt-login-auth-select";
    public const String PT_LOGIN_LINK = "pt-login-link";
    public const String PT_LOGOFF_LINK = "pt-logoff-link";
    public const String PT_MY_ACCOUNT_LINK = "pt-my-account-link";
    public const String PT_MY_HOME_LINK = "pt-my-home-link";
    public const String PT_SEARCH_CONTROLS = "pt-search-controls";
    public const String PT_SEARCH_SUBMIT_BUTTON = "pt-search-submit-button";
    public const String PT_TOPBAR = "pt-topbar";
    public const String PT_USER_NAV = "pt-user-nav";
    public const String PT_WELCOME_TEXT = "pt-welcome-text";
    public const String PT_RULES_DEBUG_LINK = "pt-rules-debug";
    // DCD: Used for Top Best Best tag
    public const String PT_TOP_BEST_BET = "pt-top-best-bet-text";
    // Used in DefaultHeaderView.java
    public const String PT_HEADER = "pt-header";
    public const String PT_HEADER_LEFT = "pt-header-left";
    public const String PT_HEADER_RIGHT = "pt-header-right";
    // Used in DefaultFooterView.java
    public const String PT_FOOTER = "pt-footer";
    // Used on Login page
    public const String PT_LOGIN_PASSWORD_FIELD = "pt-login-password-field";
    public const String PT_LOGIN_REMEMBER_CHECKBOX = "pt-login-remember-checkbox";
    public const String PT_LOGIN_USERNAME_TEXTBOX = "pt-login-username-textbox";
    public const String PT_LOGIN_CREATE_ACCOUNT = "pt-login-create-account";
    /* Private Constants */
    // Used in object instances such as pages and portlets.
    //
    // These Strings get concatenated with an instance id to form a unique id for each object.
    // They are private because they should only be accessed via the 
    // GetIDStringForPortalContent(), GetIDStringForExternalContent() and GetIDStringForPortlet() methods.
    private const String PT_EXTERNAL_CONTENT_INSTANCE_ID_PREFIX = "pt-external-content-";
    private const String PT_PAGE_INSTANCE_ID_PREFIX = "pt-page-";
    private const String PT_PORTAL_CONTENT_INSTANCE_ID_PREFIX = "pt-portal-content-";
    private const String PT_PORTLET_INSTANCE_ID_PREFIX = "pt-portlet-";
    /* Public Methods */
    public static String GetIDStringForExternalContent(int pageID)
    {
      return PT_EXTERNAL_CONTENT_INSTANCE_ID_PREFIX + XPConvert.ToString(pageID);
      }
    public static String GetIDStringForPage(int pageID)
    {
      return PT_PAGE_INSTANCE_ID_PREFIX + XPConvert.ToString(pageID);
    }
    public static String GetIDStringForPortalContent(int pageID)
    {
      return PT_PORTAL_CONTENT_INSTANCE_ID_PREFIX + XPConvert.ToString(pageID);
      }
    public static String GetIDStringForPortlet(int portletID)
    {
      return PT_PORTLET_INSTANCE_ID_PREFIX + XPConvert.ToString(portletID);
      }
  }
}