using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.intrinsicportlets
{
  /// <summary>
  /// Controls process the events generated by users. This is an abstract
  /// intrinsic portlet control that handle repost actions.
  /// </summary>
  /// <author>josephc</author>
  public abstract class IntrinsicPortletControl : IControl
  {
    // Associated Activity Space
    
    /// <summary>
    /// Parent Activity Space 
    /// </summary>
    protected AActivitySpace m_asOwner;
    // Associated model
    
    /// <summary>
    /// Model 
    /// </summary>
    protected IModel m_model;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public abstract Redirect CheckActionSecurityAndExecute(XPHashtable arguments);
    
    /// <summary>
    /// This method is used by the ASManager to return new instances of managed
    /// objects.
    /// </summary>
    /// <returns>A new instance of the managed class (i.e. return new Foo();)</returns>
    public abstract Object Create();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public abstract String GetName();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace parent)
    {
      m_model = model;
      m_asOwner = parent;
    }
    
    /// <summary>
    /// This method is a dispatcher. For each repost action it should perform
    /// the right action.
    /// </summary>
    /// <param name="_nAction">Action to perform</param>
    /// <param name="_htFormData">Hash table containing form data</param>
    public abstract void PerformRepostAction(int _nAction, XPHashtable _htFormData);
    }
}