using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.intrinsicportlets
{
  /// <summary>
  /// This is the base intrinsic portlet view.  All intrinsic portlet views should
  /// extend this base class.
  /// </summary>
  /// <author>josephc</author>
  public abstract class IntrinsicPortletView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView");
    
    /// <summary>
    /// The name of the intrinsic portlet form prefix (for use in Javascript,
    /// etc...). The portlet ID will be appended to the prefix.
    /// </summary>
    public const String INTRINSIC_PORTLET_HTMLFORM_NAME = "IntrinsicPortletForm";
    
    /// <summary>
    /// The name of the JavaScript used to submit the form. The portlet ID will
    /// be appended to the prefix.
    /// </summary>
    public const String INTRINSIC_PORTLET_JAVASCRIPT_SUBMIT_FORM = "IntrinsicPortletSubmitForm";
    // Associated Activity Space
    
    /// <summary>
    /// Parent Activity Space 
    /// </summary>
    protected AActivitySpace m_asOwner;
    // Associated read-only model
    
    /// <summary>
    /// RO interface to model 
    /// </summary>
    protected IModelRO m_model;
    
    /// <summary>
    /// Set to true if you want your portlet to have a form and JavaScript for
    /// repost.
    /// </summary>
    protected bool m_bAddFormToPortlet = false;
    
    /// <summary>
    /// Set to true if you want your portlet to have a multi-part form 
    /// </summary>
    protected bool m_bMultiPart = false;
    
    /// <summary>
    /// This method is used by the ASManager to return new instances of managed
    /// objects.
    /// </summary>
    /// <returns>A new instance of the managed class (i.e. return new Foo();)</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public abstract Object Create();
    
    /// <summary>
    /// This is called by the MyPortalContentView, which aggregates all the
    /// intrinsic portlet views. This method calls DisplayPortlet() in order to
    /// generate the HTML specific to the portlet. If a form is required, then
    /// the HTML returned from DisplayPortlet() is put into a form.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>XPException Exception thrown if portlet was uanble to display.</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      if (m_bAddFormToPortlet)
      {
        HTMLForm myForm;
        HTMLInput myInput;
        // wrapper table avoids extra white space from form
        HTMLTable wrapperTable;
        IIntrinsicPortletModelRO iModelRO = (IIntrinsicPortletModelRO) m_model;
        String strPortletFormName = INTRINSIC_PORTLET_HTMLFORM_NAME + iModelRO.GetPortletID();
        try
        {
          // Form and hidden inputs
          myForm = new HTMLForm("");
          myForm.AddInnerHTMLElement(new HTMLComment("Begin: Display form and hidden inputs"));
          if (m_bMultiPart)
          {
            myForm.SetEncType(AFormDP.MULTIPART_ENCODING);
          }
          myForm.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(),
           m_asOwner.GetName(), m_asOwner.IsSubSpace()));
          myForm.SetMethod(AFormDP.POST);
          myForm.SetName(strPortletFormName);
          // Hidden Inputs
          // The action for the repost control to perform (repost, finish, cancel, etc...)
          myInput = new HTMLInput(HTMLInputTypes.HIDDEN, RepostControl.HTMLINPUT_POSTTOSELF,
           "");
          myForm.AddInnerHTMLElement(myInput);
          myInput.SetValue(XPConvert.ToString(RepostControl.POSTTOSELF_ACTION_UNDEFINED));
          // Name of space to POST this form to.
          myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACENAME_INPUT,
           "");
          myForm.AddInnerHTMLElement(myInput);
          myInput.SetValue(m_asOwner.GetName());
          // ID of space to POST this form to.
          myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACEID_INPUT,
           "");
          myForm.AddInnerHTMLElement(myInput);
          myInput.SetValue(m_asOwner.GetSpaceID());
          // Name of control to POST this form to.
          myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.CONTROL_INPUT,
           "");
          myForm.AddInnerHTMLElement(myInput);
          myInput.SetValue(((IFormAS) m_asOwner).GetRepostControlName());
          // Name of display page to display after POST.
          myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.PAGE_INPUT,
           "");
          myForm.AddInnerHTMLElement(myInput);
          myInput.SetValue(m_asOwner.GetCurrentPage().GetName());
          myForm.AddInnerHTMLElement(new HTMLComment("End: Display form and hidden inputs"));
          // the following block of code wraps our form
          // in an outer empty table, thus preventing empty
          // white space from being displayed after the form
          wrapperTable = new HTMLTable();
          wrapperTable.SetCellSpacing(CommonHTMLStrings.ZERO);
          wrapperTable.SetCellPadding(CommonHTMLStrings.ZERO);
          wrapperTable.SetBorder(CommonHTMLStrings.ZERO);
          wrapperTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          HTMLTableRow rowHack = new HTMLTableRow();
          HTMLTableCell cellHack = new HTMLTableCell();
          cellHack.AddInnerHTMLElement(DisplayPortlet());
          rowHack.AddInnerHTMLElement(cellHack);
          wrapperTable.AddInnerHTMLElement(myForm);
          myForm.AddInnerHTMLElement(rowHack);
        }
        catch (HTMLException e)
        {
          log.Error(e, m_asOwner.GetString(163, "ptmsgs_portalinfrastructure"));
          throw new XPException(m_asOwner.GetString(163, "ptmsgs_portalinfrastructure"),
           e);
        }
        return wrapperTable;
      } else
      {
        return DisplayPortlet();
      }
    }
    
    /// <summary>
    /// This is called by the ??, which aggregates all the
    /// intrinsic portlet WML views. This method calls DisplayPortletWML() in order to
    /// generate the WML specific to the portlet.
    /// </summary>
    /// <returns>HTMLElement representing WML for portlet</returns>
    public virtual String DisplayWML()
    {
      return DisplayPortletWML();
    }
    
    /// <summary>
    /// Portlet Javascript is aggregated by PlumtreeDP.  Note that you may need
    /// to take into account the portletID in your Javascript.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <throws>
    /// XPException Exception thrown if portlet was uanble to generate
    /// JavaScript.
    /// </throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      if (m_bAddFormToPortlet)
      {
        HTMLScript myScript;
        IIntrinsicPortletModelRO iModelRO = (IIntrinsicPortletModelRO) m_model;
        String strPortletFormName = IntrinsicPortletView.INTRINSIC_PORTLET_HTMLFORM_NAME + iModelRO.GetPortletID();
        String strPortletJavaScriptSubmitForm = IntrinsicPortletView.INTRINSIC_PORTLET_JAVASCRIPT_SUBMIT_FORM + iModelRO.GetPortletID();
        try
        {
          // This javascript function reposts the page based upon hidden HTML inputs in
          // the form.
          XPStringBuilder sb = new XPStringBuilder(300);
          sb.Append("\n");
          sb.Append("function ").Append(strPortletJavaScriptSubmitForm).Append("(varPostToSelf)\n");
          sb.Append("{\n");
          sb.Append("  if ((varPostToSelf != ").Append(RepostControl.POSTTOSELF_ACTION_FINISH).Append("  ) && (varPostToSelf != ").Append(RepostControl.POSTTOSELF_ACTION_GOTOPAGE).Append(")) {\n");
          sb.Append("    document.").Append(strPortletFormName).Append(".").Append(RepostControl.HTMLINPUT_POSTTOSELF).Append(".value= varPostToSelf;\n");
          sb.Append("    document.").Append(strPortletFormName).Append(".submit();\n");
          sb.Append("  }\n");
          sb.Append("}\n");
          myScript = new HTMLScript("text/javaScript");
          myScript.AddInnerHTMLString(sb.ToString());
        }
        catch (HTMLException e)
        {
          log.Error(e, m_asOwner.GetString(164, "ptmsgs_portalinfrastructure"));
          throw new XPException(m_asOwner.GetString(164, "ptmsgs_portalinfrastructure"),
           e);
        }
        return myScript;
      } else
      {
        return null;
      }
    }
    
    /// <summary>
    /// Displays the HTML for the portlet. The child classes must implement this
    /// function. This function is called by Display().
    /// </summary>
    /// <returns>HTML for portlet</returns>
    public abstract HTMLElement DisplayPortlet();
    
    /// <summary>
    /// Displays the WML for the portlet. The child classes must implement this
    /// function.  This function is called by DisplayWML().
    /// </summary>
    /// <returns>WML for portlet</returns>
    public abstract String DisplayPortletWML();
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public abstract String GetName();
    
    /// <summary>
    /// Inits the Section with the read-only Model and the Activity Space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="parent"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = model;
      m_asOwner = parent;
    }
  }
}