using System;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.layout
{
  /// <summary>
  /// The LayoutDisplay is responsible for transforming URLs in the layout,
  /// running the layout through the Tag Engine (using the DisplayTree class)
  /// and returning the converted HTML.
  /// </summary>
  public interface ILayoutDisplay
  {
    
    /// <summary>
    /// This method runs the markup layout through the Tag Engine.
    /// This method assumes that at least once in a request, one of the
    /// calls to this method includes layout markup that displays the
    /// Javascript generated in the tag engine.
    /// </summary>
    /// <param name="_markup">The layout markup to convert to HTML.</param>
    /// <param name="_currentSpace">The current Activity Space.</param>
    /// <returns>The converted HTML.</returns>
    HTMLElement ProcessLayout(Object[][] _markup, AActivitySpace _currentSpace);
    
    /// <summary>
    /// This method runs the markup layout for the main page through the Tag Engine,
    /// and ensures that there is an HTML head tag for JavaScript display.
    /// This method assumes that the call to this method includes layout markup
    /// that displays the Javascript generated in the tag engine.
    /// This method should only be called once per request.
    /// </summary>
    /// <param name="_markup">The layout markup to convert to HTML.</param>
    /// <param name="_currentSpace">The current Activity Space.</param>
    /// <returns>The converted HTML with HTML head tag.</returns>
    HTMLElement ProcessMainPageLayout(Object[][] _markup, AActivitySpace _currentSpace);
    }
}