using System;
using com.plumtree.openfoundation.reflect;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.layout.impl
{
  public class LayoutManager : ILayoutManager
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.layout.impl.LayoutManager");
    
    /// <summary>
    /// To make sure people don't create LayoutManagers directly, we require
    /// a special key that only the LayoutService has.  Call LayoutService.getManagerInstance()
    /// instead to get the Layout Manager.
    /// </summary>
    /// <param name="_oKey"></param>
    public LayoutManager(Object _oKey)
    {
      if (!LayoutService.isValid(_oKey))
      {
        throw new XPIllegalAccessException("Layout Manager can only be created by the Layout Service. " + "Call LayoutService.getManagerInstance() to access the Layout Manager.");
        }
    }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.layout.ILayoutManager#GetLayout(int, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
     */
     
    public virtual Object[][] GetLayout(int _nWebServiceId, AActivitySpace _asSpace)
    {
      return GetLayout(_nWebServiceId, _asSpace, false);
    }
    public virtual Object[][] GetLayout(int _nWebServiceId, AActivitySpace _asSpace,
     bool bTest)
    {
      try
      {
        IPTWebServiceManager ptWebServiceManager = (IPTWebServiceManager) ((IPTSession) _asSpace.GetUserSession()).GetWebServices();
        IPTGadgetInfo ptWebServiceInfo = ptWebServiceManager.GetWebServiceInfo(_nWebServiceId);
        // DCA - getting app data state object to let the webservice know the state of the application
        // This is mostly for portlet settings, like what community the portlet is on, which doesn't really apply here since we're not 
        // really a portlet, but we're trying to reuse code instead of reinventing the wheel.
        /* Community Id - not needed */
        Object appDataStateObject = AppDataObjectFactory.GetInstance().GetAppDataObject(0,
         /* Page Id - not needed */
        0, PTConfigHelper.GetMainServerApplicationURL(false), _asSpace);
        // DCA - get web service provider
        IPTAsyncGadgetProvider wsProvider = ptWebServiceManager.GetWebServiceProvider(_nWebServiceId,
         null);
        if (null == wsProvider)
        {
          log.Error("LayoutManager:GetLayout Could not find web service with Id: " + XPConvert.ToString(_nWebServiceId));
          throw new PTException("Invalid web service Id provided: " + _nWebServiceId + ".",
           PT_RESULTCODES.PT_E_INVALIDARGUMENT);
        }
        // We have to use the same states object for both calls.  If we get it again
        // from the session, it will be different and this won't work (for request mode,
        // which we use).
        IPTStates pStates = ((IPTSession) _asSpace.GetUserSession()).GetStates();
        // NOTE: We have to use state mode request because otherwise concurrent requests can
        // stomp on each other. Bug#65482
        // Just use the method that doesn't have the state mode, because that defaults to request mode.
        wsProvider.BeginProcessing(PT_GADGET_MODES.PT_GADGETMODES_RUNTIME,
         (IPTSession) _asSpace.GetUserSession(), ptWebServiceInfo, /* Admin Settings - not needed */
        pStates, null, appDataStateObject, /* IPTUserInterface - not needed */
        null);
        // DCA - try to get content from web service provider
        // NOTE: We have to use state mode request because otherwise concurrent requests can
        // stomp on each other. Bug#65482
        // Just use the method that doesn't have the state mode, because that defaults to request mode.
        Object[][] objLayout = wsProvider.GetHTMLText(PT_GADGET_MODES.PT_GADGETMODES_RUNTIME,
         (IPTSession) _asSpace.GetUserSession(), /* Admin Settings - not needed */
        ptWebServiceInfo, pStates, null, /* IPTUserInterface - not needed */
        appDataStateObject, null);
        PortletErrorHelper errorHelper = new PortletErrorHelper();
        if (errorHelper.IsErrorContentArray(objLayout) && !bTest)
        {
          int nErrorCode = errorHelper.GetErrorCode(objLayout);
          String strError = errorHelper.GetErrorMessage(objLayout);
          throw new PTException("Layout with web service ID: " + _nWebServiceId + " returned error code: " + nErrorCode + " and error message: " + strError,
           nErrorCode);
        }
        return objLayout;
      }
      catch (PTException pte)
      {
        log.Error(pte, "LayoutManager:GetLayout Could not begin processing web service with Id: " + XPConvert.ToString(_nWebServiceId));
        throw pte;
      }
      catch (Exception e)
      {
        log.Error(e, "LayoutManager:GetLayout Could not begin processing web service with Id: " + XPConvert.ToString(_nWebServiceId));
        throw new PTException(e, "Could not get layout with web service Id: " + _nWebServiceId + ".",
         PT_RESULTCODES.PT_E_FAIL);
      }
    }
  }
}