using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openkernel.http;
using com.plumtree.openkernel.sharedcache;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.portaluiinfrastructure.failover;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.taskapi.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.login
{
  /// <summary>
  /// This class handles IPTSession login code.
  /// </summary>
  public class PTLoginHelper : ILoginHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.login.PTLoginHelper");
    
    /// <summary>
    /// This is the number of milliseconds for which the Boolean indicating whether
    /// or not the allow user creation link is cached on the application.  After
    /// this many milliseconds, the server will be again querried, and a new
    /// value will be generated.
    /// </summary>
    public const long ALLOW_USER_CREATION_LINK_CACHE_LIFE_MS = 900000;
    
    /// <summary>
    /// storage names for allow user creation data and caching 
    /// </summary>
    private static String sKeySelect = "allowUserCreationBoolean";
    private static String sKeyLastUpdate = "allowUserCreationLastUpdate";
    
    /// <summary>
    /// configuration variables 
    /// </summary>
    private static String s_sDefaultPrefix;
    private static bool s_bShowDropdown;
    private static int s_nDropdownMode;
    private static bool s_bShowRMP;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#AttemptLogin(String,String,Object,ISessionManager,IApplication)"></seealso>
    public virtual Object AttemptLogin(String sUserName, String sPassword,
     Object token, bool bUseNumericConnect, ISessionManager subSession, IApplication application,
     String sRequestURL)
    {
      log.Info("Entering attemptLogin() 2");
      return PTLoginHelper.internalLogin(sUserName, sPassword, null, token,
       bUseNumericConnect, false, -1, subSession, application, sRequestURL,
       false);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#AttemptGuestLogin(Object,ISessionManager,IApplication)"></seealso>
    public virtual Object AttemptGuestLogin(Object token, ISessionManager subSession,
     IApplication application, String sRequestURL)
    {
      log.Info("Entering attemptGuestLogin()");
      return PTLoginHelper.internalLogin(null, null, null, token, false, true,
       -1, subSession, application, sRequestURL, false);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#AttemptGuestLogin(int,Object,ISessionManager,IApplication)"></seealso>
    public virtual Object AttemptGuestLogin(int nUserID, Object token, ISessionManager subSession,
     IApplication application, String sRequestURL)
    {
      if (-1 == nUserID)
      {
        log.Info("Entering attemptGuestLogin(), guest userid = default guest");
        } else
      {
        log.Info("Entering attemptGuestLogin(), guest userid = {0}", nUserID);
        }
      return PTLoginHelper.internalLogin(null, null, null, token, false, true,
       nUserID, subSession, application, sRequestURL, false);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#AttemptLogin(String,ISessionManager,IApplication)"></seealso>
    public virtual Object AttemptLogin(String sLoginToken, ISessionManager subSession,
     IApplication application, String sRequestURL, IXPRequest request)
    {
      log.Info("Entering attemptLogin() 1");
      // ES: check if browser has replication cookie.  if it does,
      // then it's a failover
      if (null != request)
      {
        String replicationToken = null;
        XPCookie[] cookieArr = request.GetCookies();
        for (int i = 0;i < cookieArr.Length;i++)
        {
          if (XPStringUtility.EqualsIgnoreCase(cookieArr[i].GetName(), LoginHelper.REPLICATION_COOKIE_NAME))
          {
            replicationToken = cookieArr[i].GetValue();
            break;
          }
        }
        if (null != replicationToken && ReplicationCache.GetSharedCache().ContainsKey(replicationToken))
        {
          log.Info("Failover detected.  Setting up replication.");
          // this is a failover situation
          // call internalLogin and pass in the token
          //MES- If replicationToken is invalid for some reason, then
          //	internalLogin will throw an exception.  In this case, we want
          //	to fall through to the "normal" behavior- use sLoginToken, as
          //	below.  See bug 54224.
          try
          {
            return PTLoginHelper.internalLogin(null, null, replicationToken,
             null, false, false, -1, subSession, application, sRequestURL,
             true);
          }
          catch (XPException xpe)
          {
            //MES- Do nothing here, fall through to "normal" case below (i.e.
            //	use sLoginToken instead of replicationToken)
            log.Info(xpe, "Unable to log in using replication cookie.  Falling through to standard mechanism.");
            }
        } else
        {
          log.Warn("Replication token is null or replication token is not in the cache.");
          }
      }
      log.Debug("Attempting to log in using standard login token");
      return PTLoginHelper.internalLogin(null, null, sLoginToken, null, false,
       false, -1, subSession, application, sRequestURL, false);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#GetUserSessionID(Object)"></seealso>
    public virtual String GetUserSessionID(Object userSession)
    {
      if (userSession == null)
      {
        log.Error("Unable to get user session ID - null userSession");
        return "";
      }
      IPTSession ptSession;
      try
      {
        ptSession = (IPTSession) userSession;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get user session ID - can\'t cast to IPTSession.");
        return "";
      }
      return XPConvert.ToString(ptSession.GetSessionInfo().GetCurrentUserID());
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#GetUserSessionName(Object)"></seealso>
    public virtual String GetUserSessionName(Object userSession)
    {
      if (userSession == null)
      {
        log.Error("Unable to get user session name - null userSession");
        return "";
      }
      IPTSession ptSession;
      try
      {
        ptSession = (IPTSession) userSession;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get user session ID - can\'t cast to IPTSession.");
        return "";
      }
      return ptSession.GetSessionInfo().GetCurrentUserName();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#GetIsGuestUser(Object)"></seealso>
    public virtual bool GetIsGuestUser(Object userSession)
    {
      if (userSession == null)
      {
        log.Error("Unable to get user session ID - null userSession");
        return true;
      }
      IPTSession ptSession;
      try
      {
        ptSession = (IPTSession) userSession;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get user session ID - can\'t cast to IPTSession.");
        return true;
      }
      // WilliamA - Change guest user detection mechanism to use the admin folder id
      // of the user (enabling multiple-guest-user feature) 
      // return (ptSession.GetSessionInfo().GetCurrentUserID() == PT_INTRINSICS.PT_USER_GUEST);
      return (ptSession.GetSessionInfo().CheckCurrentUserIsGuest());
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#GetDetailedFailureMessage(Exception,ISessionManager,IApplication)"></seealso>
    public virtual String GetDetailedFailureMessage(Exception exception, ISessionManager subSession,
     IApplication application)
    {
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      String strLanguage = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       subSession, application));
      String sReturn = rm.GetString(1576, ResourceConstants.PORTALBROWSINGMSGS,
       strLanguage);
      // This exception is currently passed to us as an XPException.  We need to
      // look at the inner exception (the original) to see if it is a PTException
      // from the server.
      if (exception is XPException)
      {
        Exception innerThrowable = ((XPException) exception).GetInnerException();
        if (innerThrowable is Exception)
        {
          exception = (Exception) innerThrowable;
        }
      }
      if (exception is PTException)
      {
        PTException ptEx = (PTException) exception;
        int iErrorCode = ptEx.GetErrorCode();
        switch (iErrorCode){
        case PT_RESULTCODES.PT_E_USERNAMENOTFOUND:
        {
          sReturn = rm.GetString(1574, ResourceConstants.PORTALBROWSINGMSGS,
           strLanguage);
          break;
        }
        case PT_RESULTCODES.PT_E_ACCOUNTLOCKED:
        {
          sReturn = rm.GetString(1575, ResourceConstants.PORTALBROWSINGMSGS,
           strLanguage);
          break;
        }
        case PT_RESULTCODES.PT_E_PASSWORDINVALID:
        {
          sReturn = rm.GetString(1573, ResourceConstants.PORTALBROWSINGMSGS,
           strLanguage);
          break;
        }
        case PT_RESULTCODES.PT_E_AUTHSOURCENOTFOUND:
        {
          sReturn = rm.GetString(1572, ResourceConstants.PORTALBROWSINGMSGS,
           strLanguage);
          break;
        }
        case PT_RESULTCODES.PT_E_BADSERVERCONFIG:
        {
          sReturn = rm.GetString(1571, ResourceConstants.PORTALBROWSINGMSGS,
           strLanguage);
          break;
        }
        }
      }
      return sReturn;
    }
    
    /// <summary>
    /// Method internalLogin.  This internal method still has to use session
    /// varibales directly (rather than AActivitySpace) because SSOLogin doesn't
    /// have an aActivitySpace to work with during login (it has to use a number
    /// of tmp variables).
    /// </summary>
    /// <param name="sUserName"></param>
    /// <param name="sPassword"></param>
    /// <param name="sLoginToken"></param>
    /// <param name="token"></param>
    /// <param name="bUseNumericConnect"></param>
    /// <param name="session"></param>
    /// <param name="application"></param>
    /// <returns>IPTSession</returns>
    /// <throws>Exception</throws>
    private static IPTSession internalLogin(String sUserName, String sPassword,
     String sLoginToken, Object token, bool bUseNumericConnect, bool bGuestLogin,
     int nGuestUserID, ISessionManager subSession, IApplication application,
     String sRequestURL, bool bIsFailover)
    {
      log.Info("Entering internalLogin()");
      // LOGIN
      IPTSession myIPTSession = PortalObjectsFactory.CreateSession();
      try
      {
        if (sLoginToken != null)
        {
          myIPTSession.Reconnect(sLoginToken);
        } else
        {
          if (bGuestLogin)
          {
            // Guest login -- The guest user password check is bypassed,
            // so we don't need to pass in the password.
            // NOTE: This used to be passed in via config.xml.
            // WilliamA - multiple-guest-user support
            // use the passed-in guest user ID if any
            if (-1 == nGuestUserID)
            {
              nGuestUserID = PT_INTRINSICS.PT_USER_GUEST;
            }
            myIPTSession.Connect(nGuestUserID, null, token);
          } else
          if (bUseNumericConnect)
          {
            // Numeric user login for devices
            myIPTSession.NumericConnect(sUserName, sPassword, token);
          } else
          {
            // Normal user login
            myIPTSession.Connect(sUserName, sPassword, token);
          }
        }
        // ES- if this is a failover, then we want to repopulate 
        // some things
        if (bIsFailover)
        {
          log.Info("PTLoginHelper::internalLogin: A failover situation encountered.");
          // Create a new ReplicationCacheEntry
          ReplicationCacheEntry rce = new ReplicationCacheEntry(sLoginToken);
          // Get the HTTP session
          IOKHttpSession session = myIPTSession.GetHttpUserSession();
          // Populate the cookie database
          log.Info("Found associated entry in replication cache.  About to repopulate replicated items.");
          IOKSharedCacheNode htCookies = ReplicationCache.GetCookies(sLoginToken);
          if (htCookies != null)
          {
            log.Info(htCookies.GetSize() + " cookies were found in the replication cache.");
            IXPEnumerator enumCookieKeys = htCookies.GetKeys();
            while (enumCookieKeys.MoveNext())
            {
              String cookieKey = (String) enumCookieKeys.GetCurrent();
              IOKSharedCacheNode currentCookie = (IOKSharedCacheNode) htCookies.GetElement(cookieKey);
              // Populate the cookies
              CookieInfo cookieInfo = new CookieInfo(currentCookie);
              IOKHttpCookie cookie = session.CreateCookie(cookieInfo.GetName(),
               cookieInfo.GetValue(), cookieInfo.GetDomain(), cookieInfo.GetPath(),
               cookieInfo.GetSecure(), cookieInfo.GetDateExpire());
              log.Info("Adding cookie name: " + cookieInfo.GetName() + ", value: " + cookieInfo.GetValue());
              session.SetCookie(cookieKey, cookie);
            }
          } else
          {
            log.Info("No cookies were found in the replication cache.");
          }
          // Set callback to IOKHttpSession
          session.SetSessionStateChangeCallback(rce);
          // Populate the session prefs
          IOKSharedCacheNode htSessionPrefs = ReplicationCache.GetSessionPrefs(sLoginToken);
          if (htSessionPrefs != null)
          {
            log.Info(htSessionPrefs.GetSize() + " session prefs were found in the replication cache.");
            IXPEnumerator enumSessionPrefKeys = htSessionPrefs.GetKeys();
            while (enumSessionPrefKeys.MoveNext())
            {
              String sessionPrefKey = (String) enumSessionPrefKeys.GetCurrent();
              String currentPref = (String) htSessionPrefs.GetElement(sessionPrefKey);
              log.Info("Adding session pref name: " + sessionPrefKey + ", value: " + currentPref);
              // Populate the session preferences
              myIPTSession.GetSessionInfo().AddSessionPreference(sessionPrefKey,
               currentPref);
            }
          } else
          {
            log.Info("No session prefs were found in the replication cache.");
            }
          // Set callback to IPTSessionInfo
          myIPTSession.GetSessionInfo().SetSessionPreferenceChangeCallback(rce);
          log.Info("Done setting up failover replication.");
        }
        int nCurrentUserID = myIPTSession.GetSessionInfo().GetCurrentUserID();
        // TODOCR DonH: Setting the doc url prefix should probably be done in the 
        // PTLoginActions PEI.
        String sBaseURL = ConfigHelper.GetApplicationBaseURL(ConfigHelper.GetNormalizedBaseURL(sRequestURL));
        if (XPStringUtility.EndsWith(sBaseURL, "?"))
        {
          sBaseURL = XPStringUtility.Substring(sBaseURL, 0, sBaseURL.Length - 1);
          }
        // Set this URL so that the gateway URLS can have the user ID so PTTracker can work right.
        // Make sure the application base URL does not have a question mark in it.
        myIPTSession.SetSettings(PT_SESSION_SETTINGS.PT_SESSION_RELATIVEDOCURLPREFIX,
         sBaseURL + GatewayHelpers.GATEWAY_URL_PREFIX + GatewayHelpers.NOFLAGS + GatewayHelpers.GATEWAY_ARG_DELIMITER + nCurrentUserID);
        }
      catch (Exception e)
      {
        log.Info(e, "Connect failed.");
        // mj: throw it so our parent can deal with it
        throw XPException.GetInstance(e);
      }
      return myIPTSession;
    }
    
    /// <summary>
    /// Attempts to create and connect a new user session.
    /// This method is used for Basic Auth logins.  Unfortunately, in Basic Auth
    /// the user name and password are encoded in the character encoding of the
    /// client machine, and the server does not know what that is.  Therefore
    /// we have to guess the appropriate encoding.  The user credentials
    /// passed to this method need to be unencoded as win-1252, shift-jis, Big5,
    /// etc... before they can be used.  The credentials are basic auth credentials;
    /// user name and password are separated by a colon.
    /// </summary>
    /// <returns>a valid userSession</returns>
    public virtual Object AttemptBasicAuthLogin(String sEncodedCredentials)
    {
      if (!XPStringUtility.StartsWith(XPStringUtility.ToLowerCase(sEncodedCredentials),
       HTTPBasicAuthenticator.BASIC_AUTH))
      {
        return null;
      }
      IPTSession result = null;
      // Even though the rest of the server uses UTF-8, basic auth only supports ascii and
      // ISO-8859-1, according to the spec.  IE on an English OS sends Windows-1252 and
      // IE on a Japanese OS sends Shift-JIS.  Since it is very difficult to determine what
      // encoding a basic auth client will use, we just cycle through all of them to
      // determine which one maps to a valid user name and password.
      for (int i = 0;i < HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED.Length;
      i++)
      {
        result = AttemptBasicAuthLogin(sEncodedCredentials, HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED[i]);
        if (null != result)
        {
          // It is theoretically possible to have a user name that maps to multiple valid user names
          // depending on the encoding used to decode it.  Therefore, to ensure that no one can
          // accidentally log on as an incorrect user (assuming they had the same password), if
          // two encodings login successfully, we fail alltogether.
          if (!VerifyNoAlternateLogins(sEncodedCredentials, i))
          {
            // Since we know that the user names differ in different encodings, we could use
            // HTTP Digest Authentication (which supports UTF-8) to determine the correct user
            // name and figure out which encoding is correct.  Bug#36056
            log.Warn("WebDav HTTP Basic Auth login failed.  Unable to determine correct user name because users name maps to another valid asian character user name.");
            throw new XPException("WebDav HTTP Basic Auth login failed.  Unable to determine correct user name because users name maps to another valid asian character user name.");
            }
          break;
        }
      }
      return result;
    }
    
    /// <summary>
    /// This helper method attempts to login using the credentials and decodes
    /// them with the specified encoding.
    /// </summary>
    /// <param name="sEncodedCredentials"></param>
    /// <param name="sEncoding"></param>
    /// <returns>user session</returns>
    protected virtual IPTSession AttemptBasicAuthLogin(String sEncodedCredentials,
     String sEncoding)
    {
      // Even though the rest of the server uses UTF-8, basic auth only supports ascii and
      // ISO-8859-1, according to the spec.  IE on an English OS sends Windows-1252 and
      // IE on a Japanese OS sends Shift-JIS.  Therefore we may have to try multiple encodings
      // to find the correct one.
      String strCredentials;
      try
      {
        // Do not log certain exceptions.  It is expected that logins will fail as
        // we try to guess which character encoding is appropriate.  Some systems
        // may not support all of the character encodings (such as shift-jis).
        // For performance reasons, perhaps we should remove this encoding from
        // the array if it is not supported.
        try
        {
          strCredentials = XPEncoding.GetString(XPBase64Coder.Decode(XPStringUtility.Substring(sEncodedCredentials,
           HTTPBasicAuthenticator.BASIC_AUTH.Length)), sEncoding);
        }
        catch (XPUnsupportedEncodingException e)
        {
          // Java throws this if the encoding is not supported
          return null;
        }
        catch (XPIllegalArgumentException e)
        {
          // .NET throws this if the encoding is not supported
          return null;
        }
        catch (Exception e)
        {
          // This is not an expected exception
          log.Error(e, "Unable to decode basic auth credentials using encoding " + sEncoding + ".");
          return null;
        }
        int indexOfColon = XPStringUtility.IndexOf(strCredentials, ':');
        // Since we are guessing the encoding, it's possible that we will decode it
        // incorrectly and the colon will be missing.
        if (-1 == indexOfColon)
        {
          // Invalid encoding
          return null;
        }
        String strUserName = XPStringUtility.Substring(strCredentials, 0,
         indexOfColon);
        String strPassword = XPStringUtility.Substring(strCredentials, indexOfColon + 1,
         strCredentials.Length);
        // LOGIN
        IPTSession myIPTSession;
        myIPTSession = PortalObjectsFactory.CreateSession();
        try
        {
          // Normal user login
          myIPTSession.Connect(strUserName, strPassword, null);
        }
        catch (Exception e)
        {
          // Do not log this exception.  It is expected that logins will fail as
          // we try to guess which character encoding is appropriate.
          return null;
        }
        return myIPTSession;
      }
      catch (Exception e)
      {
        // This is not an expected exception
        log.Error(e, "Unable to decode basic auth credentials using encoding " + sEncoding + ".");
        return null;
      }
    }
    
    /// <summary>
    /// This helper method verifies that after a successful login, no other
    /// character encodings could be used to get a successful login.
    /// </summary>
    /// <param name="sEncodedCredentials"></param>
    /// <param name="nSuccessfulEncoding">
    /// the index into HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED
    /// of the successful encoding.
    /// </param>
    /// <returns>
    /// false implies there were multiple logins - possible security hole
    /// if a user could login as another user.
    /// </returns>
    protected virtual bool VerifyNoAlternateLogins(String sEncodedCredentials,
     int nSuccessfulEncoding)
    {
      try
      {
        if (nSuccessfulEncoding >= HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED.Length)
        {
          return true;
        }
        String strCredentials = XPEncoding.GetString(XPBase64Coder.Decode(XPStringUtility.Substring(sEncodedCredentials,
         HTTPBasicAuthenticator.BASIC_AUTH.Length)), HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED[nSuccessfulEncoding]);
        int indexOfColon = XPStringUtility.IndexOf(strCredentials, ':');
        String strSuccessfulUserName = XPStringUtility.Substring(strCredentials,
         0, indexOfColon);
        for (int i = nSuccessfulEncoding + 1;i < HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED.Length;
        i++)
        {
          // Do not log certain exceptions.  It is expected that logins will fail as
          // we try to guess which character encoding is appropriate.  Some systems
          // may not support all of the character encodings (such as shift-jis).
          // For performance reasons, perhaps we should remove this encoding from
          // the array if it is not supported.
          try
          {
            strCredentials = XPEncoding.GetString(XPBase64Coder.Decode(XPStringUtility.Substring(sEncodedCredentials,
             HTTPBasicAuthenticator.BASIC_AUTH.Length)), HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED[i]);
            }
          catch (XPUnsupportedEncodingException e)
          {
            // Java throws this if the encoding is not supported
            break;
          }
          catch (XPIllegalArgumentException e)
          {
            // .NET throws this if the encoding is not supported
            break;
          }
          catch (Exception e)
          {
            // This is not an expected exception
            log.Error(e, "Unable to decode basic auth credentials using encoding " + HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED[i] + ".");
            break;
          }
          indexOfColon = XPStringUtility.IndexOf(strCredentials, ':');
          // Since we are guessing the encoding, it's possible that we will decode it
          // incorrectly and the colon will be missing.
          if (-1 != indexOfColon)
          {
            String strAlternateUserName = XPStringUtility.Substring(strCredentials,
             0, indexOfColon);
            if (0 != XPStringUtility.CompareIgnoreCase(strSuccessfulUserName,
             strAlternateUserName))
            {
              if (null != AttemptBasicAuthLogin(sEncodedCredentials, HTTPBasicAuthenticator.BASIC_AUTH_ENCODINGS_ORDERED[i]))
              {
                return false;
              }
            }
          }
        }
      }
      catch (Exception e)
      {
        // This is not an expected exception
        log.Error(e, "Unable to verify alternate basic auth logins.  Ignoring.");
        return true;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#GetDefaultPageRedirect()"></seealso>
    public virtual ILink GetDefaultPageRedirect(ILink suppliedLink, Object userSession,
     AActivitySpace asOwner)
    {
      if (suppliedLink == null)
      {
        return null;
      }
      ILink result = suppliedLink;
      result = GetSubPortalRedirectAfterLogin(suppliedLink, (IPTSession) userSession,
       asOwner);
      // NOTE: This shouldn't use hardcoded names
      if (result == null)
      {
        // If that fails, just redirect to mypage.
        // redirect to myPage
        result = new Redirect();
        /*MyPageAS.STR_MVC_CLASS_NAME*/
        result.SetLinkCreateNewSpace("MyPage", asOwner);
        /*SetPageControl.STR_MVC_CLASS_NAME*/
        result.SetControl("SetPage");
        /*SetPageControl.N_HOME_PAGE_ID*/
        result.AddControlArgument("PageID", 0);
      }
      return result;
    }
    public virtual ILink GetDefaultPageRedirect(ILink suppliedLink, Object userSession,
     IXPRequest request)
    {
      // TODO CR DLH: Um, is this used anywhere?  I think this was designed to solve the
      // problem Matt fixed in bug 65451, but it couldn't be used in the base subportal redirect
      // because we don't have the request object.  If we don't use this method, we should remove it
      AActivitySpace loginHelperAS = null;
      if (PTConfigService.getPTInstance().UseFriendlyURLS(PT_CLASSIDS.PT_COMMUNITY_ID,
       null) || PTConfigService.getPTInstance().UseFriendlyURLS(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
       null) || PTConfigService.getPTInstance().UseFriendlyURLS(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID,
       null))
      {
        // DCA - we need an activity space object to get the default page redirect if we're using friendly URLs. 
        // So let's make one.
        loginHelperAS = new PTLoginHelperAS();
        loginHelperAS.SetCurrentRequestURL(request.GetRequestURL());
        loginHelperAS.SetUserSession(userSession);
      }
      return GetDefaultPageRedirect(suppliedLink, userSession, loginHelperAS);
      }
    
    /// <summary>
    /// Internal helper method to get subportal redirect
    /// </summary>
    private static ILink GetSubPortalRedirectAfterLogin(ILink suppliedLink,
     IPTSession ptSession, AActivitySpace asOwner)
    {
      // NOTE: This shouldn't use hardcoded names
      // *** Subportal redirection BEGIN
      log.Debug("Entering subportal redirect.");
      ILink result = suppliedLink;
      // WilliamA - If this is a guest login (current user is guest)
      // always default to MyPage (since the caller must want to display
      // the MyPage as the login page for the subportal)
      int nDefaultPageType = PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS;
      if (null != ptSession)
      {
        nDefaultPageType = GetSubPortalFirstPageType(ptSession);
      }
      int nDefaultPageID = 0;
      if (null != ptSession)
      {
        nDefaultPageID = GetSubPortalPageID(ptSession);
      }
      // DCA - if we're coming from the login page, the ptSession in the Activity Space might be old
      if (null != ptSession && null != asOwner && !ptSession.Equals(asOwner.GetUserSession()))
      {
        asOwner.SetUserSession(ptSession);
      }
      switch (nDefaultPageType){
      case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS:
      // 1. Go to comm page
      // 2. If no access to comm page -> Go to default comm
      // 3. If no default comm -> Join comm page
      nDefaultPageID = GetAccessibleCommunityID(nDefaultPageID, ptSession);
      if (nDefaultPageID != -1)
      {
        if (PT_INTRINSICS.PT_PROFILE_COMMUNITY == nDefaultPageID)
        {
          // DCA - since this is a subportal redirect to the user profile page, we'll display the current user's profile
          int userId = TaskAPIServerUser.GetCurrentUserID(ptSession);
          if ((PTConfigService.getPTInstance().UseFriendlyURLS(PT_CLASSIDS.PT_USER_ID,
           null)) && (asOwner != null) && (result.GetType().Equals(typeof(Redirect))))
          {
            IPTURL url = new CommonOpenerFriendlyURL("", PT_CLASSIDS.PT_USER_ID,
             userId, asOwner);
            result.SetLinkToExternalURL(url.GetFullURL());
          } else
          {
            /*CommunityPageAS.STR_MVC_CLASS_NAME*/
            result.SetLinkCreateNewSpace("CommunityPage", asOwner);
            /*SetCommunityControl.STR_MVC_CLASS_NAME*/
            result.SetControl("SetCommunity");
            /*SetCommunityControl.STR_COMMUNITY_ID*/
            result.AddControlArgument("CommunityID", nDefaultPageID);
            /*SetCommunityControl.STR_PAGE_ID*/
            result.AddControlArgument("PageID", 0);
            /*SetCommunityControl.PROFILEID*/
            result.AddControlArgument("ProfileID", userId);
          }
          log.Info("Redirecting to the User Profile Page");
          break;
        }
        if ((PTConfigService.getPTInstance().UseFriendlyURLS(PT_CLASSIDS.PT_COMMUNITY_ID,
         null)) && (asOwner != null) && (result.GetType().Equals(typeof(Redirect))))
        {
          IPTURL url = new CommonOpenerFriendlyURL("", PT_CLASSIDS.PT_COMMUNITY_ID,
           nDefaultPageID, asOwner);
          result.SetLinkToExternalURL(url.GetFullURL());
        } else
        {
          /*CommunityPageAS.STR_MVC_CLASS_NAME*/
          result.SetLinkCreateNewSpace("CommunityPage", asOwner);
          /*SetCommunityControl.STR_MVC_CLASS_NAME*/
          result.SetControl("SetCommunity");
          /*SetCommunityControl.STR_COMMUNITY_ID*/
          result.AddControlArgument("CommunityID", nDefaultPageID);
          /*SetCommunityControl.STR_PAGE_ID*/
          result.AddControlArgument("PageID", 0);
        }
        log.Info("Redirecting to community with id: " + nDefaultPageID);
      } else
      {
        /*CommunitySelectionEditorAS.STR_MVC_CLASS_NAME*/
        result.SetLinkCreateNewSpace("CommunitySelection", asOwner);
        result.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        result.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
        log.Info("No Community memberships, redirecting to community selection page.");
        }
      break;
      case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS:
      if ((PTConfigService.getPTInstance().UseFriendlyURLS(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
       null)) && (asOwner != null) && (result.GetType().Equals(typeof(Redirect))))
      {
        IPTURL url = new CommonOpenerFriendlyURL("", PT_CLASSIDS.PT_CATALOGFOLDER_ID,
         nDefaultPageID, asOwner);
        result.SetLinkToExternalURL(url.GetFullURL());
      } else
      {
        /*DirAS.STR_MVC_CLASS_NAME*/
        result.SetLinkCreateNewSpace("Dir", asOwner);
        /*OpenSubFolderControl.STR_MVC_CLASS_NAME*/
        result.SetControl("OpenSubFolder");
        /*DirConstants.QS_DIRECTORY_MODE*/
        result.AddControlArgument("DirMode", /*DirConstants.BROWSE_MODE*/
        1);
        /*OpenSubFolderControl.m_SubFolderID*/
        result.AddControlArgument("subfolderID", nDefaultPageID);
      }
      log.Info("Redirecting to directory page with folder id: " + nDefaultPageID);
      break;
      case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS:
      if ((PTConfigService.getPTInstance().UseFriendlyURLS(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID,
       null)) && (asOwner != null) && (result.GetType().Equals(typeof(Redirect))))
      {
        IPTURL url = new CommonOpenerFriendlyURL("", PT_CLASSIDS.PT_MYPAGESCONTAINER_ID,
         0, asOwner);
        result.SetLinkToExternalURL(url.GetFullURL());
      } else
      {
        /*MyPageAS.STR_MVC_CLASS_NAME*/
        result.SetLinkCreateNewSpace("MyPage", asOwner);
        /*SetPageControl.STR_MVC_CLASS_NAME*/
        result.SetControl("SetPage");
        /*SetPageControl.STR_PAGE_ID*/
        result.AddControlArgument("PageID", /*SetPageControl.N_HOME_PAGE_ID*/
        0);
      }
      log.Info("Redirecting to mypage.");
      break;
      default:
      return null;
      break;
      }
      return result;
    }
    // *** Subportal redirection END	
    
    /// <summary>
    /// Gets the page type of the default first page of the subportal.
    /// </summary>
    /// <returns>int</returns>
    private static int GetSubPortalFirstPageType(IPTSession ptSession)
    {
      try
      {
        IPTSubPortalInfo subPortal = (ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo());
        int nAccessType = subPortal.GetDefaultFirstPageType();
        return nAccessType;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get the SubPortalInfo object for First Page type: ");
        throw XPException.GetInstance(e);
      }
    }
    // TODOCR: This method fails sometimes while checking ACLS in the PT object cache
    // Should we handle this error?
    //			return -1;
    
    /// <summary>
    /// Gets the page ID of the default first page of the subportal.
    /// </summary>
    /// <returns></returns>
    private static int GetSubPortalPageID(IPTSession ptSession)
    {
      try
      {
        IPTSubPortalInfo subPortal = (ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo());
        int nFirstPageID = subPortal.GetDefaultFirstPageID();
        return nFirstPageID;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get the SubPortalInfo object for First Page ID.");
        throw XPException.GetInstance(e);
      }
    }
    // TODOCR: This method fails sometimes while checking ACLS in the PT object cache
    // Should we handle this error?
    //			return -1;
    
    /// <summary>
    /// Gets the community ID of the first accessible community for this user.
    /// </summary>
    /// <param name="nSubPortalCommID"></param>
    /// <returns>int</returns>
    private static int GetAccessibleCommunityID(int nSubPortalCommID, IPTSession ptSession)
    {
      // 1. Go to comm page
      // 2. If no access to comm page -> Go to default comm
      // 3. If no default comm -> Join comm page
      IPTObjectManager objOMCommunites = ptSession.GetCommunities();
      if (objOMCommunites.IsObjectAccessible(nSubPortalCommID, ptSession.GetSessionInfo().GetCurrentUserID(),
       PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
      {
        return nSubPortalCommID;
      } else
      {
        IPTQueryResult ptCommunityMembership = ptSession.GetSessionInfo().GetCurrentCommunityMembership();
        if (ptCommunityMembership.RowCount() != 0)
        {
          int intFirstCommunityID = ptCommunityMembership.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
          return intFirstCommunityID;
        } else
        {
          return -1;
        }
      }
    }
    // The following code should really be in a separate login var pack.
    
    /// <summary>
    /// This method sets whether or not to allow user creation.
    /// </summary>
    /// <param name="space">the current Activity Space</param>
    /// <param name="application">the application</param>
    /// <param name="boolean">whether or not to allow user creation.</param>
    public static void SetAllowUserCreation(AActivitySpace space, IApplication application,
     bool b)
    {
      CachingManager cache = application.GetCachingManager();
      cache.SetEntry(sKeySelect, b);
      XPDateTime dNow = new XPDateTime();
      cache.SetEntry(sKeyLastUpdate, dNow);
    }
    
    /// <summary>
    /// This method returns whether or not to allow user creation
    /// and handles caching and refreshing of this value.
    /// </summary>
    /// <param name="space">The Activity Space</param>
    /// <param name="application">The Application</param>
    /// <returns>boolean true implies allow user creation.</returns>
    public static bool GetAllowUserCreation(AActivitySpace space, IApplication application)
    {
      log.Debug("GetAllowUserCreation()");
      XPDateTime dLastUpdated = null;
      XPDateTime dNow = null;
      Object bo = null;
      // Check if the cached version is there and still valid
      CachingManager cache = application.GetCachingManager();
      dLastUpdated = (XPDateTime) cache.GetEntry(sKeyLastUpdate);
      // NOTE: this is probably not 100% threadsafe.
      if (dLastUpdated != null)
      {
        //   There is a last updated date
        log.Debug("GetAllowUserCreation: Last updated: " + dLastUpdated);
        dNow = new XPDateTime();
        if ((dNow.GetTimeInMilliSeconds() - dLastUpdated.GetTimeInMilliSeconds()) < PTLoginHelper.ALLOW_USER_CREATION_LINK_CACHE_LIFE_MS)
        {
          // If the last updated select is still valid.
          //   attempt to get the select.
          bo = (Object) cache.GetEntry(sKeySelect);
          if (bo != null)
          {
            log.Debug("GetAllowUserCreation: Got a cached allow user creation boolean!");
            //   if it's there, return it.
            return XPConvert.ToBoolean(bo);
          }
        } else
        {
          log.Debug("GetAllowUserCreation: Out of date: " + dLastUpdated);
          }
      }
      //   Either there's no last updated date, the last updated date
      //   is too old, or there was no select cached on the application.
      //   we must make a new one.
      log.Debug("GetAllowUserCreation: Creating a new allow user creation boolean.");
      bool bAllowUserCreation;
      IPTServerConfigSettings config = (IPTServerConfigSettings) GetPTSession(space).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       true);
      if (config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ALLOW_NEW_USER_CREATION_TO_ALL) == 1)
      {
        bAllowUserCreation = true;
      } else
      {
        bAllowUserCreation = false;
      }
      // Cache new entry
      cache.SetEntry(sKeySelect, bAllowUserCreation);
      dNow = new XPDateTime();
      cache.SetEntry(sKeyLastUpdate, dNow);
      return bAllowUserCreation;
    }
    
    /// <summary>
    /// Whether or not to show the authentication source dropdown.
    /// </summary>
    public static bool ShowAuthDropdown()
    {
      return s_bShowDropdown;
    }
    
    /// <summary>
    /// Whether or not to allow the authentication source dropdown.
    /// </summary>
    public static bool AllowAuthDropdown()
    {
      if (3 == s_nDropdownMode)
      {
        return false;
      }
      return true;
    }
    
    /// <summary>
    /// Whether or not to show the remember my password checkbox.
    /// </summary>
    public static bool ShowRememberMyPassword()
    {
      return s_bShowRMP;
    }
    
    /// <summary>
    /// The default prefix 
    /// </summary>
    public static String GetDefaultPrefix()
    {
      return s_sDefaultPrefix;
    }
    
    /// <summary>
    /// Initialize various variables from the xml file.
    /// </summary>
    public static void StaticInit(PTConfigVarPack vpConfig)
    {
      s_sDefaultPrefix = null;
      s_bShowDropdown = true;
      s_bShowRMP = true;
      try
      {
        s_nDropdownMode = vpConfig.GetConfigValueAsInt("Authentication", "AllowDefaultLoginPageAuthSource",
         "value");
        switch (s_nDropdownMode){
        // Case 1 and 3 are the same, except 3 doesn't allow you to show the auth
        // sources.
        case 1:
        case 3:
        s_bShowDropdown = false;
        goto case 
        // mj: fall through to the next case to set the default prefix
        2;
        case 2:
        s_sDefaultPrefix = vpConfig.GetConfigValueAsString("Authentication",
         "DefaultAuthSourcePrefix", "value");
        break;
        case 0:
        default:
        break;
        }
      }
      // mj: defaults are set above
      catch (Exception e)
      {
        log.Error(e, "Unable to init LoginPortlet settings from config.xml");
        // Default value
        s_nDropdownMode = 0;
      }
      try
      {
        int i = vpConfig.GetConfigValueAsInt("Authentication", "AllowAutoConnect",
         "value");
        if (i == 0)
        {
          s_bShowRMP = false;
        } else
        {
          s_bShowRMP = true;
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to init LoginPortlet settings from config.xml");
        }
    }
    
    /// <summary>
    /// Method GetPTSession.  Gets IPTSession from AActivitySpace cleanly.
    /// </summary>
    /// <param name="as"></param>
    /// <returns>IPTSession</returns>
    public static IPTSession GetPTSession(AActivitySpace aSpace)
    {
      IPTSession ptSession;
      try
      {
        ptSession = (IPTSession) aSpace.GetUserSession();
      }
      catch (Exception ex)
      {
        log.Error(ex, "Couldn\'t cast UserSession to IPTSession.");
        throw new XPException("The user session must derive from IPTSession.",
         ex);
      }
      return ptSession;
    }
    
    /// <summary>
    /// Call this method to set an autologin token for the user.
    /// </summary>
    /// <param name="oWebData"></param>
    /// <param name="oUserSession"></param>
    /// <param name="nExpires">
    /// cookie expiration time in minutes.  -1 means use default value.
    /// 0 means don't set an expires time (expire at end of session).
    /// </param>
    /// <param name="bIsPersistentCookie">
    /// false means don't set an expires time
    /// (expire at end of session).
    /// </param>
    /// <param name="bIsSecure">whether or not the login cookie is secure</param>
    public virtual void SetAutologinToken(IWebData oWebData, Object oUserSession,
     int nExpires, bool bIsPersistentCookie, bool bIsSecure)
    {
      int nExpSeconds;
      int nExpMinutes;
      if (-1 == nExpires)
      {
        // Get the Remember My Password default expiration from the config varpack
        IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
        PTConfigVarPack vpPTConfig = (PTConfigVarPack) application.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID);
        String strRememberPassword = vpPTConfig.GetConfigValueAsString(ConfigConstants.AUTHENTICATION_SECTION,
         "RememberPassword", ConfigConstants.VALUE_ATTRIBUTE);
        // one week
        nExpMinutes = XPConvert.ToInteger(strRememberPassword);
        nExpSeconds = nExpMinutes * 60;
      } else
      {
        nExpMinutes = nExpires;
        nExpSeconds = nExpMinutes * 60;
      }
      // Login Token expects the expire time in minutes
      String sToken = ((IPTSession) oUserSession).GetToken(nExpMinutes);
      XPCookie cookie = new XPCookie(LoginHelper.LOGIN_TOKEN_COOKIE_NAME,
       sToken);
      cookie.SetPath(LoginHelper.LOGIN_TOKEN_COOKIE_PATH);
      // Not setting an expires value on a cookie uses the default behaviour
      // in both Java and .NET (deleted when browser is closed).  Unless
      // RMP is occurring, we want the cookie to expire with the browser session.
      if (bIsPersistentCookie)
      {
        // Cookie expects the expire time in seconds
        cookie.SetExpireTime(nExpSeconds);
      }
      cookie.SetSecure(bIsSecure);
      log.Info("SetAutologinToken() - about to add token cookie.");
      oWebData.AddCookie(cookie);
    }
    
    /// <summary>
    /// Returns an HTMLElementCollection of style sheet links.  A style sheet is
    /// named "stylesheetname-language", for instance "mainstyle12-en".  This function
    /// creates a valid PTStyleSheetLink by collecting the style sheet name from the
    /// user's subportal, and the user's language from the activity space, then forming
    /// a PTStyleSheetLink object from this information.
    /// </summary>
    /// <param name="Pass">
    /// in the userSession, this function will look up the stylesheet name
    /// from the user's subportal.
    /// </param>
    /// <param name="Pass">
    /// in the ActivitySpace, this function will look up the current
    /// user's language.
    /// </param>
    public virtual HTMLElementCollection GetStyleSheetLinks(Object userSession,
     AActivitySpace asOwner)
    {
      String strStyleSheetName = ((IPTSession) userSession).GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetStyleSheet();
      if (("").Equals(strStyleSheetName) || (strStyleSheetName == null))
      {
        strStyleSheetName = PlumtreeHelpers.s_strDefaultStyleSheet;
      }
      if (asOwner.GetIsAccessStyleNonStandard())
      {
        strStyleSheetName = PlumtreeHelpers.STYLE_PREFIX_508 + strStyleSheetName;
        }
      //JD- This will always return a language (no need for a default).  Language is derived from locale,
      //so if the user didn't select a locale, the default language will be derived from the default locale.
      String settingLanguage = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
       asOwner);
      PTStyleSheetLink ptStyleSheetLink = new PTStyleSheetLink(strStyleSheetName,
       settingLanguage);
      HTMLElementCollection ptCollection = new HTMLElementCollection();
      try
      {
        ptCollection.AddInnerHTMLElement(ptStyleSheetLink.GetLinkAsHTMLElement(ConfigHelper.GetStyleSheetsBaseURL(asOwner)));
        }
      catch (HTMLException e)
      {
        log.Error(e, "Plumtree Helpers - error adding style sheet link to Collection.");
        }
      catch (Exception e)
      {
        log.Error(e, "Plumtree Helpers - error getting style sheet.");
      }
      return ptCollection;
    }
    
    /// <summary>
    /// Checks if the current process has been recycled. This method won't do any further checks if the call to the COM server fails. 
    /// The assumption is if a check fails then COM+ recycling is not supported  
    /// </summary>
    /// <returns>
    /// An IPTSession created in new COM process with the current user logged in if the current process has been recycled.
    /// null if no recycling happened. 
    /// </returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.login.ILoginHelper#HandleCOMPlusProcessRecycled(java.lang.Object)"></seealso>
    public virtual Object HandleCOMPlusProcessRecycled(Object userSession)
    {
      //MES- Disabling this feature- it's no longer relevant
      return null;
    }
    
    /// <summary>
    /// Return the dropdown mode specified in the portal configuration.
    /// </summary>
    /// <returns>int dropdownmode</returns>
    public static int GetDropdownMode()
    {
      return s_nDropdownMode;
    }
  }
}