using System;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.navtype
{
  /// <summary>
  /// Core pluggable navigation interface.  All pluggable navigations must implement this high-level interface, 
  /// which lsist the names of view classes used for each area of the page the developer wishes to take over
  /// for navigation purposes.  Refer to IPluggableNavRO for all model-related methods to build navigation.  
  /// </summary>
  /// <author>JohnO</author>
  /// <author>DavidP</author>
  /// <seealso cref="IPluggableNavRO"></seealso>
  public interface INavTypes
  {
    
    /// <summary>
    /// Return the integer order of the navigation type.  Must be greater than 5 for external plugins.
    /// Note that this number must be unique among registered navigation
    /// plugins on any specific install.
    /// </summary>
    /// <returns>integer navigation topic position</returns>
    int GetID();
    
    /// <summary>
    /// Return the text name of this navigation type shown in the subportal editor.
    /// </summary>
    /// <returns>String plguin name</returns>
    String GetName(String _strLangID);
    
    /// <summary>
    /// Return the description of this navigation plugin shown in the subportal editor.
    /// </summary>
    /// <returns>String plugin scope</returns>
    String GetScope(String _strLangID);
    
    /// <summary>
    /// Return the names of the javascript file includes as an array of strings
    /// or null if none are used.  A single javascript include is supported
    /// for all subviews in each pluggable navigation instance.  
    /// IMPORTANT NOTE:
    /// This function is where IView.DisplayJavaScript() should be called in order
    /// for the navigation view specific javascript to appear in the navigation.
    /// </summary>
    /// <returns>String[]</returns>
    HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner);
    
    /// <summary>
    /// Return boolean to control whether or not a specific navigation feature
    /// is displayed.  Examples include the topbar, the header (banner), and
    /// the footer.
    /// </summary>
    /// <returns>boolean</returns>
    /// <seealso cref="NavFeatureEnum"></seealso>
    /// <seealso cref="NavFeatureHelper"></seealso>
    bool IsFeatureEnabled(NavFeatureEnum feature);
    
    /// <summary>
    /// Primary method to implement for pluggable navigation support.
    /// Return stringname of the view class by page area used in pluggable navigation.
    /// Viewnames returned will be registered as IView types associated with the main
    /// display class' MVC hierarchy and used to render the page via pluggable navigation.
    /// Area examples include left and right of page body, and above and below the banner.
    /// IView classes return HTML used to display the page. 
    /// </summary>
    /// <returns>String</returns>
    /// <seealso cref="NavAreaEnum"></seealso>
    /// <seealso cref="NavAreaHelper"></seealso>
    String GetNavAreaView(NavAreaEnum area);
  }
}