/*
 * Created on Mar 7, 2003
 */
 
using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portaluiinfrastructure.navtype
{
  /// <summary>
  /// Helper class to assist in the enumeration of navigation types
  /// </summary>
  /// <author>DavidP</author>
  public class NavAreaHelper
  {
    private XPArrayList navTypeArray = null;
    public static readonly NavAreaHelper INSTANCE = new NavAreaHelper();
    
    /// <summary>
    /// Constructs helper class with accessors for array of nav types.
    /// </summary>
    private NavAreaHelper()
    {
      navTypeArray = new XPArrayList();
      for (int i = 0;i < NavAreaEnum.m_navAreaEnums.Length;++i)
      {
        navTypeArray.Add(NavAreaEnum.m_navAreaEnums[i]);
      }
    }
    
    /// <summary>
    /// Enumerates the possible nav types available.
    /// </summary>
    /// <returns>IXPEnumerator</returns>
    public virtual IXPEnumerator GetCategoryTypes()
    {
      IXPEnumerator eKeys = null;
      if (navTypeArray != null && navTypeArray.GetSize() > 0)
      {
        eKeys = navTypeArray.GetEnumerator();
      }
      return eKeys;
    }
    
    /// <summary>
    /// Enumerates the possible nav types available.
    /// </summary>
    /// <returns>XPArrayList</returns>
    public virtual XPArrayList GetCategoryTypeArray()
    {
      return navTypeArray;
    }
    
    /// <summary>
    /// Returns the number of nav types.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetNumCategoryTypes()
    {
      if (navTypeArray != null)
      {
        return navTypeArray.GetSize();
      }
      return 0;
    }
    
    /// <summary>
    /// Get the name if the view class from pluggable navigation to be registered 
    /// in the AActivitySpace and called by DisplayPage to render that area of 
    /// the page
    /// </summary>
    /// <param name="plugNav"></param>
    /// <param name="pageArea"></param>
    /// <returns>String</returns>
    public virtual String GetNavAreaViewClassName(INavTypes plugNav, NavAreaEnum pageArea)
    {
      return plugNav.GetNavAreaView(pageArea);
    }
  }
}