using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.search.admin;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.opener.plugins
{
  /// <summary>
  /// This plugin enables the Common Opener to open objects using
  /// only a "kw" parameter.  The keyword is processed into its
  /// ClassID/ObjectID equivalent and put back into the QS.
  /// </summary>
  /// <author>michaeld</author>
  public class KeywordPlugin : IOpenerPlugins
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.opener.plugins.KeywordPlugin");
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.opener.IOpenerPlugins#ProcessPlugIn(RedirectData,AActivitySpace,Object)"></seealso>
    public virtual RedirectData ProcessPlugIn(RedirectData _redirectData,
     AActivitySpace _asCurrentSpace, Object _userSession)
    {
      // get the keyword from the querystring. 
      String strKeyword = HTTPHelpers.GetArgumentAsString(_redirectData.GetQSArguments(),
       IPTOpenerConstants.QS_KEYWORD, null);
      log.Debug("keyword retreived from querystring is " + strKeyword);
      if (null != strKeyword)
      {
        // replace underscores with spaces
        strKeyword = GeneralHelpers.Replace(strKeyword, "_", " ");
        SearchKeywordHelper kwHelper = new SearchKeywordHelper(_asCurrentSpace);
        try
        {
          BestBetResult ptBBResult = kwHelper.getObject(strKeyword);
          if (null != ptBBResult)
          {
            String strType = ptBBResult.getType();
            log.Debug("Best Bet Result is " + ptBBResult.getName() + " of type " + strType);
            if ((SearchResultModel.PORTAL_APP).Equals(strType))
            {
              int nClassID = ptBBResult.getPortalClassId();
              int nObjectID = ptBBResult.getPortalObjectId();
              log.Debug("Best Bet Result has classID " + nClassID + " and objectID " + nObjectID);
              if (0 != nClassID && 0 != nObjectID)
              {
                log.Debug("setting redirect data with classID " + nClassID + " and objectID " + nObjectID);
                // put ClassID in return data, overwriting if it exists. 
                _redirectData.AddQSArgument(IPTOpenerConstants.QS_CLASSID,
                 nClassID);
                // put ObjectID in return data, overwriting if it exists. 
                _redirectData.AddQSArgument(IPTOpenerConstants.QS_OBJECTID,
                 nObjectID);
                // set the mode to search browse
                _redirectData.AddQSArgument(IPTOpenerConstants.QS_MODE, IPTOpenerConstants.OPENER_MODE_SEARCH_BROWSE);
                if (PT_CLASSIDS.PT_GADGET_ID == nClassID)
                {
                }
              } else
              // Problem 1: If it's a gadget, it needs to go in a pop-up.
              {
                // redirect to search result for strKeyword
                log.Debug("redirect to search result for " + strKeyword);
                RedirectToSearch(_redirectData, _asCurrentSpace, _userSession,
                 strKeyword);
              }
            } else
            // if collab or content server.
            {
              String strCollabOrContentGatewayedURL = ptBBResult.getCollabOrContentGatewayedURL();
              if (null != strCollabOrContentGatewayedURL)
              {
                log.Debug("Redirecting to collab or content with URL " + strCollabOrContentGatewayedURL);
                RedirectToUrl(_redirectData, strCollabOrContentGatewayedURL);
                }
            }
          } else
          {
            // redirect to search result for strKeyword
            if (null != strKeyword)
            {
              log.Debug("redirect to search result for " + strKeyword);
              RedirectToSearch(_redirectData, _asCurrentSpace, _userSession,
               strKeyword);
            }
          }
        }
        catch (XPException e)
        {
          // we don't really care why this crashes. we will just ignore the keyword.
          // redirect to search result for strKeyword
          RedirectToSearch(_redirectData, _asCurrentSpace, _userSession, strKeyword);
          }
      } else
      // the keyword is null
      {
        log.Debug("keyword from querystring is null.");
      }
      return _redirectData;
    }
    private void RedirectToSearch(RedirectData _redirectData, AActivitySpace _asCurrentSpace,
     Object _userSession, String strKeyword)
    {
      Redirect redirect = new Redirect();
      redirect.SetLinkCreateNewSpace("SearchResult", _asCurrentSpace);
      redirect.SetControl("bannerstart");
      IPTSession ptSession = (IPTSession) _userSession;
      redirect.AddControlArgument(ASConstants.USERID_INPUT, XPConvert.ToString(ptSession.GetSessionInfo().GetCurrentUserID()));
      redirect.AddControlArgument(SearchResultControl.USER_QUERY, strKeyword);
      _redirectData.SetRedirect(redirect);
      _redirectData.SetHaltPlugins(true);
    }
    private void RedirectToUrl(RedirectData _redirectData, String strUrl)
    {
      Redirect redirect = new Redirect();
      redirect.SetLinkToExternalURL(strUrl);
      _redirectData.SetRedirect(redirect);
      _redirectData.SetHaltPlugins(true);
    }
  }
}