using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.opener.plugins
{
  /// <summary>
  /// This plugin enables the Common Opener to open objects using
  /// only a "uuID" parameter.  The UUID is processed into its
  /// ClassID/ObjectID equivalent and put back into the QS.
  /// </summary>
  /// <author>RickyW</author>
  public class UUIDPlugin : IOpenerPlugins
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.opener.plugins.UUIDPlugin");
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.opener.IOpenerPlugins#ProcessPlugIn(RedirectData,AActivitySpace,Object)"></seealso>
    public virtual RedirectData ProcessPlugIn(RedirectData _redirectData,
     AActivitySpace _asCurrentSpace, Object _userSession)
    {
      IPTSession ptSession = (IPTSession) _userSession;
      // get the UUID from the querystring. 
      String strUUID = HTTPHelpers.GetArgumentAsString(_redirectData.GetQSArguments(),
       IPTOpenerConstants.QS_UUID, null);
      log.Debug(IPTOpenerConstants.QS_UUID + " from querystring is " + strUUID);
      if (null != strUUID)
      {
        // decode the UUID into class/object IDs.
        IPTMigrationManager ptMigrationManager = (IPTMigrationManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
         false);
        Object[] ptIDs = (Object[]) ptMigrationManager.UUIDToObjectID(strUUID);
        if (null != ptIDs && ptIDs.Length == 2)
        {
          log.Debug("retreived classID " + ptIDs[0] + " and objectID " + ptIDs[1] + " with uuID " + strUUID);
          // put ClassID in return data, overwriting if it exists. 
          _redirectData.AddQSArgument(IPTOpenerConstants.QS_CLASSID, ptIDs[0]);
          // put ObjectID in return data, overwriting if it exists. 
          _redirectData.AddQSArgument(IPTOpenerConstants.QS_OBJECTID, ptIDs[1]);
          } else
        {
          log.Info("Unable to retreive classID and objectID from uuID " + strUUID);
          }
      } else
      {
        log.Debug("invalid uuID, uuID is null.");
      }
      return _redirectData;
    }
  }
}