using System;
using IXPList=com.plumtree.openfoundation.util.IXPList;
using XPException=com.plumtree.openfoundation.util.XPException;
using XPIllegalStateException=com.plumtree.openfoundation.util.XPIllegalStateException;
namespace com.plumtree.portaluiinfrastructure.pathways.tagging
{
  /// <summary>
  /// This Interface Provides Methods to Handle getting, Adding/Removing Tags from Pathways
  /// </summary>
  /// <author>Ravi Tunuguntla</author>
  public interface ITaggingModel
  {
    
    /// <summary>
    /// Gets the List of Tags of that are attached to this Object by pathways.
    /// </summary>
    /// <param name="id">Object Id</param>
    /// <returns>List of Tags added to This Object</returns>
    IXPList GetObjectTags(int id);
    
    /// <summary>
    /// Adds/Removes Tag specified for the Object with given ID based on Action specified.
    /// </summary>
    /// <param name="tag">Name of the Tag that needs to be Added or Removed</param>
    /// <param name="id">Concatenation of classid and Object Id PTCLASSID_PTOJECTID</param>
    /// <param name="action">Operation to perform on the Tag, 0 = Add, 1 = Delete, 2 = Edit (delete old tag and add new tag)</param>
    /// <param name="ptsource">source of the Object to be specified for Pathways it can be PTPORTAL or PTCOLLAB, for more sources see PathwaysConstants.</param>
    /// <throws>XPIllegalStateException Throws this exception if pathways is unavailable and a request to Add/Remove Tags is sent.</throws>
    void AddRemoveObjectTag(String tag, String id, int action, String ptsource);
    
    /// <summary>
    /// Renames Tag specified for the Object with given ID.
    /// </summary>
    /// <param name="tag">the Source Tag Name to be used for renaming</param>
    /// <param name="id">Concatenation of classid and Object Id PTCLASSID_PTOJECTID</param>
    /// <param name="ptsource">source of the Object to be specified for Pathways it can be PTPORTAL or PTCOLLAB, for more sources see PathwaysConstants.</param>
    /// <param name="renameTag">the Target Tag Name to be used for renaming</param>
    /// <throws>XPIllegalStateException Throws this exception if pathways is unavailable and a request to Add/Remove Tags is sent.</throws>
    void RenameObjectTag(String tag, String id, String ptsource, String renamtTag);
    
    /// <summary>
    /// True if Pathways is enabled and user can tag items, else false.
    /// </summary>
    /// <returns>boolean</returns>
    bool IsTaggingEnabled();
    
    /// <summary>
    /// This method returns an error that happened when Add/Remove/Rename Tag request is
    /// sent to pathways. This returns null if there is no error.
    /// </summary>
    /// <returns>XPException that contains the error, if Tagging was success then it returns null.</returns>
    XPException GetPathwaysTaggingError();
    
    /// <summary>
    /// This method sets error that happened when tagging request is sent to pathways.
    /// </summary>
    void SetPathwaysTaggingError(XPException e);
  }
}