using System;
using IXPEnumerator=com.plumtree.openfoundation.util.IXPEnumerator;
using XPException=com.plumtree.openfoundation.util.XPException;
using XPNullPointerException=com.plumtree.openfoundation.util.XPNullPointerException;
using XPHttpUtility=com.plumtree.openfoundation.web.XPHttpUtility;
using OpenLogService=com.plumtree.openlog.OpenLogService;
using OpenLogger=com.plumtree.openlog.OpenLogger;
using PTDebugHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using HTTPHeaderConstants=com.plumtree.uiinfrastructure.activityspace.HTTPHeaderConstants;
using IDisplayPage=com.plumtree.uiinfrastructure.activityspace.IDisplayPage;
using IWebData=com.plumtree.uiinfrastructure.activityspace.IWebData;
namespace com.plumtree.portaluiinfrastructure.pathways.tagging
{
  /// <author>
  /// Ravi Tunuguntla
  /// This display page is used to transmit server side errors to UI.
  /// This returns non null HTTP response if there is a server error 
  /// while Adding/Removing/Renaming Tags and The error message is 
  /// returned in the response
  /// </author>
  public class TaggingRESTDP : IDisplayPage
  {
    private static OpenLogger logger = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.pathways.TaggingRESTDP");
    public const String STR_MVC_CLASS_NAME = "PathwaysTags";
    protected AActivitySpace m_asOwner;
    protected ITaggingModel m_model;
    public TaggingRESTDP()
    {
    }
    public virtual void Display(IWebData webData)
    {
      webData.SetIsHTMLText(false);
      webData.SetHeader(HTTPHeaderConstants.CONTENT_TYPE, "text/json-comment-filtered");
      XPException tagErr = m_model.GetPathwaysTaggingError();
      if (null != tagErr)
      {
        // HTML encode the error string.
        String strError = XPHttpUtility.HtmlEncode(tagErr.GetMessage());
        // Setting the HTTP Error code to 400.
        webData.SetStatus(400);
        webData.SetData(strError);
      }
    }
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      if (null != m_asOwner)
      {
        for (IXPEnumerator e = m_asOwner.GetModelsEnumerator();e.MoveNext();
        )
        {
          if (e.GetCurrent() is ITaggingModel)
          {
            m_model = (ITaggingModel) e.GetCurrent();
            break;
          }
        }
      } else
      {
        throw new XPNullPointerException("Failed to initialize since Activityspace is null.");
        }
    }
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}