/*
 * Created on Dec 8, 2004
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.tags.data;
namespace com.plumtree.portaluiinfrastructure.ptlink
{
  /// <summary>
  /// Abstract class that defines common CommonOpenerURL data and functions.
  /// </summary>
  public abstract class ACommonOpenerURL : APTURL,IDataObject
  {
    
    /// <summary>
    /// Constant  to get/set baseurl.
    /// </summary>
    public const String KEY_COMMONOPENER_APPBASEURL = "baseurl";
    
    /// <summary>
    /// Constant  to get/set user id.
    /// </summary>
    public const String KEY_COMMONOPENER_USERID = "userid";
    
    /// <summary>
    /// Constant  to get/set common opener mode.
    /// </summary>
    public const String KEY_COMMONOPENER_OPENERMODE = "mode";
    protected String m_strApplicationBaseURL;
    protected int m_nOpenerMode;
    protected int m_nUserID = PTOpenerLinks.INT_PARAM_EXCLUDEVALUE;
    
    /// <summary>
    /// Constructor with no Opener mode or user id.\u0009
    /// </summary>
    /// <param name="strTitle">URL title</param>
    /// <param name="strApplicationBaseURL">Application Base URL, E.g. http://www.plumtree.com:8000.</param>
    public ACommonOpenerURL(String strTitle, String strApplicationBaseURL) : base(strTitle)
    {
      m_strApplicationBaseURL = strApplicationBaseURL;
    }
    
    /// <summary>
    /// Constructor
    /// </summary>
    /// <param name="strTitle">URL title</param>
    /// <param name="strApplicationBaseURL">Application Base URL, E.g. http://www.plumtree.com:8000.</param>
    /// <param name="nMode">CommonOpener mode.</param>
    /// <param name="nUserID">User ID.</param>
    public ACommonOpenerURL(String strTitle, String strApplicationBaseURL,
     int nMode, int nUserID) : this(strTitle, strApplicationBaseURL)
    {
      m_nUserID = nUserID;
      m_nOpenerMode = nMode;
    }
    
    /// <summary>
    /// Constructor with no Opener mode.
    /// </summary>
    /// <param name="strTitle">URL title</param>
    /// <param name="strApplicationBaseURL">Application Base URL, E.g. http://www.plumtree.com:8000.</param>
    /// <param name="nUserID">User ID.</param>
    public ACommonOpenerURL(String strTitle, String strApplicationBaseURL,
     int nUserID) : this(strTitle, strApplicationBaseURL)
    {
      m_nUserID = nUserID;
      m_nOpenerMode = -1;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetFullURL()"></seealso>
    public abstract override String GetFullURL();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetURI()"></seealso>
    public abstract override String GetURI();
    
    /// <summary>
    /// Supports <c>KEY_COMMONOPENER_APPBASEURL</c> and <c>KEY_COMMONOPENER_USERID</c> constants. 
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.APTURL#GetData(java.lang.String)"></seealso>
    public override String GetData(String strKey)
    {
      String retVal = null;
      if (KEY_COMMONOPENER_APPBASEURL.Equals(strKey))
      {
        retVal = m_strApplicationBaseURL;
      } else
      if (KEY_COMMONOPENER_USERID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_nUserID);
      } else
      {
        retVal = base.GetData(strKey);
      }
      return retVal;
    }
    
    /// <summary>
    /// Supports <c>KEY_COMMONOPENER_APPBASEURL</c> and <c>KEY_COMMONOPENER_USERID</c> constants.
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.APTURL#SetURLData(java.lang.String,java.lang.String)"></seealso>
    public override void SetURLData(String strKey, String strValue)
    {
      if (KEY_COMMONOPENER_APPBASEURL.Equals(strKey))
      {
        m_strApplicationBaseURL = strValue;
      } else
      if (KEY_COMMONOPENER_USERID.Equals(strKey))
      {
        m_nUserID = XPConvert.ToInteger(strValue);
      } else
      {
        base.SetURLData(strKey, strValue);
      }
    }
  }
}