/*
 * Created on Dec 7, 2004
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.ptlink
{
  /// <summary>
  /// Abstract PTURL class with common functionality for all URLs, i.e.
  /// URL title, URL icon, icon width and height, Icon Alt and Current marker.
  /// </summary>
  public abstract class APTURL : PTURLConstants,IPTURL,IHierarchicalDataObject
  {
    protected XPArrayList m_listParamNames = null;
    protected XPArrayList m_listParamValues = null;
    protected XPArrayList m_nonControlParamNames = null;
    protected XPArrayList m_nonControlParamValues = null;
    protected String m_Title = "";
    protected String m_IconImg = "";
    protected String m_IconWidth = "";
    protected String m_IconHeight = "";
    protected String m_IconAlt = "";
    protected String m_MarkedAsCurrent = null;
    protected String m_jsaction = "";
    protected String m_ObjectID = "-1";
    protected String m_ClassID = "-1";
    
    /// <summary>
    /// For hierarchical data only *
    /// </summary>
    protected XPHashtable m_children;
    
    /// <summary>
    /// Returns the entire URL with http:// and server name
    /// E.g http://portalserver/portal/server.pt 
    /// </summary>
    public abstract String GetFullURL();
    
    /// <summary>
    /// Returns the URI, the part of the URL after sever name
    /// E.g /portal/server.pt 
    /// </summary>
    public abstract String GetURI();
    
    /// <param name="strTitle"></param>
    protected APTURL(String strTitle)
    {
      m_Title = strTitle;
    }
    
    /// <param name="strTitle"></param>
    /// <param name="strIconImg"></param>
    protected APTURL(String strTitle, String strIconImg) : this(strTitle)
    {
      m_IconImg = strIconImg;
    }
    
    /// <summary>
    /// Supports the following keys (although not all keys might be set on every URL):
    /// <c>PTURLConstants.KEY_FULLURL
    /// PTURLConstants.KEY_URI
    /// PTURLConstants.KEY_TITLE
    /// PTURLConstants.KEY_ICONIMG
    /// PTURLConstants.KEY_ICONIMGWIDTH
    /// PTURLConstants.KEY_ICONIMGHEIGHT
    /// PTURLConstants.KEY_ICONIMGALT
    /// PTURLConstants.KEY_CURRENTMARKER
    /// PTURLConstants.KEY_OBJECTID
    /// PTURLConstants.KEY_CLASSID
    /// KEY_PARAMS</c>
    /// It is also possible to retrieve the value of specific querystring or non-control parameters 
    /// by passing in the name of the parameter as the key
    /// E.g. 
    /// To get the value of param1 in the URL below, pass in 'param1' (without the quotes )as the key.
    /// http://www.servername.com/portal/server.pt?param1=value1&param2=value2&param3=value3
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)"></seealso>
    public virtual String GetData(String strKey)
    {
      if (PTURLConstants.KEY_FULLURL.Equals(strKey))
      {
        return GetFullURL();
      } else
      if (PTURLConstants.KEY_URI.Equals(strKey))
      {
        return GetURI();
      } else
      if (PTURLConstants.KEY_TITLE.Equals(strKey))
      {
        return m_Title;
      } else
      if (PTURLConstants.KEY_ICONIMG.Equals(strKey))
      {
        return m_IconImg;
      } else
      if (PTURLConstants.KEY_ICONIMGWIDTH.Equals(strKey))
      {
        return m_IconWidth;
      } else
      if (PTURLConstants.KEY_ICONIMGHEIGHT.Equals(strKey))
      {
        return m_IconHeight;
      } else
      if (PTURLConstants.KEY_ICONIMGALT.Equals(strKey))
      {
        return m_IconAlt;
      } else
      if (PTURLConstants.KEY_CURRENTMARKER.Equals(strKey))
      {
        return m_MarkedAsCurrent;
      } else
      if (PTURLConstants.KEY_JAVASCRIPT_ACTION.Equals(strKey))
      {
        return m_jsaction;
      } else
      if (PTURLConstants.KEY_OBJECTID.Equals(strKey))
      {
        return m_ObjectID;
      } else
      if (PTURLConstants.KEY_CLASSID.Equals(strKey))
      {
        return m_ClassID;
      } else
      if (KEY_PARAMS.Equals(strKey))
      {
        // Assume average length of param name and values are 9
        XPStringBuilder buf = new XPStringBuilder(m_listParamNames.GetSize() * 8 * 2);
        for (int i = 0;i < m_listParamNames.GetSize();i++)
        {
          buf.Append(m_listParamNames.GetElement(i) + "=" + m_listParamValues.GetElement(i) + "&");
          }
        // remove last & char.
        buf.RemoveCharAt(buf.GetLength() - 1);
        return buf.ToString();
      } else
      // If no predefined URL components exists, look in the querystring parameters first, then non-control parameters. 
      {
        if (m_listParamNames != null && m_listParamValues != null)
        {
          int nIndex = m_listParamNames.IndexOf(strKey);
          if (-1 != nIndex)
          {
            return XPConvert.ToString(m_listParamValues.GetElement(nIndex));
            }
        }
        if (m_nonControlParamNames != null && m_nonControlParamValues != null)
        {
          int nIndex = m_nonControlParamNames.IndexOf(strKey);
          if (-1 != nIndex)
          {
            return XPConvert.ToString(m_nonControlParamValues.GetElement(nIndex));
            }
        }
      }
      return null;
    }
    
    /// <summary>
    /// Sets data on the URL.
    /// Supports the following keys:
    /// <c>
    /// PTURLConstants.KEY_TITLE
    /// PTURLConstants.KEY_ICONIMG
    /// PTURLConstants.KEY_ICONIMGWIDTH
    /// PTURLConstants.KEY_ICONIMGHEIGHT
    /// PTURLConstants.KEY_ICONIMGALT
    /// PTURLConstants.KEY_CURRENTMARKER
    /// </c>
    /// </summary>
    /// <param name="strKey">Key of the data</param>
    /// <param name="strValue">Value of the data</param>
    /// <seealso cref="PTURLConstants"></seealso>
    public virtual void SetURLData(String strKey, String strValue)
    {
      if (PTURLConstants.KEY_TITLE.Equals(strKey))
      {
        m_Title = strValue;
      } else
      if (PTURLConstants.KEY_ICONIMG.Equals(strKey))
      {
        m_IconImg = strValue;
      } else
      if (PTURLConstants.KEY_ICONIMGWIDTH.Equals(strKey))
      {
        m_IconWidth = strValue;
      } else
      if (PTURLConstants.KEY_ICONIMGHEIGHT.Equals(strKey))
      {
        m_IconHeight = strValue;
      } else
      if (PTURLConstants.KEY_ICONIMGALT.Equals(strKey))
      {
        m_IconAlt = strValue;
      } else
      if (PTURLConstants.KEY_CURRENTMARKER.Equals(strKey))
      {
        m_MarkedAsCurrent = strValue;
      } else
      if (PTURLConstants.KEY_JAVASCRIPT_ACTION.Equals(strKey))
      {
        m_jsaction = strValue;
      } else
      if (PTURLConstants.KEY_OBJECTID.Equals(strKey))
      {
        m_ObjectID = strValue;
      } else
      if (PTURLConstants.KEY_CLASSID.Equals(strKey))
      {
        m_ClassID = strValue;
      } else
      {
        // set an arbitrary name/value combination
        AddNonControlParameter(strKey, strValue);
      }
    }
    
    /// <summary>
    /// Adds a string parameter to the URL.
    /// This parameter is not reflected in the URL itself but can be used to store
    /// arbitrary name/value combinations on the URL object for use in PT tags
    /// (i.e., a community link tag could contain a page name and id as well)
    /// </summary>
    /// <param name="strKey">Name of the parameter.</param>
    /// <param name="strValue">Value of the parameter as a <c>String</c>.</param>
    public virtual void AddNonControlParameter(String strKey, String strValue)
    {
      if (null == m_nonControlParamNames || null == m_nonControlParamValues)
      {
        m_nonControlParamNames = new XPArrayList();
        m_nonControlParamValues = new XPArrayList();
      }
      m_nonControlParamNames.Add(strKey);
      m_nonControlParamValues.Add(strValue);
    }
    
    /// <summary>
    /// Adds a string parameter to the querystring on this URL.
    /// E.g. param=value
    /// </summary>
    /// <param name="strKey">Name of the parameter.</param>
    /// <param name="strValue">Value of the parameter as a <c>String</c>.</param>
    public virtual void AddControlParameter(String strKey, String strValue)
    {
      if (null == m_listParamNames || null == m_listParamValues)
      {
        m_listParamNames = new XPArrayList();
        m_listParamValues = new XPArrayList();
      }
      m_listParamNames.Add(strKey);
      m_listParamValues.Add(XPHttpUtility.UrlEncode(strValue, LinkConstants.UTF_8_ENCODING));
      }
    
    /// <summary>
    /// Adds a integer parameter to the querystring on this URL.
    /// E.g. param=1
    /// </summary>
    /// <param name="strKey">Name of the parameter.</param>
    /// <param name="nValue">Value of the parameter as an integer.</param>
    public virtual void AddControlParameter(String strKey, int nValue)
    {
      if (null == m_listParamNames || null == m_listParamValues)
      {
        m_listParamNames = new XPArrayList();
        m_listParamValues = new XPArrayList();
      }
      m_listParamNames.Add(strKey);
      m_listParamValues.Add(XPHttpUtility.UrlEncode(XPConvert.ToString(nValue),
       LinkConstants.UTF_8_ENCODING));
    }
    
    /// <summary>
    /// Helper function to set URL Image with the width and height component.
    /// Equivalent to setting <c>PTURLConstants.KEY_ICONIMG</c>, <c>PTURLConstants.KEY_ICONIMGWIDTH</c> and 
    /// <c>PTURLConstants.KEY_ICONIMGHEIGHT</c> manually. 
    /// </summary>
    /// <param name="image"><c>PTImageType</c> of the image to use.</param>
    /// <seealso cref="PTImageType"></seealso>
    public virtual void SetURLImageType(PTImageType image, String strImageServerBaseURL)
    {
      if (image != null)
      {
        SetURLData(PTURLConstants.KEY_ICONIMG, strImageServerBaseURL + image.GetFileName());
        SetURLData(PTURLConstants.KEY_ICONIMGWIDTH, image.GetWidth());
        SetURLData(PTURLConstants.KEY_ICONIMGHEIGHT, image.GetHeight());
      }
    }
    
    /// <summary>
    /// Gets child data for hierarchical data 
    /// </summary>
    /// <param name="children"></param>
    public virtual XPArrayList GetHierData(String key)
    {
      if (m_children == null)
      {
        return null;
      }
      return (XPArrayList) m_children.GetElement(key);
    }
    
    /// <summary>
    /// Sets child data for hierarchical data 
    /// </summary>
    /// <param name="children"></param>
    public virtual void SetHierData(String key, XPArrayList children)
    {
      // only create it when needed as most data url are not hierarchical
      if (m_children == null)
      {
        m_children = new XPHashtable();
      }
      m_children.PutElement(key, children);
    }
  }
}