using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener;
using GeneralHelpers=com.plumtree.uiinfrastructure.statichelpers.GeneralHelpers;
namespace com.plumtree.portaluiinfrastructure.ptlink
{
  // CR: DCA - this class is almost like the FriendlyURL class and in fact uses it when it comes down to actually generating the URL.
  // Maybe we should combine the two into one class?
  // rob - FriendlyURL class is just a structure to hold the components of a friendly url and an interface to generate the actual url
  // (so you don't have to call into the class type descriptor). This class is a wrapper for IDataObject interface so that you can
  // get the different url components from tags. Combining both classes would be messy since you would have additional functionality
  // in FriendlyURL that isn't needed by anywhere else except tags. No functionality is duplicated, just two layers of interfaces for
  // cleaner separation of functionality.
  
  /// <summary>
  /// Class for generating friendly Urls in Adaptive Tags
  /// </summary>
  /// <author>robertz</author>
  public class CommonOpenerFriendlyURL : ACommonOpenerURL
  {
    
    /// <summary>
    /// Class ID in the URL
    /// </summary>
    public const String KEY_FRIENDLYURL_CLASSID = "clsid";
    
    /// <summary>
    /// Object ID in the URL
    /// </summary>
    public const String KEY_FRIENDLYURL_OBJECTID = "objid";
    
    /// <summary>
    /// Object Name in the URL 
    /// </summary>
    public const String KEY_FRIENDLYURL_OBJECTNAME = "objname";
    public const String KEY_FRIENDLYURL_CHILDNAME = "childname";
    public const String KEY_FRIENDLYURL_CHILDID = "childid";
    protected int m_classId;
    protected int m_objectId;
    protected String m_objectName;
    protected int m_childId;
    protected String m_childName;
    protected String m_friendlyURL;
    protected String m_friendlyURI;
    public CommonOpenerFriendlyURL(String label, int classId, int objectId,
     AActivitySpace space) : base(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space),
     IOpenerConstants.OPENER_MODE_VIEW)
    {
      m_classId = classId;
      m_objectId = objectId;
      ConstructFriendlyURL(space);
    }
    public CommonOpenerFriendlyURL(String label, int classId, int objectId,
     String objectName, AActivitySpace space) : base(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space),
     IOpenerConstants.OPENER_MODE_VIEW)
    {
      m_classId = classId;
      m_objectId = objectId;
      m_objectName = objectName;
      ConstructFriendlyURL(space);
    }
    public CommonOpenerFriendlyURL(String label, int classId, int objectId,
     int childId, AActivitySpace space) : base(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space),
     IOpenerConstants.OPENER_MODE_VIEW)
    {
      m_classId = classId;
      m_objectId = objectId;
      m_childId = childId;
      ConstructFriendlyURL(space);
    }
    public CommonOpenerFriendlyURL(String label, int classId, int objectId,
     String objectName, int childId, AActivitySpace space) : base(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space),
     IOpenerConstants.OPENER_MODE_VIEW)
    {
      m_classId = classId;
      m_objectId = objectId;
      m_objectName = objectName;
      m_childId = childId;
      ConstructFriendlyURL(space);
    }
    public CommonOpenerFriendlyURL(String label, int classId, int objectId,
     String objectName, int childId, String childName, AActivitySpace space) : base(label,
     PTConfigService.getPTInstance().GetApplicationBaseURL(space), IOpenerConstants.OPENER_MODE_VIEW)
    {
      m_classId = classId;
      m_objectId = objectId;
      m_objectName = objectName;
      m_childId = childId;
      m_childName = childName;
      ConstructFriendlyURL(space);
    }
    
    /// <param name="space"></param>
    private void ConstructFriendlyURL(AActivitySpace space)
    {
      FriendlyURL url = null;
      if (m_objectName == null)
      {
        // DCA - m_Title is not always the object's name
        //if ( m_childId > 0 ) {
        url = new FriendlyURL(m_classId, m_objectId);
      } else
      //} else {
      //	url = new FriendlyURL(m_classId, m_Title, m_objectId);
      //}
      {
        url = new FriendlyURL(m_classId, m_objectName, m_objectId);
      }
      if (m_childName != null)
      {
        url.SetChildName(m_childName);
      }
      url.SetChildId(m_childId);
      m_friendlyURI = url.GetFriendlyURL(space);
      // construct the friendly URL from the baseURL and Friendly URI
      String baseURL = PTConfigService.getPTInstance().GetApplicationBaseURL(space.GetCurrentNormalizedBaseURL());
      baseURL = GeneralHelpers.Replace(baseURL, "?", "");
      m_friendlyURL = baseURL + m_friendlyURI;
    }
    public override String GetFullURL()
    {
      return m_friendlyURL;
    }
    public override String GetURI()
    {
      return m_friendlyURI;
    }
    
    /// <summary>
    /// Gets URL data.
    /// Supports 
    /// <c>KEY_FRIENDLYURL_CLASSID</c>
    /// <c>KEY_FRIENDLYURL_OBJECTID</c>
    /// <c>KEY_COMMONOPENER_OPENERMODE</c>
    /// <c>PTURLConstants.KEY_URLTYPE</c>
    /// <c>KEY_FRIENDLYURL_CLASSID</c>
    /// <c>KEY_FRIENDLYURL_OBJECTID</c>
    /// in addition to the common URL and CommonOpener URL data keys.
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)"></seealso>
    public override String GetData(String strKey)
    {
      String retVal = null;
      if (KEY_FRIENDLYURL_CLASSID.Equals(strKey) || PTURLConstants.KEY_CLASSID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_classId);
      } else
      if (KEY_FRIENDLYURL_OBJECTID.Equals(strKey) || PTURLConstants.KEY_OBJECTID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_objectId);
      } else
      if (KEY_FRIENDLYURL_OBJECTNAME.Equals(strKey))
      {
        retVal = m_objectName;
      } else
      if (KEY_FRIENDLYURL_CHILDID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_childId);
      } else
      if (KEY_FRIENDLYURL_CHILDNAME.Equals(strKey))
      {
        retVal = m_childName;
      } else
      if (PTMyPages.STR_PAGE_ID.Equals(strKey))
      {
        if (m_classId == PT_CLASSIDS.PT_COMMUNITY_ID || m_classId == PT_CLASSIDS.PT_USER_ID)
        {
          // For communities, the page ID should be the child ID.
          retVal = XPConvert.ToString(m_childId);
        } else
        {
          retVal = XPConvert.ToString(m_objectId);
        }
      } else
      {
        retVal = base.GetData(strKey);
      }
      return retVal;
    }
    
    /// <summary>
    /// Sets URL data.
    /// In addition to the common keys, also Supports these:
    /// <c>KEY_FRIENDLYURL_CLASSID</c>
    /// <c>KEY_FRIENDLYURL_OBJECTID</c>
    /// <c>KEY_COMMONOPENER_OPENERMODE</c>
    /// </summary>
    /// <param name="strKey"></param>
    /// <param name="nValue"></param>
    public override void SetURLData(String strKey, String strValue)
    {
      if (KEY_FRIENDLYURL_CLASSID.Equals(strKey) || PTURLConstants.KEY_CLASSID.Equals(strKey))
      {
        m_classId = XPConvert.ToInteger(strValue);
      } else
      if (KEY_FRIENDLYURL_OBJECTID.Equals(strKey) || PTURLConstants.KEY_OBJECTID.Equals(strKey))
      {
        m_objectId = XPConvert.ToInteger(strValue);
      } else
      if (KEY_FRIENDLYURL_OBJECTNAME.Equals(strKey))
      {
        m_objectName = strValue;
      } else
      if (KEY_FRIENDLYURL_CHILDID.Equals(strKey))
      {
        m_childId = XPConvert.ToInteger(strValue);
      } else
      if (KEY_FRIENDLYURL_CHILDNAME.Equals(strKey))
      {
        m_childName = strValue;
      } else
      {
        base.SetURLData(strKey, strValue);
      }
    }
  }
}