using System;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.uiinfrastructure.opener.types.classtypes;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.ptlink
{
  /// <summary>
  /// URL Class for CommonOpenerURL using Activityspace name.
  /// </summary>
  public class CommonOpenerOpenASURL : ACommonOpenerURL
  {
    
    /// <summary>
    /// Name of the Activityspace the URL is referencing.
    /// </summary>
    public const String KEY_COMMONOPENER_ASNAME = "asname";
    
    /// <summary>
    /// URL Type.
    /// </summary>
    public const String URL_TYPE_ASCOMMONOPENER = "ascommonpener";
    protected String m_strActivitySpaceName;
    
    /// <param name="strTitle"></param>
    /// <param name="strApplicationBaseURL"></param>
    /// <param name="strActivitySpaceName"></param>
    /// <param name="nUserID"></param>
    public CommonOpenerOpenASURL(String strTitle, String strApplicationBaseURL,
     String strActivitySpaceName, int nUserID) : base(strTitle, strApplicationBaseURL,
     nUserID)
    {
      m_strActivitySpaceName = strActivitySpaceName;
    }
    public CommonOpenerOpenASURL(String strTitle, String strActivitySpaceName,
     AActivitySpace owner) : base(strTitle, ConfigService.getInstance().GetApplicationBaseURL(owner),
     ((IPTSession) owner.GetUserSession()).GetSessionInfo().GetCurrentUserID())
    {
      m_strActivitySpaceName = strActivitySpaceName;
      AddControlParameter(ASConstants.PARENTSPACEID, owner.GetSpaceID());
      AddControlParameter(ASConstants.PARENTSPACENAME, owner.GetName());
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetFullURL()"></seealso>
    public override String GetFullURL()
    {
      return PTOpenerLinks.GetOpenerURLOpenAS(m_strActivitySpaceName, HTTPHelpers.GetParameterListAsString(m_listParamNames,
       m_listParamValues), m_nOpenerMode, m_strApplicationBaseURL, m_nUserID);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetURI()"></seealso>
    public override String GetURI()
    {
      return UIActivitySpaces.QS_ACTIVITY_SPACE_NAME + "=" + m_strActivitySpaceName + "&" + HTTPHelpers.GetParameterListAsString(m_listParamNames,
       m_listParamValues) + IPTOpenerConstants.QS_MODE + "=" + m_nOpenerMode + "&" + IPTOpenerConstants.QS_USERID + "=" + m_nUserID + "&";
      }
    
    /// <summary>
    /// Supports <c>KEY_COMMONOPENER_ASNAME</c> in addition to the common URL and CommonOpener
    /// URL data keys.
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)"></seealso>
    public override String GetData(String strKey)
    {
      String retVal = null;
      if (KEY_COMMONOPENER_ASNAME.Equals(strKey))
      {
        retVal = m_strActivitySpaceName;
      } else
      if (PTURLConstants.KEY_URLTYPE.Equals(strKey))
      {
        retVal = URL_TYPE_ASCOMMONOPENER;
      } else
      {
        retVal = base.GetData(strKey);
      }
      return retVal;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.IPTURL#SetURLData(java.lang.String,java.lang.String)"></seealso>
    public override void SetURLData(String strKey, String strValue)
    {
      if (KEY_COMMONOPENER_ASNAME.Equals(strKey))
      {
        m_strApplicationBaseURL = strValue;
      } else
      {
        base.SetURLData(strKey, strValue);
      }
    }
  }
}