/*
 * Created on Dec 8, 2004
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.ptlink
{
  /// <summary>
  /// URL Class for CommonOpenerURL using Object ID and Class ID pair.
  /// UPDATE FOR PORTAL 6.5: This class has been repurposed to use friendly URL
  /// instead of commonopener URL. Just keep this as a facade so that we don't have
  /// to change old code
  /// </summary>
  public class CommonOpenerOpenObjIDURL : ACommonOpenerURL,IDataObject
  {
    
    /// <summary>
    /// Class ID in the URL
    /// </summary>
    public const String KEY_COMMONOPENER_CLASSID = "clsid";
    
    /// <summary>
    /// Object ID in the URL
    /// </summary>
    public const String KEY_COMMONOPENER_OBJECTID = "objid";
    public const String URL_TYPE_OBJCOMMONOPENER = "objcommonopener";
    protected int m_nClassID;
    protected int m_nObjectID;
    public const String KEY_COMMONOPENER_PAGEID = "PageID";
    protected int m_nPageID;
    
    /// <summary>
    /// Add Control Parameters ASConstants.PARENTSPACEID and ASConstants.PARENTSPACENAME. 
    /// </summary>
    /// <param name="strTitle"></param>
    /// <param name="strApplicationBaseURL"></param>
    /// <param name="nClassID"></param>
    /// <param name="nObjectID"></param>
    /// <param name="nMode"></param>
    /// <param name="nUserID"></param>
    public CommonOpenerOpenObjIDURL(String strTitle, String strApplicationBaseURL,
     int nClassID, int nObjectID, int nMode, int nUserID) : base(strTitle,
     strApplicationBaseURL, nMode, nUserID)
    {
      m_nClassID = nClassID;
      m_nObjectID = nObjectID;
    }
    
    /// <summary>
    /// Add Control Parameters ASConstants.PARENTSPACEID and ASConstants.PARENTSPACENAME. 
    /// Stores the community page id for later use when the portlet selection layout is trying to access the pageid of the community in
    /// non-friendyURL mode.
    /// </summary>
    /// <param name="strTitle"></param>
    /// <param name="strApplicationBaseURL"></param>
    /// <param name="nClassID"></param>
    /// <param name="nObjectID"></param>
    /// <param name="nMode"></param>
    /// <param name="nUserID"></param>
    /// <param name="communityPageID"></param>
    public CommonOpenerOpenObjIDURL(String strTitle, String strApplicationBaseURL,
     int nClassID, int nObjectID, int nMode, int nUserID, int communityPageID) : base(strTitle,
     strApplicationBaseURL, nMode, nUserID)
    {
      m_nClassID = nClassID;
      m_nObjectID = nObjectID;
      m_nPageID = communityPageID;
    }
    
    /// <param name="strTitle"></param>
    /// <param name="nClassID"></param>
    /// <param name="nObjectID"></param>
    /// <param name="nMode"></param>
    /// <param name="owner"></param>
    public CommonOpenerOpenObjIDURL(String strTitle, int nClassID, int nObjectID,
     int nMode, AActivitySpace owner) : base(strTitle, ConfigHelper.GetApplicationBaseURL(owner),
     nMode, ((IPTSession) owner.GetUserSession()).GetSessionInfo().GetCurrentUserID())
    {
      m_nClassID = nClassID;
      m_nObjectID = nObjectID;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetFullURL()"></seealso>
    public override String GetFullURL()
    {
      return PTOpenerLinks.GetOpenerURLOpenObjID(m_nClassID, m_nObjectID,
       HTTPHelpers.GetParameterListAsString(m_listParamNames, m_listParamValues),
       m_nOpenerMode, m_strApplicationBaseURL, m_nUserID);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetURI()"></seealso>
    public override String GetURI()
    {
      return IPTOpenerConstants.QS_CLASSID + "=" + m_nClassID + "&" + IPTOpenerConstants.QS_OBJECTID + "=" + m_nObjectID + "&" + HTTPHelpers.GetParameterListAsString(m_listParamNames,
       m_listParamValues) + IPTOpenerConstants.QS_MODE + "=" + m_nOpenerMode + "&" + IPTOpenerConstants.QS_USERID + "=" + m_nUserID + "&";
      }
    
    /// <summary>
    /// Gets URL data.
    /// Supports 
    /// <c>KEY_COMMONOPENER_CLASSID</c>
    /// <c>KEY_COMMONOPENER_OBJECTID</c>
    /// <c>KEY_COMMONOPENER_OPENERMODE</c>
    /// <c>PTURLConstants.KEY_URLTYPE</c>
    /// <c>KEY_COMMONOPENER_CLASSID</c>
    /// <c>KEY_COMMONOPENER_OBJECTID</c>
    /// in addition to the common URL and CommonOpener URL data keys.
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)"></seealso>
    public override String GetData(String strKey)
    {
      String retVal = null;
      if (KEY_COMMONOPENER_CLASSID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_nClassID);
      } else
      if (KEY_COMMONOPENER_OBJECTID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_nObjectID);
      } else
      if (KEY_COMMONOPENER_OPENERMODE.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_nOpenerMode);
      } else
      if (PTURLConstants.KEY_URLTYPE.Equals(strKey))
      {
        retVal = URL_TYPE_OBJCOMMONOPENER;
      } else
      if (KEY_COMMONOPENER_CLASSID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_nClassID);
      } else
      if (KEY_COMMONOPENER_OBJECTID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_nObjectID);
      } else
      if (KEY_COMMONOPENER_PAGEID.Equals(strKey))
      {
        retVal = XPConvert.ToString(m_nPageID);
      } else
      {
        retVal = base.GetData(strKey);
      }
      return retVal;
    }
    
    /// <summary>
    /// Sets URL data.
    /// In addition to the common keys, also Supports these:
    /// <c>KEY_COMMONOPENER_CLASSID</c>
    /// <c>KEY_COMMONOPENER_OBJECTID</c>
    /// <c>KEY_COMMONOPENER_OPENERMODE</c>
    /// </summary>
    /// <param name="strKey"></param>
    /// <param name="nValue"></param>
    public override void SetURLData(String strKey, String strValue)
    {
      if (KEY_COMMONOPENER_CLASSID.Equals(strKey))
      {
        m_nClassID = XPConvert.ToInteger(strValue);
      } else
      if (KEY_COMMONOPENER_OBJECTID.Equals(strKey))
      {
        m_nObjectID = XPConvert.ToInteger(strValue);
      } else
      if (KEY_COMMONOPENER_OPENERMODE.Equals(strKey))
      {
        m_nOpenerMode = XPConvert.ToInteger(strValue);
      } else
      {
        base.SetURLData(strKey, strValue);
      }
    }
  }
}