/*
 */
 
using System;
using com.plumtree.portaluiinfrastructure.tags.data;
namespace com.plumtree.portaluiinfrastructure.ptlink
{
  /// <summary>
  /// PTURL Interface
  /// </summary>
  public interface IPTURL : IHierarchicalDataObject
  {
    
    /// <summary>
    /// Returns the entire URL with http:// and server name
    /// E.g http://portalserver/portal/server.pt 
    /// </summary>
    String GetFullURL();
    
    /// <summary>
    /// Returns the URI, the part of the URL after sever name
    /// E.g /portal/server.pt 
    /// </summary>
    String GetURI();
    
    /// <summary>
    /// Sets URL data.
    /// Each type of URL supports different URL data. 
    /// </summary>
    /// <param name="strKey">Key of the URL data to set.</param>
    /// <param name="strValue">Value of the URL data.</param>
    void SetURLData(String strKey, String strValue);
    
    /// <summary>
    /// Adds a string parameter to the querystring on this URL.
    /// E.g. param=value
    /// </summary>
    /// <param name="strKey">Name of the parameter.</param>
    /// <param name="strValue">Value of the parameter as a <c>String</c>.</param>
    void AddControlParameter(String strKey, String strValue);
    
    /// <summary>
    /// Adds a integer parameter to the querystring on this URL.
    /// E.g. param=1
    /// </summary>
    /// <param name="strKey">Name of the parameter.</param>
    /// <param name="nValue">Value of the parameter as an integer.</param>
    void AddControlParameter(String strKey, int nValue);
    
    /// <summary>
    /// Adds a string parameter to the URL.
    /// This parameter is not reflected in the URL itself but can be used to store
    /// arbitrary name/value combinations on the URL object for use in PT tags
    /// (i.e., a community link tag could contain a page name and id as well)
    /// </summary>
    /// <param name="strKey">Name of the parameter.</param>
    /// <param name="strValue">Value of the parameter as a <c>String</c>.</param>
    void AddNonControlParameter(String strKey, String strValue);
  }
}