using System;
// Framework Imports
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.ptmulticolumnlist
{
  /// <summary>
  /// This interface is implemented by the Model.
  /// It contains all the read-only mothods of the Model
  /// accessed by the Views.
  /// </summary>
  /// <author>Julie Fournier</author>
  public interface IPTMultiColumnListModelRO : IExpListModelRO
  {
    
    /// <summary>
    /// Returns the accesslevel of the objects for the tree control to display.
    /// </summary>
    /// <returns>int</returns>
    int GetAccessLevel();
    
    /// <summary>
    /// Returns the create new actions information.
    /// </summary>
    /// <returns>Object[][]</returns>
    Object[][] GetCreateNewInfo();
    
    /// <summary>
    /// Returns the URL to the Editor in create mode (new object).
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_sEditorASName"></param>
    /// <returns>ASURL URL to the Editor</returns>
    ASURL GetCreateNewURL(int _nClassID, String _sEditorASName);
    
    /// <summary>
    /// Returns the URL to edit the object.
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <param name="_sEditorASName"></param>
    /// <returns>ASURL URL to the Editor</returns>
    ASURL GetEditObjectURL(int _nClassID, int _nObjectID);
    
    /// <summary>
    /// Returns the row currently being edited.
    /// </summary>
    /// <returns>int</returns>
    int GetEditRow();
    
    /// <summary>
    /// Returns the comma-delimited string of classids and objectids for objects
    /// that are to be hidden by the tree.  The format of the string is as
    /// follows: ClassID1,ObjectID1, ClassID2,ObjectID2, etc..
    /// </summary>
    /// <returns>String</returns>
    String GetHiddenObjects();
    
    /// <summary>
    /// Returns true if this list includes a Plumtree object selected from the
    /// tree object selector.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetIncludePTSelect();
    
    /// <summary>
    /// Returns the number of columns other than the columns used by the
    /// Plumtree selected object.
    /// </summary>
    /// <returns>int</returns>
    int GetNumColumns();
    
    /// <summary>
    /// Returns String of Class ID of the Objects
    /// displayed in the tree.
    /// E.g.: "2,45,3"
    /// This is the format used by the tree.
    /// </summary>
    /// <returns>String</returns>
    String GetObjectClassIDs();
    
    /// <summary>
    /// Returns the zero-based display position of the selected Plumtree object,
    /// if applicable.
    /// </summary>
    /// <returns>int</returns>
    int GetPTObjectPosition();
    
    /// <summary>
    /// Returns the icon to display on each row before the
    /// input text. If the value is null, no icon is displayed.
    /// </summary>
    /// <returns>PTImageType</returns>
    PTImageType GetRowIcon();
    
    /// <summary>
    /// Returns a String of Class IDs and Object IDs of the Objects
    /// to select in the tree.
    /// E.g.: "classID1,ObjID1,classID2,objID2"
    /// This is the format used by the tree.
    /// </summary>
    /// <returns>String</returns>
    String GetSelectedItems();
    
    /// <summary>
    /// Returns the leaf type of the tree.
    /// </summary>
    /// <returns>int</returns>
    int GetTreeLeafType();
    
    /// <summary>
    /// Returns the selection type of the tree.
    /// Converts the boolean value to a string so that it can be
    /// put in the query string for the tree.
    /// </summary>
    /// <returns>String</returns>
    String GetTreeMultiSelect();
    
    /// <summary>
    /// Returns the query filter for the tree.
    /// </summary>
    /// <returns>String</returns>
    String GetTreeQueryFilter();
    
    /// <summary>
    /// Returns tree AS ID.
    /// </summary>
    /// <returns>String</returns>
    String GetTreeSpaceID();
    
    /// <summary>
    /// Returns the Tree sub title.
    /// </summary>
    /// <returns>String</returns>
    String GetTreeSubTitle();
    
    /// <summary>
    /// Returns the Tree title.
    /// </summary>
    /// <returns>String</returns>
    String GetTreeTitle();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.SelectPTObjectModel#GetDisplayObjects()"></seealso>
    String GetDisplayObjects();
    
    /// <summary>
    /// Returns true if it should be possible to edit Objects from this class ID.
    /// </summary>
    /// <param name="_nClassID"></param>
    bool IsEditLinkEnabled(int _nClassID);
  }
}