using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portaluiinfrastructure.ptmulticolumnlist
{
  /// <summary>
  /// This class contains the additional repost actions.
  /// The ones specific to the Property Editor (other than
  /// "change page", "finish" and "cancel" actions).
  /// </summary>
  /// <author>Julie Fournier</author>
  public class PTMultiColumnListRepostControl : ExpListControl
  {
    
    /// <summary>
    /// Unique identifier for the control 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PTMultiColumnListRepost";
    
    /// <summary>
    /// The edit action - sets the row being edited on the model 
    /// </summary>
    public const int POSTTOSELF_ACTION_EDIT = 10;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PTMultiColumnListRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Calls the method associated to the repost action.
    /// Editors using this framework need to call that method from
    /// the PerformRepostAction method of the main RepostControl.
    /// </summary>
    /// <param name="_nAction"></param>
    /// <param name="_htFormData"></param>
    public override void PerformRepostAction(int _nAction, XPHashtable _htFormData)
    {
      base.PerformRepostAction(_nAction, _htFormData);
      PTMultiColumnListModel myMultiColumnListModel = (PTMultiColumnListModel) m_model;
      if (_nAction == myMultiColumnListModel.GetUniqueInt(POSTTOSELF_ACTION_EDIT))
      {
        myMultiColumnListModel.ModifyRow(_htFormData);
      }
    }
  }
}