using System;
using IPTSession=com.plumtree.server.IPTSession;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using PathwaysQueryArguments=com.plumtree.portaluiinfrastructure.search.pathways.PathwaysQueryArguments;
namespace com.plumtree.portaluiinfrastructure.restconsumerframework.pathways
{
  /// <author>BobbyT</author>
  public interface IPathwaysRestAPIService
  {
    
    /// <summary>
    /// Checks if Pathways service is enabled from the config settings.  
    /// </summary>
    /// <returns>true if Pathways is enabled, otherwise false.</returns>
    bool IsPathwaysEnabled();
    
    /// <summary>
    /// Gets the Pathways API base URL from the Pathways API Web Service object
    /// </summary>
    /// <param name="session">the current user session.</param>
    /// <returns>the URL to the Pathways API Web Service, null if service is not installed.</returns>
    String GetPathwaysAPIBaseURL(IPTSession session);
    
    /// <summary>
    /// Gets the Pathways API Gatewayed URL from the Pathways API Web Service object
    /// This is used when making Pathways API calls on the client side via JSON.
    /// </summary>
    /// <param name="session">the current user session.</param>
    /// <returns>the gatewayed URL to the Pathways API Web Service, null if service is not installed.</returns>
    String GetPathwaysAPIGatewayedURL(AActivitySpace space, IPTSession session);
    //	public String GetAPIVersion();
    
    /// <summary>
    /// Returns a list of Pathways Views from Pathways Rest API.
    /// </summary>
    /// <returns>a list of PathwaysViewsRestData</returns>
    PathwaysViewsRestData[] GetViews();
    
    /// <summary>
    /// Returns a Tag Cloud from a Pathways search query.
    /// </summary>
    /// <param name="view">the Pathways view to use when retrieving the Tag Cloud</param>
    /// <param name="format">the payload format of the response</param>
    /// <param name="query">the Pathways search query</param>
    /// <param name="tagCount">the maximum number of tags to return for the Tag Cloud</param>
    /// <returns></returns>
    PathwaysTagRestData[] GetTagCloud(String view, String format, String query,
     String tagCount);
    
    /// <summary>
    /// Returns a list of search results from a Pathways search query.
    /// </summary>
    /// <param name="view">the Pathways view to use when retrieving the Tag Cloud</param>
    /// <param name="format">the payload format of the response</param>
    /// <param name="query">the Pathways search query</param>
    /// <param name="tagCount">the maximum number of tags to return for the Tag Cloud</param>
    /// <param name="objectTypes">restrict the objects to search for in pathways</param>
    /// <returns>array of PathwaysSearchRestData</returns>
    PathwaysSearchRestData[] DoSearch(PathwaysQueryArguments pathwaysQueryArguments);
    
    /// <summary>
    /// This Method is used to Add/Remove a Pathways Tag on a particular document. This uses 
    /// Pathways REST API to connect to Pathways and execute the requested action.
    /// </summary>
    /// <param name="tname">Name of the Tag on Which to take action</param>
    /// <param name="fullId">Complete ID (CLASSID_DOCUMENTID) of the Document the tag is related to</param>
    /// <param name="action">Action Operation to perform on the tag, 0 = Add, 1 = Delete, 2 = Edit (delete old tag and add new tag)</param>
    /// <param name="ptsource">Source of the Object, for Portal it is 'PTPORTAL' and collab it is 'PTCOLLAB'. More sources are in PathwaysConstants.</param>
    void AddRemoveTagRest(String tname, String fullId, int action, String ptsource);
    
    /// <summary>
    /// This Method is used to Rename a Pathways Tag on a particular document. This uses 
    /// Pathways REST API to connect to Pathways and execute the requested action.
    /// </summary>
    /// <param name="tname">the Source Tag Name to be used for renaming</param>
    /// <param name="fullId">Complete ID (CLASSID_DOCUMENTID) of the Document the tag is related to</param>
    /// <param name="ptsource">Source of the Object, for Portal it is 'PTPORTAL' and collab it is 'PTCOLLAB'. More sources are in PathwaysConstants.</param>
    /// <param name="renametag">the Target Tag Name to be used for renaming</param>
    void RenameTagRest(String tname, String fullId, String ptsource, String renametag);
    
    /// <summary>
    /// Returns the total count of search results returned 
    /// </summary>
    int GetTotalCount();
    
    /// <summary>
    /// Returns if the current user experience supports adaptive layout mode
    /// </summary>
    /// <returns></returns>
    bool IsAdaptiveLayoutMode();
  }
}