using System;
using PT_INTRINSICS=com.plumtree.server.PT_INTRINSICS;
namespace com.plumtree.portaluiinfrastructure.restconsumerframework.pathways
{
  /// <summary>
  /// This class contains constants for the Pathways Handlers.  These can
  /// be used in both the JSON format and the XML format.
  /// </summary>
  /// <author>Ravi Tunuguntla</author>
  public class PathwaysConstants
  {
    
    /// <summary>
    /// PTSOURCE Field for Portal content used by Pathways REST API
    /// </summary>
    public const String PTSOURCE_PORTAL = "PTPORTAL";
    public const String PTSOURCE_COLLAB = "PTCOLLAB";
    public const String PTSOURCE_CONTENT = "PTCONTENT";
    
    /// <summary>
    /// REST request format is xml type
    /// </summary>
    public const String KEY_XML = "format=xml";
    
    /// <summary>
    /// REST request key for object type item
    /// </summary>
    public const String KEY_ITEM = "item";
    
    /// <summary>
    /// REST request key for tags metadata of document
    /// </summary>
    public const String KEY_TAGS = "tags";
    
    /// <summary>
    /// REST response key for Tag node
    /// </summary>
    public const String KEY_TAG = "tag";
    
    /// <summary>
    /// REST response value of the Tag node.
    /// </summary>
    public const String TAG_VALUE = "value";
    
    /// <summary>
    /// Click Through URL Link Prefix for the Pathways Tag on a document 
    /// </summary>
    public const String SEARCH_URL_PREFIX = "searchurlprefix";
    
    /// <summary>
    /// REST response if this used created the tag for Tag node
    /// </summary>
    public const String TAG_OWNER = "isAppliedByCurrentUser";
    public const String TAG_COUNT = "count";
    public const String TAG_NORMALIZED_COUNT = "normalizedCount";
    
    /// <summary>
    /// Search Response Element names in Rest API Response *
    /// </summary>
    public const String SEARCH_ACTIVITY_RANK = "activityRank";
    public const String SEARCH_CLASSID = "classId";
    public const String SEARCH_DESCRIPTION = "description";
    public const String SEARCH_FOLDER_CLASSID = "folderClassId";
    public const String SEARCH_FOLDERID = "folderId";
    public const String SEARCH_FOLDER_NAME = "folderName";
    public const String SEARCH_ICON_LINK = "iconLink";
    public const String SEARCH_IS_FAVORITE = "isFavorite";
    public const String SEARCH_LAST_MODIFIED = "lastModified";
    public const String SEARCH_NAME = "name";
    public const String SEARCH_OBJECTID = "objectId";
    public const String SEARCH_PATH = "path";
    public const String SEARCH_RANK = "rank";
    public const String SEARCH_RESULT_SCORE = "resultScore";
    public const String SEARCH_SOURCE = "source";
    public const String SEARCH_TAGS = "tags";
    public const String SEARCH_TYPE = "type";
    public const String SEARCH_URL = "URL";
    public const String SEARCH_VIEW_DETAIL_URL = "viewDetailURL";
    //these are new items from pathways that don't have a PT_INTRINSIC option
    //<rank>
    public const int INT_RANK = 500;
    //<folderId>
    public const int INT_FOLDERID = 501;
    //<viewDetailURL>
    public const int INT_VIEW_DETAILS_URL = 502;
    
    /// <summary>
    /// The faux property (faux since it's not saved in the DB, only indexed) that contains
    /// the owner id of a manually submitted document.  Used for Graffiti expert identification. 
    /// </summary>
    public static readonly int INT_PT_OWNER_ID = PT_INTRINSICS.PT_OWNER_ID;
    
    /// <summary>
    /// Rest API URL Parameters *
    /// </summary>
    public const String TAGS_RESOURCE = "tags";
    public const String ITEMS_RESOURCE = "items";
    public const String VERSION_RESOURCE = "version";
    public const String VIEWS_RESOURCE = "views";
    public const String START_AT_ARG = "startAt";
    public const String VIEW_ID_ARG = "viewId";
    public const String QUERY_ARG = "query";
    public const String RESULT_COUNT_ARG = "resultCount";
    public const String ORDER_ARG = "order";
    public const String ORDER_BY_ARG = "orderby";
    public const String TAG_COUNT_ARG = "tagCount";
    public const String FORMAT_ARG = "format";
    public const String OBJECT_TYPES_ARG = "objectTypes";
    public const String ADMINFOLDERS_ARG = "adminFolders";
    public const String DIRFOLDERS_ARG = "kdFolders";
    public const String SPELLCHECK_ARG = "spellcheck";
    
    /// <summary>
    /// Prefix used when performing Pathways Searching by tagname
    /// i.e. http://pathways.devnet.plumtree.com:11960/graffiti/api/items?format=XML&startAt=1&viewId=null&query=tag:"test"&resultCount=20&order=DES&orderby=RANK
    /// </summary>
    public const String TAG_QUERY_PREFIX = "tag:";
    /*
     * REST response for pathways search results
     */
     
    public const String SEARCH_TOTAL_COUNT = "totalCount";
    /*
     * Pathways orderBy values
     */
     
    public const String RANK_ARG = "RANK";
    public const String LAST_MODIFIED_DATE_ARG = "LAST_MODIFIED";
    public const String NAME_ARG = "NAME";
    public const String ASC_ARG = "ASC";
    public const String DES_ARG = "DES";
    
    /// <summary>
    /// Version Response Element names in Rest API Response *
    /// </summary>
    public const String API_VERSION = "version";
    
    /// <summary>
    /// Views Response Element names in Rest API Response *
    /// </summary>
    public const String VIEWS_ID = "id";
    public const String VIEWS_LAST_MODIFIED = "lastModified";
    public const String VIEWS_NAME = "name";
    //publisher result type
    
    /// <summary>
    /// Pathways search query terms *
    /// </summary>
    public const String PUBLISHER_ITEMS = "PublisherItems";
    //collab result type - NOTE:  when choosing collab items, this entire list of items is added
    public static readonly String[] COLLAB_ITEMS = new String[]{"CollabDiscussion",
     "CollabDocument", "CollabEvent", "CollabMessage", "CollabProject", "CollabTask"};
    //portal result types, need to be singularily listed as Banner Search and Advanced Search have different options
    public const String ADMIN_FOLDERS = "AdminFolders";
    public const String AUTHENTICATION_SOURCES = "AuthenticationSources";
    public const String COMMUNITIES = "Communities";
    public const String COMMUNITY_PAGES = "CommunityPages";
    public const String COMMUNITY_TEMPLATES = "CommunityTemplates";
    public const String CONTENT_SOURCES = "ContentSources";
    public const String CONTENT_TYPES = "ContentTypes";
    public const String CRAWLERS = "Crawlers";
    public const String DOCUMENT_FOLDERS = "DocumentFolders";
    public const String EXPERIENCE_DEFINITIONS = "ExperienceDefinitions";
    public const String EXTERNAL_OPERATIONS = "ExternalOperations";
    public const String FEDERATED_SEARCHES = "Federated Searches";
    public const String FILTERS = "Filters";
    public const String GROUPS = "Groups";
    public const String INVITATIONS = "Invitations";
    public const String JOBS = "Jobs";
    public const String PAGE_TEMPLATES = "PageTemplates";
    public const String PORTAL_DOCUMENTS = "PortalDocuments";
    public const String PORTLETS = "Portlets";
    public const String PORTLET_TEMPLATES = "PortletTemplates";
    public const String PROFILE_SOURCES = "ProfileSources";
    public const String PROPERTIES = "Properties";
    public const String REMOTE_SERVERS = "RemoteServers";
    public const String SNAPSHOT_QUERIES = "SnapshotQueries";
    public const String USERS = "Users";
    public const String WEB_SERVICES = "WebServices";
  }
}