using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using PTDebugHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
namespace com.plumtree.portaluiinfrastructure.restconsumerframework.pathways
{
  /// <summary>
  /// Container for Pathways Search results data
  /// </summary>
  /// <author>BobbyT</author>
  public class PathwaysSearchRestData
  {
    private static OpenLogger logger = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PATHWAYS),
     "com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysSearchRestData");
    public String activityRank = null;
    public String classId;
    public String description = null;
    public String folderClassId;
    public String folderId;
    public String folderName = null;
    public String iconLink = null;
    public bool isFavorite = false;
    public String lastModified = null;
    public String name = null;
    public String objectId;
    public String path = null;
    public String rank = null;
    public String resultScore = null;
    public String source = null;
    public String type = null;
    public String URL = null;
    public String viewDetailURL = null;
    public PathwaysTagRestData[] tags = null;
    public PathwaysSearchRestData()
    {
    }
    
    /// <summary>
    /// This is the Pathways Rest API response from Publisher:
    /// <item>
    /// <activityRank>0.0</activityRank>
    /// <classId>PTCONTENT</classId>
    /// <description>...Hey fellahs! &lt;span class=&quot;ptHighlight&quot;&gt;KD&lt;/span&gt;_&lt;span class=&quot;ptHighlight&quot;&gt;Publishing&lt;/span&gt;_Test1 Edit Boing! Gen Info Page! Gen Info Comm...Hey fellahs! &lt;span class=&quot;ptHighlight&quot;&gt;KD&lt;/span&gt;_&lt;span class=&quot;ptHighlight&quot;&gt;Publishing&lt;/span&gt;_Test1 Edit Boing! Gen Info Page! Gen Info Comm...</description>
    /// <folderClassId></folderClassId>
    /// <folderId></folderId>
    /// <folderName></folderName>
    /// <iconLink>plumtree/content/private/img/icon_content_item.gif</iconLink>
    /// <isFavorite>false</isFavorite>
    /// <lastModified>2008-10-21T14:44:00-07:00</lastModified>
    /// <name>KD_Publishing_Test1</name>
    /// <objectId>4b254574-e806-444f-b9c8-27d4d8040306</objectId>
    /// <path>http://spt-boreal.devnet.plumtree.com:7087/publishedcontent/publish/johnkr_doesn_t_like__shabu_shabu_/kd_publishing_test1.html</path>
    /// <rank>1</rank>
    /// <resultScore>40.6</resultScore>
    /// <source>PTCONTENT</source>
    /// <type>Publisher Item</type>
    /// <URL>http://spt-alpine.devnet.plumtree.com/portal/server.pt/gateway/PTARGS_32_2_209_0_0_47/http;/spt-boreal.devnet.plumtree.com;7087/publishedcontent/publish/johnkr_doesn_t_like__shabu_shabu_/kd_publishing_test1.html</URL>
    /// <viewDetailURL>http://spt-alpine.devnet.plumtree.com/portal/server.pt/gateway/PTARGS_32_2_224_0_0_47/http;/spt-boreal.devnet.plumtree.com;7087/publishedcontent/publish/johnkr_doesn_t_like__shabu_shabu_/kd_publishing_test1.html</viewDetailURL>
    /// </item>
    /// </summary>
    public virtual bool Init(XPHashtable data)
    {
      activityRank = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_ACTIVITY_RANK));
      //		classId = XPConvert.ToInteger(data.GetElement(PathwaysConstants.SEARCH_CLASSID));
      classId = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_CLASSID));
      description = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_DESCRIPTION));
      //		folderClassId = XPConvert.ToInteger(data.GetElement(PathwaysConstants.SEARCH_FOLDER_CLASSID));
      //		folderId = XPConvert.ToInteger(data.GetElement(PathwaysConstants.SEARCH_FOLDERID));
      folderClassId = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_FOLDER_CLASSID));
      folderId = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_FOLDERID));
      folderName = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_FOLDER_NAME));
      iconLink = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_ICON_LINK));
      isFavorite = XPConvert.ToBoolean(data.GetElement(PathwaysConstants.SEARCH_IS_FAVORITE));
      lastModified = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_LAST_MODIFIED));
      name = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_NAME));
      //		objectId = XPConvert.ToInteger(data.GetElement(PathwaysConstants.SEARCH_OBJECTID));
      objectId = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_OBJECTID));
      path = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_PATH));
      rank = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_RANK));
      resultScore = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_RESULT_SCORE));
      source = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_SOURCE));
      type = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_TYPE));
      URL = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_URL));
      viewDetailURL = XPConvert.ToString(data.GetElement(PathwaysConstants.SEARCH_VIEW_DETAIL_URL));
      // Retrieve the nested tag list for the search result if any.
      XPHashtable tagsData = (XPHashtable) (data.GetElement(PathwaysConstants.SEARCH_TAGS));
      if (tagsData != null)
      {
        // TODO: change to constant
        Object tagNode = tagsData.GetElement("tag");
        if (tagNode is XPArrayList)
        {
          //this mean there is more than 1 tag associated to this search result, we need to grab all values
          XPArrayList tagList = (XPArrayList) tagNode;
          int tagListSize = tagList.GetSize();
          tags = new PathwaysTagRestData[tagListSize];
          for (int i = 0;i < tagListSize;i++)
          {
            PathwaysTagRestData tagData = new PathwaysTagRestData();
            // TODO: check if it's a hashtable first, check for errors.
            if (tagData.Init((XPHashtable) tagList.GetElement(i)))
            {
              tags[i] = tagData;
            }
          }
        } else
        {
          //there is only 1 item for tags, so we'll just read the hashtable instead	
          tags = new PathwaysTagRestData[1];
          XPHashtable tagNodeHash = (XPHashtable) tagNode;
          if (tagNodeHash != null)
          {
            PathwaysTagRestData tagData = new PathwaysTagRestData();
            if (tagData.Init(tagNodeHash))
            {
              tags[0] = tagData;
            }
          }
        }
      }
      return true;
    }
  }
}