using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.arraywrapper;
namespace com.plumtree.portaluiinfrastructure.resultwrapper
{
  /// <summary>
  /// PTObjectManagerQueryWrapper: The PTObjectManagerQueryWrapper class wraps the
  /// IPTTurboQueryResult  Server object that's returned by the various Query
  /// methods of IPTObjectManager. This wrapper handles the details of retrieving
  /// a subset of the data, sorting on the client when necessary, etc.
  /// </summary>
  /// <author>Michael Smedber</author>
  public class APTQueryWrapper : PTSortedArrayWrapper,IASQueryResult
  {
    
    /// <summary>
    /// MES- By default, we only show the first 1000 rows. 
    /// </summary>
    public const int PTTQRW_DEFAULT_MAX_ROWS = 1000;
    
    /// <summary>
    /// MES- In this mode, all the data is on the client, we can sort on the
    /// client.
    /// </summary>
    public const int PTTQRW_MODE_CLIENT = 0;
    
    /// <summary>
    /// MES- In this mode, the data we hold is truncated, we have to go to the
    /// Server for sorts.
    /// </summary>
    public const int PTTQRW_MODE_TRUNCATED = 1;
    
    /// <summary>
    /// MES- The maximum number of rows we'll return 
    /// </summary>
    protected int m_iMaxRows = 0;
    
    /// <summary>
    /// MES- Our mode- we have to treat large result sets special.  Value should
    /// be PTTQRW_MODE_CLIENT or PTTQRW_MODE_TRUNCATED
    /// </summary>
    protected int m_iMode = 0;
    public APTQueryWrapper() : base()
    {
      m_iMaxRows = PTTQRW_DEFAULT_MAX_ROWS;
      m_iMode = PTTQRW_MODE_CLIENT;
    }
    
    /// <summary>
    /// MES- GetFields emulates the IPTQueryResult call of the same name. It's
    /// just a tiny wrapper around PTSortedArrayWrapper::GetItem, but it offers
    /// the name expected by IPTQueryResult callers.
    /// </summary>
    /// <param name="iRow">is the row desired</param>
    /// <param name="iPropID">is the PT_PROPIDs id of the Property desired</param>
    /// <returns>the object from the array</returns>
    public virtual Object GetFields(int iRow, int iPropID)
    {
      return GetItem(iRow, iPropID);
    }
    
    /// <summary>
    /// MES- IsComplete returns a boolean indicating if the rows we can return
    /// are the complete rowset (i.e. have we truncated the rowset because it's
    /// too large to bring to the client.)
    /// </summary>
    /// <returns>A boolean indicating completeness.</returns>
    public virtual bool IsComplete()
    {
      if (PTTQRW_MODE_CLIENT == m_iMode)
      {
        return true;
      } else
      {
        return false;
      }
    }
    
    /// <summary>
    /// MES- MaxRows returns the maximum number of rows an instance may contain
    /// before entering PTTQRW_MODE_TRUNCATED mode.
    /// </summary>
    /// <returns>an int containing the maximum rows.</returns>
    public virtual int MaxRows()
    {
      return m_iMaxRows;
    }
    
    /// <summary>
    /// MES- SetMaxRows allows clients to set the maximum number of rows that
    /// this     wrapper will hold before entering PTTQRW_MODE_TRUNCATED mode.
    /// Call this     function BEFORE querying.
    /// </summary>
    /// <param name="iMaxRows">is the maximum number of rows desired, which must be > 0</param>
    /// <throws>XPException </throws>
    public virtual void SetMaxRows(int iMaxRows)
    {
      if (0 < iMaxRows)
      {
        m_iMaxRows = iMaxRows;
      } else
      {
        throw new XPException("Error in APTQueryWrapper::SetMaxRows, " + XPConvert.ToString(iMaxRows) + " is not an allowed value for Max Rows.  Value must be greater than 0.");
        }
    }
  }
}