using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.resultwrapper
{
  /// <author>Michael Smedberg</author>
  public class ASQueryResultWrapper : IASQueryResult
  {
    private IPTQueryResult m_ptResult = null;
    
    /// <summary>
    /// MES- Is our result set complete?  See the IsComplete method. 
    /// </summary>
    private bool m_bIsComplete = true;
    
    /// <summary>
    /// Creates a new ASQueryResultWrapper object.
    /// </summary>
    /// <param name="ptResult"></param>
    /// <throws>XPException </throws>
    public ASQueryResultWrapper(IPTQueryResult ptResult)
    {
      if (null == ptResult)
      {
        throw new XPException("Invalid QueryResult supplied, it is null");
        }
      m_ptResult = ptResult;
    }
    
    /// <param name="asResult"></param>
    /// <param name="nPropID"></param>
    /// <returns></returns>
    public static XPArrayList ConvertToArrayList(IASQueryResult asResult,
     int nPropID)
    {
      XPArrayList list = new XPArrayList(asResult.GetCount());
      for (int i = 0;i < asResult.GetCount();i++)
      {
        list.Add(asResult.GetFields(i, nPropID));
      }
      return list;
    }
    
    /// <param name="asResult"></param>
    /// <param name="anPropID"></param>
    /// <returns></returns>
    public static XPArrayList ConvertToArrayList(IASQueryResult asResult,
     int[] anPropID)
    {
      XPArrayList list = new XPArrayList(asResult.GetCount());
      for (int i = 0;i < asResult.GetCount();i++)
      {
        String[] objAr = new String[anPropID.Length];
        for (int j = 0;j < anPropID.Length;j++)
        {
          Object value = asResult.GetFields(i, anPropID[j]);
          objAr[j] = XPConvert.ToString(value);
        }
        list.Add(objAr);
      }
      return list;
    }
    
    /// <returns></returns>
    public virtual int GetCount()
    {
      return m_ptResult.RowCount();
    }
    
    /// <param name="nIndex"></param>
    /// <param name="nPropertyMask"></param>
    /// <returns></returns>
    public virtual Object GetFields(int nIndex, int nPropertyMask)
    {
      return m_ptResult.ItemAsObject(nIndex, nPropertyMask);
    }
    
    /// <summary>
    /// MES- IsComplete returns a boolean indicating if the rows we can return
    /// are the complete rowset (i.e. have we truncated the rowset because it's
    /// too large to bring to the client.)
    /// </summary>
    /// <returns>A boolean indicating completeness.</returns>
    public virtual bool IsComplete()
    {
      //MES- The code that set us up knows if we're complete, 
      //	just return our member value
      return m_bIsComplete;
    }
    
    /// <summary>
    /// MES- SetIsComplete lets the code that sets us up decide
    /// if we have all the data.  For example, if some code creates
    /// a QueryResult by doing a query that's constrained to a given
    /// number of rows, and the query returns that number of rows (and
    /// would therefore probably return more if more were asked for)
    /// the code should call SetIsComplete(false).  The default value
    /// is true.
    /// </summary>
    /// <param name="bIsComplete">
    /// indicates if the QueryResult we're wrapping
    /// is complete (i.e does it contain all rows that match the Query
    /// constraints, or has it been truncated?)
    /// </param>
    public virtual void SetIsComplete(bool bIsComplete)
    {
      //MES- Just store the value
      m_bIsComplete = bIsComplete;
    }
  }
}