using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public class BreadcrumbControl : SearchResultControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.search.BreadcrumbControl");
    public const String STR_MVC_CLASS_NAME = "crumb";
    public const String KEY_OF_MODEL_TO_RESTORE_DATA = "restorekey";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Factory method to make a breadcrumb link for search results.
    /// </summary>
    /// <param name="model">Current batch of search results</param>
    /// <param name="parent">ActivitySpace we're living in</param>
    /// <param name="urlText">Desired text within URL</param>
    /// <param name="key">Key of model to display</param>
    public static HTMLElement makeURL(ISearchResultModelRO model, AActivitySpace parent,
     String urlText, String key)
    {
      // Create a URL that directs into the current Activity Space
      ILinkElement url = null;
      bool embedInForm = SpaceNeedsPassthruURL(parent);
      if (embedInForm)
      {
        url = new PassthruURL();
      } else
      {
        url = new ASURL(parent);
        url.SetLinkGetCachedSpace(parent);
        url.SetDisplayPage(parent.GetCurrentPage().GetName());
      }
      // Create a BreadcrumbControl within the search space
      url.SetControl(BreadcrumbControl.STR_MVC_CLASS_NAME);
      // Set superclass data
      addCommonData(model, url);
      // Set link text
      url.AddInnerHTMLString(urlText);
      // Set other data
      url.AddControlArgument(BreadcrumbControl.KEY_OF_MODEL_TO_RESTORE_DATA,
       key);
      return url.GetURLAsHTMLElement();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new BreadcrumbControl();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()"></seealso>
    protected override Redirect ExecuteSearchControl(XPHashtable args, String keyOnPage)
    {
      // First result
      String[] values = (String[]) args.GetElement(KEY_OF_MODEL_TO_RESTORE_DATA);
      if (null == values)
      {
        log.Error("could not find key of model to restore");
        return null;
      }
      String keyOfModelToRestore = values[0];
      // Tell the model to return to the specified model
      _model.RestoreFromBreadcrumb(keyOnPage, keyOfModelToRestore);
      // Don't need to redirect to a different page or space; just
      // redisplay the page
      return null;
    }
  }
}