using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public class DrilldownControl : SearchResultControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.search.DrilldownControl");
    public const String STR_MVC_CLASS_NAME = "drill";
    public const String CATEGORY_DATA = "ddcat";
    public const String GROUPBY_DATA = "ddgroupby";
    public const String CATEGORY_FOR_NO_DRILLDOWN = ".";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Factory method to make a drilldown link.
    /// </summary>
    /// <param name="model">Current batch of search results</param>
    /// <param name="linkText">Desired link text</param>
    /// <param name="category">Desired category to drill down into</param>
    public static HTMLElement makeURL(ISearchResultModelRO model, AActivitySpace parent,
     String linkText, int category)
    {
      return DrilldownControl.makeURL(model, parent, new HTMLGenericElement(linkText),
       category);
    }
    
    /// <summary>
    /// Factory method to make a drilldown link.
    /// </summary>
    /// <param name="model">Current batch of search results</param>
    /// <param name="linkText">Desired link text</param>
    /// <param name="category">Desired category to drill down into</param>
    public static HTMLElement makeURL(ISearchResultModelRO model, AActivitySpace parent,
     HTMLElement linkText, int category)
    {
      // Create a URL that directs into the current Activity Space
      ILinkElement url = null;
      bool embedInForm = SpaceNeedsPassthruURL(parent);
      if (embedInForm)
      {
        url = new PassthruURL();
      } else
      {
        url = new ASURL(parent);
        url.SetLinkGetCachedSpace(parent);
        url.SetDisplayPage(parent.GetCurrentPage().GetName());
      }
      // Set a DrilldownControl as the URL's target
      url.SetControl(DrilldownControl.STR_MVC_CLASS_NAME);
      // Set superclass data
      addCommonData(model, url);
      // Set link text
      url.AddInnerHTMLElement(linkText);
      // Set other data
      url.AddControlArgument(DrilldownControl.CATEGORY_DATA, XPConvert.ToString(category));
      url.AddControlArgument(DrilldownControl.GROUPBY_DATA, model.GetLastGroupByField());
      return url.GetURLAsHTMLElement();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DrilldownControl();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()"></seealso>
    protected override Redirect ExecuteSearchControl(XPHashtable args, String key)
    {
      // category
      String[] values = (String[]) args.GetElement(CATEGORY_DATA);
      if (null == values)
      {
        log.Error("could not find category data in query string.");
        return null;
      }
      // Special case.. let category "all" mean "do no drilldown".
      if (values[0].Equals(CATEGORY_FOR_NO_DRILLDOWN))
      {
        // Just redisplay the page where the "all results" option was selected
        _model.RestoreFromBreadcrumb(key, key);
        return null;
      }
      int category;
      try
      {
        category = XPConvert.ToInteger(values[0]);
      }
      catch (Exception e)
      {
        log.Error("could not parse categgory data in query string: " + values[0]);
        return null;
      }
      // groupby field
      values = (String[]) args.GetElement(GROUPBY_DATA);
      if (null == values)
      {
        log.Error("could not find groupby field in query string.");
        return null;
      }
      String groupByField = values[0];
      // Tell the model to go to the new category
      _model.Drilldown(key, groupByField, category);
      // Don't need to redirect to a different page or space; just
      // redisplay the page
      return null;
    }
  }
}