using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public class GroupedResultsView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.search.GroupedResultsView");
    
    /// <summary>
    /// Class name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GroupedResultsView";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new GroupedResultsView();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    private AActivitySpace m_asOwner = null;
    private ISearchResultModelRO _model = null;
    private IGroupedResultsViewHelper _helper = null;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace owner)
    {
      _model = (ISearchResultModelRO) model;
      m_asOwner = owner;
    }
    
    /// <summary>
    /// Sets the helper class that actually displays HTML
    /// </summary>
    public virtual void SetHelper(IGroupedResultsViewHelper helper)
    {
      _helper = helper;
      _helper.Init(m_asOwner, _model, this);
    }
    public virtual IGroupedResultsViewHelper GetHelper()
    {
      return _helper;
    }
    
    /// <summary>
    /// Displays html
    /// </summary>
    public virtual HTMLElement Display()
    {
      HTMLElement c = null;
      // If the last search failed..
      if (null != _model.GetError())
      {
        // Display nothing.  The error should appear on the page because
        // ErrorView is embedded in PlumtreeDP.
        return null;
      }
      try
      {
        c = _helper.DisplayCollection();
        if (null == c)
        {
          return new HTMLGenericElement("");
        }
        _helper.InitDisplayResults();
        HTMLElement he = null;
        he = _helper.DisplayHeader();
        if (null != he)
        {
          c.AddInnerHTMLElement(he);
        }
        int numGroups = _model.GetNumResultGroups();
        if (numGroups > 0)
        {
          // Grouped view
          for (int grp = 0;grp < numGroups;grp++)
          {
            he = _helper.DisplayGroupHeader(grp);
            if (null != he)
            {
              c.AddInnerHTMLElement(he);
            }
            int numResults = _model.GetReturnedResultsInGroup(grp);
            // Loop over results in this group
            for (int j = 0;j < numResults;j++)
            {
              int overallRank = _model.GetResultRank(grp, j);
              he = _helper.DisplaySingleResult(overallRank, (1 == (j % 2)),
               grp);
              if (null != he)
              {
                c.AddInnerHTMLElement(he);
              }
            }
            he = _helper.DisplayGroupFooter(grp);
            if (null != he)
            {
              c.AddInnerHTMLElement(he);
            }
          }
        } else
        {
          // Ungrouped view
          he = _helper.DisplayHeaderIfUngrouped();
          if (null != he)
          {
            c.AddInnerHTMLElement(he);
          }
          int numResults = _model.GetNumDisplayableItems();
          for (int j = 0;j < numResults;j++)
          {
            he = _helper.DisplaySingleResult(j, (1 == (j % 2)), 0);
            if (null != he)
            {
              c.AddInnerHTMLElement(he);
            }
          }
          he = _helper.DisplayFooterIfUngrouped();
          if (null != he)
          {
            c.AddInnerHTMLElement(he);
          }
        }
        he = _helper.DisplayFooter();
        if (null != he)
        {
          c.AddInnerHTMLElement(he);
        }
      }
      catch (SearchModelException e)
      {
        // Just display the exception.
        log.Error(e, e.Message);
        c = new HTMLGenericElement(e.Message);
      }
      catch (HTMLException e)
      {
        // Same.
        log.Error(e, e.Message);
        c = new HTMLGenericElement(e.Message);
      }
      return c;
    }
    
    /// <summary>
    /// Displays javascript
    /// </summary>
    public virtual HTMLScript DisplayJavascript()
    {
      return _helper.DisplayJavascript();
    }
    
    /// <summary>
    /// Returns a standard group header; this is a helper for
    /// implementations of IGroupedResultsViewHelper
    /// </summary>
    public virtual HTMLElement DisplayStandardGroupHeaderRow(int groupNum,
     String cellHeight, String colSpan, bool _bAlwaysReturnRow)
    {
      int numDisplayed = _model.GetReturnedResultsInGroup(groupNum);
      String totalResults = _model.GetTotalResultsInGroup(groupNum);
      String groupTitle = XPHttpUtility.HtmlEncode(_model.GetGroupName(groupNum));
      bool allReturned = _model.isEntireGroupReturned(groupNum);
      Object groupIcon = _model.GetGroupIcon(groupNum);
      // If there is nothing to display in this group, don't display
      // a header.
      if (0 == numDisplayed)
      {
        return null;
      }
      // Otherwise, create text for the header..
      HTMLElementCollection msg = new HTMLElementCollection();
      if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD && !_bAlwaysReturnRow)
      {
        msg.AddInnerHTMLElement(new HTMLBr());
      }
      if (null != groupIcon)
      {
        HTMLImg icon = (HTMLImg) groupIcon;
        icon.SetBorder("0");
        icon.SetAlign("absmiddle");
        msg.AddInnerHTMLElement(icon);
        msg.AddInnerHTMLString("&nbsp;");
      }
      msg.AddInnerHTMLString("<b>");
      msg.AddInnerHTMLString(groupTitle);
      msg.AddInnerHTMLString("</b>");
      msg.AddInnerHTMLString("  (");
      msg.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(831,
       "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(numDisplayed), totalResults));
      bool moreThanOneGroup = (_model.GetNumResultGroups() > 1);
      if (!allReturned && moreThanOneGroup)
      {
        msg.AddInnerHTMLString("; ");
        // "More >>"
        msg.AddInnerHTMLElement(DrilldownControl.makeURL(_model, m_asOwner,
         m_asOwner.GetString(830, "ptmsgs_portalbrowsingmsgs"), groupNum));
        }
      msg.AddInnerHTMLString(")");
      // In 508 mode, just return this as text
      if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD && !_bAlwaysReturnRow)
      {
        msg.AddInnerHTMLElement(new HTMLBr());
        msg.AddInnerHTMLElement(new HTMLBr());
        return msg;
      }
      // In standard UI, return a table row with the requested height and span
      HTMLTableRow row = new HTMLTableRow();
      row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
      // Add a cell for the label
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetColSpan(colSpan);
      cell.SetHeight(cellHeight);
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      cell.AddInnerHTMLElement(msg);
      return row;
    }
  }
}