using System;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public interface IBaseSearchQueryRO
  {
    
    /// <summary>
    /// Returns the abstract types the search was restricted to, if any.
    /// </summary>
    int GetAbstractTypeRestrictions();
    
    /// <summary>
    /// Returns the admin folders the search was restricted to, if any.
    /// </summary>
    int[] GetAdminFolderRestrictions();
    
    /// <summary>
    /// Returns the applications the search was restricted to, if any.
    /// </summary>
    int GetApplicationRestrictions();
    
    /// <summary>
    /// Utility method to lookup the name of a community given its id.
    /// </summary>
    String GetCommunityNameForID(int id);
    
    /// <summary>
    /// Returns the communities the search was restricted to, if any.
    /// </summary>
    int[] GetCommunityRestrictions();
    
    /// <summary>
    /// Returns the Content Server portlets the search was restricted to, if any.
    /// </summary>
    int[] GetPortletRestrictions();
    
    /// <summary>
    /// Returns the Collab projects the search was restricted to, if any.
    /// </summary>
    int[] GetCollabProjectRestrictions();
    
    /// <summary>
    /// Utility method to lookup the name of a portlet given its id.
    /// </summary>
    String GetPortletNameForID(int id);
    
    /// <summary>
    /// Returns the document folders the search was restricted to, if any.
    /// </summary>
    int[] GetDocFolderRestrictions();
    
    /// <summary>
    /// Utility method to lookup the name of a folder given its id.
    /// Pass isAdmin = true for admin folders, false for doc folders.
    /// </summary>
    String GetFolderNameForID(int id, bool isAdmin);
    
    /// <summary>
    /// Returns true if the folder restrictions included subfolders.
    /// </summary>
    bool GetIncludeSubfolders();
    
    /// <summary>
    /// Returns the two-character code for the language restriction, if
    /// any, or null otherwise.
    /// </summary>
    String GetLanguageRestriction();
    
    /// <summary>
    /// Returns the types (as PT_CLASSIDs) the search was restricted to, if any.
    /// </summary>
    int[] GetObjectTypeRestrictions();
    
    /// <summary>
    /// Returns the user's original search string.
    /// </summary>
    String GetSearchString();
    
    /// <summary>
    /// Returns the original search string with meta search substrings being replaced with
    /// locale specific substrings 
    /// e.g: tag:test will be returned as etiqueta:test in spanish
    /// </summary>
    /// <returns></returns>
    String GetLocalizedSearchString();
  }
}