using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.pagination;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public interface IBaseSearchResultModelRO : IModelRO,IPaginationRO,IBaseSearchQueryRO
  {
    
    /// <summary>
    /// Returns the keyword-in-context (KWIC) information for
    /// a result.
    /// This method html-encodes always returns an html-encoded result, except
    /// that keywords are surrounded by highlighting tags.  Note that
    /// html-encoding is NOT applied to the return value of any other
    /// method from this interface.
    /// </summary>
    String GetKWIC(int rank);
    
    /// <summary>
    /// Returns a result's abstract (app-independent) type: DOCUMENT,
    /// CONTAINER, or OTHER.
    /// </summary>
    String GetResultAbsType(int rank);
    
    /// <summary>
    /// Returns a result's application: PTPORTAL, PTCOLLAB, PTCONTENT.
    /// </summary>
    String GetResultApp(int rank);
    
    /// <summary>
    /// Returns true if a result is a Best Bet.
    /// </summary>
    bool isResultBestBet(int rank);
    
    /// <summary>
    /// Returns a result's class ID.  Defined for portal objects only, returns
    /// -1 for other types.
    /// </summary>
    int GetResultClassID(int rank);
    
    /// <summary>
    /// Returns the value of a gadget field for the result. Portlet
    /// fields are a small set of special case fields:
    /// PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_TYPE
    /// PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_ALIGNMENT
    /// PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_USER_INTERFACES
    /// </summary>
    String GetResultPortletField(int rank, int fieldId);
    
    /// <summary>
    /// Returns a result's creation date.
    /// </summary>
    XPDateTime GetResultCreated(int rank);
    
    /// <summary>
    /// Returns the value of an EOD property for a result.
    /// </summary>
    String GetResultEODField(int rank, int propertyId);
    
    /// <summary>
    /// Returns the ID of the folder in which this result is found.
    /// </summary>
    int GetResultFolderID(int rank);
    
    /// <summary>
    /// Returns the icon corresponding to an item's application and class,
    /// and any other relevant info (i.e. file extension)
    /// This actually returns an HTMLImg.
    /// </summary>
    Object GetResultIcon(int rank);
    
    /// <summary>
    /// Returns a result's last-modified date.
    /// </summary>
    XPDateTime GetResultLastModified(int rank);
    
    /// <summary>
    /// Returns a result's name.
    /// </summary>
    String GetResultName(int rank);
    
    /// <summary>
    /// Returns a result's object ID.  Defined for portal objects only, returns
    /// -1 for other types.
    /// </summary>
    int GetResultObjectID(int rank);
    
    /// <summary>
    /// Returns the full path to a result.
    /// </summary>
    String GetResultPath(int rank);
    
    /// <summary>
    /// Returns a result's size.
    /// </summary>
    int GetResultSize(int rank);
    
    /// <summary>
    /// Returns a result's app-specific subtype: PTCARD, PTGADGET, etc.
    /// </summary>
    String GetResultSubType(int rank);
    //
    //  Error states
    //
    
    /// <summary>
    /// Returns any SearchExecutionError that occurred during the
    /// last search.  If this is non-null, then no search results
    /// are available (and calling any of the getResultXXX methods
    /// will result in throwing another exception).  This error
    /// should be displayed to the user in some way.
    /// </summary>
    SearchExecutionError GetError();
    
    /// <summary>
    /// Returns any SearchExecutionWarning that occurred during the
    /// last search.  If this is non-null, then the warning should
    /// be displayed to the user, but some search results are still
    /// available (they may not be complete or may not match the
    /// user's expectations).
    /// </summary>
    SearchExecutionWarning GetWarning();
    
    /// <summary>
    /// Returns true if the model has been initialized (i.e. if
    /// a search has been run).
    /// </summary>
    bool IsInitialized();
  }
}