using System;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public interface IGroupedResultsViewHelper
  {
    
    /// <summary>
    /// Called to set the activityspace, model, and view being used
    /// </summary>
    void Init(AActivitySpace owner, ISearchResultModelRO model, GroupedResultsView view);
    
    /// <summary>
    /// Returns javascript for the view.
    /// </summary>
    HTMLScript DisplayJavascript();
    
    /// <summary>
    /// Returns the element that all other elements will be added to,
    /// such as an HTMLElementCollection or HTMLTable.
    /// If null is returned, no other methods from this interface will be
    /// called, and the view will not be displayed.
    /// </summary>
    HTMLElement DisplayCollection();
    
    /// <summary>
    /// Returns an element that will appear before all results, whether
    /// or not the results are grouped.
    /// </summary>
    HTMLElement DisplayHeader();
    
    /// <summary>
    /// Returns an element that will appear after all results regardless
    /// of whether the results are grouped.
    /// </summary>
    HTMLElement DisplayFooter();
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow containing column
    /// headings) that will be used if the results are not grouped.  Not called
    /// if the results are grouped.
    /// </summary>
    HTMLElement DisplayHeaderIfUngrouped();
    
    /// <summary>
    /// Returns an element that will appear after all results if the results
    /// are not grouped.  Not called if the results are grouped.
    /// </summary>
    HTMLElement DisplayFooterIfUngrouped();
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow containing column
    /// headings) that will be used if the results are grouped.  Not called
    /// if the results are ungrouped.
    /// </summary>
    HTMLElement DisplayGroupHeader(int groupNum);
    
    /// <summary>
    /// Returns an element that will appear after all results in a single group.
    /// Not called if the results are ungrouped.
    /// </summary>
    HTMLElement DisplayGroupFooter(int groupNum);
    
    /// <summary>
    /// Returns the element (e.g. an HTMLTableRow) for a single search result.
    /// The "oddRow" argument helps in making tables where every other item is
    /// shaded, note that this is not the same as (resultNum % 2) for grouped results.
    /// </summary>
    HTMLElement DisplaySingleResult(int resultNum, bool oddRow, int groupNum);
    
    /// <summary>
    /// Call this method before calling any of the other methods to do initialization. 
    /// </summary>
    void InitDisplayResults();
  }
}