using System;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public interface ISearchQueryRO : IBaseSearchQueryRO
  {
    
    /// <summary>
    /// Returns true if this advanced search consists of a nested
    /// set of clauses that are too complex to easily summarize.
    /// </summary>
    bool IsASTooComplexToSummarize();
    
    /// <summary>
    /// If advanced search, returns the operator for the indicated
    /// property condition (localized).
    /// </summary>
    String GetASConstraintOperator(int condition);
    
    /// <summary>
    /// If advanced search, returns the property name for the indicated
    /// property condition.
    /// </summary>
    String GetASConstraintProperty(int condition);
    
    /// <summary>
    /// If advanced search, returns the comparison value for the indicated
    /// property condition.
    /// </summary>
    String GetASConstraintValue(int condition);
    
    /// <summary>
    /// If advanced search, returns the number of property restrictions.
    /// </summary>
    int GetASNumPropertyConstraints();
    
    /// <summary>
    /// If advanced search, returns whether individual property conditions
    /// are ANDed or ORed together (true <-> AND).
    /// </summary>
    bool GetASPropertyClauseOperator();
    
    /// <summary>
    /// If advanced search, returns whether text and property conditions
    /// (as a group) are ANDed or ORed together (true <-> AND).
    /// </summary>
    bool GetASTopLevelOperator();
    
    /// <summary>
    /// Returns true if this result was generated by an advanced search.
    /// </summary>
    bool isAdvancedSearch();
  }
}