using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.pagination;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public interface ISearchResultModel : IModel,IPagination,ISaveSearchModel
  {
    
    /// <summary>
    /// SearchResultModel holds onto a "page mode" string for the benefit of client
    /// code.. it doesn't care about the contents.
    /// </summary>
    void SetPageMode(String pageMode);
    
    /// <summary>
    /// Drill down into the indicated category.
    /// Pass in the groupby field that was used to generate
    /// the set of categories you are using; the model should validate
    /// that it is using the right categories.
    /// </summary>
    void Drilldown(String key, String groupByField, int category);
    
    /// <summary>
    /// Returns true if the model has been initialized (i.e. if
    /// a search has been run).  This could be in ISearchResultModelRO,
    /// but is here for convenience, since the caller probably needs
    /// to call Search() if this returns false.
    /// </summary>
    bool IsInitialized();
    
    /// <summary>
    /// Perform a different categorization on the current result set
    /// </summary>
    void Reorganize(String key, String groupByField);
    
    /// <summary>
    /// Update sort order
    /// </summary>
    /// <param name="sortOrder"></param>
    /// <param name="additionalInfo"></param>
    void ChangeSortOrder(String sortOrder, Object additionalInfo);
    
    /// <summary>
    /// Follow a breadcrumb link with the specified key.
    /// </summary>
    void RestoreFromBreadcrumb(String keyOfPageWhereLinkAppears, String keyToRestore);
    
    /// <summary>
    /// Initialize the model by running the provided query with the
    /// provided settings.
    /// </summary>
    void Search(String searchString, String basicFields, IPTFilter advancedFilter,
     SearchSettingCollection settings);
    // only if basic search
    // only if advanced search
    
    /// <summary>
    /// Initialize the model by running the provided query with the
    /// provided settings (allSettings).  removableSettings, if non-null,
    /// are those settings that may be removed on a followup search.
    /// </summary>
    void Search(String searchString, String basicFields, IPTFilter advancedFilter,
     SearchSettingCollection allSettings, SearchSettingCollection removableSettings);
    // only if basic search
    // only if advanced search
    
    /// <summary>
    /// Search within results already generated for the
    /// indicated additional query string.
    /// </summary>
    void SearchWithinResults(String key, String additionalQuery);
    
    /// <summary>
    /// Rerun the search that generated the indicated page; call this
    /// following any action that may change the result set.
    /// </summary>
    void RefreshResults(String keyOnPage);
    
    /// <summary>
    /// Tell the model that there was an error on the previous search.
    /// </summary>
    void SetError(SearchExecutionError e);
    
    /// <summary>
    /// Tell the model that there was a warning on the previous search.
    /// </summary>
    void SetWarning(SearchExecutionWarning e);
    
    /// <summary>
    /// Filter the search result based on the filterId
    /// </summary>
    void Filter(String key, int filterId);
    
    /// <summary>
    /// Gets the property id that is currently used as the
    /// order by property in the model. 
    /// </summary>
    /// <returns>	Property Id as a string</returns>
    String GetSortOrder();
  }
}