using System;
using com.plumtree.openfoundation.util;
using PathwaysTagRestData=com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysTagRestData;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public interface ISearchResultModelRO : IBaseSearchResultModelRO,ISearchQueryRO,
  ISaveSearchModelRO
  {
    
    /// <summary>
    /// Returns a key that may be used in ISearchResultModel.FollowBreadcrumb
    /// to use the indicated breadcrumb step (must be between 1 and
    /// getDrilldownDepth(), inclusive).
    /// </summary>
    String GetBreadcrumbKey(int step);
    
    /// <summary>
    /// Returns a displayable label for the indicated breadcrumb
    /// (must be between 2 and getDrilldownDepth(), inclusive).
    /// </summary>
    String GetBreadcrumbLabel(int step);
    
    /// <summary>
    /// Returns the number of times the given correction actually matched a document.
    /// </summary>
    int GetCorrectionFrequency(int misspellingIndex, int correctionIndex);
    
    /// <summary>
    /// Returns a key that should be attached to all URLs that access
    /// this model; this key allows the model to find the search result
    /// on which a URL was generated if the user hits the BACK button.
    /// </summary>
    String GetCurrentKey();
    
    /// <summary>
    /// Returns true if this model has been drilled down into a single
    /// category of the given organization scheme.
    /// </summary>
    bool hasDrilledDownIntoSingleCategory(String orgType);
    
    /// <summary>
    /// Returns the number of drilldown steps the user has taken.
    /// </summary>
    int GetDrilldownDepth();
    
    /// <summary>
    /// Returns true if all results in the group were returned.
    /// </summary>
    bool isEntireGroupReturned(int group);
    
    /// <summary>
    /// Returns the name of the indicated group.
    /// </summary>
    String GetGroupName(int group);
    
    /// <summary>
    /// Returns an icon (actually an HTMLImg) for the indicated group,
    /// or null if there is no appropriate icon.
    /// </summary>
    Object GetGroupIcon(int group);
    
    /// <summary>
    /// Returns the most recent categorization field
    /// </summary>
    String GetLastGroupByField();
    
    /// <summary>
    /// SearchResultModel holds onto a "page mode" string for the benefit of client
    /// code.. it doesn't care about the contents.
    /// </summary>
    String GetPageMode();
    
    /// <summary>
    /// Returns a single misspelled token.
    /// </summary>
    String GetMisspelledToken(int misspellingIndex);
    
    /// <summary>
    /// Returns the number of corrections for the indicated misspelling.
    /// </summary>
    int GetNumCorrections(int misspellingIndex);
    
    /// <summary>
    /// Returns the number of misspelled tokens.
    /// </summary>
    int GetNumMisspelledTokens();
    
    /// <summary>
    /// Returns the number of result groups.
    /// </summary>
    int GetNumResultGroups();
    
    /// <summary>
    /// Get URL arguments that are sufficient to reconstruct
    /// this search result if it has been flushed from the cache.
    /// These are returned as an XPHashtable from a String key to an array
    /// of String values.
    /// </summary>
    XPHashtable GetReconstructionArgs();
    
    /// <summary>
    /// Same as getReconstructionArgs(), but if pageContext is false,
    /// omit any args that indicate
    /// what page the model is on - i.e. the model will come back on page
    /// 1 with the default sort order and organization.
    /// </summary>
    XPHashtable GetReconstructionArgs(bool pageContext);
    XPHashtable GetReconstructionArgs(String prefix, bool wantPageContext);
    
    /// <summary>
    /// Returns an internal key used by Best Bets; do not call otherwise
    /// </summary>
    String GetResultBestBetKey(int rank);
    
    /// <summary>
    /// Returns an URL that may be used for clickthrough in "view" mode.
    /// Equivalent to GetResultClickthroughURL(rank, allowPopup, false).
    /// </summary>
    HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup);
    
    /// <summary>
    /// Returns an URL that may be used for clickthrough.
    /// </summary>
    HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup, bool editMode);
    
    /// <summary>
    /// Returns an URL that may be used for clickthrough.
    /// </summary>
    HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup, bool editMode,
     String extraParameters);
    
    /// <summary>
    /// Returns an edit link that may be used for clickthrough.
    /// Equivalent to GetResultClickthroughURL(rank, allowPopup, true).
    /// </summary>
    HTMLAnchor GetResultEditLink(int rank, bool allowPopup);
    
    /// <summary>
    /// Special call for Collab Server results; returns the URL used to open the
    /// containing project.
    /// </summary>
    String GetResultCollabProjectURL(int rank);
    
    /// <summary>
    /// Special call for Collab Server results; returns the name of the item's
    /// containing project.
    /// </summary>
    String GetResultCollabProjectName(int rank);
    
    /// <summary>
    /// Special call for Content Server results; returns the "last published by" username.
    /// </summary>
    String GetResultContentLastPubUser(int rank);
    
    /// <summary>
    /// Special call for Content Server results; returns the IDs of this result's parent portlets.
    /// </summary>
    int[] GetResultContentPortletIDs(int rank);
    
    /// <summary>
    /// Returns an URL that may be used to open a "properties" page for the item,
    /// or null if there is no such page.
    /// </summary>
    HTMLAnchor GetResultPropertiesURL(int rank, bool allowPopup);
    
    /// <summary>
    /// Returns the overall relevance rank of a grouped result.
    /// </summary>
    int GetResultRank(int groupNum, int resultNum);
    
    /// <summary>
    /// Returns the number of results in the indicated group
    /// that were actually returned.
    /// </summary>
    int GetReturnedResultsInGroup(int group);
    
    /// <summary>
    /// Returns arguments that can be used for a followup search with
    /// the same settings as the current search.
    /// If removeOptional is true, then any settings that are in the
    /// "removable" set (as returned by GetRemovableSettings()) are not
    /// included in the returned XPHashtable.
    /// </summary>
    XPHashtable GetSearchAgainArgs(bool includeOptional);
    
    /// <summary>
    /// Returns a single corrected token for the indicated misspelling.
    /// </summary>
    String GetSpellingCorrection(int misspellingIndex, int correctionIndex);
    
    /// <summary>
    /// Returns the total number of results in the indicated group.
    /// The total may be an estimate of the form "~ 100".
    /// </summary>
    String GetTotalResultsInGroup(int group);
    
    /// <summary>
    /// Returns settings that were used for this search, but that could
    /// be removed from followup searches if desired
    /// </summary>
    SearchSettingCollection GetRemovableSettings();
    
    /// <summary>
    /// Returns true if the user's search phrase was spell-corrected.
    /// </summary>
    bool wasSpellCorrected();
    XPDateFormat GetDateFormat(AActivitySpace owner);
    String GetResultStyleClass(String subType);
    bool ContentInstalled();
    bool CollabInstalled();
    int GetSelectedTypeFilter();
    
    /// <summary>
    /// Returns the pathways tags associated to the pathways search result item
    /// </summary>
    /// <param name="rank">- the search result # you want info from</param>
    PathwaysTagRestData[] GetPathwaysResultTags(int rank);
    
    /// <summary>
    /// Returns the pathways tag cloud associated with the pathways search result
    /// </summary>
    XPHashtable GetTagCloud();
    
    /// <summary>
    /// Returns true if it is a Pathways search, otherwise it is a regular search.
    /// </summary>
    bool IsPathwaysSearch();
  }
}
/* RANK ENGINE REMOVED FROM NEO RELEASE, DO NOT NEED THIS METHOD
 * Returns the Pathways score for the result.
 *
 public double GetPathwaysResultScore(int rank);
 */
 
