using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>
  /// CraigS
  /// Simple view to return pagination for an IBaseSearchResultModelRO:
  /// << Prev 10   Results 11-20 of 57  Next 10 >>
  /// You can either make this its own Section in your space, or
  /// just call the static DisplayPagination() method,
  /// passing in a model interface.
  /// </author>
  public class PaginationView : IView
  {
    public const String STR_MVC_CLASS_NAME = "PaginationView";
    protected AActivitySpace m_asOwner = null;
    protected IBaseSearchResultModelRO _model = null;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      try
      {
        return DisplayPagination(_model, m_asOwner);
      }
      catch (Exception e)
      {
        throw XPException.GetInstance(e);
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      // nothing needed
      return null;
    }
    
    /// <summary>
    /// Returns an HTMLElement for pagination of the results table.
    /// </summary>
    public static HTMLElement DisplayPagination(IBaseSearchResultModelRO model,
     AActivitySpace parent)
    {
      HTMLElementCollection group = new HTMLElementCollection();
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      group.AddInnerHTMLElement(span);
      const int PAGES_TO_DISPLAY = 10;
      try
      {
        String sortOrder = model.GetSortOrder();
        int currFirst = model.GetFirstDisplayableItem();
        int totResults = model.GetTotalItems();
        int pageSize = model.GetItemsPerPage();
        bool shownOneItem = false;
        // If there is only one page
        if (totResults <= pageSize)
        {
          // Don't bother
          return group;
        }
        // Add a space at the beginning so we don't run into a cell border
        span.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // First, check whether we can display a "previous" link.
        int prevFirst = 0;
        if (currFirst > pageSize)
        {
          // we're at least one page beyond the beginning;
          // we can back up one page
          prevFirst = currFirst - pageSize;
        } else
        if (currFirst > 1)
        {
          // odd case: we're partway thru the first page.
          // how did we get here?
          // display a link to go back to the first result
          prevFirst = 1;
        }
        // If we can display a "previous" link
        if (0 < prevFirst)
        {
          // Display "prev" link
          span.AddInnerHTMLElement(PaginationControl.makeURL(model, parent,
           parent.GetString(207, "ptmsgs_portalinfrastructure"), sortOrder,
           prevFirst, pageSize));
        } else
        {
          // Display a nonclickable link
          span.AddInnerHTMLString(parent.GetString(207, "ptmsgs_portalinfrastructure"));
          }
        shownOneItem = true;
        int currPage = (currFirst - 1) / pageSize;
        // integer divide!
        int firstPageToDisplay = (currPage / PAGES_TO_DISPLAY);
        firstPageToDisplay = (firstPageToDisplay * PAGES_TO_DISPLAY) - 1;
        int lastPageToDisplay = firstPageToDisplay + PAGES_TO_DISPLAY + 1;
        for (int page = firstPageToDisplay;page <= lastPageToDisplay;page++)
        {
          if (page < 0)
          {
            continue;
          }
          int firstResultInPage = (page * pageSize) + 1;
          int lastResultInPage = (firstResultInPage + pageSize) - 1;
          // If we're over the total number of results
          if (firstResultInPage > totResults)
          {
            // we're all done
            break;
          }
          // If this is the last page
          if (lastResultInPage > totResults)
          {
            // show the exact number of results we'll be displaying
            lastResultInPage = totResults;
          }
          String linkText = "...";
          // If we're not showing the first or last link
          if ((page > firstPageToDisplay) && (page < lastPageToDisplay))
          {
            // show the actual result range
            linkText = XPConvert.ToString(firstResultInPage) + "-" + XPConvert.ToString(lastResultInPage);
            }
          if (shownOneItem)
          {
            span.AddInnerHTMLString("&nbsp;|&nbsp;");
          }
          shownOneItem = true;
          // If this isn't the current page
          if (page != currPage)
          {
            // make a link
            span.AddInnerHTMLElement(PaginationControl.makeURL(model, parent,
             linkText, sortOrder, firstResultInPage, pageSize));
          } else
          {
            // else make a nonclickable thing
            span.AddInnerHTMLString(linkText);
          }
        }
        // Finally, handle the "next" link
        // Calculate start of next page
        int nextFirst = currFirst + pageSize;
        // Check that "next" won't go beyond the end of
        // the result set
        if (nextFirst > totResults)
        {
          nextFirst = 0;
        }
        if (shownOneItem)
        {
          span.AddInnerHTMLString("&nbsp;|&nbsp;");
        }
        shownOneItem = true;
        // if displaying "next" link
        if (0 != nextFirst)
        {
          //				int numOnNextPage = totResults - nextFirst + 1;
          //
          //				if (numOnNextPage > pageSize)
          //				{
          //					numOnNextPage = pageSize;
          //				}
          span.AddInnerHTMLElement(PaginationControl.makeURL(model, parent,
           
          // Should we really be using the numOnNextPage instead of pageSize?
          parent.GetString(208, "ptmsgs_portalinfrastructure"), sortOrder,
           nextFirst, pageSize));
        } else
        {
          // Show a nonclickable "Next"
          span.AddInnerHTMLString(parent.GetString(208, "ptmsgs_portalinfrastructure"));
          }
        // Finally, add a space on the end
        span.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      catch (Exception e)
      {
        throw XPException.GetInstance(e);
      }
      return group;
    }
    
    /// <summary>
    /// Returns an alternative version of the pagination bar that works well with
    /// screenreading software.
    /// </summary>
    public static HTMLElement Display508StylePagination(ISearchResultModelRO model,
     AActivitySpace parent)
    {
      HTMLElementCollection group = new HTMLElementCollection();
      HTMLSpan span = new HTMLSpan();
      group.AddInnerHTMLElement(span);
      const int PAGES_TO_DISPLAY = 10;
      try
      {
        String sortOrder = model.GetSortOrder();
        int currFirst = model.GetFirstDisplayableItem();
        int totResults = model.GetTotalItems();
        int pageSize = model.GetItemsPerPage();
        int currPage = (currFirst - 1) / pageSize;
        // If there is only one page
        if (totResults <= pageSize)
        {
          // Don't bother
          return group;
        }
        // Show the current page
        span.AddInnerHTMLString(XPResourceManager.FormatMessage(parent.GetString(492,
         "ptmsgs_portalinfrastructure"), XPConvert.ToString(currPage + 1)));
        span.AddInnerHTMLString("  ");
        // Check whether we can display a "previous" link.
        int prevFirst = 0;
        if (currFirst > pageSize)
        {
          // we're at least one page beyond the beginning;
          // we can back up one page
          prevFirst = currFirst - pageSize;
        } else
        if (currFirst > 1)
        {
          // odd case: we're partway thru the first page.
          // how did we get here?
          // display a link to go back to the first result
          prevFirst = 1;
        }
        // If we can display a "previous" link
        if (0 < prevFirst)
        {
          // Display "prev" link
          HTMLElement prevLink = PaginationControl.makeURL(model, parent,
           parent.GetString(494, "ptmsgs_portalinfrastructure"), sortOrder,
           prevFirst, pageSize);
          span.AddInnerHTMLElement(prevLink);
          span.AddInnerHTMLString(".  ");
        }
        // Handle the "next" link
        // Calculate start of next page
        int nextFirst = currFirst + pageSize;
        // Check that "next" won't go beyond the end of
        // the result set
        if (nextFirst > totResults)
        {
          nextFirst = 0;
        }
        // if displaying "next" link
        if (0 != nextFirst)
        {
          int numOnNextPage = totResults - nextFirst + 1;
          if (numOnNextPage > pageSize)
          {
            numOnNextPage = pageSize;
          }
          span.AddInnerHTMLElement(PaginationControl.makeURL(model, parent,
           parent.GetString(493, "ptmsgs_portalinfrastructure"), sortOrder,
           nextFirst, pageSize));
          span.AddInnerHTMLString(".  ");
        }
        // Now, handle "jump to page" links
        // integer divide!
        int firstPageToDisplay = (currPage / PAGES_TO_DISPLAY);
        firstPageToDisplay = (firstPageToDisplay * PAGES_TO_DISPLAY) - 1;
        int lastPageToDisplay = firstPageToDisplay + PAGES_TO_DISPLAY + 1;
        bool shownOneLink = false;
        for (int page = firstPageToDisplay;page <= lastPageToDisplay;page++)
        {
          if (page < 0)
          {
            continue;
          }
          int firstResultInPage = (page * pageSize) + 1;
          int lastResultInPage = (firstResultInPage + pageSize) - 1;
          // If we're over the total number of results
          if (firstResultInPage > totResults)
          {
            // we're all done
            break;
          }
          // If this is the last page
          if (lastResultInPage > totResults)
          {
            // show the exact number of results we'll be displaying
            lastResultInPage = totResults;
          }
          String linkText = "";
          // If we're not showing the last link
          if (page < lastPageToDisplay)
          {
            // show the actual page number
            linkText = XPConvert.ToString(page + 1);
          } else
          {
            // use the "more" text
            linkText = parent.GetString(496, "ptmsgs_portalinfrastructure");
            }
          if (shownOneLink)
          {
            // Add a comma to separate page numbers
            span.AddInnerHTMLString(", ");
          } else
          {
            // Show the "Jump to page:" text
            span.AddInnerHTMLString(parent.GetString(495, "ptmsgs_portalinfrastructure"));
            span.AddInnerHTMLString(" ");
            // For the rest, just show commas
            shownOneLink = true;
          }
          // If this isn't the current page
          if (page != currPage)
          {
            // make a pagination link
            span.AddInnerHTMLElement(PaginationControl.makeURL(model, parent,
             linkText, sortOrder, firstResultInPage, pageSize));
          } else
          {
            // If this is the current page, show plain text, not a link
            span.AddInnerHTMLString(linkText);
          }
        }
        if (shownOneLink)
        {
          span.AddInnerHTMLString(".");
        }
      }
      catch (Exception e)
      {
        throw XPException.GetInstance(e);
      }
      return group;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PaginationView();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      _model = (IBaseSearchResultModelRO) model;
      m_asOwner = parent;
    }
  }
}