using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>
  /// JosephSi This control is used when the end user chooses a different
  /// option from the  "Organize by:" pulldown menu near the top of the
  /// search results page. This action triggers a request sent to the
  /// search server to re-run the search and categorize the results in a
  /// particular way
  /// </author>
  public class ReorganizationControl : SearchResultControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.search.ReorganizationControl");
    public const String STR_MVC_CLASS_NAME = "reorganization";
    public const String GROUP_BY_FIELD = "in_se_OrganizationMenu";
    public const String SPECIAL_SORT_BY_LASTMODIFIED_VALUE = "lastmodified";
    public const String SPECIAL_SORT_BY_NAME_VALUE = "name";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ReorganizationControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()"></seealso>
    protected override Redirect ExecuteSearchControl(XPHashtable args, String key)
    {
      // Group by field
      String[] values = (String[]) args.GetElement(GROUP_BY_FIELD);
      if (null == values)
      {
        log.Error("could not find group by field in query string.");
      }
      String groupByField = values[0];
      if (groupByField.Equals(SPECIAL_SORT_BY_LASTMODIFIED_VALUE))
      {
        // Special case: relevance-rank, but sort by date
        _model.GoToPage(SearchResultModel.SORTORDER_MODIFIED_DESC, /* first= */
        1, ((IBaseSearchResultModelRO) _model).GetItemsPerPage(), key);
      } else
      if (groupByField.Equals(SPECIAL_SORT_BY_NAME_VALUE))
      {
        // Special case: relevance-rank, but sort by date
        _model.GoToPage(SearchResultModel.SORTORDER_NAME_ASC, /* first= */
        1, ((IBaseSearchResultModelRO) _model).GetItemsPerPage(), key);
      } else
      {
        // Tell the model to group by the new property
        _model.Reorganize(key, groupByField);
      }
      // Don't need to redirect to a different page or space; just
      // redisplay the page
      return null;
    }
  }
}