using System;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>DustinA</author>
  public class SearchObjectTypes
  {
    // Special ClassID values for abstract types and applications
    public const int MIN_SPECIAL_CLASSID_VALUE = 9999;
    public const int DOCUMENT_ABSTRACTTYPE = 10000;
    public const int FOLDER_ABSTRACTTYPE = 10001;
    public const int OTHER_ABSTRACTTYPE = 10002;
    public const int PORTAL_APPLICATION = 10003;
    public const int CONTENT_APPLICATION = 10004;
    public const int COLLAB_APPLICATION = 10005;
    public const int CONTENT_APPLICATION_ON_DETAIL_PAGE = 10006;
    public const int COLLAB_APPLICATION_ON_DETAIL_PAGE = 10007;
    
    /// <summary>
    /// Total number of selectable items 
    /// </summary>
    public const int CLASSIDCOUNT = 35;
    
    /// <summary>
    /// Number of selectable items on the "detailed" view 
    /// </summary>
    public const int DETAILEDCOUNT = 29;
    
    /// <summary>
    /// Number of types visible on the "detailed" view to users without admin access:
    /// cards, folders, community pages, communities, portlets, users, collab, content 
    /// </summary>
    /// <TODO>: Update this value if changing the non-admin search types</TODO>
    public const int ENDUSERCOUNT = 8;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_00 = PT_CLASSIDS.PT_CATALOGCARD_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_01 = PT_CLASSIDS.PT_CATALOGFOLDER_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_02 = PT_CLASSIDS.PT_COMMUNITY_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_03 = PT_CLASSIDS.PT_GADGET_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_04 = PT_CLASSIDS.PT_USER_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_05 = PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_06 = PT_CLASSIDS.PT_AUTHSOURCE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_07 = PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_08 = PT_CLASSIDS.PT_CRAWLER_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_09 = PT_CLASSIDS.PT_DATASOURCE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_10 = PT_CLASSIDS.PT_DOCUMENTTYPE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_11 = PT_CLASSIDS.PT_EXTOPERATION_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_12 = PT_CLASSIDS.PT_FEDERATEDPORTAL_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_13 = PT_CLASSIDS.PT_FILTER_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_14 = PT_CLASSIDS.PT_INVITATION_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_15 = PT_CLASSIDS.PT_JOB_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_16 = PT_CLASSIDS.PT_PAGETEMPLATE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_17 = PT_CLASSIDS.PT_GADGETBUNDLE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_18 = PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_19 = PT_CLASSIDS.PT_GADGETTEMPLATE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_20 = PT_CLASSIDS.PT_PROPERTY_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_21 = PT_CLASSIDS.PT_SAVEDSEARCH_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_22 = PT_CLASSIDS.PT_PROFILESOURCE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_23 = PT_CLASSIDS.PT_USERGROUP_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_24 = PT_CLASSIDS.PT_WEBSERVICE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_25 = PT_CLASSIDS.PT_PAGE_ID;
    
    /// <summary>
    /// A type 
    /// </summary>
    public static readonly int CLASSID_26 = PT_CLASSIDS.PT_SUBPORTAL_ID;
    private static int[] _searchObjectTypes = null;
    public static int[] GetOrderedSearchObjectTypes()
    {
      if (null == _searchObjectTypes)
      {
        Initialize();
      }
      return _searchObjectTypes;
    }
    private static void Initialize()
    {
      // Initializes the array containing the order of class IDs
      //  (this could be a static initializer were it not for dot-net conversion issues)
      _searchObjectTypes = new int[SearchObjectTypes.CLASSIDCOUNT];
      // Six portal object types selectable by everyone go first
      _searchObjectTypes[0] = SearchObjectTypes.CLASSID_00;
      _searchObjectTypes[1] = SearchObjectTypes.CLASSID_01;
      _searchObjectTypes[2] = SearchObjectTypes.CLASSID_02;
      _searchObjectTypes[3] = SearchObjectTypes.CLASSID_25;
      _searchObjectTypes[4] = SearchObjectTypes.CLASSID_03;
      _searchObjectTypes[5] = SearchObjectTypes.CLASSID_04;
      // Next, collab and content
      _searchObjectTypes[6] = SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE;
      _searchObjectTypes[7] = SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE;
      //
      // NOTE: If updating the non-admin types, also update the ENDUSERCOUNT variable
      //
      // Now admin types, which aren't displayed for non-admins
      _searchObjectTypes[8] = SearchObjectTypes.CLASSID_05;
      _searchObjectTypes[9] = SearchObjectTypes.CLASSID_06;
      _searchObjectTypes[10] = SearchObjectTypes.CLASSID_07;
      _searchObjectTypes[11] = SearchObjectTypes.CLASSID_08;
      _searchObjectTypes[12] = SearchObjectTypes.CLASSID_09;
      _searchObjectTypes[13] = SearchObjectTypes.CLASSID_10;
      _searchObjectTypes[14] = SearchObjectTypes.CLASSID_11;
      _searchObjectTypes[15] = SearchObjectTypes.CLASSID_12;
      _searchObjectTypes[16] = SearchObjectTypes.CLASSID_13;
      //'Groups' is not longer 'User Groups' so it goes here.
      _searchObjectTypes[17] = SearchObjectTypes.CLASSID_23;
      _searchObjectTypes[18] = SearchObjectTypes.CLASSID_14;
      _searchObjectTypes[19] = SearchObjectTypes.CLASSID_15;
      _searchObjectTypes[20] = SearchObjectTypes.CLASSID_16;
      _searchObjectTypes[21] = SearchObjectTypes.CLASSID_17;
      _searchObjectTypes[22] = SearchObjectTypes.CLASSID_19;
      _searchObjectTypes[23] = SearchObjectTypes.CLASSID_22;
      _searchObjectTypes[24] = SearchObjectTypes.CLASSID_20;
      _searchObjectTypes[25] = SearchObjectTypes.CLASSID_18;
      _searchObjectTypes[26] = SearchObjectTypes.CLASSID_21;
      _searchObjectTypes[27] = SearchObjectTypes.CLASSID_26;
      _searchObjectTypes[28] = SearchObjectTypes.CLASSID_24;
      // Finally, abstract types and application constraints
      // selectable on the alternate view
      _searchObjectTypes[29] = SearchObjectTypes.DOCUMENT_ABSTRACTTYPE;
      _searchObjectTypes[30] = SearchObjectTypes.FOLDER_ABSTRACTTYPE;
      _searchObjectTypes[31] = SearchObjectTypes.OTHER_ABSTRACTTYPE;
      _searchObjectTypes[32] = SearchObjectTypes.PORTAL_APPLICATION;
      _searchObjectTypes[33] = SearchObjectTypes.COLLAB_APPLICATION;
      _searchObjectTypes[34] = SearchObjectTypes.CONTENT_APPLICATION;
    }
  }
}