using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.filter;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.pathways.tagging;
using com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;
using com.plumtree.portaluiinfrastructure.search.exceptions;
using com.plumtree.portaluiinfrastructure.search.pathways;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.impl.core;
using com.plumtree.server.portalpagesperf;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using AccessStyles=com.plumtree.uiinfrastructure.constants.AccessStyles;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public class SearchResultModel : ISearchResultModelRO,ISearchResultModel,
  ITaggingModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.search.SearchResultModel");
    private static OpenLogger pathwayslog = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PATHWAYS),
     "com.plumtree.portaluiinfrastructure.search.SearchResultModel");
    
    /// <summary>
    /// Name of this class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SearchResult";
    public const String MODEL_MODE_INPUT = "in_hi_model_mode";
    
    /// <summary>
    /// String that getResultApp() returns for portal items 
    /// </summary>
    public const String PORTAL_APP = "PTPORTAL";
    
    /// <summary>
    /// String that getResultApp() returns for community templating items
    /// (whose subtypes are the same as those for portal items, but do not
    /// correspond to "real" portal objects) 
    /// </summary>
    public const String TEMPLATING_APP = "PTCONTENTTEMPLATE";
    
    /// <summary>
    /// String that getResultApp() returns for Collab items 
    /// </summary>
    public const String COLLAB_APP = "PTCOLLAB";
    
    /// <summary>
    /// String that getResultApp() returns for Content items 
    /// </summary>
    public const String CONTENT_APP = "PTCONTENT";
    
    /// <summary>
    /// String that getResultAbsType() returns for documents 
    /// </summary>
    public const String DOCUMENT_ABSTYPE = "DOCUMENT";
    
    /// <summary>
    /// String that getResultAbsType() returns for containers 
    /// </summary>
    public const String CONTAINER_ABSTYPE = "CONTAINER";
    
    /// <summary>
    /// String that getResultAbsType() returns for any other item 
    /// </summary>
    public const String OTHER_ABSTYPE = "OTHER";
    /* control object for friendly URLs */
    public const String FRIENDLY_CONTROL = "control";
    /* control object for non-friendly URLs */
    public const String UNFRIENDLY_CONTROL = "in_hi_control";
    /* control name for banner search */
    public const String BANNER_SEARCH_CONTROL = "bannerstart";
    /* control name for advanced search */
    public const String ADVANCED_SEARCH_CONTROL = "advancedstart";
    /* control name for admin object search */
    public const String ADMIN_OBJECT_SEARCH_CONTROL = "searchstart";
    
    /// <summary>
    /// Supported sort orders.  Note that any numeric or date property
    /// should work, but it's convenient to provide these simple definitions.
    /// </summary>
    public const String SORTORDER_RELEVANCE = "0";
    // == PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED
    public const String SORTORDER_CREATED_ASC = "3";
    public const String SORTORDER_CREATED_DESC = "-3";
    // == PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED
    public const String SORTORDER_MODIFIED_ASC = "4";
    public const String SORTORDER_MODIFIED_DESC = "-4";
    // == PT_INTRINSICS.PT_PROPERTY_OBJECTNAME
    public const String SORTORDER_NAME_ASC = "1";
    public const String SORTORDER_NAME_DESC = "-1";
    
    /// <summary>
    /// Built-in group-by string identifiers.
    /// </summary>
    public const String GROUPBY_FOLDER = "ancestors";
    public const String GROUPBY_OBJECTTYPE = "subtype";
    private const String CACHE_KEY_SEPARATOR_STR = "/";
    private const char CACHE_KEY_SEPARATOR_CHAR = '/';
    public const String GROUP_BY_PREFS_KEY = "GroupBySearchPrefs";
    
    /// <summary>
    /// Date time string format when parsing the date string that comes back from
    /// Pathways REST API.
    /// </summary>
    private const String EOD_DATE_FORMAT_PATTERN = "yyyy-MM-dd\'T\'HH:mm:ss";
    
    /// <summary>
    /// Name of folder returned when db lookup of name fails- must
    /// be localized before displaying. NOTE: this must be kept in 
    /// sync with what is returned by PTSearch.dll
    /// </summary>
    public const String UNKNOWN_FOLDER_NAME = "Unknown Folder";
    
    /// <summary>
    /// User's original search filter
    /// </summary>
    protected IPTFilter m_advancedFilter = null;
    
    /// <summary>
    /// User's original search string
    /// </summary>
    protected String m_initialSearchString = null;
    
    /// <summary>
    /// Whether best bets were initially requested
    /// </summary>
    protected bool m_initialBestBets = false;
    
    /// <summary>
    /// Field that was used for group-by on the original search.  This field
    /// will also be the default for group-by on any later drilldown, or
    /// after the user uses a breadcrumb control to undo the drilldown.
    /// </summary>
    protected String m_initialGroupBy = null;
    
    /// <summary>
    /// Name this search has been saved under
    /// </summary>
    protected String m_savedSearchName = null;
    
    /// <summary>
    /// Fields that search-within-results queries will run against
    /// </summary>
    protected String m_swrFields = null;
    
    /// <summary>
    /// Whether the original search used a filter (i.e. advanced search)
    /// </summary>
    protected bool m_isAdvancedSearch = false;
    
    /// <summary>
    /// The current "mode" that the client page is in.  This class doesn't care about
    /// the contents; this is just a convenient holder for client code.  See get/set
    /// methods below.
    /// </summary>
    protected String m_pageMode = null;
    
    /// <summary>
    /// User's desired number of results per page
    /// </summary>
    protected int m_pageSize = 20;
    
    /// <summary>
    /// default pagesize to check for
    /// </summary>
    protected const int DEFAULT_PAGE_SIZE = 10;
    
    /// <summary>
    /// Integer that client views can use to get/set error conditions for
    /// saved search (or they can use the getError() mechanism, but
    /// this affects *all* views, not just the saved search view).
    /// </summary>
    protected int m_savedSearchErrorCode = 0;
    /*
     *  Number of search-within-results done so far
     */
     
    protected int m_swrCount = 0;
    /*
     * if adaptive layout mode is on/supported
     */
     
    protected bool m_isAdaptiveLayoutMode = true;
    /*
     * if pathways search is enabled
     */
     
    protected bool m_isPathwaysEnabled = false;
    /*
     * if this is a pathways search
     */
     
    protected bool m_isPathwaysSearch = false;
    /*
     * boolean is to check if there is an error with Pathways
     */
     
    protected bool m_isPathwaysInError = false;
    /*
     * if there was a pathways search within results
     */
     
    protected bool m_isPathwaysSearchWithinResults = false;
    /*
     * if there is a filter by type search
     */
     
    protected bool m_isPathwaysFilterByType = false;
    /*
     * if there is a sort by results that pathways executed
     */
     
    protected bool m_isPathwaysSortBy = false;
    /*
     * pathways rest api service
     */
     
    internal IPathwaysRestAPIService m_pathwaysRESTAPIService;
    /*
     * Pathways helper service
     */
     
    protected IPathwaysHelper m_pathwaysHelperService;
    /*
     * banner search helper to get banner search preferences and search constraints
     */
     
    protected IBannerSearchHelper m_bannerSearchHelper;
    /*
     * pathways Collab Helper Service
     */
     
    protected ICollaborationHelper m_pathwaysCollabHelper;
    /*
     * pathways tagcloud
     */
     
    protected XPHashtable m_pathwaysTagCloud = null;
    /*
     * pathways hashtable to store query arguments for retrieval later in the PathwaysSearch Response
     */
     
    protected XPHashtable m_pathwaysQueryArgs = null;
    /*
     * pathways format
     */
     
    protected String m_pathwaysFormat = "XML";
    /*
     * pathways startAt value
     */
     
    protected int m_pathwaysStartAt = 1;
    /*
     * pathways view id
     */
     
    protected String m_pathwaysViewId = "ev";
    /*
     * pathways order
     */
     
    protected String m_pathwaysOrder = "DES";
    /*
     * pathways orderBy
     */
     
    protected String m_pathwaysOrderBy = "RANK";
    /*
     * pathways totalCount via search
     */
     
    protected int m_pathwaysTotalCount = 0;
    /*
     * pathways ObjectTypes via search
     */
     
    protected XPArrayList m_pathwaysObjectTypes = null;
    /*
     * Pathways Query Arguments
     * making public for unit test usability
     */
     
    public PathwaysQueryArguments m_pathwaysQueryArgument = null;
    //form data
    internal XPHashtable formData = null;
    //
    //  Private data
    //
    
    /// <summary>
    /// Owning ActivitySpace
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// COM-side search request object we are using
    /// </summary>
    private IPTSearchRequest m_request = null;
    
    /// <summary>
    /// COM-side response we are currently displaying
    /// </summary>
    private IPTSearchResponse m_currentResponse = null;
    //for unit test purposes
    public IPTSearchResponse m_unitTestSearchResponse = null;
    
    /// <summary>
    /// Owning session
    /// </summary>
    private IPTSession m_session;
    
    /// <summary>
    /// Error on last search attempt
    /// </summary>
    private SearchExecutionError m_error = null;
    
    /// <summary>
    /// Warning on last search attempt
    /// </summary>
    private SearchExecutionWarning m_warning = null;
    
    /// <summary>
    /// Search settings that could be removed on a followup search
    /// </summary>
    private SearchSettingCollection m_removableSettings = null;
    
    /// <summary>
    /// Key of current response being displayed
    /// </summary>
    private String m_currentKey = null;
    
    /// <summary>
    /// Previous queries we have run, corresponding breadcrumbs,
    /// and the resulting responses.
    /// m_crumbCache is a map from String key to String
    /// </summary>
    private XPHashtable m_crumbCache = null;
    
    /// <summary>
    /// Previous queries we have run, corresponding breadcrumbs,
    /// and the resulting responses.
    /// _queryCache is a map from String key to IPTSearchQuery
    /// _crumbCache is a map from String key to String
    /// _responseCache is a map from String key to IPTSearchResponse
    /// </summary>
    private XPHashtable m_queryCache = null;
    
    /// <summary>
    /// Previous queries we have run, corresponding breadcrumbs,
    /// and the resulting responses.
    /// m_responseCache is a map from String key to IPTSearchResponse
    /// </summary>
    private XPHashtable m_responseCache = null;
    
    /// <summary>
    /// Whether this model instance has been initialized by calling
    /// Search(); if false, search results aren't available yet
    /// </summary>
    private bool m_initialized = false;
    private XPException m_taggingError;
    
    /// <summary>
    /// Whether the initialization checking of the search request should be ignored
    /// </summary>
    private bool m_disableInitChecking = false;
    
    /// <summary>
    /// isPathwaysSearch checks if the current search request is a pathways search
    /// </summary>
    public virtual bool IsPathwaysSearch()
    {
      return m_isPathwaysSearch;
    }
    
    /// <returns>boolean to state if Pathways is in error</returns>
    public virtual bool IsPathwaysInError()
    {
      return m_isPathwaysInError;
    }
    
    /// <summary>
    /// This function checks to make sure that request is valid for a pathways search or not
    /// </summary>
    /// <param name="settings">SearchSettingcollection</param>
    /// <param name="currentControl"></param>
    /// <param name="advancedFilter"></param>
    /// <returns></returns>
    private bool isValidPathwaysSearch(SearchSettingCollection settings, String currentControl,
     IPTFilter advancedFilter)
    //Since we have modified the advanced search layout to only provide pathways supported arguments for advanced search,
    // this function checks if there is a language restriction set or if NO subfolders are set to be searched for a pathways
    // enabled advanced search.  These two settings are not supported by Pathways.
    {
      //if this is banner search, then we return true, as we don't need to verify if this is valid pathways search
      if (BANNER_SEARCH_CONTROL.Equals(currentControl))
      {
        return true;
      }
      //means that this is advanced search and we need to check for a few things that may make this legacy search
      Object languageRestriction = settings.GetSettingValue(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE);
      if ((null != languageRestriction) && 
      //we are adding this check for false here to allow the unit test to run a pathways advanced search, through
      //the portal, the limit by locale setting is never set if it's not set in the editor, it's actually null.  The 
      //CardLanguagePlugInModel just sets a default language, but never actually sets this setting.  In the unit test
      //this setting is set to false.  
      (XPConvert.ToBoolean(languageRestriction) != false))
      {
        //someone chose to restrict by language, pathways currently doesn't support, need to use legacy
        return false;
      }
      //setting this to an object b/c if you check and there are no admin/doc folders being restricted
      //null is returned if folder filter is enabled, there can be admin or kd folders selected, and include subfolder is selected
      //false is returned if the filter the search doesn't include subfolders
      Object containsSubFolders = settings.GetSettingValue(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS);
      if ((null != containsSubFolders) && (XPConvert.ToBoolean(containsSubFolders) != false))
      {
        return false;
      }
      //we are setting the fall back search mode here each time b/c we have not defaulted to a legacy search for
      //advanced search.  This is to help the layout display the search results correctly when this does occur.
      m_pathwaysHelperService.SetLegacySearchMode(false);
      //did all the checking, nothing to invalidate this as a pathways request
      return true;
    }
    
    /// <summary>
    /// Sets the pathways OrderBy and Order based on the sort that the customer chose in search results page
    /// </summary>
    /// <param name="value">sort order for search results</param>
    private void SetPathwaysNewSortOrder(String value)
    {
      //there was no sort order, so just set back the defaults
      if (null == value)
      {
        m_pathwaysOrderBy = PathwaysConstants.RANK_ARG;
        m_pathwaysOrder = PathwaysConstants.DES_ARG;
      } else
      if (value.Equals(SORTORDER_RELEVANCE))
      {
        m_pathwaysOrderBy = PathwaysConstants.RANK_ARG;
        //need to set the default Order back, just in case it was set by another sort
        m_pathwaysOrder = PathwaysConstants.DES_ARG;
      } else
      if (value.Equals(SORTORDER_MODIFIED_ASC))
      {
        m_pathwaysOrderBy = PathwaysConstants.LAST_MODIFIED_DATE_ARG;
        m_pathwaysOrder = PathwaysConstants.ASC_ARG;
      } else
      if (value.Equals(SORTORDER_MODIFIED_DESC))
      {
        m_pathwaysOrderBy = PathwaysConstants.LAST_MODIFIED_DATE_ARG;
        m_pathwaysOrder = PathwaysConstants.ASC_ARG;
      } else
      if (value.Equals(SORTORDER_NAME_ASC))
      {
        m_pathwaysOrderBy = PathwaysConstants.NAME_ARG;
        m_pathwaysOrder = PathwaysConstants.ASC_ARG;
      } else
      if (value.Equals(SORTORDER_NAME_DESC))
      {
        m_pathwaysOrderBy = PathwaysConstants.NAME_ARG;
        m_pathwaysOrder = PathwaysConstants.DES_ARG;
      } else
      {
      }
      //do nothing
      m_pathwaysQueryArgument.SetOrder(m_pathwaysOrder);
      m_pathwaysQueryArgument.SetOrderBy(m_pathwaysOrderBy);
    }
    
    /// <summary>
    /// Sets the pathways search constraints for banner search
    /// </summary>
    /// <param name="AActivityspace">for current search</param>
    private void SetPathwaysSearchConstraints(AActivitySpace aSpace)
    {
      m_pathwaysObjectTypes = m_bannerSearchHelper.GetSearchConstraints(aSpace);
      m_pathwaysQueryArgument.SetObjectTypes(m_pathwaysObjectTypes);
    }
    
    /// <summary>
    /// Sets the pathways constraints from the advanced search
    /// </summary>
    /// <param name="advPathwaysObjectTypes">takes in</param>
    private void SetAdvancedPathwaysSearchConstraints(int[] advPathwaysObjectTypes)
    {
      //we will need to check here to see if the collab and publisher need to be added to the advanced search
      //constraints as advPathwaysObjectTypes only contains portal objects (just the way advanced search stores
      //the search elements), this is different than how banner search does it
      //need to convert the Object[] to XPArrayList
      XPArrayList advObjectTypes = new XPArrayList();
      int appValue = m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS);
      bool isPortal = false;
      //no checking of portal items as the advPathwaysObjectTypes already contains those
      switch (appValue){
      case PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB:
      advObjectTypes = m_bannerSearchHelper.setCollabItems(advObjectTypes);
      break;
      case PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT:
      advObjectTypes = m_bannerSearchHelper.setContentItems(advObjectTypes);
      break;
      case (PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB + PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT):
      advObjectTypes = m_bannerSearchHelper.setCollabItems(advObjectTypes);
      advObjectTypes = m_bannerSearchHelper.setContentItems(advObjectTypes);
      break;
      case (PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB + PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL):
      advObjectTypes = m_bannerSearchHelper.setCollabItems(advObjectTypes);
      isPortal = true;
      break;
      case (PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT + PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL):
      advObjectTypes = m_bannerSearchHelper.setContentItems(advObjectTypes);
      isPortal = true;
      break;
      case (PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT + PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL + PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB):
      advObjectTypes = m_bannerSearchHelper.setCollabItems(advObjectTypes);
      advObjectTypes = m_bannerSearchHelper.setContentItems(advObjectTypes);
      isPortal = true;
      break;
      default:
      isPortal = true;
      break;
      }
      //now we add the extra arguments if it was portal, the below code is doing the String conversion of the result
      //types for pathways REST API
      if (isPortal)
      {
        for (int i = 0;i < advPathwaysObjectTypes.Length;i++)
        {
          advObjectTypes.Add(m_bannerSearchHelper.GetPathwaysClassIdStringValue(XPConvert.ToInteger(advPathwaysObjectTypes[i])));
          }
      }
      m_pathwaysQueryArgument.SetObjectTypes(advObjectTypes);
    }
    
    /// <summary>
    /// Parses through the advancedFilter to get the property search contraints from an advanced search
    /// Example of such a setting in advanced search is:
    /// Author Contains "John Hill"
    /// City Contains No Value
    /// Return results based on "All Criteria" or "Any Criteria"
    /// </summary>
    /// <param name="advancedFilter"></param>
    private void SetAdvancedPathwaysSearchCriteria()
    {
      //this returns the size of the items in the filterclause
      int propConstraintSize = GetASNumPropertyConstraints();
      String propertyName = "";
      String constraintTerm = "";
      XPArrayList pathwaysSearchCriteria = new XPArrayList();
      //this value checks if we're suppose to AND all the property values, if false = OR
      bool topLevelSearchCriteriaOperatorAND = GetASTopLevelOperator();
      for (int i = 0;i < propConstraintSize;i++)
      {
        //we are getting the property name, operator, and property value which needs to
        //be converted properly into pathways strings
        //ie:  author:"John Hill" AND Keyword:doc will search for all John hill items as the author that also
        //has the keyword property of doc
        propertyName = GetASConstraintProperty(i);
        //BT: Bug 10153125 - For the property name, we need convert it into a single string 
        //and take out the spaces for multi-word properties
        //ie: "Reference Property" becomes "referenceproperty"
        propertyName = propertyName.Replace(" ", "");
        //also just to be consistent with what Pathways used to do, we lowercase the property name
        propertyName = XPStringUtility.ToLowerCase(propertyName);
        //NOTE:  we do not try and get the operator value associated to the property b/c for pathways it can
        //only be CONTAINS, as we've passed the CheckIfValidPathwaysRequest().  Will need to add more code when
        //more operator functionality will be added to Pathways.
        constraintTerm = propertyName + ":\"" + GetASConstraintValue(i) + "\"";
        pathwaysSearchCriteria.Add(constraintTerm);
      }
      //setting the property contraints and top operator
      m_pathwaysQueryArgument.SetAdvancedPropertyConstraints(pathwaysSearchCriteria,
       topLevelSearchCriteriaOperatorAND);
    }
    
    /// <summary>
    /// Set pathways search object types based on the filter type selected from the search results page
    /// </summary>
    /// <param name="boolean">value to set filters or not</param>
    private void SetPathwaysFilters(bool setFilters)
    {
      if (!setFilters)
      {
      } else
      //do nothing
      //filter type has been set, so set the query arguments 
      {
        Object[] objTypes = m_request.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES);
        //checking to see if portal filter item
        if (null != objTypes)
        {
          m_pathwaysObjectTypes.Clear();
          for (int i = 0;i < objTypes.Length;i++)
          {
            int filterId = XPConvert.ToInteger(objTypes[i]);
            String searchFilter = m_bannerSearchHelper.GetPathwaysClassIdStringValue(filterId);
            m_pathwaysObjectTypes.Add(searchFilter);
          }
        }
        //checking for collab or content items
        int searchSettingApps = m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS);
        XPArrayList additionalFilter = new XPArrayList();
        switch (searchSettingApps){
        case PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB:
        //XPArrayList collabFilter = new XPArrayList();
        m_pathwaysObjectTypes = m_bannerSearchHelper.setCollabItems(additionalFilter);
        break;
        case PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT:
        //XPArrayList contentFilter = new XPArrayList();
        m_pathwaysObjectTypes = m_bannerSearchHelper.setContentItems(additionalFilter);
        break;
        case PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL:
        //do nothing
        break;
        default:
        //the default is that it's not any of those apps, which means its all 3 of them.
        ///temporary list holds the collab and publisher items search constraints for pathways
        m_pathwaysObjectTypes = m_bannerSearchHelper.setCollabItems(m_pathwaysObjectTypes);
        m_pathwaysObjectTypes = m_bannerSearchHelper.setContentItems(m_pathwaysObjectTypes);
        break;
        }
      }
      /*
       * basic search doesn't set this value, but may be needed later on
       * int searchSettingAbsTypes = _request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES);
       */
       
      //setting filter
      m_pathwaysQueryArgument.SetObjectTypes(m_pathwaysObjectTypes);
    }
    /* RANK ENGINE HAS BEEN REMOVED FROM NEO RELEASE, WE DO NOT NEED THIS CALL
     * Gets pathways ResultScore
     * @param rank of pathways item
     *
     public double GetPathwaysResultScore(int rank)
     {
     return m_currentResponse.GetFieldsAsDouble(rank, PT_INTRINSICS.PT_PROPERTY_SEARCHSCORE);
     }
     */
     
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.IsASTooComplexToSummarize()"></seealso>
    public virtual bool IsASTooComplexToSummarize()
    {
      checkInitialized();
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      IPTPropertyFilterItem fi = m_advancedFilter.GetPropertyFilter();
      if (null == fi)
      {
        return false;
      }
      if (PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT == fi.GetType())
      {
        return false;
      }
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) fi;
      for (int j = 0;j < clause.GetCount();j++)
      {
        fi = clause.GetItem(j);
        if (PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES == fi.GetType())
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// returns the int operator value of the clause
    /// </summary>
    /// <param name="condition"></param>
    /// <returns>int operator value</returns>
    public virtual int GetIntASConstraintOperator(int condition)
    {
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) m_advancedFilter.GetPropertyFilter();
      IPTPropertyFilterStatement stmt = (IPTPropertyFilterStatement) clause.GetItem(condition);
      return stmt.GetOperator();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.getASConstraintOperator()"></seealso>
    public virtual String GetASConstraintOperator(int condition)
    {
      checkInitialized();
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) m_advancedFilter.GetPropertyFilter();
      IPTPropertyFilterStatement stmt = (IPTPropertyFilterStatement) clause.GetItem(condition);
      bool isDateTime = IsDateTimeProperty(stmt.GetOperand());
      int opID = stmt.GetOperator();
      switch (opID){
      case PT_FILTEROPS.PT_FILTEROP_CONTAINS:
      return m_asOwner.GetString(324, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_DOESNOTCONTAIN;
      case PT_FILTEROPS.PT_FILTEROP_DOESNOTCONTAIN:
      return m_asOwner.GetString(325, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_EQ;
      case PT_FILTEROPS.PT_FILTEROP_EQ:
      case PT_FILTEROPS.PT_FILTEROP_EQ_NOCASE:
      case PT_FILTEROPS.PT_FILTEROP_NUMERIC_EQ:
      return m_asOwner.GetString(326, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_NE;
      case PT_FILTEROPS.PT_FILTEROP_NE:
      case PT_FILTEROPS.PT_FILTEROP_NUMERIC_NOTEQ:
      return m_asOwner.GetString(327, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_LT;
      case PT_FILTEROPS.PT_FILTEROP_LT:
      if (isDateTime)
      {
        // Comes Before
        return m_asOwner.GetString(36, "ptmsgs_portalinfrastructure");
      } else
      {
        return m_asOwner.GetString(328, "ptmsgs_portalinfrastructure");
      }
      goto case PT_FILTEROPS.PT_FILTEROP_GT;
      case PT_FILTEROPS.PT_FILTEROP_GT:
      if (isDateTime)
      {
        // Comes After
        return m_asOwner.GetString(35, "ptmsgs_portalinfrastructure");
      } else
      {
        return m_asOwner.GetString(330, "ptmsgs_portalinfrastructure");
      }
      goto case PT_FILTEROPS.PT_FILTEROP_LTE;
      case PT_FILTEROPS.PT_FILTEROP_LTE:
      if (isDateTime)
      {
        // Comes Before
        return m_asOwner.GetString(36, "ptmsgs_portalinfrastructure");
      } else
      {
        return m_asOwner.GetString(329, "ptmsgs_portalinfrastructure");
      }
      goto case PT_FILTEROPS.PT_FILTEROP_GTE;
      case PT_FILTEROPS.PT_FILTEROP_GTE:
      if (isDateTime)
      {
        // Comes After
        return m_asOwner.GetString(35, "ptmsgs_portalinfrastructure");
      } else
      {
        return m_asOwner.GetString(331, "ptmsgs_portalinfrastructure");
      }
      goto case PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE;
      case PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE:
      // "in the last.."
      {
        long relativeTime = XPConvert.ToLong(stmt.GetValueAsString());
        const int MS_PER_DAY = 86400000;
        int MS_PER_WEEK = MS_PER_DAY * 7;
        if (relativeTime < 0)
        {
          relativeTime = -1 * relativeTime;
        }
        if (0 == (relativeTime % MS_PER_WEEK))
        {
          return XPResourceManager.FormatMessage(m_asOwner.GetString(531,
           "ptmsgs_portalinfrastructure"), XPConvert.ToString(relativeTime / MS_PER_WEEK));
          } else
        if (0 == (relativeTime % MS_PER_DAY))
        {
          return XPResourceManager.FormatMessage(m_asOwner.GetString(530,
           "ptmsgs_portalinfrastructure"), XPConvert.ToString(relativeTime / MS_PER_DAY));
          } else
        {
          return XPResourceManager.FormatMessage(m_asOwner.GetString(532,
           "ptmsgs_portalinfrastructure"), XPConvert.ToString(relativeTime));
          }
        goto case PT_FILTEROPS.PT_FILTEROP_ISEMPTY;
      }
      case PT_FILTEROPS.PT_FILTEROP_ISEMPTY:
      return m_asOwner.GetString(332, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_ISNOTEMPTY;
      case PT_FILTEROPS.PT_FILTEROP_ISNOTEMPTY:
      return m_asOwner.GetString(333, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_REGEXPMATCH;
      case PT_FILTEROPS.PT_FILTEROP_REGEXPMATCH:
      return m_asOwner.GetString(335, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_REGEXPNOTMATCH;
      case PT_FILTEROPS.PT_FILTEROP_REGEXPNOTMATCH:
      return m_asOwner.GetString(336, "ptmsgs_portalinfrastructure");
      goto case PT_FILTEROPS.PT_FILTEROP_IN;
      case PT_FILTEROPS.PT_FILTEROP_IN:
      return m_asOwner.GetString(334, "ptmsgs_portalinfrastructure");
      break;
      }
      return m_asOwner.GetString(341, "ptmsgs_portalinfrastructure");
    }
    private bool IsDateTimeProperty(int propID)
    {
      // Is this cached somewhere?
      IPTQueryResult ptQR = m_session.GetProperties().QuerySingleObject(propID);
      if (null != ptQR && ptQR.RowCount() > 0)
      {
        return (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == ptQR.ItemAsInt(0, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
        }
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.getASConstraintPropertyID()"></seealso>
    public virtual String GetASConstraintProperty(int condition)
    {
      checkInitialized();
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) m_advancedFilter.GetPropertyFilter();
      IPTPropertyFilterStatement stmt = (IPTPropertyFilterStatement) clause.GetItem(condition);
      int propID = stmt.GetOperand();
      try
      {
        IPTQueryResult ptQR = m_session.GetProperties().QuerySingleObject(propID);
        if (null != ptQR && ptQR.RowCount() > 0)
        {
          String result = ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
          if (null != result)
          {
            return result;
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Error in GetASConstraintProperty()");
      }
      return m_asOwner.GetString(340, "ptmsgs_portalinfrastructure");
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.getASConstraintValue()"></seealso>
    public virtual String GetASConstraintValue(int condition)
    {
      checkInitialized();
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) m_advancedFilter.GetPropertyFilter();
      IPTPropertyFilterStatement stmt = (IPTPropertyFilterStatement) clause.GetItem(condition);
      if (PT_FILTEROPS.PT_FILTEROP_ISEMPTY == stmt.GetOperator())
      {
        // "property Foo contains no value"
        return "";
      }
      if (PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE == stmt.GetOperator())
      {
        // "in the last X", handled above in GetASConstraintOperator
        return "";
      }
      // If it's a date/time
      if (IsDateTimeProperty(stmt.GetOperand()))
      {
        // Have to initialize this to something non-null for jumpability.
        XPDateTime dtConstraint = new XPDateTime();
        bool gotDate = false;
        try
        {
          dtConstraint = stmt.GetValueAsXPDateTime();
          gotDate = true;
        }
        catch (Exception e)
        {
          gotDate = false;
        }
        if (gotDate)
        {
          // Format the date nicely
          XPDateFormat fmt = GetDateFormat(m_asOwner);
          return fmt.Format(dtConstraint);
        }
      }
      // Otherwise, treat as String
      return stmt.GetValueAsString();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.getASNumPropertyConstraints()"></seealso>
    public virtual int GetASNumPropertyConstraints()
    {
      checkInitialized();
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      IPTPropertyFilterItem pfi = m_advancedFilter.GetPropertyFilter();
      if (null == pfi)
      {
        return 0;
      }
      return ((IPTPropertyFilterClauses) pfi).GetCount();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.getASOverallPropertyOperator()"></seealso>
    public virtual bool GetASPropertyClauseOperator()
    {
      checkInitialized();
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) m_advancedFilter.GetPropertyFilter();
      return (clause.GetOperator() == PT_BOOLOPS.PT_BOOLOP_AND);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.getASTopLevelOperator()"></seealso>
    public virtual bool GetASTopLevelOperator()
    {
      checkInitialized();
      if (!m_isAdvancedSearch)
      {
        throw new NotAdvancedSearchException();
      }
      return (m_advancedFilter.GetOperator() == PT_BOOLOPS.PT_BOOLOP_AND);
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getAbstractTypeRestrictions()"></seealso>
    public virtual int GetAbstractTypeRestrictions()
    {
      checkInitialized();
      return (m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getAdminFolderRestrictions()"></seealso>
    public virtual int[] GetAdminFolderRestrictions()
    {
      checkInitialized();
      return objectArrayToIntArray(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchQueryRO.isAdvancedSearch()"></seealso>
    public virtual bool isAdvancedSearch()
    {
      checkInitialized();
      return m_isAdvancedSearch;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getApplicationRestrictions()"></seealso>
    public virtual int GetApplicationRestrictions()
    {
      checkInitialized();
      return (m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getBreadcrumbKey()"></seealso>
    public virtual String GetBreadcrumbKey(int step)
    {
      checkInitialized();
      String key = ancestorKey(m_currentKey, step - 1);
      // If the default grouping is, say, "ancestors", then the breadcrumb should
      // lead the user back to a search that's grouped that way
      if (null != m_initialGroupBy)
      {
        key+=m_initialGroupBy;
      }
      return key;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getBreadcrumbLabel()"></seealso>
    public virtual String GetBreadcrumbLabel(int step)
    {
      checkInitialized();
      return (String) m_crumbCache.GetElement(ancestorKey(m_currentKey, step - 1));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getCommunityNameForID()"></seealso>
    public virtual String GetCommunityNameForID(int id)
    {
      try
      {
        IPTQueryResult ptQR = m_session.GetCommunities().QuerySingleObject(id);
        if (null != ptQR && ptQR.RowCount() > 0)
        {
          String result = ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
          if (null != result)
          {
            return result;
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Error in GetCommunityNameForID()");
      }
      return m_asOwner.GetString(338, "ptmsgs_portalinfrastructure");
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.GetPortletNameForID()"></seealso>
    public virtual String GetPortletNameForID(int id)
    {
      try
      {
        IPTQueryResult ptQR = m_session.GetGadgets().QuerySingleObject(id);
        if (null != ptQR && ptQR.RowCount() > 0)
        {
          String result = ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
          if (null != result)
          {
            return result;
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Error in GetPortletNameForID()");
      }
      return m_asOwner.GetString(451, "ptmsgs_portalinfrastructure");
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getCommunityRestrictions()"></seealso>
    public virtual int[] GetCommunityRestrictions()
    {
      checkInitialized();
      return objectArrayToIntArray(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getPortletRestrictions()"></seealso>
    public virtual int[] GetPortletRestrictions()
    {
      checkInitialized();
      return objectArrayToIntArray(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getCollabProjectRestrictions()"></seealso>
    public virtual int[] GetCollabProjectRestrictions()
    {
      checkInitialized();
      return objectArrayToIntArray(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID));
      }
    
    /// <summary>
    /// Return the stylesheet for the community; used when processing the style
    /// sheet.
    /// </summary>
    public virtual String GetStyleSheet(int nCommunityID)
    {
      try
      {
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        IPTCommunityManager ptOM = (IPTCommunityManager) ptSession.GetCommunities();
        IPTCommunityInfo objCommunityInfo = ptOM.CachedOpenCommunityInfo(nCommunityID,
         false);
        return (objCommunityInfo).GetStyleSheet();
      }
      catch (Exception e)
      {
        log.Error(e, "Error in GetStyleSheet()");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(1522, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1523,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return "";
    }
    
    /// <summary>
    /// Return the headerID for the community; used when processing the style
    /// sheet.
    /// </summary>
    public virtual int GetHeaderID(int nCommunityID)
    {
      try
      {
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        IPTCommunityManager ptOM = (IPTCommunityManager) ptSession.GetCommunities();
        IPTCommunityInfo objCommunityInfo = ptOM.CachedOpenCommunityInfo(nCommunityID,
         false);
        return (objCommunityInfo).GetHeaderID();
      }
      catch (Exception e)
      {
        log.Error(e, "Error in GetHeaderID()");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(1520, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1521,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getCorrectionFrequency()"></seealso>
    public virtual int GetCorrectionFrequency(int misspellingIndex, int correctionIndex)
    {
      checkInitialized();
      return m_currentResponse.GetCorrectionFrequency(misspellingIndex, correctionIndex);
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getCurrentKey()"></seealso>
    public virtual String GetCurrentKey()
    {
      return m_currentKey;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.hasDrilledDownIntoSingleCategory()"></seealso>
    public virtual bool hasDrilledDownIntoSingleCategory(String orgType)
    {
      checkInitialized();
      int orgIdx = XPStringUtility.IndexOf(m_currentKey, CACHE_KEY_SEPARATOR_STR + orgType);
      // No reorg by this type
      if (-1 == orgIdx)
      {
        return false;
      }
      int lastSlash = XPStringUtility.LastIndexOf(m_currentKey, CACHE_KEY_SEPARATOR_STR);
      // We've drilled down if there's anything after "/subtype", for example
      return (lastSlash != orgIdx);
    }
    
    /// <summary>
    /// Helper method that returns true if the first drilldown step was into 
    /// the "collab server" object-type category
    /// </summary>
    private bool firstDrilldownIsIntoCollabCategory(String theKey)
    {
      if (null == theKey)
      {
        return false;
      }
      // theKey is something like "/subtype.5/..." or "/ancestors.2/..."
      // we want to return true if it starts with "/subtype.", and the number afterwards
      // (the 5 in this case) corresponds to the "PTCOLLAB" category..
      // this String is "/subtype."
      String neededPrefix = CACHE_KEY_SEPARATOR_STR + GROUPBY_OBJECTTYPE + ".";
      // if it starts with something else, return false
      if (!XPStringUtility.StartsWith(theKey, neededPrefix))
      {
        return false;
      }
      // extract the group number that was selected
      String groupNum = XPStringUtility.Substring(theKey, neededPrefix.Length);
      // groupNum is now something like "5/ancestors.2/...", or just "5/"
      // look for the "/" and cut it off, along with anything after it
      int endIdx = XPStringUtility.IndexOf(groupNum, CACHE_KEY_SEPARATOR_CHAR);
      if (-1 != endIdx)
      {
        groupNum = XPStringUtility.Substring(groupNum, 0, endIdx);
      }
      // now try to extract a group number
      int groupId = 0;
      try
      {
        groupId = XPConvert.ToInteger(groupNum);
      }
      catch (Exception e)
      {
        // if anything goes wrong..
        return false;
      }
      // groupId now contains the group number.. so extract the original search
      // response from cache
      IPTSearchResponse firstResponse = (IPTSearchResponse) m_responseCache.GetElement(CACHE_KEY_SEPARATOR_STR + GROUPBY_OBJECTTYPE);
      // make sure it wasn't the "all others" group
      if ((groupId >= firstResponse.GetNumGroups()) || (groupId < 0))
      {
        return false;
      }
      // get the label for the desired group
      String groupLabel = firstResponse.GetGroupLabel(groupId);
      // finally!  if the label was "PTCOLLAB", it's what we want
      return ((null != groupLabel) && (groupLabel.Equals("PTCOLLAB")));
    }
    
    /// <param name="m_asOwner"></param>
    /// <param name="classId"></param>
    /// <returns></returns>
    public static String getDisplayableNameForType(AActivitySpace m_asOwner,
     int classId)
    {
      switch (classId){
      case PT_CLASSIDS.PT_USER_ID:
      return m_asOwner.GetString(298, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_USERGROUP_ID;
      case PT_CLASSIDS.PT_USERGROUP_ID:
      return m_asOwner.GetString(299, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_AUTHSOURCE_ID;
      case PT_CLASSIDS.PT_AUTHSOURCE_ID:
      return m_asOwner.GetString(300, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_PROFILESOURCE_ID;
      case PT_CLASSIDS.PT_PROFILESOURCE_ID:
      return m_asOwner.GetString(301, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_CATALOGFOLDER_ID;
      case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
      return m_asOwner.GetString(297, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_CATALOGCARD_ID;
      case PT_CLASSIDS.PT_CATALOGCARD_ID:
      return m_asOwner.GetString(296, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
      case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
      return m_asOwner.GetString(302, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_FILTER_ID;
      case PT_CLASSIDS.PT_FILTER_ID:
      return m_asOwner.GetString(303, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_SAVEDSEARCH_ID;
      case PT_CLASSIDS.PT_SAVEDSEARCH_ID:
      return m_asOwner.GetString(304, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_DATASOURCE_ID;
      case PT_CLASSIDS.PT_DATASOURCE_ID:
      return m_asOwner.GetString(305, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_PROPERTY_ID;
      case PT_CLASSIDS.PT_PROPERTY_ID:
      return m_asOwner.GetString(306, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_DOCUMENTTYPE_ID;
      case PT_CLASSIDS.PT_DOCUMENTTYPE_ID:
      return m_asOwner.GetString(307, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_CRAWLER_ID;
      case PT_CLASSIDS.PT_CRAWLER_ID:
      return m_asOwner.GetString(308, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_GADGET_ID;
      case PT_CLASSIDS.PT_GADGET_ID:
      return m_asOwner.GetString(309, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_INVITATION_ID;
      case PT_CLASSIDS.PT_INVITATION_ID:
      return m_asOwner.GetString(310, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_FEDERATEDPORTAL_ID;
      case PT_CLASSIDS.PT_FEDERATEDPORTAL_ID:
      return m_asOwner.GetString(470, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID;
      case PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID:
      return m_asOwner.GetString(312, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID;
      case PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID:
      return m_asOwner.GetString(313, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_GADGETBUNDLE_ID;
      case PT_CLASSIDS.PT_GADGETBUNDLE_ID:
      return m_asOwner.GetString(314, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_PAGETEMPLATE_ID;
      case PT_CLASSIDS.PT_PAGETEMPLATE_ID:
      return m_asOwner.GetString(315, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_WEBSERVICE_ID;
      case PT_CLASSIDS.PT_WEBSERVICE_ID:
      return m_asOwner.GetString(316, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_EXTOPERATION_ID;
      case PT_CLASSIDS.PT_EXTOPERATION_ID:
      return m_asOwner.GetString(317, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_GADGETTEMPLATE_ID;
      case PT_CLASSIDS.PT_GADGETTEMPLATE_ID:
      return m_asOwner.GetString(318, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_JOB_ID;
      case PT_CLASSIDS.PT_JOB_ID:
      return m_asOwner.GetString(319, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_COMMUNITY_ID;
      case PT_CLASSIDS.PT_COMMUNITY_ID:
      return m_asOwner.GetString(320, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_SITEMAPFOLDER_ID;
      case PT_CLASSIDS.PT_SITEMAPFOLDER_ID:
      return m_asOwner.GetString(321, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_PAGE_ID;
      case PT_CLASSIDS.PT_PAGE_ID:
      return m_asOwner.GetString(505, "ptmsgs_portalinfrastructure");
      goto case PT_CLASSIDS.PT_SUBPORTAL_ID;
      case PT_CLASSIDS.PT_SUBPORTAL_ID:
      return m_asOwner.GetString(519, "ptmsgs_portalinfrastructure");
      break;
      }
      return m_asOwner.GetString(339, "ptmsgs_portalinfrastructure");
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getDocFolderRestrictions()"></seealso>
    public virtual int[] GetDocFolderRestrictions()
    {
      checkInitialized();
      return objectArrayToIntArray(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getDrilldownDepth()"></seealso>
    public virtual int GetDrilldownDepth()
    {
      checkInitialized();
      int depth = (new XPStringTokenizer(m_currentKey, CACHE_KEY_SEPARATOR_STR,
       false)).GetTokenCount();
      if (XPStringUtility.EndsWith(m_currentKey, CACHE_KEY_SEPARATOR_STR))
      {
        depth++;
      }
      return depth;
    }
    
    /// <summary>
    /// Helper method to check whether groupIdx is actually the
    /// "all others" group
    /// </summary>
    private bool isAllOthersGroup(int groupIdx)
    {
      return (groupIdx == m_currentResponse.GetNumGroups());
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.isEntireGroupReturned()"></seealso>
    public virtual bool isEntireGroupReturned(int groupIdx)
    {
      checkInitialized();
      // If it's the "all others" group
      if (isAllOthersGroup(groupIdx))
      {
        // always say there is more stuff to see
        return false;
      }
      int returned = GetReturnedResultsInGroup(groupIdx);
      int total = 0;
      try
      {
        total = XPConvert.ToInteger(GetTotalResultsInGroup(groupIdx));
      }
      catch (Exception e)
      {
        // If the total results string contained something non-numeric,
        // like "~200", then we know not all results were returned
        return false;
      }
      return (returned == total);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getFolderNameForID()"></seealso>
    public virtual String GetFolderNameForID(int id, bool isAdmin)
    {
      try
      {
        IPTObject ptObj = null;
        if (isAdmin)
        {
          /*lock=*/
          ptObj = m_session.GetAdminCatalog().OpenAdminFolder(id, false);
          } else
        {
          /*lock=*/
          ptObj = m_session.GetCatalog().OpenFolder(id, false);
        }
        if (null != ptObj)
        {
          String name = ptObj.GetLocalizedName();
          if (null != name)
          {
            return name;
          }
        }
      }
      catch (Exception e)
      {
        log.Warn(e, "Exception thrown in GetFolderNameForID().  This is often caused by a clickthrough to the search results page from the \"More\" link in a Snapshot Query portlet, and in this case it means that the user does not have rights to search some of the folders specified in the Snapshot Query.  In this case, the warning is harmless.");
        }
      return m_asOwner.GetString(337, "ptmsgs_portalinfrastructure");
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getGroupName()"></seealso>
    public virtual String GetGroupName(int groupIdx)
    {
      checkInitialized();
      if (isAllOthersGroup(groupIdx))
      {
        return m_asOwner.GetString(520, "ptmsgs_portalinfrastructure");
      }
      String preLocalizedName = m_currentResponse.GetGroupLabel(groupIdx);
      // Folder names are looked up from the database, and if this lookup
      // fails (e.g. because the db and search server are out of sync) then
      // PTSearch will return "Unknown Folder". We need to look for this 
      // and localize it here    
      if (preLocalizedName != null && XPStringUtility.Trim(preLocalizedName).Equals(UNKNOWN_FOLDER_NAME))
      {
        return m_asOwner.GetString(1605, "ptmsgs_portalbrowsingmsgs");
      }
      String lastGroupBy = GetLastGroupByField();
      // if the last group-by was anything other than OBJECTTYPE, just return the
      // group label we already have
      if ((null == lastGroupBy) || (!(lastGroupBy.Equals(GROUPBY_OBJECTTYPE))))
      {
        return preLocalizedName;
      }
      return localizeObjectTypeName(preLocalizedName);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.GetGroupIcon()"></seealso>
    public virtual Object GetGroupIcon(int groupIdx)
    {
      checkInitialized();
      String lastGroupBy = GetLastGroupByField();
      if (null == lastGroupBy)
      {
        return null;
      }
      if (lastGroupBy.Equals(GROUPBY_FOLDER))
      {
        // Folder categorization.. return the "open folder" icon
        PTConstruct c = UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER,
         true, m_asOwner);
        if (null != c)
        {
          // See bug 35590.  PTConstruct doesn't put an alt-tag on this icon, so we
          // have to do it here.  This means downcasting the HTMLElement to an HTMLImg.
          // Apparently this is done elsewhere in the portal code, too.
          HTMLImg img = (HTMLImg) c.GetHTMLElement();
          img.SetAlt(m_asOwner.GetString(821, "ptmsgs_portalbrowsingmsgs"));
          return img;
        } else
        {
          return null;
        }
      }
      // For any other type of categorization except object type, return no icon
      if (!lastGroupBy.Equals(GROUPBY_OBJECTTYPE))
      {
        return null;
      }
      // Under object type categorization, return no icon for "all others"
      if (isAllOthersGroup(groupIdx))
      {
        return null;
      }
      // Otherwise look up the icon using the group name
      String label = m_currentResponse.GetGroupLabel(groupIdx);
      if (!XPStringUtility.StartsWith(label, "PT"))
      {
        // Non-portal or unknown type
        return null;
      }
      ClassTypeDescManager cdm = PTConfigHelper.GetPTClassTypeDescrManager();
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
       m_asOwner);
      if (null != cdm)
      {
        if (label.Equals("PTCARD"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_CATALOGCARD_ID,
           strLangID);
        }
        if (label.Equals("PTFOLDER"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
           strLangID);
        }
        if (label.Equals("PTGADGET"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_GADGET_ID,
           strLangID);
        }
        if (label.Equals("PTCOMMUNITY"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_COMMUNITY_ID,
           strLangID);
        }
        if (label.Equals("PTUSER"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_USER_ID, strLangID);
          }
        if (label.Equals("PTPAGE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_PAGE_ID, strLangID);
          }
        // What icons should we use for Collab and Content?
        if (label.Equals("PTCOLLAB"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_CATALOGCARD_ID,
           strLangID);
        }
        if (label.Equals("PTCONTENT"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_CATALOGCARD_ID,
           strLangID);
        }
        if (label.Equals("PTGROUP"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_USERGROUP_ID,
           strLangID);
        }
        if (label.Equals("PTAUTHSOURCE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_AUTHSOURCE_ID,
           strLangID);
        }
        if (label.Equals("PTPROFILESOURCE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_PROFILESOURCE_ID,
           strLangID);
        }
        if (label.Equals("PTADMINFOLDER"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_ADMIN_FOLDER_ID,
           strLangID);
        }
        if (label.Equals("PTFILTER"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_FILTER_ID,
           strLangID);
        }
        if (label.Equals("PTSAVEDSEARCH"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_SAVEDSEARCH_ID,
           strLangID);
        }
        if (label.Equals("PTDATASOURCE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_DATASOURCE_ID,
           strLangID);
        }
        if (label.Equals("PTCARDPROPERTY"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_PROPERTY_ID,
           strLangID);
        }
        if (label.Equals("PTDOCUMENTTYPE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_DOCUMENTTYPE_ID,
           strLangID);
        }
        if (label.Equals("PTCRAWLER"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_CRAWLER_ID,
           strLangID);
        }
        if (label.Equals("PTINVITATION"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_INVITATION_ID,
           strLangID);
        }
        if (label.Equals("PTFEDPORTAL"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_FEDERATEDPORTAL_ID,
           strLangID);
        }
        if (label.Equals("PTGADGETSERVER"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID,
           strLangID);
        }
        if (label.Equals("PTCOMMTEMPLATE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID,
           strLangID);
        }
        if (label.Equals("PTGADGETBUNDLE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_GADGETBUNDLE_ID,
           strLangID);
        }
        if (label.Equals("PTPAGETEMPLATE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_PAGETEMPLATE_ID,
           strLangID);
        }
        if (label.Equals("PTWEBSERVICE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_WEBSERVICE_ID,
           strLangID);
        }
        if (label.Equals("PTEXTOPERATION"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_EXTOPERATION_ID,
           strLangID);
        }
        if (label.Equals("PTGADGETTEMPLATE"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_GADGETTEMPLATE_ID,
           strLangID);
        }
        if (label.Equals("PTJOB"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_JOB_ID, strLangID);
          }
        if (label.Equals("PTSITEMAP"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_SITEMAPFOLDER_ID,
           strLangID);
        }
        if (label.Equals("PTSUBPORTAL"))
        {
          return cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_SUBPORTAL_ID,
           strLangID);
        }
      }
      // If still unknown, use no icon
      return null;
    }
    
    /// <summary>
    /// Special-case method for use only by DrilldownView.  Not exposed through ISearchResultModelRO
    /// interface.
    /// Returns the set of groups that was generated for some ancestor of the drilled-down
    /// response currently being shown.  This is used to generate a view that lets the user
    /// jump to a sibling of the current response.  For example, if the user has drilled down
    /// into the "Documents" category, such a view might let the user jump over to the (sibling)
    /// "Portlets" category.
    /// For now, this method only works if the requested ancestor was grouped by object type.
    /// </summary>
    public virtual XPHashtable GetGroupsForAncestorKey(String ancestorKey)
    {
      checkInitialized();
      // Check whether oldKey is an ancestor of the current key.
      if (!XPStringUtility.StartsWith(m_currentKey, ancestorKey))
      {
        throw new SearchModelException("In SearchResultModel.GetGroupsForAncestorKey, provided key is not an ancestor of the current key");
        }
      // Check that the requested ancestor used object-type categorization.
      if (!XPStringUtility.EndsWith(ancestorKey, GROUPBY_OBJECTTYPE))
      {
        throw new SearchModelException("SearchResultModel.GetGroupsForAncestorKey currently only supports ancestors that were grouped by object type.");
        }
      // Fetch the old response.
      IPTSearchResponse ancestorResponse = (IPTSearchResponse) m_responseCache.GetElement(ancestorKey);
      if (null == ancestorResponse)
      {
        throw new CacheFlushedException(m_asOwner);
      }
      XPHashtable groups = new XPHashtable();
      int numGroups = ancestorResponse.GetNumGroups();
      for (int j = 0;j < numGroups;j++)
      {
        String rawName = ancestorResponse.GetGroupLabel(j);
        groups.PutElement(localizeObjectTypeName(rawName), j);
      }
      return groups;
    }
    
    /// <summary>
    /// Special-case method for use only by DrilldownView.  Not exposed through ISearchResultModelRO
    /// interface.
    /// Returns the ID of the last group we drilled down into.  For example, if the initial
    /// search was grouped by Object Type, and the user selected Portlets (group 3) and drilled down,
    /// this would return "3".
    /// </summary>
    public virtual String GetLastDrilldownGroup()
    {
      int lastSlash = XPStringUtility.LastIndexOf(m_currentKey, CACHE_KEY_SEPARATOR_STR);
      String keyFragment = XPStringUtility.Substring(m_currentKey, 0, lastSlash);
      int lastDot = XPStringUtility.LastIndexOf(keyFragment, '.');
      return XPStringUtility.Substring(keyFragment, lastDot + 1);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISaveSearchModelRO.GetHasBeenSaved()"></seealso>
    public virtual bool GetHasBeenSaved()
    {
      return (m_savedSearchName != null);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getIncludeSubfolders()"></seealso>
    public virtual bool GetIncludeSubfolders()
    {
      checkInitialized();
      return (XPConvert.ToBoolean((m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS))));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getKWIC()"></seealso>
    public virtual String GetKWIC(int rank)
    {
      checkInitialized();
      // Note PTSearch actually checks for a KWIC for the content field
      // if there is no KWIC for PT_PROPERTY_OBJECTSUMMARY.
      // Also, the result of GetKWICFields is always html-encoded.
      String kwic = m_currentResponse.GetKWICFieldsAsString(rank, PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY);
      if ((null != kwic) && (kwic.Length > 0))
      {
        return kwic;
      }
      // If no KWIC, simply return the entire summary field,
      // but HTML-encode it to match behavior of GetKWICFields.
      return XPHttpUtility.HtmlEncode(m_currentResponse.GetFieldsAsString(rank,
       PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY));
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getLanguageRestriction()"></seealso>
    public virtual String GetLanguageRestriction()
    {
      checkInitialized();
      bool wasRestricted = (XPConvert.ToBoolean((m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE))));
      //boolean wasRestricted = (_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE) != 0);
      if (wasRestricted)
      {
        return ((m_request.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE)));
        }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getLastGroupByField()"></seealso>
    public virtual String GetLastGroupByField()
    {
      String key = GetLastGroupByFieldForKey(m_currentKey);
      return key;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.search.ISearchResultModel.SetPageMode()"></seealso>
    public virtual void SetPageMode(String pageMode)
    {
      m_pageMode = pageMode;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.search.ISearchResultModelRO.GetPageMode()"></seealso>
    public virtual String GetPageMode()
    {
      return m_pageMode;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getMisspelledToken()"></seealso>
    public virtual String GetMisspelledToken(int misspellingIndex)
    {
      checkInitialized();
      return m_currentResponse.GetMisspelledToken(misspellingIndex);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getNumCorrections()"></seealso>
    public virtual int GetNumCorrections(int misspellingIndex)
    {
      checkInitialized();
      return m_currentResponse.GetNumCorrections(misspellingIndex);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getNumMisspelledTokens()"></seealso>
    public virtual int GetNumMisspelledTokens()
    {
      checkInitialized();
      return m_currentResponse.GetNumMisspelledTokens();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getNumResultGroups()"></seealso>
    public virtual int GetNumResultGroups()
    {
      checkInitialized();
      // Get number of actual groups
      int numGroups = m_currentResponse.GetNumGroups();
      // If there was already at least one group
      if (numGroups > 0)
      {
        // Put everything else into its own group
        if (allOthersGroupExists())
        {
          numGroups++;
        }
      }
      return numGroups;
    }
    
    /// <summary>
    /// Helper method to figure out whether there is an "all others" group.
    /// </summary>
    private bool allOthersGroupExists()
    {
      if (((String) m_currentResponse.GetTotalResultsNotInAnyGroup()).Equals("0") || ((String) m_currentResponse.GetTotalResultsNotInAnyGroup()).Equals("~ 0"))
      {
        return false;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getObjectTypeRestrictions()"></seealso>
    public virtual int[] GetObjectTypeRestrictions()
    {
      checkInitialized();
      return objectArrayToIntArray(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES));
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getReconstructionArgs()"></seealso>
    public virtual XPHashtable GetReconstructionArgs()
    {
      return GetReconstructionArgs(true);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getReconstructionArgs()"></seealso>
    public virtual XPHashtable GetReconstructionArgs(bool wantPageContext)
    {
      return GetReconstructionArgs(SearchResultControl.RECONSTRUCTION_ARGS_PREFIX,
       wantPageContext);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getReconstructionArgs()"></seealso>
    public virtual XPHashtable GetReconstructionArgs(String prefix, bool wantPageContext)
    {
      // TODO: This is called once per link on the advanced search page.  It would be
      // nice if we could cache this so we only do the DB query once per page instead
      // of doing an identical query 10x on every page.  Bug#67468
      IXPCollection exclusions = null;
      if (!wantPageContext)
      {
        exclusions = SearchSettingCollection.GetPageContextSettings();
      }
      XPHashtable args = new XPHashtable();
      internalGetArgs(args, prefix, /* settingsArgs= */
      true, /* includedSettings= */
      null, /* excludedSettings= */
      exclusions, /* queryArgs= */
      true);
      return args;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultAbsType()"></seealso>
    public virtual String GetResultAbsType(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetResultAbsType(rank);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultApp()"></seealso>
    public virtual String GetResultApp(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetResultApp(rank);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultName()"></seealso>
    public virtual bool isResultBestBet(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetIsBestBet(rank);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultBestBetKey()"></seealso>
    public virtual String GetResultBestBetKey(int rank)
    {
      checkInitialized();
      String app = GetResultApp(rank);
      // if a portal item
      if (app.Equals(PORTAL_APP))
      {
        return (GetResultClassID(rank) + "." + GetResultObjectID(rank));
      }
      return m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_BESTBETKEY);
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultClassID()"></seealso>
    public virtual int GetResultClassID(int rank)
    {
      checkInitialized();
      int classId = -1;
      try
      {
        classId = m_currentResponse.GetFieldsAsInt(rank, PT_INTRINSICS.PT_PROPERTY_CLASSID);
        }
      catch (Exception e)
      {
        // ClassID is not defined for non-portal objects.
        classId = -1;
      }
      return classId;
    }
    
    /// <summary>
    /// Returns an edit link that may be used for clickthrough.
    /// </summary>
    public virtual HTMLAnchor GetResultEditLink(int rank, bool allowPopup)
    {
      /* editMode= */
      return GetResultClickthroughURL(rank, allowPopup, true);
    }
    
    /// <summary>
    /// Returns a view link that may be used for clickthrough.
    /// </summary>
    public virtual HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup)
    {
      /* editMode= */
      return GetResultClickthroughURL(rank, allowPopup, false);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultClickthroughURL()"></seealso>
    public virtual HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup,
     bool editMode)
    {
      /* extraParams= */
      return GetResultClickthroughURL(rank, allowPopup, editMode, null);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultClickthroughURL()"></seealso>
    public virtual HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup,
     bool editMode, String extraParams)
    {
      checkInitialized();
      String app = GetResultApp(rank);
      if (app.Equals(PORTAL_APP))
      {
        int nClassID = GetResultClassID(rank);
        int nObjectID = GetResultObjectID(rank);
        String strObjectName = GetResultName(rank);
        if (allowPopup && (PT_CLASSIDS.PT_GADGET_ID == nClassID))
        {
          // Open gadget preview, in a popup whenever it's possible
          HTMLAnchor anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          String strOptQSArgs = "&" + ASConstants.SUBSPACE + "=" + "mySubspaceKey";
          // Add extra parameters if requested
          if (null != extraParams)
          {
            strOptQSArgs = strOptQSArgs + "&" + extraParams;
          }
          anchor.SetOnClick(PTOpenerLinks.GetJSOpenInNewWindow(PTOpenerLinks.GetOpenerJSURLOpenObjID(nClassID,
           nObjectID, strOptQSArgs, (editMode ? IPTOpenerConstants.OPENER_MODE_EDIT : IPTOpenerConstants.OPENER_MODE_VIEW)),
           PTOpenerLinks.GetWindowName("" + nClassID + "_" + nObjectID), "450",
           "450", false));
          return anchor;
        } else
        {
          // Otherwise, make a plain opener URL
          // Add extra parameters if requested
          String strOptQSArgs = null;
          if (null != extraParams)
          {
            strOptQSArgs = "&" + extraParams;
          }
          return new HTMLAnchor(PTOpenerLinks.GetOpenerURLOpenObjID(nClassID,
           nObjectID, strObjectName, (editMode ? IPTOpenerConstants.OPENER_MODE_EDIT : IPTOpenerConstants.OPENER_MODE_VIEW),
           m_asOwner, m_asOwner.GetName(), m_asOwner.GetSpaceID(), strOptQSArgs));
          }
      } else
      {
        // for Collab and Content, the URL is stored in field PT5
        String url = m_currentResponse.GetFieldsAsString(rank, PT_INTRINSICS.PT_PROPERTY_DOCUMENTURL);
        int gatewayObjectId = 0;
        int gatewayClassId = PT_CLASSIDS.PT_GADGET_ID;
        String appPrefix = "";
        if (app.Equals(COLLAB_APP))
        {
          if (m_isPathwaysSearch)
          {
            gatewayObjectId = GetCollabPortletOrWebServiceID();
            appPrefix = GetPathwaysCollabURLPrefix(url);
          } else
          {
            gatewayObjectId = GetCollabPortletOrWebServiceID();
            appPrefix = GetCollabURLPrefix();
          }
          if (gatewayObjectId < 0)
          {
            gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
            gatewayObjectId = -1 * gatewayObjectId;
          }
        } else
        {
          //do nothing for a pathways search, url value is already determined above at the beginning and that's the URL we
          //want to use to create the clickthrough.
          if (!m_isPathwaysSearch)
          {
            //TODO see if you need to edit the content field.
            //SE: VV- Bug 54592 (Jatco): Checking if multiple portlets are associated to a single
            //Content Item. If there are multiple portlets associated, then we use the web service id
            //as gatewayClassId. If there's just one portlet, use the gadget id as gatewayClassId.
            if (HasMultiplePortlets(rank))
            {
              // There are multiple portlets so use web service id.	
              gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
              String contentWSID = (String) (m_currentResponse.GetResultInternalField(rank,
               PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_CONTENT_WS_ID));
              if ((null != contentWSID) && (0 < contentWSID.Length))
              {
                try
                {
                  gatewayObjectId = XPConvert.ToInteger(contentWSID);
                }
                catch (Exception e)
                {
                  gatewayObjectId = 0;
                }
              }
            } else
            {
              // There's only one portlet so use portlet id for the contruction of the gateway URL
              int[] gatewayObjectIds = GetResultContentPortletIDs(rank);
              try
              {
                gatewayObjectId = gatewayObjectIds[0];
              }
              catch (Exception e)
              {
                gatewayObjectId = 0;
              }
            }
          }
        }
        // Collab and Content URLs need to be gatewayed
        String gatewayPfx = GatewayHelpers.ConstructPrefPageLink(m_asOwner,
         /* objectID= */
        gatewayObjectId, /* communityID= */
        0, /* pageID= */
        0, /* prefType= */
        0, /* classID= */
        gatewayClassId);
        if (null != extraParams)
        {
          // Stick the extra parameters on the end of the gatewayed URL.  It's not clear
          // that this is the best way to accomplish this, but at least we shouldn't make
          // an invalid URL this way.
          if (-1 == XPStringUtility.IndexOf(url, "?"))
          {
            url = url + "?" + extraParams;
          } else
          {
            url = url + "&" + extraParams;
          }
        }
        String strHref;
        // SE: Bug 62927 - Fix for Sumitomo. Avoid double-encoding publishedcontent URLs that 
        // we get from the search index. We are assuming here that these URLs are always encoded.
        // Note: Prior to this fix, the double-encoded URL does work if there's a web server front-end
        // because it un-encodes the '%'s before passing the request through. However if the user did 
        // a click-through directly against the appserver (Tomcat, Weblogic), they will encounter a 404.
        if (app.Equals(CONTENT_APP))
        {
          if (m_isPathwaysSearch)
          {
            //bug 8252316 - PATHWAYS RETURNS INCORRECT PORTAL URL
            //this url will be broken due to the bug above, until it's fixed, this piece of code would have the
            //incorrect clickthrough ID, however, I will not code around the pathways issue.
            strHref = url;
            pathwayslog.Debug("SearchResultModel::getResultClickthroughURL - strHref = " + strHref);
            } else
          {
            // A published content URL with multi-byte characters encoded looks like the following:
            // http://se611dnet.devnet.plumtree.com/portal/server.pt/gateway/PTARGS_0_0_334_0_0_43/http://se611dnet-cs640.devnet.plumtree.com:7087/publishedcontent/publish/kanji_test_%E7%94%B8/%E8%A8%98%E4%BA%8B/kanji_test_%E7%94%B8.html
            //
            // We need to make this URL "gateway-friendly" but avoid re-encoding the '%' in the URL. So we should
            // only pass the base URL into GatewayHelpers.CreateGatewayFriendlyURL and leave the rest of the
            // URL alone as that's already been encoded.
            // Find the end index of the base URL
            int iGatewayBaseURLEndIndex = XPStringUtility.IndexOf(XPStringUtility.ToLowerCase(url),
             "://");
            /* move past "://" */
            iGatewayBaseURLEndIndex = XPStringUtility.IndexOf(XPStringUtility.ToLowerCase(url),
             "/", iGatewayBaseURLEndIndex + 3);
            String strGatewayBaseURL = "";
            String strGatewaySfx = "";
            if (-1 != iGatewayBaseURLEndIndex)
            {
              // Get the base URL, i.e. http://<server>:<port>/
              strGatewayBaseURL = XPStringUtility.Substring(url, 0, iGatewayBaseURLEndIndex);
              log.Debug("SearchResultModel::getResultClickthroughURL - strGatewayBaseURL = " + strGatewayBaseURL);
              // The rest of the URL
              strGatewaySfx = XPStringUtility.Substring(url, iGatewayBaseURLEndIndex);
              log.Debug("SearchResultModel::getResultClickthroughURL - strGatewaySfx = " + strGatewaySfx);
              // Make the base gateway URL gateway friendly
              strGatewayBaseURL = GatewayHelpers.CreateGatewayFriendlyURL(appPrefix + strGatewayBaseURL);
              }
            // Now reconstruct the fully encoded gateway URL
            strHref = gatewayPfx + strGatewayBaseURL + strGatewaySfx;
            log.Debug("SearchResultModel::getResultClickthroughURL - strHref = " + strHref);
            }
        } else
        {
          if (m_isPathwaysSearch)
          {
            strHref = gatewayPfx + GatewayHelpers.CreateGatewayFriendlyURL(appPrefix);
            } else
          {
            strHref = gatewayPfx + GatewayHelpers.CreateGatewayFriendlyURL(appPrefix + url);
            }
        }
        return new HTMLAnchor(strHref);
      }
    }
    //SE: VV- Bug 54592 (Jatco):This is the actual method that checks if there are multiple
    //portlets. If there is more than 1 token in String strMultiplePortletIDs, then there are
    //multiple portlets, if not, there's just one portlet.
    private bool HasMultiplePortlets(int rank)
    {
      String strMultiplePortletIDs = "";
      //must check if this is pathways search, if so, we must get this item another way
      if (m_isPathwaysSearch)
      {
        strMultiplePortletIDs = "";
      } else
      {
        strMultiplePortletIDs = (String) (m_currentResponse.GetResultInternalField(rank,
         PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_CONTENT_PORTLET_ID));
      }
      XPStringTokenizer st = new XPStringTokenizer(strMultiplePortletIDs);
      if (st.GetTokenCount() > 1)
      {
        return true;
      } else
      {
        return false;
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.search.ISearchResultModelRO.GetResultCollabProjectName()"></seealso>
    public virtual String GetResultCollabProjectName(int rank)
    {
      checkInitialized();
      String projName = m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_COLLAB_PROJ_NAME);
      if ((null == projName) || (0 == projName.Length))
      {
        return null;
      }
      return projName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultCollabProjectURL()"></seealso>
    public virtual String GetResultCollabProjectURL(int rank)
    {
      checkInitialized();
      String url = m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_COLLAB_PROJ_URL);
      if ((null != url) && (url.Length > 0))
      {
        int gatewayObjectId = GetCollabPortletOrWebServiceID();
        int gatewayClassId = PT_CLASSIDS.PT_GADGET_ID;
        if (gatewayObjectId < 0)
        {
          gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
          gatewayObjectId = -1 * gatewayObjectId;
        }
        String gatewayPfx = GatewayHelpers.ConstructPrefPageLink(m_asOwner,
         /* objectID= */
        gatewayObjectId, /* communityID= */
        0, /* pageID= */
        0, /* prefType= */
        0, /* classID= */
        gatewayClassId);
        return gatewayPfx + GatewayHelpers.CreateGatewayFriendlyURL(GetCollabURLPrefix() + url);
        } else
      {
        return null;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchResultModelRO.GetResultPortletField()"></seealso>
    public virtual String GetResultPortletField(int rank, int fieldId)
    {
      checkInitialized();
      bool ok = ((PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_TYPE == fieldId) || (PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_ALIGNMENT == fieldId) || (PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_USER_INTERFACES == fieldId));
      if (!ok)
      {
        throw new SearchModelException("SearchResultModel.GetResultPortletField does not support field " + fieldId);
        }
      return m_currentResponse.GetResultInternalField(rank, fieldId);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultContentLastPubUser()"></seealso>
    public virtual String GetResultContentLastPubUser(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_CONTENT_PUBLISHED_USER);
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultContentPortletIDs()"></seealso>
    public virtual int[] GetResultContentPortletIDs(int rank)
    {
      checkInitialized();
      String s = m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_CONTENT_PORTLET_ID);
      if ((null == s) || (0 == s.Length))
      {
        return null;
      }
      XPArrayList al = new XPArrayList();
      XPStringTokenizer tok = new XPStringTokenizer(s);
      while (tok.HasMoreTokens())
      {
        String oneID = tok.GetNextToken();
        int id = -1;
        try
        {
          id = XPConvert.ToInteger(oneID);
        }
        catch (Exception e)
        {
          log.Warn("Unable to parse Content Server portlet ID: " + oneID + ".  Please report this error to Plumtree.");
          id = -1;
        }
        if (-1 != id)
        {
          al.Add(id);
        }
      }
      if (0 == al.GetSize())
      {
        return null;
      }
      int[] ids = new int[al.GetSize()];
      for (int j = 0;j < al.GetSize();j++)
      {
        ids[j] = XPConvert.ToInteger(al.GetElement(j));
      }
      return ids;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultCreated()"></seealso>
    public virtual XPDateTime GetResultCreated(int rank)
    {
      checkInitialized();
      return ConvertSearchDateTimeToXPDateTime(m_currentResponse.GetFieldsAsDouble(rank,
       PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED));
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultField()"></seealso>
    public virtual String GetResultEODField(int rank, int propertyId)
    {
      checkInitialized();
      return m_currentResponse.GetFieldsAsString(rank, propertyId);
    }
    public virtual Object GetResultEODFieldAsObject(int rank, int propertyId)
    {
      checkInitialized();
      return m_currentResponse.GetFieldsAsObject(rank, propertyId);
    }
    private int GetPathwaysResultFolderID(int rank)
    {
      return m_currentResponse.GetFieldsAsInt(rank, PathwaysConstants.INT_FOLDERID);
      }
    private int GetLegacyResultFolderID(int rank)
    {
      // Eventually, we should make a full-fledged GetResultFolderID method
      // on PTSearchResponse..
      String parentIDField = m_currentResponse.GetResultInternalField(rank,
       PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_PARENTIDS);
      if ((null != parentIDField) && (parentIDField.Length > 2))
      {
        // Some cards have more than one parent, space-separated.  If so,
        // do not return any of them - we can't be sure which one the user
        // has rights to see without doing some expensive database queries.
        // We may want to revisit this for a future release.
        int firstSpace = XPStringUtility.IndexOf(XPStringUtility.Trim(parentIDField),
         ' ');
        // If a space in the parentids field, meaning more than one parent..
        if (-1 != firstSpace)
        {
          // return 0 for "unknown parent"
          return 0;
        }
        try
        {
          // The parentid field is of the form od123 or dd123, so look at
          // the third character and after
          return XPConvert.ToInteger(XPStringUtility.Substring(parentIDField,
           2));
        }
        catch (Exception e)
        {
          throw XPException.GetInstance(e);
        }
      }
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultFolderID()"></seealso>
    public virtual int GetResultFolderID(int rank)
    {
      if (m_isPathwaysSearch)
      {
        return GetPathwaysResultFolderID(rank);
      } else
      {
        return GetLegacyResultFolderID(rank);
      }
    }
    /*
     * this function gets called by SavSrchResultsView and SavedSearchPortletView, guessing it's for saved searches.
     */
     
    public virtual void ExternalLightInitialization(IPTSearchResponse sr,
     AActivitySpace asSpace)
    {
      m_currentResponse = sr;
      m_initialized = true;
      m_asOwner = asSpace;
    }
    
    /// <summary>
    /// Get Pathways icon based on result type
    /// </summary>
    public virtual Object GetPathwaysResultIcon(int rank)
    {
      HTMLImg icon = null;
      String app = GetResultApp(rank);
      String indexedURL = (m_currentResponse.GetFieldsAsString(rank, PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEURL));
      if (app.Equals(PORTAL_APP))
      {
        //we need to remove "plumtree/" from the url b/c the SearchResultsDataTag puts it back in.
        indexedURL = GeneralHelpers.Replace(indexedURL, "plumtree/", "");
        String subType = GetResultSubType(rank);
        String altText = localizeObjectTypeName(subType);
        icon = new HTMLImg(indexedURL, altText);
        icon.SetUseDisplayOptionsBaseUrl(false);
        return icon;
      } else
      {
        //relative, so we need to append the image server base url. We truly need the 
        //base folder itself. Simply calling ConfigHelper.GetImageBaseURL() will
        //append /plumtree on the end of the base folder, which we don't want, since the 
        //network search result images don't necessarily live under the plumtree
        //folder. That's why we have to do this
        bool isSecure = m_asOwner.GetIsSecuredSpace();
        String imgSvrBaseURL = ((ImgSvrURLHelper) ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString()).GetCachingManager().GetEntry("ImageServerHelper")).GetRootURL(isSecure);
        String altText = "";
        if (app.Equals(COLLAB_APP))
        {
          //TODO this will always return null, i'm not sure if we need this here at all
          altText = m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_COLLAB_ICON_ALT_TEXT);
          if (null == altText)
          {
            altText = m_asOwner.GetString(342, "ptmsgs_portalinfrastructure");
            } else
          {
            int altTextId = -1;
            try
            {
              altTextId = XPConvert.ToInteger(altText);
            }
            catch (Exception e)
            {
              // on any failure, just use the generic text
              altText = m_asOwner.GetString(342, "ptmsgs_portalinfrastructure");
              altTextId = -1;
            }
            if (altTextId != -1)
            {
              altText = m_asOwner.GetString(altTextId, "ptmsgs_collabserverobjecttypes");
              }
          }
        } else
        if (app.Equals(CONTENT_APP))
        {
          altText = m_asOwner.GetString(343, "ptmsgs_portalinfrastructure");
          } else
        if (app.Equals(TEMPLATING_APP))
        {
          altText = m_asOwner.GetString(320, "ptmsgs_portalinfrastructure");
          }
        if (null != indexedURL)
        {
          icon = new HTMLImg(imgSvrBaseURL + indexedURL, altText);
          icon.SetUseDisplayOptionsBaseUrl(false);
        } else
        {
          // If PT53 isn't indexed for some reason, use the "sheet of paper" PTCARD
          // icon as a default
          ClassTypeDescManager cdm = PTConfigHelper.GetPTClassTypeDescrManager();
          if (null != cdm)
          {
            String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
             m_asOwner);
            icon = cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_CATALOGCARD_ID,
             strLangID);
            icon.SetAlt(altText);
          }
        }
      }
      return icon;
    }
    public virtual Object GetLegacyResultIcon(int rank)
    {
      HTMLImg icon = null;
      int classId = GetResultClassID(rank);
      if (-1 != classId)
      {
        // Portal objects.
        String altTag = null;
        String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
         m_asOwner);
        if (PT_CLASSIDS.PT_CATALOGCARD_ID == classId)
        {
          // CARDS: Use the icon associated with the card's actual file type.
          String uuid = GetResultTypeUUID(rank);
          // If the image UUID is defined
          if ((null != uuid) && (0 < uuid.Length))
          {
            // get the image for this UUID
            /* smallImage= */
            icon = PlumtreeHelpers.GetHTMLImage(uuid, true);
            // See if we can get a tooltip based on the UUID.  Use the PTDocTypesVarPack.
            IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
            if (null != application)
            {
              PTDocTypesVarPack varPack = (PTDocTypesVarPack) application.GetVarPackManager().GetVariablePackage(PTDocTypesVarPack.VARPACK_ID);
              if (null != varPack)
              {
                altTag = varPack.GetLocalizedName(uuid, strLangID);
              }
            }
          }
        }
        if (null == icon)
        {
          // If we couldn't get an icon corresponding to the UUID, use the default
          // icon for the item's type.
          ClassTypeDescManager cdm = PTConfigHelper.GetPTClassTypeDescrManager();
          if (null != cdm)
          {
            icon = cdm.GetDefaultIconForClassType(classId, strLangID);
          }
        }
        if (null != icon)
        {
          if ((null == altTag) || (0 == altTag.Length))
          {
            String subType = GetResultSubType(rank);
            altTag = localizeObjectTypeName(subType);
          }
          icon.SetAlt(altTag);
        }
      } else
      {
        // The URL for collab/content/templating icons are stored in field PT53
        String indexedURL = (m_currentResponse.GetFieldsAsString(rank, PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEURL));
        //relative, so we need to append the image server base url. We truly need the 
        //base folder itself. Simply calling ConfigHelper.GetImageBaseURL() will
        //append /plumtree on the end of the base folder, which we don't want, since the 
        //network search result images don't necessarily live under the plumtree
        //folder. That's why we have to do this
        bool isSecure = m_asOwner.GetIsSecuredSpace();
        String imgSvrBaseURL = ((ImgSvrURLHelper) ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString()).GetCachingManager().GetEntry("ImageServerHelper")).GetRootURL(isSecure);
        String altText = "";
        String app = GetResultApp(rank);
        if (app.Equals(COLLAB_APP))
        {
          altText = m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_COLLAB_ICON_ALT_TEXT);
          if (null == altText)
          {
            altText = m_asOwner.GetString(342, "ptmsgs_portalinfrastructure");
            } else
          {
            int altTextId = -1;
            try
            {
              altTextId = XPConvert.ToInteger(altText);
            }
            catch (Exception e)
            {
              // on any failure, just use the generic text
              altText = m_asOwner.GetString(342, "ptmsgs_portalinfrastructure");
              altTextId = -1;
            }
            if (altTextId != -1)
            {
              altText = m_asOwner.GetString(altTextId, "ptmsgs_collabserverobjecttypes");
              }
          }
        } else
        if (app.Equals(CONTENT_APP))
        {
          altText = m_asOwner.GetString(343, "ptmsgs_portalinfrastructure");
          } else
        if (app.Equals(TEMPLATING_APP))
        {
          altText = m_asOwner.GetString(320, "ptmsgs_portalinfrastructure");
          }
        if (null != indexedURL)
        {
          icon = new HTMLImg(imgSvrBaseURL + indexedURL, altText);
          icon.SetUseDisplayOptionsBaseUrl(false);
        } else
        {
          // If PT53 isn't indexed for some reason, use the "sheet of paper" PTCARD
          // icon as a default
          ClassTypeDescManager cdm = PTConfigHelper.GetPTClassTypeDescrManager();
          if (null != cdm)
          {
            String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
             m_asOwner);
            icon = cdm.GetDefaultIconForClassType(PT_CLASSIDS.PT_CATALOGCARD_ID,
             strLangID);
            icon.SetAlt(altText);
          }
        }
      }
      return icon;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultIcon()"></seealso>
    public virtual Object GetResultIcon(int rank)
    {
      checkInitialized();
      if (m_isPathwaysSearch)
      {
        return GetPathwaysResultIcon(rank);
      } else
      {
        return GetLegacyResultIcon(rank);
      }
    }
    /*
     * this code was retrieved from PTPropertyMap.ParseDate
     * pathways returns a string, needed to convert to XPDateTime properly
     */
     
    private XPDateTime GetPathwaysLastModified(int rank)
    {
      String strDate = m_currentResponse.GetFieldsAsString(rank, PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED);
      XPDateFormat dfDateFormat = GetDateFormat(m_asOwner);
      XPDateTime dt = null;
      /*
       * pathways returns a ISO-8601 format String "date" in the response that has been converted from a
       * java.util.GregorianCalendar object.  That's the jist of it... b/c we can't use GregorianCalendar object as
       * there is no jumpable code for this, I need to parse it into "MM/dd/yyyy hh:mm:ss a" type format
       * ie:  pathways returns this date:  2008-05-02T15:46:00-07:00 - YYYY-MM-DDTHH:MM:SS-HH:00
       */
       
      // Pathways returns the date string in GMT already so we can drop out the timezone offset
      // as openfoundation handles displaying local time appropriately.
      // After droping the offset, it should look like this: 2008-10-21T14:03:00
      strDate = XPStringUtility.Substring(strDate, 0, strDate.Length - 6);
      String g_formatPatternEODDate = EOD_DATE_FORMAT_PATTERN;
      dfDateFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT,
       XPDateFormat.SHORT);
      dfDateFormat.ApplyPattern(g_formatPatternEODDate);
      dt = dfDateFormat.Parse(strDate);
      return dt;
    }
    //This function is being omitted b/c pathways doesn't return an object created date.  This was only used in admin mode of search, keeping around
    //in case we need a String to Date conversion function for other things.
    /*
     * this function is used to convert the Pathways string value to a XPDate value, this is used by the
     * GroupedResultsViewHelper.java file when constructing the search results page via Admin Mode, it is looking
     * specifically for the created date of the search result
     * @param rank the index of the search result in the array
     * @param property the property id value
     * @return the XPDateTime value of the current search result
     
     
     private XPDateTime GetPathwaysStringToDateConversion(int rank, int property)
     {
     String strDate =  m_currentResponse.GetFieldsAsString(rank, property);
     
     XPDateFormat dfDateFormat = GetDateFormat(m_asOwner);
     XPDateTime dt = null;
     
     /*
     * pathways returns a ISO-8601 format String "date" in the response that has been converted from a
     * java.util.GregorianCalendar object.  That's the jist of it... b/c we can't use GregorianCalendar object as
     * there is no jumpable code for this, I need to parse it into "MM/dd/yyyy hh:mm:ss a" type format
     * ie:  pathways returns this date:  2008-05-02T15:46:00-07:00 - YYYY-MM-DDTHH:MM:SS-HH:00
     *
     // Pathways returns the date string in GMT already so we can drop out the timezone offset
     // as openfoundation handles displaying local time appropriately.
     // After dropping the offset, it should look like this: 2008-10-21T14:03:00
     strDate = strDate.substring(0, strDate.length() - 6);
     String g_formatPatternEODDate = EOD_DATE_FORMAT_PATTERN;
     dfDateFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT, XPDateFormat.SHORT);
     dfDateFormat.ApplyPattern(g_formatPatternEODDate);
     
     dt = dfDateFormat.Parse(strDate);
     return dt;
     }
     */
     
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultLastModified()"></seealso>
    public virtual XPDateTime GetResultLastModified(int rank)
    {
      checkInitialized();
      if (m_isPathwaysSearch)
      {
        return GetPathwaysLastModified(rank);
      } else
      //native search
      {
        return ConvertSearchDateTimeToXPDateTime(m_currentResponse.GetFieldsAsDouble(rank,
         PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED));
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultName()"></seealso>
    public virtual String GetResultName(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetFieldsAsString(rank, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME);
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultObjectID()"></seealso>
    public virtual int GetResultObjectID(int rank)
    {
      checkInitialized();
      int objectId = -1;
      try
      {
        objectId = m_currentResponse.GetFieldsAsInt(rank, PT_INTRINSICS.PT_PROPERTY_OBJECTID);
        }
      catch (Exception e)
      {
        // ObjectID is not defined for non-portal objects.
        objectId = -1;
      }
      return objectId;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultPath()"></seealso>
    public virtual String GetResultPath(int rank)
    {
      checkInitialized();
      // For documents in multiple folders, this returns one path to the document
      // chosen more or less at random.  The user may not be able to see this
      // particular path, so be careful displaying it if GetResultFolderID()
      // returns zero.
      return m_currentResponse.GetResultPath(rank);
    }
    public virtual XPHashtable GetTagCloud()
    {
      PathwaysSearchResponse pathwaysSR = (PathwaysSearchResponse) m_currentResponse;
      return pathwaysSR.getTagCloudList();
    }
    private HTMLAnchor GetPathwaysCollabResultPropertiesURL(int rank, bool allowPopup)
    {
      /*
       * pathways returns the URL to the properties from the <viewDetailURL> node, if it's missing, it means there is none.
       * There is a bug #70398 against Pathways about not all collab objects returning a properties url.
       */
       
      String url = m_currentResponse.GetFieldsAsString(rank, PathwaysConstants.INT_VIEW_DETAILS_URL);
      if ((null == url) || (url.Length == 0))
      {
        return null;
      } else
      {
        int startIndex = XPStringUtility.IndexOf(url, "http;");
        url = XPStringUtility.Substring(url, startIndex);
      }
      int gatewayObjectId = GetCollabPortletOrWebServiceID();
      int gatewayClassId = PT_CLASSIDS.PT_GADGET_ID;
      if (gatewayObjectId < 0)
      {
        gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
        gatewayObjectId = -1 * gatewayObjectId;
      }
      String gatewayPfx = GatewayHelpers.ConstructPrefPageLink(m_asOwner,
       /* objectID= */
      gatewayObjectId, /* communityID= */
      0, /* pageID= */
      0, /* prefType= */
      0, /* classId= */
      gatewayClassId);
      HTMLAnchor collabProps = null;
      if (allowPopup)
      {
        collabProps = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        collabProps.SetOnClick("collabPopUp(\'" + gatewayPfx + url + "\'); return false;");
        } else
      {
        collabProps = new HTMLAnchor(gatewayPfx + url);
      }
      return collabProps;
    }
    public virtual HTMLAnchor GetLegacyResultPropertiesURL(int rank, bool allowPopup)
    {
      // Collab properties
      String url = m_currentResponse.GetResultInternalField(rank, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_COLLAB_PROPS_URL);
      if ((null == url) || (url.Length == 0))
      {
        return null;
      }
      int gatewayObjectId = GetCollabPortletOrWebServiceID();
      int gatewayClassId = PT_CLASSIDS.PT_GADGET_ID;
      if (gatewayObjectId < 0)
      {
        gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
        gatewayObjectId = -1 * gatewayObjectId;
      }
      String gatewayPfx = GatewayHelpers.ConstructPrefPageLink(m_asOwner,
       /* objectID= */
      gatewayObjectId, /* communityID= */
      0, /* pageID= */
      0, /* prefType= */
      0, /* classId= */
      gatewayClassId);
      HTMLAnchor collabProps = null;
      if (allowPopup)
      {
        collabProps = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        collabProps.SetOnClick("collabPopUp(\'" + gatewayPfx + GatewayHelpers.CreateGatewayFriendlyURL(GetCollabURLPrefix() + url) + "\'); return false;");
        } else
      {
        collabProps = new HTMLAnchor(gatewayPfx + GatewayHelpers.CreateGatewayFriendlyURL(GetCollabURLPrefix() + url));
        }
      return collabProps;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultPropertiesURL()"></seealso>
    public virtual HTMLAnchor GetResultPropertiesURL(int rank, bool allowPopup)
    {
      checkInitialized();
      String app = GetResultApp(rank);
      if (app.Equals(CONTENT_APP) || app.Equals(TEMPLATING_APP))
      {
        // No properties page for Content or templating items
        return null;
      }
      if (app.Equals(PORTAL_APP))
      {
        HTMLAnchor a = null;
        int nClassID = GetResultClassID(rank);
        int nObjectID = GetResultObjectID(rank);
        if (allowPopup)
        {
          a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          String strOptQSArgs = "&" + ASConstants.SUBSPACE + "=" + "mySubspaceKey";
          String strOnclick = PTOpenerLinks.GetJSOpenInNewWindow(PTOpenerLinks.GetOpenerJSURLOpenObjID(nClassID,
           nObjectID, strOptQSArgs, IPTOpenerConstants.OPENER_MODE_VIEW_META_DATA),
           PTOpenerLinks.GetWindowName("" + nClassID + "_" + nObjectID), "600",
           "450", true) + "; return false;";
          a.SetOnClick(strOnclick);
        } else
        {
          a = new HTMLAnchor(PTOpenerLinks.GetOpenerURLOpenObjID(GetResultClassID(rank),
           GetResultObjectID(rank), IPTOpenerConstants.OPENER_MODE_VIEW_META_DATA,
           m_asOwner));
        }
        return a;
      } else
      //else it's collab property
      {
        if (m_isPathwaysSearch)
        {
          return GetPathwaysCollabResultPropertiesURL(rank, allowPopup);
        } else
        {
          return GetLegacyResultPropertiesURL(rank, allowPopup);
        }
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultRank()"></seealso>
    public virtual int GetResultRank(int groupNum, int resultNum)
    {
      checkInitialized();
      if (isAllOthersGroup(groupNum))
      {
        return m_currentResponse.GetRankForUncategorizedDoc(resultNum);
      }
      return m_currentResponse.GetRank(groupNum, resultNum);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultSize()"></seealso>
    public virtual int GetResultSize(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetResultSize(rank);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getResultSubType()"></seealso>
    public virtual String GetResultSubType(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetResultSubType(rank);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.search.ISearchResultModelRO#GetResultStyleClass(java.lang.String)"></seealso>
    public virtual String GetResultStyleClass(String subType)
    {
      String styleClass = "ali-kd-doc-text";
      // check for bad input first
      if ((null == subType) || (0 == subType.Length))
      {
        return styleClass;
      }
      // first, check for Collab types.. these are always 1 or 2 characters
      if (subType.Length <= 2)
      {
        // see if it's an integer
        int collabTypeId = 0;
        try
        {
          collabTypeId = XPConvert.ToInteger(subType);
        }
        catch (Exception e)
        {
          collabTypeId = 0;
        }
        // Note that "ptmsgs_collabserverobjecttypes.xml" contains the user-facing
        // names of the Collab types, and the IDs of strings in that file correspond
        // to the same values as the collab_type field.  We just need to make sure
        // the values are reasonable..
        if (0 != collabTypeId)
        {
          //return m_asOwner.GetString(collabTypeId, "ptmsgs_collabserverobjecttypes");
          return styleClass;
        }
      }
      // now, if it doesn't start with "PT", it's not something we know about
      if (!XPStringUtility.StartsWith(subType, "PT"))
      {
        return styleClass;
      }
      // This list needs to remain consistent with the 
      // list in PTIndexer.cpp, TypeStringFromClassID()
      // NOTE: These are mostly commented out because we don't have custom
      // styles and images for them yet.  We will add them in as we get
      // the new styles and images.
      /*
       if (subType.equals("PTUSER"))
       {
       //return m_asOwner.GetString(298, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTGROUP"))
       {
       //return m_asOwner.GetString(299, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTAUTHSOURCE"))
       {
       //return m_asOwner.GetString(300, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTPROFILESOURCE"))
       {
       //return m_asOwner.GetString(301, "ptmsgs_portalinfrastructure");
       }
       */
       
      if (subType.Equals("PTFOLDER"))
      {
        styleClass = "ali-search-folder";
      }
      /*
       if (subType.equals("PTCARD"))
       {
       //return m_asOwner.GetString(296, "ptmsgs_portalinfrastructure");
       }
       */
       
      if (subType.Equals("PTADMINFOLDER"))
      {
        styleClass = "ali-search-folder";
      }
      /*
       if (subType.equals("PTFILTER"))
       {
       //return m_asOwner.GetString(303, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTSAVEDSEARCH"))
       {
       //return m_asOwner.GetString(304, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTDATASOURCE"))
       {
       //return m_asOwner.GetString(305, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTCARDPROPERTY"))
       {
       //return m_asOwner.GetString(306, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTDOCUMENTTYPE"))
       {
       // return m_asOwner.GetString(307, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTCRAWLER"))
       {
       // return m_asOwner.GetString(308, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTGADGET"))
       {
       //return m_asOwner.GetString(309, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTINVITATION"))
       {
       //return m_asOwner.GetString(310, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTFEDPORTAL"))
       {
       //return m_asOwner.GetString(470, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTGADGETSERVER"))
       {
       //return m_asOwner.GetString(312, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTCOMMTEMPLATE"))
       {
       //return m_asOwner.GetString(313, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTGADGETBUNDLE"))
       {
       //return m_asOwner.GetString(314, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTPAGETEMPLATE"))
       {
       //return m_asOwner.GetString(315, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTWEBSERVICE"))
       {
       //return m_asOwner.GetString(316, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTEXTOPERATION"))
       {
       //return m_asOwner.GetString(317, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTGADGETTEMPLATE"))
       {
       //return m_asOwner.GetString(318, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTJOB"))
       {
       //return m_asOwner.GetString(319, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTCOMMUNITY"))
       {
       //return m_asOwner.GetString(320, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTPAGE"))
       {
       //return m_asOwner.GetString(505, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTSITEMAP"))
       {
       //return m_asOwner.GetString(321, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTSUBPORTAL"))
       {
       //return m_asOwner.GetString(519, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTCOLLAB"))
       {
       //return m_asOwner.GetString(323, "ptmsgs_portalinfrastructure");
       }
       
       if (subType.equals("PTCONTENT"))
       {
       //return m_asOwner.GetString(322, "ptmsgs_portalinfrastructure");
       }
       */
       
      return styleClass;
    }
    
    /// <param name="rank"></param>
    /// <returns></returns>
    public virtual String GetResultTypeUUID(int rank)
    {
      checkInitialized();
      return m_currentResponse.GetFieldsAsString(rank, PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID);
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getReturnedResultsInGroup()"></seealso>
    public virtual int GetReturnedResultsInGroup(int groupIdx)
    {
      checkInitialized();
      if (isAllOthersGroup(groupIdx))
      {
        return m_currentResponse.GetReturnedResultsNotInAnyGroup();
      }
      return m_currentResponse.GetReturnedResultsInGroup(groupIdx);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISaveSearchModel.SetSavedSearchErrorCode()"></seealso>
    public virtual void SetSavedSearchErrorCode(int code)
    {
      m_savedSearchErrorCode = code;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISaveSearchModelRO.GetSavedSearchErrorCode()"></seealso>
    public virtual int GetSavedSearchErrorCode()
    {
      return m_savedSearchErrorCode;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISaveSearchModel.SetSavedSearchName()"></seealso>
    public virtual void SetSavedSearchName(String name)
    {
      m_savedSearchName = name;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISaveSearchModelRO.GetSavedSearchName()"></seealso>
    public virtual String GetSavedSearchName()
    {
      return m_savedSearchName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getSearchAgainArgs()"></seealso>
    public virtual XPHashtable GetSearchAgainArgs(bool includeOptional)
    {
      // Never want to include current page context when we "search again"
      IXPList exclusions = SearchSettingCollection.GetPageContextSettings();
      // Add all the optional (aka removable) settings from the exclusions
      // list.  If the user wanted them, we'll add them separately below
      IXPList optional = new XPArrayList();
      // If requested and there are optional settings, add them to the
      // exclusions list
      if (null != m_removableSettings)
      {
        IXPEnumerator optionalIDs = m_removableSettings.GetSettingIDs();
        while (optionalIDs.MoveNext())
        {
          Object id = optionalIDs.GetCurrent();
          optional.Add(id);
          exclusions.Add(id);
        }
      }
      // Now, we can get all required settings 
      XPHashtable args = new XPHashtable();
      internalGetArgs(args, StartSearchControl.REQUIRED_CONSTRAINT_PREFIX,
       /* settingsArgs= */
      true, /* includedSettings= */
      null, /* excludedSettings= */
      exclusions, /* queryArgs= */
      false);
      // If the caller wanted optional settings, add these as well
      if (includeOptional && (0 < optional.GetSize()))
      {
        const String FAKE_OPTION = "a";
        internalGetArgs(args, StartSearchControl.OPTIONAL_CONSTRAINT_PREFIX + FAKE_OPTION + "_",
         /* settingsArgs= */
        true, /* includedSettings= */
        optional, /* excludedSettings= */
        null, /* queryArgs= */
        false);
        // Finally, add an argument to tell StartSearchControl that the
        // fake "optional selection" was actually selected
        args.PutElement(StartSearchControl.SELECTED_PREFIX, new String[]{FAKE_OPTION});
        }
      return args;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchQueryRO.getSearchString()"></seealso>
    public virtual String GetSearchString()
    {
      checkInitialized();
      return m_initialSearchString;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.search.IBaseSearchQueryRO#GetLocalizedSearchString()"></seealso>
    public virtual String GetLocalizedSearchString()
    {
      if (null != m_initialSearchString && XPStringUtility.StartsWith(m_initialSearchString,
       PathwaysConstants.TAG_QUERY_PREFIX))
      {
        return m_asOwner.GetString(550, "ptmsgs_portalinfrastructure") + ":" + XPStringUtility.Substring(m_initialSearchString,
         PathwaysConstants.TAG_QUERY_PREFIX.Length, m_initialSearchString.Length);
        }
      return m_initialSearchString;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getSpellingCorrection()"></seealso>
    public virtual String GetSpellingCorrection(int misspellingIndex, int correctionIndex)
    {
      checkInitialized();
      return m_currentResponse.GetCorrectedToken(misspellingIndex, correctionIndex);
      }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.getTotalResultsInGroup()"></seealso>
    public virtual String GetTotalResultsInGroup(int groupIdx)
    {
      checkInitialized();
      if (isAllOthersGroup(groupIdx))
      {
        return (String) m_currentResponse.GetTotalResultsNotInAnyGroup();
        }
      return m_currentResponse.GetTotalResultsInGroup(groupIdx);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
      // Release references to COM objects to allow them to be garbage 
      // collected as soon as possible
      /*createRequest=*/
      LegacyInit(false);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SearchResultModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.Drilldown()"></seealso>
    public virtual void Drilldown(String keyOnPage, String groupByField, int category)
    {
      restoreState(keyOnPage);
      // Sanity check: The key on the page should end with the group-by field
      // used to generate the page.  If not, something bad happened.
      if ((null == groupByField) || (0 == groupByField.Length) || (!XPStringUtility.EndsWith(keyOnPage,
       groupByField)))
      {
        throw new InvalidStateException(keyOnPage + " groupByField=" + groupByField);
        }
      // Go back to page one
      SetFirstPageAndPageSize();
      // Make sure the request still has the group-by setting used on the
      // page where the link was clicked - someone might have clicked "back"
      // after changing it
      m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
       groupByField);
      // .. and we need relevance ranking
      m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, 0);
      // Get the query to be ANDed with all previous queries
      IPTSearchQuery query;
      bool isAllOthers = isAllOthersGroup(category);
      if (isAllOthers)
      {
        query = m_currentResponse.GetQueryForAllOthers();
      } else
      {
        query = m_currentResponse.GetQueryForGroup(category);
      }
      String breadcrumb;
      if (isAllOthers)
      {
        breadcrumb = m_asOwner.GetString(520, "ptmsgs_portalinfrastructure");
        } else
      {
        breadcrumb = localizeObjectTypeName(m_currentResponse.GetGroupLabel(category));
        }
      // We need to cache the result of this search.
      // The new key equals the current key, plus a dot, plus the index of the
      // category we're drilling down into, plus a slash, plus the group-by setting.
      // indicates that the model is now uncategorized:
      //    /objtype  =>  /objtype.3/    or
      //    /objtype  =>  /objtype.3/ancestors
      String newKey = m_currentKey + "." + category + CACHE_KEY_SEPARATOR_STR + groupByField;
      doLegacySearch(query, breadcrumb, newKey);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchResultModelRO.GetError()"></seealso>
    public virtual SearchExecutionError GetError()
    {
      return m_error;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetFirstDisplayableItem"></seealso>
    public virtual int GetFirstDisplayableItem()
    {
      checkInitialized();
      return (m_currentResponse.GetSkipped() + 1);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetItemsPerPage"></seealso>
    public virtual int GetItemsPerPage()
    {
      checkInitialized();
      return m_pageSize;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetNumDisplayableItems"></seealso>
    public virtual int GetNumDisplayableItems()
    {
      checkInitialized();
      return m_currentResponse.GetResultsReturned();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.GetRemovableSettings()"></seealso>
    public virtual SearchSettingCollection GetRemovableSettings()
    {
      return m_removableSettings;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetItemsPerPage"></seealso>
    public virtual String GetSortOrder()
    {
      checkInitialized();
      int orderByProperty = 0;
      try
      {
        orderByProperty = m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY);
        }
      catch (Exception e)
      {
        rethrowCOMModelException(e);
      }
      return XPConvert.ToString(orderByProperty);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetTotalItems"></seealso>
    public virtual int GetTotalItems()
    {
      checkInitialized();
      return m_currentResponse.GetTotalMatches();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchResultModelRO.GetWarning()"></seealso>
    public virtual SearchExecutionWarning GetWarning()
    {
      return m_warning;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.RefreshResults()"></seealso>
    public virtual void RefreshResults(String keyOnPage)
    {
      // If the results were uncategorized (ungrouped)
      if (XPStringUtility.EndsWith(keyOnPage, CACHE_KEY_SEPARATOR_STR))
      {
        // Just call GoToPage() as if a pagination link were chosen
        GoToPage(XPConvert.ToString(m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY)),
         m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS) + 1,
         m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS),
         keyOnPage);
      } else
      {
        // Otherwise, if grouped, we need to call Reorganize() and recache the
        // result, since the generated categories may change.
        // Figure out what the last group-by field was.
        String lastGroupBy = GetLastGroupByFieldForKey(keyOnPage);
        // Go back to the way things were before the categorization occurred.
        restoreState(lastUncategorizedKey(keyOnPage));
        // _currentKey now contains the uncategorized key.
        Reorganize(m_currentKey, lastGroupBy);
      }
    }
    public virtual bool GetHasDisplayedObjects(int classID)
    {
      if (!m_initialized)
      {
        return false;
      }
      int num = GetNumDisplayableItems();
      for (int rank = 0;rank < num;rank++)
      {
        try
        {
          if (GetResultClassID(rank) == classID)
          {
            return true;
          }
        }
        catch (Exception e)
        {
          log.Error(e, "In GetHasDisplayedObjects: Invalid Rank? = " + rank + " PageSize=" + num);
          }
      }
      return false;
    }
    
    /// <summary>
    /// Same as GoToPage but only changes sort order.
    /// Called from SortOrderControl
    /// </summary>
    /// <param name="sortOrder"></param>
    /// <param name="additionalInfo"></param>
    public virtual void ChangeSortOrder(String sortOrder, Object additionalInfo)
    {
      String keyOnPage = (String) additionalInfo;
      try
      {
        restoreState(lastUncategorizedKey(keyOnPage));
        if (null == sortOrder)
        {
          throw new InvalidArgumentException("sortOrder", "null");
        }
        int orderByProp = 0;
        try
        {
          orderByProp = XPConvert.ToInteger(sortOrder);
        }
        catch (Exception e)
        {
          throw new InvalidArgumentException("sortOrder", sortOrder);
        }
        try
        {
          // Set the sort order
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY,
           orderByProp);
        }
        catch (Exception e)
        {
          SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
        }
        doLegacySearch(null, null, null);
      }
      catch (SearchExecutionWarning e)
      {
        this.SetWarning(e);
      }
      catch (SearchExecutionError e)
      {
        this.SetError(e);
      }
      catch (SearchExecutionException e)
      {
      }
    }
    // shouldn't happen; all instances should be an Error or Warning
    
    /// <seealso cref="com.plumtree.uiinfrastructure.pagination.IPagination#GoToPage"></seealso>
    public virtual void GoToPage(String sortOrder, int first, int pageSize,
     Object additionalInfo)
    {
      String keyOnPage = (String) additionalInfo;
      try
      {
        restoreState(lastUncategorizedKey(keyOnPage));
        if (first <= 0)
        {
          throw new InvalidArgumentException("first", XPConvert.ToString(first));
          }
        if (pageSize <= 0)
        {
          throw new InvalidArgumentException("pageSize", XPConvert.ToString(pageSize));
          }
        if (null == sortOrder)
        {
          throw new InvalidArgumentException("sortOrder", "null");
        }
        int orderByProp = 0;
        try
        {
          orderByProp = XPConvert.ToInteger(sortOrder);
        }
        catch (Exception e)
        {
          throw new InvalidArgumentException("sortOrder", sortOrder);
        }
        // Save the user's new desired page size
        m_pageSize = pageSize;
        try
        {
          // Set the new first result and page size on the request object
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS,
           first - 1);
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS,
           pageSize);
          // Set the sort order
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY,
           orderByProp);
          // Make sure we aren't grouped by any property; we don't support
          // pagination on grouped results
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
           "");
        }
        catch (Exception e)
        {
          SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
        }
        // Call doSearch to do the real work.
        // No new query or breadcrumb, and no need to save this response in the cache.
        if (m_isPathwaysSearch)
        {
          doPathwaysSearch(keyOnPage, null, null, null, null, sortOrder);
          } else
        {
          doLegacySearch(null, null, null);
        }
      }
      catch (SearchExecutionWarning e)
      {
        this.SetWarning(e);
      }
      catch (SearchExecutionError e)
      {
        this.SetError(e);
      }
      catch (SearchExecutionException e)
      {
        log.Error(e, "this should never happen");
      }
    }
    // shouldn't happen; all instances should be an Error or Warning
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_session = (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.isInitialized()"></seealso>
    public virtual bool IsInitialized()
    {
      return m_initialized;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.Reorganize"></seealso>
    public virtual void Reorganize(String keyOnPage, String groupByField)
    {
      restoreState(lastUncategorizedKey(keyOnPage));
      try
      {
        // Set the group-by field
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
         groupByField);
        if (!m_isPathwaysSearch)
        {
          // Make sure we're relevance ranked 
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY,
           0);
        }
      }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
      // Make sure we're on page one..
      SetFirstPageAndPageSize();
      // We need to cache the result of this search.
      // Note that the current key now ends with a slash, thanks to the
      // lastUncategorizedKey() call above.
      // The new key equals the current key up to and including the slash,
      // followed by the group-by field.
      // For example, if grouping by "ancestor":
      //   if currently not grouped,           /         =>  /ancestor
      //   if currently grouped by objtype,    /objtype  =>  /ancestor
      String newKey = m_currentKey + groupByField;
      // No new query or breadcrumb, but new key
      if (m_isPathwaysSearch)
      {
        doPathwaysSearch(keyOnPage, null, null, null, newKey, null);
      } else
      {
        doLegacySearch(null, null, newKey);
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.RestoreFromBreadcrumb()"></seealso>
    public virtual void RestoreFromBreadcrumb(String keyOfPageWhereLinkAppears,
     String keyToRestore)
    {
      restoreState(keyToRestore);
      // Clear any previous errors
      m_error = null;
      m_warning = null;
      try
      {
        // Restore the group-by and order-by settings to reasonable values.
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY,
         0);
        String groupby = GetLastGroupByFieldForKey(m_currentKey);
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
         groupby);
      }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
      // Rerun the search.
      // note: Earlier versions of this class just redisplayed the page using
      // the result set in _currentResponse (which the call to restoreState()
      // brought back).  But we can't be sure what the ORDERBY setting was when
      // that result set was generated, so it's safest to rerun the search
      // using relevance ranking.
      if (m_isPathwaysSearch)
      {
        doPathwaysSearch(null, null, null, null, keyToRestore, null);
      } else
      {
        /* no additional query */
        doLegacySearch(null, /* no additional breadcrumb */
        null, /* no new key */
        null);
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.Search()"></seealso>
    public virtual void Search(String searchString, String basicFields, IPTFilter advancedFilter,
     SearchSettingCollection settings)
    // only if basic search
    // only if advanced search
    {
      Search(searchString, basicFields, advancedFilter, settings, null);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.Search()">
    /// This function will determine what type of search this current request is (banner, advanced, federated, etc...) and will determine if it is a valid
    /// Pathways search request or legacy search request.  It will also handle any pathways server errors and execute a default Legacy search instead.
    /// </seealso>
    public virtual void Search(String searchString, String basicFields, IPTFilter advancedFilter,
     SearchSettingCollection settings, SearchSettingCollection removableSettings)
    // only if basic search
    // only if advanced search
    {
      /*
       * check if pathways is enabled
       */
       
      m_pathwaysRESTAPIService = PathwaysRestAPIService.GetInstance(m_asOwner);
      m_isPathwaysEnabled = m_pathwaysRESTAPIService.IsPathwaysEnabled();
      m_isAdaptiveLayoutMode = m_pathwaysRESTAPIService.IsAdaptiveLayoutMode();
      if (m_isPathwaysEnabled)
      {
        m_pathwaysHelperService = PathwaysHelperService.GetInstance();
        //we must always check if pathways has/had an error and if that timeout value has expired so we can try another pathways search request.
        m_isPathwaysInError = m_pathwaysHelperService.IsErrorState();
      }
      // Keep removable settings around for a Control to use later
      m_removableSettings = removableSettings;
      //we are checking to see if this is advanced search or banner search
      formData = m_asOwner.GetCurrentFormData();
      //  bug fix 9370276 - searching by document properties is not working properly
      //  We can figure out if a classid supports friendly urls, but it's hard to figure out what the class id is when friendly urls are turned on
      //  as friendly URLS don't always have the classid.
      //  Assume friendly urls are turned on, so we will check for the control via "control" param.  If it's empty, then we check for the unfriendly control
      String currentControl = HTTPHelpers.GetArgumentAsString(formData, FRIENDLY_CONTROL,
       "");
      if (currentControl.Equals(""))
      {
        currentControl = HTTPHelpers.GetArgumentAsString(formData, UNFRIENDLY_CONTROL,
         "");
      }
      String ADMIN_MODE = "admin";
      // we are checking to see if pathways is enabled and not in error
      // the below seems to work for making sure pathways isn't invoked for anything but a banner and advanced search
      if (m_isPathwaysEnabled && !m_isPathwaysInError)
      {
        // in the case that it is a) advanced search/banner search and 508 mode or it's b) pathways enabled
        // but adaptive layout mode turned OFF, this will result in the search defaulting to legacy search mode. 
        // Bannersearch would always result in a pathways search regardless of layout mode, if that is the functionality we
        // want then we just need to remove the accessstyle check.
        if (m_asOwner.GetAccessStyle().Equals(AccessStyles.STANDARD) && 
        //check for adaptive mode supported
        m_isAdaptiveLayoutMode && 
        //checks for banner search, advanced search, and saved search in standard mode
        (BANNER_SEARCH_CONTROL.Equals(currentControl) || (ReconstructSearchControl.STR_MVC_CLASS_NAME).Equals(currentControl) || ADVANCED_SEARCH_CONTROL.Equals(currentControl)) && 
        // Bug fix 8408676 - CANNOT RUN PATHWAYS ADVANCED SEARCH WHEN COMING FROM ADMINISTRATION 
        // checking to make sure that we're not in admin mode when we're doing a search, pathways does not return an object created property
        // for its search results.  We are also not supporting admin mode for Pathways search.
        !m_pageMode.Equals(ADMIN_MODE))
        {
          //checking to see if this is a valid pathways request
          if (isValidPathwaysSearch(settings, currentControl, advancedFilter))
          {
            try
            {
              pathwayslog.Debug("SearchResultModel.search():  initiating pathways search");
              SetUpPathwaysSearchRequest(searchString, basicFields, advancedFilter,
               settings, removableSettings);
            }
            catch (Exception ex)
            {
              //we are catching an exception here b/c Pathways server has returned an error of some sort, we are defaulting
              //the search to legacy now.
              pathwayslog.Error(ex, "SearchResultModel.search:: an exception occurred while trying to connect to the pathways" + "server, will use legacy search instead.");
              SetUpLegacySearchRequest(searchString, basicFields, advancedFilter,
               settings, removableSettings);
            }
          } else
          {
            //handles the fall back case when this current advanced search is not valid for pathways
            pathwayslog.Debug("SearchResultModel.search():  This search requires legacy search instead of Pathways");
            m_pathwaysHelperService.SetLegacySearchMode(true);
            SetUpLegacySearchRequest(searchString, basicFields, advancedFilter,
             settings, removableSettings);
          }
        } else
        {
          //this is not a banner, saved, or advanced search
          log.Debug("SearchResultModel.search():  initiating legacy search");
          SetUpLegacySearchRequest(searchString, basicFields, advancedFilter,
           settings, removableSettings);
        }
      } else
      {
        //pathways is not enabled or there was a Pathways server issue so we're using legacy
        log.Debug("SearchResultModel.search():  initiating legacy search");
        SetUpLegacySearchRequest(searchString, basicFields, advancedFilter,
         settings, removableSettings);
      }
      //Keep the filter around as well*/
      m_advancedFilter = advancedFilter;
    }
    
    /// <summary>
    /// Helper function for a Pathways search request.  This function is used to separate out the logic that would have been in the
    /// Search(str, str, IPTFilter, str,str) function to handle a pathways search request
    /// </summary>
    /// <param name="searchString">the search term</param>
    /// <param name="basicFields">the basic search field</param>
    /// <param name="advancedFilter">the advanced filter that is created via advanced search</param>
    /// <param name="settings">the settings collection of the search</param>
    /// <removableSettings>the settings to remove</removableSettings>
    public virtual void SetUpPathwaysSearchRequest(String searchString, String basicFields,
     IPTFilter advancedFilter, SearchSettingCollection settings, SearchSettingCollection removableSettings)
    // only if basic search
    // only if advanced search
    {
      //we are clearing all search results from the previous pathways search
      pathwaysReinit();
      if ((null == searchString) && (null == advancedFilter))
      {
        pathwayslog.Error(m_asOwner.GetString(536, "ptmsgs_portalinfrastructure"));
        throw new EmptyQueryException(m_asOwner);
      }
      // for banner search
      if (null != searchString)
      {
        // Save the initial search string, for display on the result page
        m_initialSearchString = searchString;
      } else
      {
        // For advanced search, if there is a top-level text search, save
        // it as the initial search string instead
        m_initialSearchString = advancedFilter.GetSearchString();
        // Don't keep around empty strings
        if ((null != m_initialSearchString) && (0 == m_initialSearchString.Length))
        {
          m_initialSearchString = null;
        }
        // If the user didn't provide a search string
        if (null == m_initialSearchString)
        {
          // Check that the filter has at least one property condition
          //This is where the search criteria settings are stored in advanced search, we will have
          //to use this to set the proper search criteria for pathways
          IPTPropertyFilterItem propFilter = advancedFilter.GetPropertyFilter();
          if (null == propFilter)
          {
            pathwayslog.Error(m_asOwner.GetString(536, "ptmsgs_portalinfrastructure"));
            throw new EmptyQueryException(m_asOwner);
          } else
          {
            if (0 == ((IPTPropertyFilterClauses) propFilter).GetCount())
            {
              pathwayslog.Error(m_asOwner.GetString(536, "ptmsgs_portalinfrastructure"));
              throw new EmptyQueryException(m_asOwner);
            }
          }
        }
        // Keep the filter around as well
        m_advancedFilter = advancedFilter;
      }
      // Keep removable settings around for a Control to use later
      m_removableSettings = removableSettings;
      try
      {
        // Bump up the counter of total searches
        // !!!TODO: David Pipes to rename this counter to ..._TOTAL_SEARCHES
        PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_SELECTION_SEARCHES);
        //this call will actually update the _request with all the search settings, ie:  advanced search has a bunch of filters and search criteria, this call
        //will iterate through the SearchSettingCollection and update the request object with these settings
        settings.updateRequest(m_request);
        // Manufacture the initial query
        if (null != advancedFilter)
        {
          // Remember that this is advanced search
          m_isAdvancedSearch = true;
          // Search-within-results queries always go against
          // the "cardsearch" alias
          m_swrFields = "cardsearch";
          m_disableInitChecking = true;
          //to support filtering, we are initializing this value here as banner search would have done so in SetPathwaysFilters
          m_pathwaysObjectTypes = new XPArrayList();
        } else
        {
          // Save fields for use by search-within-results
          m_swrFields = basicFields;
        }
      }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
      // Construct the initial key
      String initialKey = CACHE_KEY_SEPARATOR_STR;
      try
      {
        doPathwaysSearch(m_initialSearchString, advancedFilter, /*breadcrumb= */
        null, null, initialKey, null);
      }
      catch (SearchExecutionError ex)
      {
        throw new SearchExecutionError(ex.GetMessage());
      }
    }
    /*
     * Helper function for Legacy search request.  The content use to exist in Search(str, str, IPTFilter, str, str), but has been
     * refactored here for easy to see separation of the legacy search() code.
     */
     
    // only if basic search
    public virtual void SetUpLegacySearchRequest(String searchString, String basicFields,
     IPTFilter advancedFilter, SearchSettingCollection settings, SearchSettingCollection removableSettings)
    // only if advanced search
    {
      // Release references to any previous searches.
      // This is a brand-new search..
      /* createRequest= */
      LegacyInit(true);
      if ((null == searchString) && (null == advancedFilter))
      {
        throw new EmptyQueryException(m_asOwner);
      }
      // If this was a basic search
      if (null != searchString)
      {
        // Save the initial search string, for display on the result page
        m_initialSearchString = searchString;
      } else
      {
        // For advanced search, if there is a top-level text search, save
        // it as the initial search string instead
        m_initialSearchString = advancedFilter.GetSearchString();
        // Don't keep around empty strings
        if ((null != m_initialSearchString) && (0 == m_initialSearchString.Length))
        {
          m_initialSearchString = null;
        }
        // If the user didn't provide a search string
        if (null == m_initialSearchString)
        {
          // Check that the filter has at least one property condition
          IPTPropertyFilterItem propFilter = advancedFilter.GetPropertyFilter();
          if (null == propFilter)
          {
            throw new EmptyQueryException(m_asOwner);
          } else
          {
            if (0 == ((IPTPropertyFilterClauses) propFilter).GetCount())
            {
              throw new EmptyQueryException(m_asOwner);
            }
          }
        }
        // Keep the filter around as well
        m_advancedFilter = advancedFilter;
      }
      //TODO remove after testing
      //SetAdvancedPathwaysSearchCriteria(advancedFilter);
      // Keep removable settings around for a Control to use later
      m_removableSettings = removableSettings;
      IPTSearchQuery query = null;
      try
      {
        // Bump up the counter of total searches
        // !!!TODO: David Phipps to rename this counter to ..._TOTAL_SEARCHES
        PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_SELECTION_SEARCHES);
        // Set desired request settings
        settings.updateRequest(m_request);
        // Manufacture the initial query
        if (null != advancedFilter)
        {
          // Manufacture an advanced query given the supplied filter
          query = m_request.CreateAdvancedQuery(advancedFilter);
          // Remember that this is advanced search
          m_isAdvancedSearch = true;
          // Search-within-results queries always go against
          // the "cardsearch" alias
          m_swrFields = "cardsearch";
        } else
        {
          // Manufacture a basic query given the supplied search string
          query = m_request.CreateBasicQuery(searchString, basicFields);
          // Save fields for use by search-within-results
          m_swrFields = basicFields;
        }
        // Get the page size that is being used and save it
        // for convenient access later
        m_pageSize = m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS);
        // Keep the initial page's grouping setting around - if the user
        // clicks a breadcrumb link to undo a drilldown step, then we'll
        // need to know how to group the resulting page.
        m_initialGroupBy = m_request.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP);
        // .. but don't keep around any empty strings.
        if ((null != m_initialGroupBy) && (0 == m_initialGroupBy.Length))
        {
          m_initialGroupBy = null;
        }
        // Keep track of whether Best Bets will be used at all
        m_initialBestBets = XPConvert.ToBoolean(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS));
        }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
      // Make sure we're on the first page
      SetFirstPageAndPageSize();
      // Construct the initial key
      String initialKey = CACHE_KEY_SEPARATOR_STR;
      if (null != m_initialGroupBy)
      {
        initialKey+=m_initialGroupBy;
      }
      doLegacySearch(query, /* breadcrumb= */
      null, /* key= */
      initialKey);
    }
    /*
     * PathwaysSearchWithinResults, gets called from the SearchWithinResults() function
     * @param keyOnPage the cache key that keeps count of current search
     * @param additionalQuery is the next search query of 1+ previous search query
     */
     
    public virtual void PathwaysSearchWithinResults(String keyonPage, String additionalQuery)
    {
      /*
       * to search within a pathways result, pathways needs the additional search query appended to the query string
       * ie:  &query=(search1) and search2&xxxxx
       * So we will need to construct this new query value to pass into pathways to do a search.
       */
       
      // We need to cache the result of this search.
      // The new key is the current key up to the last slash, plus the
      // string "swr" and a unique index, plus a trailing slash that indicates
      // that the results are now uncategorized.
      int lastSlash = XPStringUtility.LastIndexOf(m_currentKey, CACHE_KEY_SEPARATOR_CHAR);
      String newKey = XPStringUtility.Substring(m_currentKey, 0, lastSlash + 1) + "swr" + m_swrCount + CACHE_KEY_SEPARATOR_CHAR;
      m_isPathwaysSearchWithinResults = true;
      // Call doPathwaysSearch to do the real work
      //need to set the breadcrumb value
      /*breadcrumb*/
      doPathwaysSearch(null, null, additionalQuery, additionalQuery, newKey,
       null);
    }
    public virtual void LegacySearchWithinResults(String keyonPage, String additionalQuery)
    {
      IPTSearchQuery query = null;
      try
      {
        // Make a new basic query given the string and the
        // set of fields that were used for the original search
        query = m_request.CreateBasicQuery(additionalQuery, m_swrFields);
        }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
      // We need to cache the result of this search.
      // The new key is the current key up to the last slash, plus the
      // string "swr" and a unique index, plus a trailing slash that indicates
      // that the results are now uncategorized.
      int lastSlash = XPStringUtility.LastIndexOf(m_currentKey, CACHE_KEY_SEPARATOR_CHAR);
      String newKey = XPStringUtility.Substring(m_currentKey, 0, lastSlash + 1) + "swr" + m_swrCount + CACHE_KEY_SEPARATOR_CHAR;
      // Call doSearch to do the real work
      /* breadcrumb= */
      doLegacySearch(query, additionalQuery, newKey);
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.SearchWithinResults()"></seealso>
    public virtual void SearchWithinResults(String keyOnPage, String additionalQuery)
    {
      restoreState(lastUncategorizedKey(keyOnPage));
      try
      {
        // Make sure we go to page one..
        SetFirstPageAndPageSize();
        // No categorization after doing search-within-results
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
         "");
        // .. and we want to order by relevance
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY,
         0);
      }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
      // Keep track of how many times we've done search-within-results
      m_swrCount++;
      if (m_isPathwaysSearch)
      {
        PathwaysSearchWithinResults(keyOnPage, additionalQuery);
      } else
      {
        LegacySearchWithinResults(keyOnPage, additionalQuery);
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.SetError()"></seealso>
    public virtual void SetError(SearchExecutionError e)
    {
      m_error = e;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModel.SetError()"></seealso>
    public virtual void SetWarning(SearchExecutionWarning e)
    {
      m_warning = e;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.ISearchResultModelRO.wasSpellCorrected()"></seealso>
    public virtual bool wasSpellCorrected()
    {
      checkInitialized();
      return (0 < GetNumMisspelledTokens());
    }
    /*
     * method needed to get the tag cloud item
     */
     
    protected virtual XPHashtable getPathwaysTagCloud()
    {
      checkInitialized();
      return m_pathwaysTagCloud;
    }
    
    /// <summary>
    /// doPathwaysSearch() will construct the calls to construct the REST API request and parse the response
    /// </summary>
    /// <param name="searchString">the query string to search with</param>
    /// <param name="advancedFilter">the advanced filter</param>
    /// <param name="additionalBreadcrumb">for the breadcrumb</param>
    /// <param name="additionalQuery">for the additional search query</param>
    /// <param name="String">newKey - used for drill down, key reminder of where we are in search</param>
    /// <param name="sortOrder">the sort order to sort results with</param>
    protected virtual void doPathwaysSearch(String searchString, IPTFilter advancedFilter,
     String additionalBreadcrumb, String additionalQuery, String newKey, String sortOrder)
    {
      try
      {
        // Clear any previous errors
        m_error = null;
        m_warning = null;
        PathwaysSearchResponse resp = null;
        PathwaysSearchRestData[] searchData = null;
        // If we're doing an initial query
        if (null == m_currentKey)
        {
          if (null == advancedFilter)
          {
            //setting object types to limit the search in pathways, we are getting constraints via the preferences of the user session
            SetPathwaysSearchConstraints(m_asOwner);
            int pageSize = m_bannerSearchHelper.GetIntSetting(m_session.GetSessionInfo(),
             "searchPageSize", DEFAULT_PAGE_SIZE);
            if (pageSize != DEFAULT_PAGE_SIZE)
            {
              m_pageSize = pageSize;
            }
            //TODO should really be reading the resultCount from the "searchresults preferences" editor		
            // TODO search prefs allows a sort by "relevence, last modified date" AND "folder (ancestors) and
            //object type (subtype).  Need to add support to sort these objects too.  ORDERBY should be:
            //sort by folder/ancestors = PATH
            //sort by object type/subtype = CONTENTTYPE
            String sortOrderValue = m_bannerSearchHelper.GetBannerSearchPreferenceSortOrder(m_asOwner);
            SetPathwaysNewSortOrder(sortOrderValue);
            //in pathwaysReinit(), we created a new PathwaysQueryArgument that set the default values of the query arguments
            //we're just setting the searchString now here, and pageSize b/c that could have changed.  The format, startAt, viewid,
            //don't change.  Order, OrderBy, and pathwaysObjectTypes have already been set as well.
            //setting page size
            m_pathwaysQueryArgument.SetResultCount(m_pageSize);
          } else
          //else we're doing advanced search
          {
            //advanced search result size
            int pageSize = m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS);
            if (pageSize != DEFAULT_PAGE_SIZE)
            {
              m_pageSize = pageSize;
            }
            m_pathwaysQueryArgument.SetResultCount(m_pageSize);
            //admin folders to restrict search to
            m_pathwaysQueryArgument.SetAdminFolders(GetAdminFolderRestrictions());
            //directory folders to restrict search to
            m_pathwaysQueryArgument.SetDirFolders(GetDocFolderRestrictions());
            //returns result types to constrain to for portal objects
            int[] advObjectTypes = GetObjectTypeRestrictions();
            //no need to check for null, as this should NEVER be empty b/c adv search editor checks
            SetAdvancedPathwaysSearchConstraints(advObjectTypes);
            //special property and search criteria
            SetAdvancedPathwaysSearchCriteria();
            //set that this is a pathways search
            m_pathwaysQueryArgument.SetIsAdvancedSearch(true);
            //TODO spellcheck, there is a global setting that we may need to resolve
            m_pathwaysQueryArgument.SetSpellCheck(((PathwaysSearchRequest) m_request).GetGlobalSpellingCheck(),
             XPConvert.ToBoolean(m_request.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK)));
            }
          //setting search string, common for banner and advanced search
          m_pathwaysQueryArgument.SetQuery(searchString);
          // TODO need to add verification of search data, if null, it means there were zero results returned
          searchData = m_pathwaysRESTAPIService.DoSearch(m_pathwaysQueryArgument);
          //setting totalCount of search results
          m_pathwaysQueryArgument.SetTotalCount(m_pathwaysRESTAPIService.GetTotalCount());
          resp = new PathwaysSearchResponse(searchData, m_pathwaysQueryArgument);
          //if we ever get a null response, there must have been some problem with the pathways search, will
          //throw error and it will default to a legacy search
          //currently, I'm testing for null data here, but we should really verify the searchData stuff, will need to see where that verification code is
          if (null == resp)
          {
            m_disableInitChecking = false;
            throw new SearchExecutionError("Received null value from PathwaysSearchRequest.doPathwaysSearch");
            }
        } else
        /*
         * we are handling follow up search, search within results, resorting of results, or filter by for banner search
         */
         
        {
          searchData = doFollowUpPathwaysSearch(searchString, advancedFilter,
           additionalBreadcrumb, additionalQuery, newKey, sortOrder);
          //TODO add code to check that the searchData is valid, otherwise, do NOT pass it in the resp into PathwaysSearchResponse
          resp = new PathwaysSearchResponse(searchData, m_pathwaysQueryArgument);
          }
        // If the caller supplied a cached search key
        if (null != newKey)
        {
          // We need to cache the query, breadcrumb, and response.
          //TODO comment why craig wrote this
          int lastSlash = XPStringUtility.LastIndexOf(newKey, CACHE_KEY_SEPARATOR_CHAR);
          String baseOfNewKey = XPStringUtility.Substring(newKey, 0, lastSlash + 1);
          //setback the search string to legacy new search value, we only changed it b/c we had to refactor the search keywords for 
          //pathways to search within results
          if (m_isPathwaysSearchWithinResults)
          {
            searchString = additionalQuery;
          }
          if (null != searchString)
          {
            m_queryCache.PutElement(newKey, searchString);
            // If this key is something like "/ancestors", and we haven't already
            // cached a query for "/", then cache this query under this name as well
            if ((!newKey.Equals(baseOfNewKey)) && (!m_queryCache.ContainsKey(baseOfNewKey)))
            {
              m_queryCache.PutElement(baseOfNewKey, searchString);
            }
          }
          if (null != additionalBreadcrumb)
          {
            m_crumbCache.PutElement(newKey, additionalBreadcrumb);
            // If this key is something like "/ancestors", and we haven't already
            // cached a breadcrumb for "/", then cache this query under this name as well
            if ((!newKey.Equals(baseOfNewKey)) && (!m_crumbCache.ContainsKey(baseOfNewKey)))
            {
              m_crumbCache.PutElement(baseOfNewKey, additionalBreadcrumb);
              }
          }
          m_responseCache.PutElement(newKey, (IPTSearchResponse) resp);
          m_currentKey = newKey;
        }
        // Keep the last key and response around for easy access
        m_currentResponse = (IPTSearchResponse) resp;
        /* This is for Unit tests only:  setting a copy of the response object to use in unit test */
        SetSearchResponseForUnitTest(m_currentResponse);
        // We have displayable results now
        m_initialized = true;
        m_disableInitChecking = false;
      }
      //checking/handling for an issue with connection to the pathways search server
      catch (Exception ex)
      {
        //pathways search service could be down, need to catch this error and default to legacy search
        pathwayslog.Error(ex, "SearchResultsModel::doPathwaysSearch()  A Pathways search exception occurred");
        m_pathwaysHelperService.StartErrorState();
        pathwayslog.Info("SearchResultModel.doPathwaysSearch::  pathways server connection issue occurred, will retry Pathways Search later.");
        throw new SearchExecutionError("pathways exception occurred");
      }
    }
    
    /// <summary>
    /// doFollowUpPathwaysSearch handles all actions of pathways search that is not the initial search request
    /// </summary>
    /// <param name="searchString">the query string to search with</param>
    /// <param name="advancedFilter">the advanced filter</param>
    /// <param name="additionalBreadcrumb">for the breadcrumb</param>
    /// <param name="additionalQuery">for the additional search query</param>
    /// <param name="String">newKey - used for drill down, key reminder of where we are in search</param>
    /// <param name="sortOrder">the sort order to sort results with</param>
    protected virtual PathwaysSearchRestData[] doFollowUpPathwaysSearch(String searchString,
     IPTFilter advancedFilter, String additionalBreadcrumb, String additionalQuery,
     String newKey, String sortOrder)
    {
      //keep a list of previous searches
      String[] ancestorKeys = allAncestors(m_currentKey);
      int numSearchQueries = ancestorKeys.Length;
      if (null != additionalQuery)
      {
        numSearchQueries++;
      }
      // construct a simple array of queries that be read from.
      Object[] queryHistory = new Object[numSearchQueries];
      //index of the last search term history; size of array - 1 = index of last search term
      int searchHistoryLengthIndex = queryHistory.Length - 1;
      for (int j = 0;j < ancestorKeys.Length;j++)
      {
        queryHistory[j] = m_queryCache.GetElement(ancestorKeys[j]);
      }
      if (null != additionalQuery)
      {
        queryHistory[searchHistoryLengthIndex] = additionalQuery;
      }
      try
      {
        //if the search string is not null, this means we're either doing a follow up search or Sorting by object.
        //Reorganize() calls this to resort, follow up search goes here b/c the _currentKey is no longer null
        //RestoreFromBreadCrumb() would hit this clause as well, it needs to execute a new search from the previous search term.
        //GoToPage() will send a sortOrder through, this is for pagination.  When the user clicks on a new page, GotoPage() passes in a new sort order
        //we need to execute the same previous search with the same sort order.
        //We could also have a situation where the results have been filtered by object, and we're paginating... when this happens, searchString = "" and
        //we need to set the sort order again.
        //search is being resorted by user
        if (null != sortOrder)
        {
          m_isPathwaysSortBy = true;
          //we need to handle the case for if this is a search within results search, to maintain the search terms
          if (m_isPathwaysSearchWithinResults)
          {
            //if we're in search within results, the search string needs to be maintained
            searchString = m_bannerSearchHelper.SetPathwaysSearchHistory(queryHistory);
            } else
          {
            searchString = XPConvert.ToString(queryHistory[searchHistoryLengthIndex]);
            }
          //set the new sort order if it's valid
          SetPathwaysNewSortOrder(sortOrder);
        } else
        //SearchWithResults/PathwaysSearchWithinResults() will hit this clause.  It needs to execute a new search within the search
        //results of the previous search.  Since Pathways can achieve this by AND'ing the searches together, I have to build the search string
        //in a new way.
        if (null != additionalQuery)
        {
          //ancestor array already added the additionalQuery, so we can pass in the whole thing
          searchString = m_bannerSearchHelper.SetPathwaysSearchHistory(queryHistory);
          } else
        //we are doing a filter by object, doesn't call sortOrder as we keep the original sort
        {
          //if we had executed a search within results, must reset the query string properly for pathways
          if (m_isPathwaysSearchWithinResults)
          {
            //we need to reconstruct the searchwithinresults query
            searchString = m_bannerSearchHelper.SetPathwaysSearchHistory(queryHistory);
            } else
          {
            //not an additional query, so we have to grab the last search value from the array
            searchString = XPConvert.ToString(queryHistory[searchHistoryLengthIndex]);
            }
        }
        //we must always reset the filters if a filter type was chosen by a user
        SetPathwaysFilters(m_isPathwaysFilterByType);
        //need to check for pagination, set the new first result and page size on the request object
        int skipValue = m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS);
        m_pageSize = m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS);
        //skipvalue + 1 = new startAt value to query for in pathways
        m_pathwaysStartAt = skipValue + 1;
        //setting the new values of the pathwaysQuery arguments
        m_pathwaysQueryArgument.SetStartAt(m_pathwaysStartAt);
        m_pathwaysQueryArgument.SetQuery(searchString);
        m_pathwaysQueryArgument.SetResultCount(m_pageSize);
        PathwaysSearchRestData[] searchData = m_pathwaysRESTAPIService.DoSearch(m_pathwaysQueryArgument);
        //setting totalCount of search results
        m_pathwaysQueryArgument.SetTotalCount(m_pathwaysRESTAPIService.GetTotalCount());
        return searchData;
      }
      catch (Exception e)
      {
        throw new XPException("error in followup pathways search:  " + e);
        }
    }
    
    /// <summary>
    /// doLegacySearch() actually calls the COM side to do the search;
    /// this is called from any method that has made a change to the
    /// _request object and needs to update the search results.
    /// doLegacySearch() also handles the various caches.
    /// </summary>
    protected virtual void doLegacySearch(IPTSearchQuery additionalQuery,
     String additionalBreadcrumb, String newKey)
    {
      // Clear any previous errors
      m_error = null;
      m_warning = null;
      IPTSearchResponse resp = null;
      // If we're doing an initial query
      if (null == m_currentKey)
      {
        // Use Best Bets if and only if we are relevance ranked and have no group-by.  (See bug 42054.)
        if (m_initialBestBets && (0 == m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY)) && ((null == m_request.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP)) || (0 == m_request.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP).Length)))
        {
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS,
           true);
        } else
        {
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS,
           false);
        }
        // call Search()
        try
        {
          resp = m_request.Search(additionalQuery);
        }
        catch (Exception e)
        {
          SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
        }
        if (null == resp)
        {
          // Something went wrong on the COM side
          throw new SearchExecutionError("Received null pointer from IPTSearchRequest.Search");
          }
      } else
      {
        String[] ancestorKeys = allAncestors(m_currentKey);
        int numQueries = ancestorKeys.Length;
        if (null != additionalQuery)
        {
          numQueries++;
        }
        // Use Best Bets if and only if we are relevance ranked and have no group-by or drilldown.  (See bug 42054.)
        if (m_initialBestBets && (1 == numQueries) && (0 == m_request.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY)) && ((null == m_request.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP)) || (0 == m_request.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP).Length)))
        {
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS,
           true);
        } else
        {
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS,
           false);
        }
        // construct a simple array of queries that can be unpacked on the COM side
        Object[] queryArray = new Object[numQueries];
        for (int j = 0;j < ancestorKeys.Length;j++)
        {
          queryArray[j] = m_queryCache.GetElement(ancestorKeys[j]);
        }
        if (null != additionalQuery)
        {
          queryArray[queryArray.Length - 1] = additionalQuery;
        }
        // (bit of a hack..)
        // If we're in "object type" categorization and have already drilled down
        // into a single object type category, categorize on Collab types this time..
        // this will do no good if the drilldown wasn't into the "Collab Server Objects"
        // category, but will do no harm, either..
        bool needToRestoreGroupByObjectType = false;
        {
          String currGroupBy = m_request.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP);
          if (((null != currGroupBy) && (currGroupBy.Equals(GROUPBY_OBJECTTYPE))) && (firstDrilldownIsIntoCollabCategory(newKey)))
          {
            m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
             "collab_type");
            needToRestoreGroupByObjectType = true;
          }
        }
        // call FollowupSearch() to AND the queries together on the COM side
        try
        {
          resp = m_request.FollowupSearch(queryArray);
        }
        catch (Exception e)
        {
          SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
        }
        // restore group-by setting if necessary
        if (needToRestoreGroupByObjectType)
        {
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
           GROUPBY_OBJECTTYPE);
        }
        if (null == resp)
        {
          // Something went wrong on the COM side
          throw new SearchExecutionError("Received null pointer from IPTSearchRequest.FollowupSearch ( submitted " + queryArray.Length + " queries)");
          }
      }
      // Now that the search has run, unset the INITIALSEARCHSTRING setting,
      // to be sure it is only logged once per sequence of searches
      m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING,
       "");
      // If the caller supplied a key
      if (null != newKey)
      {
        // We need to cache the query, breadcrumb, and response.
        int lastSlash = XPStringUtility.LastIndexOf(newKey, CACHE_KEY_SEPARATOR_CHAR);
        String baseOfNewKey = XPStringUtility.Substring(newKey, 0, lastSlash + 1);
        if (null != additionalQuery)
        {
          m_queryCache.PutElement(newKey, additionalQuery);
          // If this key is something like "/ancestors", and we haven't already
          // cached a query for "/", then cache this query under this name as well
          if ((!newKey.Equals(baseOfNewKey)) && (!m_queryCache.ContainsKey(baseOfNewKey)))
          {
            m_queryCache.PutElement(baseOfNewKey, additionalQuery);
          }
        }
        if (null != additionalBreadcrumb)
        {
          m_crumbCache.PutElement(newKey, additionalBreadcrumb);
          // If this key is something like "/ancestors", and we haven't already
          // cached a breadcrumb for "/", then cache this query under this name as well
          if ((!newKey.Equals(baseOfNewKey)) && (!m_crumbCache.ContainsKey(baseOfNewKey)))
          {
            m_crumbCache.PutElement(baseOfNewKey, additionalBreadcrumb);
          }
        }
        m_responseCache.PutElement(newKey, resp);
        m_currentKey = newKey;
      }
      // Keep the last key and response around for easy access
      m_currentResponse = resp;
      // Check for warnings
      int warning = m_currentResponse.GetWarning();
      if (PT_SEARCH_WARNING.PT_SEARCHWARNING_NONE != warning)
      {
        switch (warning){
        case PT_SEARCH_WARNING.PT_SEARCHWARNING_QUERY_TIMED_OUT:
        m_warning = new QueryTimeoutWarning(m_asOwner);
        break;
        case PT_SEARCH_WARNING.PT_SEARCHWARNING_WILDCARD_TOO_GENERAL:
        m_warning = new WildcardExpansionWarning(m_asOwner);
        break;
        case PT_SEARCH_WARNING.PT_SEARCHWARNING_QUERY_IS_PARTIAL:
        m_warning = new PartialQueryWarning(m_asOwner);
        break;
        }
      }
      /* This is for Unit tests only:  setting a copy of the response object to use in unit test */
      SetSearchResponseForUnitTest(resp);
      // We have displayable results now
      m_initialized = true;
    }
    
    /// <summary>
    /// Helper method to convert an indexed object type or abstract
    /// type to its localized equivalent
    /// </summary>
    protected virtual String localizeObjectTypeName(String objType)
    {
      // check for bad input first
      if ((null == objType) || (0 == objType.Length))
      {
        return objType;
      }
      // first, check for Collab types.. these are always 1 or 2 characters
      if (objType.Length <= 2)
      {
        // see if it's an integer
        int collabTypeId = 0;
        try
        {
          collabTypeId = XPConvert.ToInteger(objType);
        }
        catch (Exception e)
        {
          collabTypeId = 0;
        }
        // Note that "ptmsgs_collabserverobjecttypes.xml" contains the user-facing
        // names of the Collab types, and the IDs of strings in that file correspond
        // to the same values as the collab_type field.  We just need to make sure
        // the values are reasonable..
        if (0 != collabTypeId)
        {
          return m_asOwner.GetString(collabTypeId, "ptmsgs_collabserverobjecttypes");
          }
      }
      // now, if it doesn't start with "PT", it's not something we know about
      if (!XPStringUtility.StartsWith(objType, "PT"))
      {
        return objType;
      }
      // This list needs to remain consistent with the 
      // list in PTIndexer.cpp, TypeStringFromClassID()
      if (objType.Equals("PTUSER"))
      {
        return m_asOwner.GetString(298, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTGROUP"))
      {
        return m_asOwner.GetString(299, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTAUTHSOURCE"))
      {
        return m_asOwner.GetString(300, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTPROFILESOURCE"))
      {
        return m_asOwner.GetString(301, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTFOLDER"))
      {
        return m_asOwner.GetString(297, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTCARD"))
      {
        return m_asOwner.GetString(296, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTADMINFOLDER"))
      {
        return m_asOwner.GetString(302, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTFILTER"))
      {
        return m_asOwner.GetString(303, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTSAVEDSEARCH"))
      {
        return m_asOwner.GetString(304, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTDATASOURCE"))
      {
        return m_asOwner.GetString(305, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTCARDPROPERTY"))
      {
        return m_asOwner.GetString(306, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTDOCUMENTTYPE"))
      {
        return m_asOwner.GetString(307, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTCRAWLER"))
      {
        return m_asOwner.GetString(308, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTGADGET"))
      {
        return m_asOwner.GetString(309, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTINVITATION"))
      {
        return m_asOwner.GetString(310, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTFEDPORTAL"))
      {
        return m_asOwner.GetString(470, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTGADGETSERVER"))
      {
        return m_asOwner.GetString(312, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTCOMMTEMPLATE"))
      {
        return m_asOwner.GetString(313, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTGADGETBUNDLE"))
      {
        return m_asOwner.GetString(314, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTPAGETEMPLATE"))
      {
        return m_asOwner.GetString(315, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTWEBSERVICE"))
      {
        return m_asOwner.GetString(316, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTEXTOPERATION"))
      {
        return m_asOwner.GetString(317, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTGADGETTEMPLATE"))
      {
        return m_asOwner.GetString(318, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTJOB"))
      {
        return m_asOwner.GetString(319, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTCOMMUNITY"))
      {
        return m_asOwner.GetString(320, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTPAGE"))
      {
        return m_asOwner.GetString(505, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTSITEMAP"))
      {
        return m_asOwner.GetString(321, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTSUBPORTAL"))
      {
        return m_asOwner.GetString(519, "ptmsgs_portalinfrastructure");
      }
      //if (objType.equals("PTSYNDICATED")) return _ui_PTSYNDICATED;
      //if (objType.equals("PTSYNDGADGET")) return _ui_PTSYNDGADGET;
      if (objType.Equals("PTCOLLAB"))
      {
        return m_asOwner.GetString(323, "ptmsgs_portalinfrastructure");
      }
      if (objType.Equals("PTCONTENT"))
      {
        return m_asOwner.GetString(322, "ptmsgs_portalinfrastructure");
      }
      return objType;
    }
    
    /// <summary>
    /// If the user's hit the BACK button before clicking a link, this
    /// method restores our state to the way things were on the page
    /// where the user clicked the button.
    /// </summary>
    protected virtual void restoreState(String keyOnPage)
    {
      // If we're not even initialized yet
      if ((!m_initialized) || (null == m_currentKey) || (null == m_responseCache))
      {
        throw new InvalidStateException(keyOnPage);
      }
      // If BACK button wasn't hit
      if (keyOnPage.Equals(m_currentKey))
      {
        return;
      }
      // Fetch the response on the page where the link was selected
      if (m_isPathwaysSearch)
      {
        IPTSearchResponse r = (IPTSearchResponse) m_responseCache.GetElement(keyOnPage);
        m_currentResponse = (IPTSearchResponse) r;
      } else
      {
        IPTSearchResponse r = (IPTSearchResponse) m_responseCache.GetElement(keyOnPage);
        m_currentResponse = r;
      }
      // NOTE: r may be null if this search was never run; the caller should
      // be able to handle this case!
      // Restore state
      m_currentKey = keyOnPage;
      // Restore group-by settings to their former state
      int lastSlash = XPStringUtility.LastIndexOf(m_currentKey, CACHE_KEY_SEPARATOR_CHAR);
      String groupByField = XPStringUtility.Substring(m_currentKey, lastSlash + 1);
      try
      {
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
         groupByField);
      }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
    }
    
    /// <param name="args"></param>
    /// <param name="prefix"></param>
    /// <param name="wantSettingsArgs"></param>
    /// <param name="includedSettings"></param>
    /// <param name="excludedSettings"></param>
    /// <param name="wantQueryArgs"></param>
    /// <throws>SearchModelException </throws>
    private void internalGetArgs(XPHashtable args, String prefix, bool wantSettingsArgs,
     IXPCollection includedSettings, IXPCollection excludedSettings, bool wantQueryArgs)
    {
      // Encode user's query.
      if (wantQueryArgs)
      {
        if (null != m_advancedFilter)
        {
          FilterForm.EncodeFilterAsControlArgs(m_session, m_asOwner, m_advancedFilter,
           args, prefix);
        } else
        {
          if (null != m_initialSearchString)
          {
            args.PutElement(prefix + SearchResultControl.USER_QUERY, new String[]{m_initialSearchString});
            }
          if (null != m_swrFields)
          {
            args.PutElement(prefix + SearchResultControl.BASIC_FIELDS, new String[]{m_swrFields});
            }
        }
      }
      if (wantSettingsArgs)
      {
        // Encode search settings.
        try
        {
          SearchSettingCollection.encodeRequestSettings(m_request, args, prefix,
           includedSettings, excludedSettings);
        }
        catch (Exception e)
        {
          rethrowCOMModelException(e);
        }
      }
    }
    
    /// <param name="o"></param>
    /// <returns></returns>
    private int[] objectArrayToIntArray(Object o)
    {
      if (null == o)
      {
        return null;
      }
      Object[] oa = (Object[]) o;
      if (0 == oa.Length)
      {
        return null;
      }
      int[] ia = new int[oa.Length];
      for (int j = 0;j < oa.Length;j++)
      {
        ia[j] = XPConvert.ToInteger(oa[j]);
      }
      return ia;
    }
    /*
     * as noted below, the 4.0 collab gadget id is a negative number.
     * Created a helper class based on IEnsembleHelper to grab the collab information that pathways needs, we could have possibly got this
     * information by parsing the URL of a collab item, but this was needed to get a consistent gateway URL for collab items
     */
     
    private int GetPathwaysCollabPortletOrWebServiceID()
    {
      m_pathwaysCollabHelper = CollaborationHelperService.getInstance();
      int collabWebServiceID = m_pathwaysCollabHelper.GetWebServiceID(m_session);
      if (collabWebServiceID != -1)
      {
        //we return a negative value, since that's what collab 4.0 would have returned.
        return -collabWebServiceID;
      } else
      {
        //there is no service under that name, throw error, although we should not get to this point.
        const String BAD_COLLAB_MESSAGE = "Got invalid Collab portlet or webservice ID.  For Collab 3.0, complete Collab installation by using the Project Selector portlet to open a project.  For Collab 4.0, visit the Collaboration Server Administration utility, which should automatically fix this problem.  If these steps do not solve the problem, check for Collab installer errors or an incorrect Collab configuration.";
        log.Error(BAD_COLLAB_MESSAGE);
        throw new XPException(BAD_COLLAB_MESSAGE);
      }
    }
    
    /// <summary>
    /// Returns a portlet or web service ID to be used in gatewaying any Collab Server
    /// search results.
    /// This ID is the same for all Collab results in the system.
    /// Under the covers, the portal server is doing a query against the Collab database
    /// to get this ID (and caching it; the query is done only once).  Collab 3.0 returns
    /// a positive number that corresponds to a portlet ID; Collab 4.0 returns a negative
    /// number corresponding to (-1 *) a web service ID.
    /// Callers of this function must be prepared to handle both cases!
    /// </summary>
    private int GetCollabPortletOrWebServiceID()
    {
      if (m_isPathwaysSearch)
      {
        return GetPathwaysCollabPortletOrWebServiceID();
      } else
      //this is legacy search
      {
        int id = -1;
        // The rank doesn't matter here; this is just a constant that's the same
        // for all results.
        String s = m_currentResponse.GetResultInternalField(0, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_COLLAB_PORTLET_ID);
        try
        {
          id = XPConvert.ToInteger(s);
        }
        catch (Exception e)
        {
          const String BAD_COLLAB_MESSAGE = "Got invalid Collab portlet or webservice ID.  For Collab 3.0, complete Collab installation by using the Project Selector portlet to open a project.  For Collab 4.0, visit the Collaboration Server Administration utility, which should automatically fix this problem.  If these steps do not solve the problem, check for Collab installer errors or an incorrect Collab configuration.";
          log.Error(e, BAD_COLLAB_MESSAGE);
          throw new XPException(BAD_COLLAB_MESSAGE);
        }
        return id;
      }
    }
    /*
     * this will parse the collab URL from the url being passed in, which is the document url
     * @param url = collab search result <URL> property from pathways result set
     */
     
    private String GetPathwaysCollabURLPrefix(String collabURL)
    {
      //the collab search content <URL> contains the URL to collab that we need to set as the 
      //collab URL prefix.  It returns a gateway url, so we must grab the url after the gateway info
      int startIndex = XPStringUtility.IndexOf(collabURL, "http;");
      collabURL = XPStringUtility.Substring(collabURL, startIndex);
      //replace the beginning http; that gateway returns to http://
      collabURL = collabURL.Replace("http;/", "http://");
      //replace the semicolons with colons
      collabURL = collabURL.Replace(";", ":");
      return collabURL;
    }
    // This is the same for all Collab results.
    private String GetCollabURLPrefix()
    {
      // The rank doesn't matter here; this is just a constant that's the same
      // for all results.
      return m_currentResponse.GetResultInternalField(0, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_COLLAB_URL_PREFIX);
      }
    
    /// <summary>
    /// Helper function to tell the request object to go to
    /// the first page; should call this when any conditions are
    /// added to the search
    /// </summary>
    private void SetFirstPageAndPageSize()
    {
      try
      {
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS,
         0);
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS,
         m_pageSize);
      }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
    }
    
    /// <param name="key"></param>
    /// <returns></returns>
    private String GetLastGroupByFieldForKey(String key)
    {
      int lastSlash = XPStringUtility.LastIndexOf(key, CACHE_KEY_SEPARATOR_CHAR);
      // If the key ends with a slash
      if (lastSlash == key.Length)
      {
        return "";
      } else
      {
        // The group-by field is everything following the slash
        return XPStringUtility.Substring(key, lastSlash + 1);
      }
    }
    
    /// <summary>
    /// Helper method to return all ancestor keys for a key.
    /// </summary>
    private String[] allAncestors(String key)
    {
      XPStringTokenizer tok = new XPStringTokenizer(key, CACHE_KEY_SEPARATOR_STR,
       false);
      int numAncestors = tok.GetTokenCount();
      if (XPStringUtility.EndsWith(key, CACHE_KEY_SEPARATOR_STR))
      {
        numAncestors++;
      }
      String[] result = new String[numAncestors];
      result[0] = CACHE_KEY_SEPARATOR_STR;
      for (int j = 1;j < numAncestors;j++)
      {
        result[j] = result[j - 1] + tok.GetNextToken() + CACHE_KEY_SEPARATOR_STR;
        }
      return result;
    }
    
    /// <summary>
    /// Helper method to break a key into its ancestor keys,
    /// and return a single ancestor at the indicated depth.
    /// For example, if the key is "/subtype.3/ancestor.4/swr1/"
    /// then ancestorKey(key, 0) == "/"
    /// ancestorKey(key, 1) == "/subtype.3/"
    /// ancestorKey(key, 2) == "/subtype.3/ancestor.4/"
    /// </summary>
    private String ancestorKey(String key, int depth)
    {
      XPStringTokenizer tok = new XPStringTokenizer(key, CACHE_KEY_SEPARATOR_STR,
       false);
      String result = CACHE_KEY_SEPARATOR_STR;
      for (int j = 0;j < depth;j++)
      {
        if (!tok.HasMoreTokens())
        {
          throw new ArgumentBoundsException("key", depth);
        }
        result+=(tok.GetNextToken() + CACHE_KEY_SEPARATOR_STR);
      }
      return result;
    }
    
    /// <summary>
    /// Convenience method to check whether the search has been run
    /// yet
    /// </summary>
    private void checkInitialized()
    {
      /* Pathways needs to construct the filters from IPTFilters for advanced search before it executes the search
       * since this model class has all the functions that will return the filter items necessary, for example, GetASConstraintOperator()
       * I am setting a special boolean flag that will allow pathways advanced search to use all the functions before
       * the search actually gets executed, it will be reset to false so that the rest of the original code still works as intended
       * this is pretty awful, but until you can come up with a better solution, this is the way to go as you'd have to
       * duplicate code anyways*/
       
      if (m_disableInitChecking)
      {
      } else
      //do nothing, we just don't want to throw an error
      if (!m_initialized)
      {
        throw new NotInitializedException();
      }
    }
    
    /// <summary>
    /// Helper method to return the last uncategorized key before the
    /// given key, i.e.
    /// /subtype => /
    /// /subtype.0/ancestors => /subtype.0/
    /// </summary>
    private String lastUncategorizedKey(String key)
    {
      if (XPStringUtility.EndsWith(key, CACHE_KEY_SEPARATOR_STR))
      {
        return key;
      }
      int lastSlash = XPStringUtility.LastIndexOf(key, CACHE_KEY_SEPARATOR_CHAR);
      return XPStringUtility.Substring(key, 0, lastSlash + 1);
    }
    
    /// <summary>
    /// Clears out any results from previous pathways searches
    /// This code was copied from Init(boolean) as it was what legacy search used to clear and initialize all the constants
    /// for legacy search.  I am reusing everything at the moment b/c i don't know what we can discount.  Until we add advanced
    /// search, everything is going to be kept the same.
    /// </summary>
    private void pathwaysReinit()
    {
      m_initialized = false;
      // No search string or filter yet.
      m_initialSearchString = null;
      m_initialBestBets = false;
      m_advancedFilter = null;
      // default is pathways search
      m_isAdvancedSearch = false;
      m_isPathwaysSearch = true;
      // Default number of results per page for banner search and advanced search
      m_pageSize = 10;
      // No search within results
      m_swrCount = 0;
      // No error state.
      m_error = null;
      m_warning = null;
      // If there are any old cached responses, call their Clear() methods
      // to release memory ASAP, in case garbage collection doesn't run for
      // a long time.
      if (null != m_responseCache)
      {
        IXPEnumerator e = m_responseCache.GetElements();
        while (e.MoveNext())
        {
          PathwaysSearchResponse r = (PathwaysSearchResponse) e.GetCurrent();
          r.Clear();
        }
      }
      // Initialize caches.
      m_queryCache = new XPHashtable();
      m_crumbCache = new XPHashtable();
      m_responseCache = new XPHashtable();
      // No search yet, so current key and response are null
      m_currentKey = null;
      m_currentResponse = null;
      // No removable settings
      m_removableSettings = null;
      m_bannerSearchHelper = BannerSearchHelperService.GetInstance();
      m_pathwaysQueryArgument = new PathwaysQueryArguments(m_pathwaysFormat,
       m_pathwaysOrder, m_pathwaysOrderBy, m_pathwaysStartAt, m_pathwaysViewId,
       null, m_pageSize, m_pathwaysObjectTypes);
      try
      {
        InternalSession m_InternalSession = ((IInternalPTSession) m_session).GetInternalSession();
        m_request = (IPTSearchRequest) new PathwaysSearchRequest(m_InternalSession,
         m_pathwaysQueryArgument);
        // Initialize the global "max number of drilldown groups" setting, using the
        // helper function in ReorganizationViewHelper.
        int maxNumGroups = ReorganizationViewHelper.GetMaxNumGroups();
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXNUMGROUPS,
         maxNumGroups);
      }
      catch (Exception e)
      {
        SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
      }
    }
    
    /// <summary>
    /// Clear out any results from previous searches
    /// </summary>
    private void LegacyInit(bool createRequest)
    {
      m_initialized = false;
      // No search string or filter yet.
      m_initialSearchString = null;
      m_initialBestBets = false;
      m_advancedFilter = null;
      // Default is basic search.
      m_isAdvancedSearch = false;
      // this is not a pathways search, setting to false
      m_isPathwaysSearch = false;
      // Default number of results per page.
      m_pageSize = 20;
      // No search within results
      m_swrCount = 0;
      // No error state.
      m_error = null;
      m_warning = null;
      // If there are any old cached responses, call their Clear() methods
      // to release memory ASAP, in case garbage collection doesn't run for
      // a long time.
      if (null != m_responseCache)
      {
        IXPEnumerator e = m_responseCache.GetElements();
        while (e.MoveNext())
        {
          IPTSearchResponse r = (IPTSearchResponse) e.GetCurrent();
          r.Clear();
        }
      }
      // Initialize caches.
      m_queryCache = new XPHashtable();
      m_crumbCache = new XPHashtable();
      m_responseCache = new XPHashtable();
      // No search yet, so current key and response are null
      m_currentKey = null;
      m_currentResponse = null;
      // No removable settings
      m_removableSettings = null;
      if (createRequest)
      {
        // Get the IPTSearchRequest we'll use for searches.
        try
        {
          m_request = m_session.GetSearchRequest();
          // Since this will always be an end-user search from some page in the
          // UI, use the short (30 second) timeout instead of the default 10-minute.
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_USE_SHORT_TIMEOUT,
           true);
          // Initialize the global "max number of drilldown groups" setting, using the
          // helper function in ReorganizationViewHelper.
          int maxNumGroups = ReorganizationViewHelper.GetMaxNumGroups();
          m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXNUMGROUPS,
           maxNumGroups);
        }
        catch (Exception e)
        {
          SearchUIUtility.RethrowCOMExecutionException(e, m_asOwner);
        }
      }
    }
    
    /// <summary>
    /// Helper method to translate and rethrow a COM exception as
    /// a SearchModelException
    /// </summary>
    private void rethrowCOMModelException(Exception e)
    {
      log.Error(e, e.Message);
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append(m_asOwner.GetString(345, "ptmsgs_portalinfrastructure"));
      sb.Append(e.Message);
      throw new SearchModelException(sb.ToString());
    }
    public static XPDateTime ConvertSearchDateTimeToXPDateTime(double searchTime)
    {
      // PTSearch indexes date/times as minutes since 2000/01/01 00:00:00 UTC.
      // XPDateTime wants milliseconds since 1970/01/01 00:00:00 UTC.
      long msec2000 = (long) (searchTime * 60000.0);
      long msec1970 = msec2000 + 946684800000L;
      return new XPDateTime(msec1970);
    }
    public virtual XPDateFormat GetDateFormat(AActivitySpace owner)
    {
      XPLocale xpLocale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(owner);
      XPTimeZone xpTimeZone = PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(owner);
      return XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT, XPDateFormat.SHORT,
       xpLocale, xpTimeZone);
    }
    public virtual void Filter(String key, int filterId)
    {
      restoreState(lastUncategorizedKey(key));
      // Go back to page one
      SetFirstPageAndPageSize();
      // add filter to search request
      /*no filter*/
      if (filterId < 0)
      {
        ClearFilterOnSearch();
      } else
      if (filterId < SearchObjectTypes.MIN_SPECIAL_CLASSID_VALUE)
      {
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
         new int[]{filterId});
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES,
         0);
      } else
      if (filterId == SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE)
      {
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
         new int[]{});
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT);
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES,
         0);
      } else
      if (filterId == SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE)
      {
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
         new int[]{});
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB);
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES,
         0);
      } else
      if (filterId > SearchObjectTypes.MIN_SPECIAL_CLASSID_VALUE)
      {
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
         new int[]{});
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, 0);
        m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES,
         filterId);
      }
      if (m_isPathwaysSearch)
      {
        m_isPathwaysFilterByType = true;
        doPathwaysSearch(null, null, null, null, null, null);
      } else
      {
        doLegacySearch(null, null, null);
      }
    }
    private void ClearFilterOnSearch()
    {
      int maxToDisplay = SearchObjectTypes.ENDUSERCOUNT;
      bool bShouldDisplayAdminObjects = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      if (bShouldDisplayAdminObjects && isAdvancedSearch())
      {
        maxToDisplay = SearchObjectTypes.DETAILEDCOUNT;
      }
      int[] searchObjectTypes = SearchObjectTypes.GetOrderedSearchObjectTypes();
      XPArrayList xpObjectTypes = new XPArrayList();
      bool searchPortal = false;
      bool searchContent = false;
      bool searchCollab = false;
      for (int i = 0;i < maxToDisplay;i+=1)
      {
        if (searchObjectTypes[i] < SearchObjectTypes.MIN_SPECIAL_CLASSID_VALUE)
        {
          xpObjectTypes.Add(XPConvert.ToString(searchObjectTypes[i]));
          searchPortal = true;
        } else
        if (searchObjectTypes[i] == SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE)
        {
          searchContent = ContentInstalled();
        } else
        if (searchObjectTypes[i] == SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE)
        {
          searchCollab = CollabInstalled();
        }
      }
      int[] arrObjectTypes = new int[xpObjectTypes.GetSize()];
      for (int i = 0;i < xpObjectTypes.GetSize();i+=1)
      {
        arrObjectTypes[i] = XPConvert.ToInteger(xpObjectTypes.GetElement(i));
        }
      // Finally, add the application constraint
      int apps = 0;
      if (searchPortal)
      {
        apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL;
      }
      if (searchCollab)
      {
        apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB;
      }
      if (searchContent)
      {
        apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT;
      }
      m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, arrObjectTypes);
      m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, apps);
      m_request.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES, 0);
      }
    public virtual bool ContentInstalled()
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTServerConfigSettings ptSC = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      int setting2 = ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_CONTENT_SERVER_INSTALLED);
      return (setting2 == 1);
    }
    public virtual bool CollabInstalled()
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTServerConfigSettings ptSC = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      int set = ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_COLLAB_SERVER_INSTALLED);
      return (set == 1);
    }
    public virtual int GetSelectedTypeFilter()
    {
      int selectedFilter = -1;
      int[] objTypefilter = GetObjectTypeRestrictions();
      int abstractFilter = GetAbstractTypeRestrictions();
      int appFilter = GetApplicationRestrictions();
      if (null != objTypefilter && objTypefilter.Length == 1)
      {
        selectedFilter = objTypefilter[0];
      } else
      if (abstractFilter > 0)
      {
        selectedFilter = abstractFilter;
      } else
      if (appFilter == PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT)
      {
        selectedFilter = SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE;
        } else
      if (appFilter == PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB)
      {
        selectedFilter = SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE;
        }
      return selectedFilter;
    }
    
    /// <summary>
    /// getTags method to get tags from pathways search result
    /// </summary>
    /// <param name="rank">search result item number</param>
    public virtual PathwaysTagRestData[] GetPathwaysResultTags(int rank)
    {
      PathwaysSearchResponse currResponse = (PathwaysSearchResponse) m_currentResponse;
      PathwaysTagRestData[] tags = currResponse.getSearchResultsTagData(rank);
      return tags;
    }
    
    /// <summary>
    /// Not used in SearchResultModel
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#GetObjectTags(int)"></seealso>
    public virtual IXPList GetObjectTags(int rank)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#AddRemoveObjectTag(java.lang.String,java.lang.String,int,String)"></seealso>
    public virtual void AddRemoveObjectTag(String tagname, String strid, int action,
     String ptsource)
    {
      IPathwaysRestAPIService svcPathwaysRest = PathwaysRestAPIService.GetInstance(m_asOwner);
      if (svcPathwaysRest.IsPathwaysEnabled())
      {
        try
        {
          svcPathwaysRest.AddRemoveTagRest(tagname, strid, action, ptsource);
          }
        catch (Exception e)
        {
          m_taggingError = new XPException("An Exception occured while making REST request to Add/Remove Tag",
           e);
        }
      } else
      {
        throw new XPIllegalStateException("Failed to Send Add/Remove Tag REST request to Pathways, it is not enabled!");
        }
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#RenameObjectTag(java.lang.String,java.lang.String,String,String)"></seealso>
    public virtual void RenameObjectTag(String tagname, String strid, String ptsource,
     String renametag)
    {
      IPathwaysRestAPIService svcPathwaysRest = PathwaysRestAPIService.GetInstance(m_asOwner);
      if (svcPathwaysRest.IsPathwaysEnabled())
      {
        svcPathwaysRest.RenameTagRest(tagname, strid, ptsource, renametag);
        } else
      {
        throw new XPIllegalStateException("Failed to Send Rename Tag REST request to Pathways, it is not enabled!");
        }
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#IsTaggingEnabled(java.lang.String,java.lang.String,boolean)"></seealso>
    public virtual bool IsTaggingEnabled()
    {
      IPathwaysRestAPIService svcPathwaysRest = PathwaysRestAPIService.GetInstance(m_asOwner);
      if (null != svcPathwaysRest)
      {
        return svcPathwaysRest.IsPathwaysEnabled();
      }
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#GetPathwaysTaggingError()"></seealso>
    public virtual XPException GetPathwaysTaggingError()
    {
      return m_taggingError;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#SetPathwaysTaggingError(XPException">e)</seealso>
    public virtual void SetPathwaysTaggingError(XPException e)
    {
      m_taggingError = e;
    }
    /*
     * For unit test, a way to set the saved search response.  This function is being called in doPathwaysSearch and doLegacySearch
     * to set the search response after each search is done.
     */
     
    private void SetSearchResponseForUnitTest(IPTSearchResponse response)
    {
      m_unitTestSearchResponse = response;
    }
    /*
     * For unit test, a way to get the saved search response from a unit test
     */
     
    public virtual IPTSearchResponse GetSearchResponseForUnitTest()
    {
      return m_unitTestSearchResponse;
    }
  }
}