using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>
  /// CraigS
  /// Helper class containing a batch of search settings, plus methods
  /// to do useful things with them.
  /// </author>
  public class SearchSettingCollection
  {
    
    /// <summary>
    /// String equivalents of PT_SEARCH_SETTING settings
    /// </summary>
    public const String PT_SEARCHSETTING_LANGUAGE_S = "lang";
    public const String PT_SEARCHSETTING_LIMITBYLOCALE_S = "lbl";
    public const String PT_SEARCHSETTING_SKIPRESULTS_S = "first";
    public const String PT_SEARCHSETTING_MAXRESULTS_S = "page";
    public const String PT_SEARCHSETTING_APPS_S = "apps";
    public const String PT_SEARCHSETTING_ABSTYPES_S = "abstype";
    public const String PT_SEARCHSETTING_OBJTYPES_S = "objtype";
    public const String PT_SEARCHSETTING_DDFOLDERS_S = "ddfolder";
    public const String PT_SEARCHSETTING_ADMINFOLDERS_S = "adfolder";
    public const String PT_SEARCHSETTING_OBJIDS_S = "objids";
    public const String PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S = "subfolders";
    public const String PT_SEARCHSETTING_COMMUNITY_ID_S = "community";
    public const String PT_SEARCHSETTING_KWIC_S = "kwic";
    public const String PT_SEARCHSETTING_SPELLCHECK_S = "spell";
    public const String PT_SEARCHSETTING_BESTBETS_S = "bbs";
    public const String PT_SEARCHSETTING_THESAURUS_S = "thesaurus";
    public const String PT_SEARCHSETTING_ORDERBY_S = "orderby";
    public const String PT_SEARCHSETTING_ACCESS_LEVEL_S = "access";
    public const String PT_SEARCHSETTING_GROUPBYPROP_S = "groupby";
    public const String PT_SEARCHSETTING_QUERYTYPE_S = "querytype";
    public const String PT_SEARCHSETTING_INITIALSEARCHSTRING_S = "initialsearchstring";
    public const String PT_SEARCHSETTING_GADGET_FIELDS_S = "gadfields";
    public const String PT_SEARCHSETTING_GADGET_TYPE_S = "gadtype";
    public const String PT_SEARCHSETTING_GADGET_ALIGNMENT_S = "gadalign";
    public const String PT_SEARCHSETTING_ASSOC_PORTLET_ID_S = "portletid";
    public const String PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID_S = "projectid";
    public const String PT_SEARCHSETTING_GADGET_SEARCH_TYPE_S = "gadsrchtype";
    public const String PT_SEARCHSETTING_USER_IS_GUEST_S = "userisguest";
    public const String GADGET_SEARCH_TYPE_BANNERSEARCH = "bannersearch";
    public const String GADGET_SEARCH_TYPE_NONCOMMUNITYFOLDER = "noncommunityfolder";
    
    /// <summary>
    /// Map from PT_SEARCH_SETTING to Object, contains things
    /// we need to set on an IPTSearchRequest object later
    /// </summary>
    protected XPHashtable _settings = null;
    public SearchSettingCollection()
    {
      _settings = new XPHashtable();
    }
    
    /// <summary>
    /// Static helper method to map a string (i.e. a URL parameter)
    /// to a PT_SEARCH_SETTING value.
    /// </summary>
    public static int getSettingIdFromString(String s)
    {
      if (s.Equals(PT_SEARCHSETTING_LANGUAGE_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE;
      }
      if (s.Equals(PT_SEARCHSETTING_LIMITBYLOCALE_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE;
      }
      if (s.Equals(PT_SEARCHSETTING_SKIPRESULTS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS;
      }
      if (s.Equals(PT_SEARCHSETTING_MAXRESULTS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS;
      }
      if (s.Equals(PT_SEARCHSETTING_APPS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS;
      }
      if (s.Equals(PT_SEARCHSETTING_ABSTYPES_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES;
      }
      if (s.Equals(PT_SEARCHSETTING_OBJTYPES_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES;
      }
      if (s.Equals(PT_SEARCHSETTING_DDFOLDERS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS;
      }
      if (s.Equals(PT_SEARCHSETTING_ADMINFOLDERS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS;
      }
      if (s.Equals(PT_SEARCHSETTING_OBJIDS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS;
      }
      if (s.Equals(PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS;
      }
      if (s.Equals(PT_SEARCHSETTING_COMMUNITY_ID_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID;
      }
      if (s.Equals(PT_SEARCHSETTING_KWIC_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC;
      }
      if (s.Equals(PT_SEARCHSETTING_SPELLCHECK_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK;
      }
      if (s.Equals(PT_SEARCHSETTING_BESTBETS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS;
      }
      if (s.Equals(PT_SEARCHSETTING_THESAURUS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS;
      }
      if (s.Equals(PT_SEARCHSETTING_ORDERBY_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY;
      }
      if (s.Equals(PT_SEARCHSETTING_ACCESS_LEVEL_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL;
      }
      if (s.Equals(PT_SEARCHSETTING_GROUPBYPROP_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP;
      }
      if (s.Equals(PT_SEARCHSETTING_QUERYTYPE_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE;
      }
      if (s.Equals(PT_SEARCHSETTING_INITIALSEARCHSTRING_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING;
      }
      if (s.Equals(PT_SEARCHSETTING_GADGET_FIELDS_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS;
      }
      if (s.Equals(PT_SEARCHSETTING_GADGET_TYPE_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE;
      }
      if (s.Equals(PT_SEARCHSETTING_GADGET_ALIGNMENT_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT;
      }
      if (s.Equals(PT_SEARCHSETTING_GADGET_SEARCH_TYPE_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE;
      }
      if (s.Equals(PT_SEARCHSETTING_ASSOC_PORTLET_ID_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID;
      }
      if (s.Equals(PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID;
        }
      if (s.Equals(PT_SEARCHSETTING_USER_IS_GUEST_S))
      {
        return PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST;
      }
      return 0;
    }
    
    /// <summary>
    /// Static helper method to map a PT_SEARCH_SETTING
    /// to the URL parameter used to encode it
    /// </summary>
    public static String getStringFromSettingId(int s)
    {
      switch (s){
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE:
      return PT_SEARCHSETTING_LANGUAGE_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE:
      return PT_SEARCHSETTING_LIMITBYLOCALE_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS:
      return PT_SEARCHSETTING_SKIPRESULTS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS:
      return PT_SEARCHSETTING_MAXRESULTS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS:
      return PT_SEARCHSETTING_APPS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES:
      return PT_SEARCHSETTING_ABSTYPES_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES:
      return PT_SEARCHSETTING_OBJTYPES_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS:
      return PT_SEARCHSETTING_DDFOLDERS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS:
      return PT_SEARCHSETTING_ADMINFOLDERS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS:
      return PT_SEARCHSETTING_OBJIDS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS:
      return PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID:
      return PT_SEARCHSETTING_COMMUNITY_ID_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC:
      return PT_SEARCHSETTING_KWIC_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK:
      return PT_SEARCHSETTING_SPELLCHECK_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS:
      return PT_SEARCHSETTING_BESTBETS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS:
      return PT_SEARCHSETTING_THESAURUS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY:
      return PT_SEARCHSETTING_ORDERBY_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL:
      return PT_SEARCHSETTING_ACCESS_LEVEL_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP:
      return PT_SEARCHSETTING_GROUPBYPROP_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE:
      return PT_SEARCHSETTING_QUERYTYPE_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS:
      return PT_SEARCHSETTING_GADGET_FIELDS_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE:
      return PT_SEARCHSETTING_GADGET_TYPE_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT:
      return PT_SEARCHSETTING_GADGET_ALIGNMENT_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE:
      return PT_SEARCHSETTING_GADGET_SEARCH_TYPE_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID:
      return PT_SEARCHSETTING_ASSOC_PORTLET_ID_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID:
      return PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST:
      return PT_SEARCHSETTING_USER_IS_GUEST_S;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_TIMEOUT;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_TIMEOUT:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING:
      default:
      // Not supported; can't change these settings via URL parameters
      return null;
      break;
      }
    }
    
    /// <returns></returns>
    public static IXPList GetPageContextSettings()
    {
      XPArrayList l = new XPArrayList();
      l.Add(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP);
      l.Add(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS);
      l.Add(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY);
      return l;
    }
    
    /// <summary>
    /// Get an enumeration of the settings stored in the collection
    /// </summary>
    public virtual IXPEnumerator GetSettingIDs()
    {
      return _settings.GetKeys();
    }
    
    /// <summary>
    /// Get the size of the map
    /// </summary>
    public virtual int GetSize()
    {
      return _settings.GetSize();
    }
    
    /// <summary>
    /// Get an enumeration of the settings stored in the collection
    /// </summary>
    public virtual Object GetSettingValue(int key)
    {
      return _settings.GetElement(key);
    }
    
    /// <summary>
    /// Helper method that indicates whether this collection simply
    /// restricts a search to a community.  Used by the UI to replace
    /// the "Search with Same Restrictions" message with "Search in Same Community"
    /// when possible.
    /// </summary>
    public virtual bool IsSimpleCommunityRestriction()
    {
      return ((_settings.GetSize() == 1) && (_settings.ContainsKey(PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID)));
      }
    
    /// <summary>
    /// Helper method that indicates whether this collection simply
    /// restricts a search to a folder (possibly including subfolders).
    /// Used by the UI to replace the "Search with Same Restrictions" message
    /// with "Search in Same Folder" when possible.
    /// </summary>
    public virtual bool IsSimpleFolderRestriction()
    {
      int numFolderRestrictions = 0;
      int numIgnorableRestrictions = 0;
      // Count folder restrictions
      if (_settings.ContainsKey(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS))
      {
        numFolderRestrictions++;
      }
      if (_settings.ContainsKey(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS))
      {
        numFolderRestrictions++;
      }
      // Count restrictions we don't care about
      if (_settings.ContainsKey(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS))
      {
        numIgnorableRestrictions++;
      }
      if (_settings.ContainsKey(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS))
      {
        numIgnorableRestrictions++;
      }
      return (_settings.GetSize() == (numFolderRestrictions + numIgnorableRestrictions));
      }
    
    /// <summary>
    /// Add a setting to the map (for use only within the search package)
    /// </summary>
    public virtual void add(int setting, Object value)
    {
      _settings.PutElement(setting, value);
    }
    
    /// <summary>
    /// Add a setting to the map
    /// </summary>
    public virtual void add(int setting, bool value)
    {
      _settings.PutElement(setting, value);
    }
    
    /// <summary>
    /// Add a setting to the map
    /// </summary>
    public virtual void add(int setting, int value)
    {
      _settings.PutElement(setting, value);
    }
    
    /// <summary>
    /// Add a setting to the map
    /// </summary>
    public virtual void add(int setting, String value)
    {
      _settings.PutElement(setting, value);
    }
    
    /// <summary>
    /// Add a setting to the map
    /// </summary>
    public virtual void add(int setting, int[] value)
    {
      _settings.PutElement(setting, value);
    }
    
    /// <summary>
    /// Helper method for debugging
    /// </summary>
    public virtual String dump()
    {
      XPStringBuilder buf = new XPStringBuilder(200);
      IXPEnumerator e = _settings.GetKeys();
      while (e.MoveNext())
      {
        Object key = e.GetCurrent();
        buf.Append(getStringFromSettingId(XPConvert.ToInteger(key)));
        buf.Append("=");
        buf.Append(_settings.GetElement(key));
        buf.Append("\n");
      }
      return buf.ToString();
    }
    
    /// <summary>
    /// Encode all settings in the provided IPTSearchRequest, ready
    /// for URL encoding, into the provided XPHashtable.  The map keys are
    /// Strings (e.g. PT_SEARCHSETTING_OBJTYPES_S) prepended with the
    /// provided prefix.  The values are String[]-ified setting values.
    /// inclusions and exclusions are IXPCollections of Integers.
    /// If the inclusions collection is non-null, only settings contained
    /// within it are included in the returned map.
    /// Any settings contained in the exclusions collection are omitted
    /// from the returned map.
    /// </summary>
    public static void encodeRequestSettings(IPTSearchRequest request, XPHashtable map,
     String keyPrefix, IXPCollection inclusions, IXPCollection exclusions)
    {
      // Don't encode querytype or initialsearchstring
      //    encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE,
      //                        request, map, keyPrefix);
      //    encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING,
      //                        request, map, keyPrefix);
      encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE, request,
       map, keyPrefix, inclusions, exclusions);
      encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
       request, map, keyPrefix, inclusions, exclusions);
      encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE,
       request, map, keyPrefix, inclusions, exclusions);
      encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST,
       request, map, keyPrefix, inclusions, exclusions);
      encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE,
       /* default= */
      false, request, map, keyPrefix, inclusions, exclusions);
      encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
       /* default= */
      true, request, map, keyPrefix, inclusions, exclusions);
      encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC, /* default= */
      true, request, map, keyPrefix, inclusions, exclusions);
      encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK, /* default= */
      false, request, map, keyPrefix, inclusions, exclusions);
      encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, /* default= */
      false, request, map, keyPrefix, inclusions, exclusions);
      encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS, /* default= */
      false, request, map, keyPrefix, inclusions, exclusions);
      encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS,
       /* default= */
      false, request, map, keyPrefix, inclusions, exclusions);
      encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS, /* default= */
      0, request, map, keyPrefix, inclusions, exclusions);
      encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, /* default= */
      0, request, map, keyPrefix, inclusions, exclusions);
      encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, /* default= */
      10, request, map, keyPrefix, inclusions, exclusions);
      encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, /* default= */
      0, request, map, keyPrefix, inclusions, exclusions);
      encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES, /* default= */
      0, request, map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, request,
       map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS,
       request, map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS,
       request, map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS, request,
       map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID,
       request, map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE,
       request, map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT,
       request, map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID,
       request, map, keyPrefix, inclusions, exclusions);
      encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID,
       request, map, keyPrefix, inclusions, exclusions);
      // Now, remove any settings that were in the exclusions list
      if (null != exclusions)
      {
        IXPEnumerator eExclusions = exclusions.GetEnumerator();
        while (eExclusions.MoveNext())
        {
          int setting = XPConvert.ToInteger(eExclusions.GetCurrent());
          map.RemoveElement(keyPrefix + getStringFromSettingId(setting));
          }
      }
    }
    
    /// <summary>
    /// Parse the URL-ified String[] setting value and return an
    /// Object that can be passed to add() (and from there into
    /// IPTSearchRequest.SetSettings()).
    /// </summary>
    public static Object parseURLString(int id, String[] value)
    {
      switch (id){
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST:
      // string
      return value[0];
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS:
      // boolean
      return XPConvert.ToInteger(value[0]) != 0;
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL:
      // int
      return XPConvert.ToInteger(value[0]);
      goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES;
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID:
      case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID:
      // array of integers
      int[] r = new int[value.Length];
      for (int j = 0;j < value.Length;j++)
      {
        r[j] = XPConvert.ToInteger(value[j]);
      }
      return r;
      goto default;
      default:
      break;
      }
      // Others not supported
      return null;
    }
    
    /// <summary>
    /// Merge another batch of settings into ours
    /// </summary>
    public virtual void merge(SearchSettingCollection otherSet)
    {
      IXPEnumerator otherKeys = otherSet._settings.GetKeys();
      while (otherKeys.MoveNext())
      {
        int key = XPConvert.ToInteger(otherKeys.GetCurrent());
        int setting = key;
        Object value = otherSet._settings.GetElement(key);
        this.add(setting, value);
      }
    }
    
    /// <summary>
    /// Return a stringified version of v that can be used in an URL
    /// </summary>
    public static String[] stringifySettingValue(int id, Object v)
    {
      try
      {
        switch (id){
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST:
        // string
        return new String[]{(String) v};
        goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE;
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS:
        {
          // boolean
          bool b = XPConvert.ToBoolean(v);
          if (b)
          {
            return new String[]{"1"};
          } else
          {
            return new String[]{"0"};
          }
          goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS;
        }
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL:
        {
          // int
          int i = XPConvert.ToInteger(v);
          return new String[]{XPConvert.ToString(i)};
          goto case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES;
        }
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID:
        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID:
        // array of integers
        return stringifyIntArray((int[]) v);
        goto default;
        default:
        break;
        }
      }
      // Others not supported
      catch (Exception e)
      {
        throw new XPException("Attempted to add a constraint with an incorrect type to a search request.  The search setting id was " + id + ".",
         e);
      }
      return null;
    }
    
    /// <summary>
    /// Update an IPTSearchRequest with our settings
    /// </summary>
    public virtual void updateRequest(IPTSearchRequest request)
    {
      IXPEnumerator keys = _settings.GetKeys();
      while (keys.MoveNext())
      {
        int key = XPConvert.ToInteger(keys.GetCurrent());
        int setting = key;
        Object value = _settings.GetElement(key);
        request.SetSettings(setting, value);
      }
    }
    
    /// <param name="settingId"></param>
    /// <param name="inclusions"></param>
    /// <param name="exclusions"></param>
    /// <returns></returns>
    private static bool checkExclusion(int settingId, IXPCollection inclusions,
     IXPCollection exclusions)
    {
      Object id = settingId;
      if ((null != exclusions) && (exclusions.Contains(id)))
      {
        return false;
      }
      if ((null == inclusions) || (inclusions.Contains(id)))
      {
        return true;
      }
      return false;
    }
    
    /// <param name="settingId"></param>
    /// <param name="defaultValue"></param>
    /// <param name="request"></param>
    /// <param name="map"></param>
    /// <param name="keyPrefix"></param>
    /// <param name="inclusions"></param>
    /// <param name="exclusions"></param>
    private static void encodeBoolSetting(int settingId, bool defaultValue,
     IPTSearchRequest request, XPHashtable map, String keyPrefix, IXPCollection inclusions,
     IXPCollection exclusions)
    {
      if (!checkExclusion(settingId, inclusions, exclusions))
      {
        return;
      }
      Object o = request.GetSettingsAsObject(settingId);
      if (null == o)
      {
        return;
      }
      bool b = XPConvert.ToBoolean(o);
      if (b != defaultValue)
      {
        if (b)
        {
          map.PutElement(keyPrefix + getStringFromSettingId(settingId), new String[]{"1"});
          } else
        {
          map.PutElement(keyPrefix + getStringFromSettingId(settingId), new String[]{"0"});
          }
      }
    }
    
    /// <param name="settingId"></param>
    /// <param name="request"></param>
    /// <param name="map"></param>
    /// <param name="keyPrefix"></param>
    /// <param name="inclusions"></param>
    /// <param name="exclusions"></param>
    private static void encodeIntArraySetting(int settingId, IPTSearchRequest request,
     XPHashtable map, String keyPrefix, IXPCollection inclusions, IXPCollection exclusions)
    {
      if (!checkExclusion(settingId, inclusions, exclusions))
      {
        return;
      }
      Object o = request.GetSettingsAsObject(settingId);
      if (null == o)
      {
        return;
      }
      Object[] a = (Object[]) o;
      if (0 < a.Length)
      {
        String[] s = new String[a.Length];
        for (int j = 0;j < a.Length;j++)
        {
          s[j] = XPConvert.ToString(a[j]);
        }
        map.PutElement(keyPrefix + getStringFromSettingId(settingId), s);
        }
    }
    
    /// <param name="settingId"></param>
    /// <param name="defaultValue"></param>
    /// <param name="request"></param>
    /// <param name="map"></param>
    /// <param name="keyPrefix"></param>
    /// <param name="inclusions"></param>
    /// <param name="exclusions"></param>
    private static void encodeIntSetting(int settingId, int defaultValue,
     IPTSearchRequest request, XPHashtable map, String keyPrefix, IXPCollection inclusions,
     IXPCollection exclusions)
    {
      if (!checkExclusion(settingId, inclusions, exclusions))
      {
        return;
      }
      Object o = request.GetSettingsAsObject(settingId);
      if (null == o)
      {
        return;
      }
      int value = XPConvert.ToInteger(o);
      if (value != defaultValue)
      {
        map.PutElement(keyPrefix + getStringFromSettingId(settingId), new String[]{XPConvert.ToString(value)});
        }
    }
    
    /// <param name="settingId"></param>
    /// <param name="request"></param>
    /// <param name="map"></param>
    /// <param name="keyPrefix"></param>
    /// <param name="inclusions"></param>
    /// <param name="exclusions"></param>
    private static void encodeStringSetting(int settingId, IPTSearchRequest request,
     XPHashtable map, String keyPrefix, IXPCollection inclusions, IXPCollection exclusions)
    {
      if (!checkExclusion(settingId, inclusions, exclusions))
      {
        return;
      }
      Object o = request.GetSettingsAsObject(settingId);
      if (null == o)
      {
        return;
      }
      String value = (String) o;
      if (0 < value.Length)
      {
        map.PutElement(keyPrefix + getStringFromSettingId(settingId), new String[]{value});
        }
    }
    
    /// <param name="r"></param>
    /// <returns></returns>
    private static String[] stringifyIntArray(int[] r)
    {
      String[] s = new String[r.Length];
      for (int j = 0;j < r.Length;j++)
      {
        s[j] = XPConvert.ToString(r[j]);
      }
      return s;
    }
  }
}
// class SearchSettingCollection
