using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portaluiinfrastructure.search
{
  /// <author>CraigS</author>
  public class TypeFilterControl : SearchResultControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.search.DrilldownControl");
    public const String STR_MVC_CLASS_NAME = "typefilter";
    public const String FILTER_DATA = "filterId";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Factory method to make a drilldown link.
    /// </summary>
    /// <param name="model">Current batch of search results</param>
    /// <param name="linkText">Desired link text</param>
    /// <param name="category">Desired category to drill down into</param>
    public static ILinkElement makeURL(ISearchResultModelRO model, AActivitySpace parent)
    {
      // Create a URL that directs into the current Activity Space
      ILinkElement url = null;
      bool embedInForm = SpaceNeedsPassthruURL(parent);
      if (embedInForm)
      {
        url = new PassthruURL();
      } else
      {
        url = new ASURL(parent);
        url.SetLinkGetCachedSpace(parent);
        url.SetDisplayPage(parent.GetCurrentPage().GetName());
      }
      // Set a DrilldownControl as the URL's target
      url.SetControl(TypeFilterControl.STR_MVC_CLASS_NAME);
      // Set superclass data
      addCommonData(model, url);
      // Set other data
      //url.AddControlArgument(PaginationControl.PAGE_SIZE_DATA, pageSize);
      return url;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TypeFilterControl();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()"></seealso>
    protected override Redirect ExecuteSearchControl(XPHashtable args, String key)
    {
      // category
      String[] values = (String[]) args.GetElement(FILTER_DATA);
      if (null == values)
      {
        log.Error("could not find category data in query string.");
        return null;
      }
      int filterId;
      try
      {
        filterId = XPConvert.ToInteger(values[0]);
      }
      catch (Exception e)
      {
        log.Error("could not parse categgory data in query string: " + values[0]);
        return null;
      }
      // Tell the model to filter
      _model.Filter(key, filterId);
      // Don't need to redirect to a different page or space; just
      // redisplay the page
      return null;
    }
  }
}