using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.search
{
  public class UpdateSortOrderControl : SearchResultControl
  {
    public const String STR_MVC_CLASS_NAME = "orderby";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.search.UpdateSortOrderControl");
    public const String ORDER_BY_DATA = "order";
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()"></seealso>
    protected override Redirect ExecuteSearchControl(XPHashtable args, String key)
    {
      String orderBy;
      // Sort order
      String[] values = (String[]) args.GetElement(ORDER_BY_DATA);
      if (null != values)
      {
        orderBy = values[0];
      } else
      {
        log.Error("could not find order by data in query string");
        return null;
      }
      // Tell the model to go to the new page
      _model.ChangeSortOrder(orderBy, key);
      // Don't need to redirect to a different page or space; just
      // redisplay the page
      return null;
    }
    
    /// <summary>
    /// Factory method to make a pagination link for some search results.
    /// </summary>
    /// <param name="model">Current batch of search results</param>
    /// <param name="parent">ActivitySpace we're living in</param>
    /// <param name="urlText">Desired text within URL</param>
    /// <param name="orderBy">Sort order within which newFirst is to be interpreted</param>
    /// <param name="newFirst">Desired first result on new page</param>
    public static ASURL makeURL(IBaseSearchResultModelRO model, AActivitySpace parent,
     String orderBy)
    {
      // Create a URL that directs into the current Activity Space
      ASURL url = null;
      if (!model.IsInitialized())
      {
        return null;
      }
      //		boolean embedInForm = SpaceNeedsPassthruURL(parent);
      //
      //		if (embedInForm)
      //		{
      //			url = new PassthruURL();
      //		}
      //		else
      //		{
      url = new ASURL(parent);
      url.SetLinkGetCachedSpace(parent);
      url.SetDisplayPage(parent.GetCurrentPage().GetName());
      //		}
      // Create a PaginationControl within the search space
      url.SetControl(UpdateSortOrderControl.STR_MVC_CLASS_NAME);
      // Set superclass data
      // NOTE: We know we're always passed a fullblown
      // ISearchResultModelRO, since there's only one
      // implementation of either interface (SearchResultModel).
      try
      {
        addCommonData((ISearchResultModelRO) model, url);
      }
      catch (XPException e)
      {
        return null;
      }
      // Set link text
      //url.AddInnerHTMLString(urlText);
      // Set other data
      if (orderBy != null)
      {
        url.AddControlArgument(PaginationControl.ORDER_BY_DATA, orderBy);
        }
      return url;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UpdateSortOrderControl();
    }
  }
}