using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.search.exceptions
{
  /// <summary>
  /// Error6321Exception indicates that an exception occured for which there is no internationalized
  /// message. The english text of the exception will be embedded as a comment in the returned page.
  /// </summary>
  public class Error6321Exception : SearchExecutionError
  {
    public const String UNKNOWN_ERROR = "Error Message: No further information available.";
    // This wraps the "real" java exception that we don't have an internationalized message for.
    private XPException _exception = null;
    
    /// <summary>
    /// Creates a new Error6321Exception object.
    /// </summary>
    /// <param name="msg">The internationalized message.</param>
    /// <param name="exception">The un-internationalized exception.</param>
    public Error6321Exception(String msg, XPException exception) : base(msg)
    {
      _exception = exception;
    }
    public virtual XPException GetException()
    {
      return _exception;
    }
    public override HTMLComment GetComment()
    {
      // Error is one for which no internationalized message exists. Embed the english error
      // in a comment in the page.
      if (_exception != null)
      {
        XPStringBuilder sb = new XPStringBuilder();
        sb.Append("Error Message: " + _exception.GetMessage() + "\n");
        sb.Append(_exception.GetStackTrace());
        return new HTMLComment(XPHttpUtility.HtmlEncode(sb.ToString()));
      } else
      {
        return new HTMLComment(UNKNOWN_ERROR);
      }
    }
  }
}