using System;
using XPArrayList=com.plumtree.openfoundation.util.XPArrayList;
using XPStringBuilder=com.plumtree.openfoundation.util.XPStringBuilder;
namespace com.plumtree.portaluiinfrastructure.search.pathways
{
  /// <author>
  /// lmah
  /// Pathways Query Arguments class to contain the query parameters for the Pathways search
  /// </author>
  public class PathwaysQueryArguments
  {
    //json or xml
    public String format = null;
    //defines the order of search results, ie: asc, des
    public String order = "DES";
    //results to sort by, ie:  rank, path
    public String orderBy = "RANK";
    //starting result count at
    public int startAt = -1;
    //limit result set to an existing view
    public String viewId = null;
    //search query
    public String query = "";
    //maximum number of results to return
    public int resultCount = -1;
    //restrict search to specific object types
    public XPArrayList objectTypes = null;
    //total count of search results
    public int totalCount = -1;
    //list of admin folders to restrict
    public int[] adminFolders = null;
    //list of directory folders to restrict
    public int[] dirFolders = null;
    //list of property constraints for advanced search
    public XPArrayList advPropertyConstraints = null;
    //boolean value for if all advanced property constraints should be AND'ed or OR'ed together
    internal bool topLevelSearchCriteriaOperatorAND = false;
    //boolean value for if this is advanced sarch or not
    internal bool _isAdvancedSearch = false;
    //boolean value for spellcheck
    internal bool _isSpellCheck = false;
    public static String opAND = "AND";
    public static String opOR = "OR";
    public PathwaysQueryArguments(String argFormat, String argOrder, String argOrderBy,
     int argStartAt, String argViewId, String argQuery, int argResultCount,
     XPArrayList argObjectTypes)
    {
      format = argFormat;
      startAt = argStartAt;
      viewId = argViewId;
      query = argQuery;
      resultCount = argResultCount;
      objectTypes = argObjectTypes;
    }
    public virtual String GetFormat()
    {
      return format;
    }
    public virtual String GetOrder()
    {
      return order;
    }
    public virtual String GetOrderBy()
    {
      return orderBy;
    }
    public virtual int GetStartAt()
    {
      return startAt;
    }
    public virtual String GetViewId()
    {
      return viewId;
    }
    public virtual String GetQuery()
    {
      return query;
    }
    public virtual int GetResultCount()
    {
      return resultCount;
    }
    public virtual int GetTotalCount()
    {
      return totalCount;
    }
    //may not need this function, leaving here just in case
    public virtual int[] GetIntAdminFolders()
    {
      return adminFolders;
    }
    public virtual String GetStringAdminFolders()
    {
      if (null == adminFolders)
      {
        return null;
      } else
      {
        XPStringBuilder strAdminFolder = new XPStringBuilder();
        for (int i = 0;i < adminFolders.Length;i++)
        {
          strAdminFolder.Append(adminFolders[i]).Append(",");
        }
        //removing the trailing comma from the string
        return strAdminFolder.Substring(0, (strAdminFolder.GetLength() - 1));
        }
    }
    //may not need this function, leaving here just in case
    public virtual int[] GetDirFolders()
    {
      return dirFolders;
    }
    public virtual String GetStringDirFolders()
    {
      if (null == dirFolders)
      {
        return null;
      } else
      {
        XPStringBuilder strDirFolder = new XPStringBuilder();
        for (int i = 0;i < dirFolders.Length;i++)
        {
          strDirFolder.Append(dirFolders[i]).Append(",");
        }
        return strDirFolder.Substring(0, (strDirFolder.GetLength() - 1));
        }
    }
    public virtual XPArrayList GetObjectTypes()
    {
      return objectTypes;
    }
    public virtual bool GetSpellCheck()
    {
      return _isSpellCheck;
    }
    public virtual XPArrayList GetAdvancedPropertyContraints()
    {
      return advPropertyConstraints;
    }
    public virtual String GetAdvancedSearchTopPropertyOperator()
    {
      //top operator value to either AND or OR all advanced search property constraints
      if (topLevelSearchCriteriaOperatorAND)
      {
        return opAND;
      } else
      {
        return opOR;
      }
    }
    public virtual bool isAdvancedSearch()
    {
      return _isAdvancedSearch;
    }
    public virtual void SetFormat(String argFormat)
    {
      format = argFormat;
    }
    public virtual void SetOrder(String argOrder)
    {
      order = argOrder;
    }
    public virtual void SetOrderBy(String argOrderBy)
    {
      orderBy = argOrderBy;
    }
    public virtual void SetStartAt(int argStartAt)
    {
      startAt = argStartAt;
    }
    public virtual void SetViewId(String argViewId)
    {
      viewId = argViewId;
    }
    public virtual void SetQuery(String argQuery)
    {
      query = argQuery;
    }
    public virtual void SetResultCount(int argResultCount)
    {
      resultCount = argResultCount;
    }
    public virtual void SetObjectTypes(XPArrayList argObjectTypes)
    {
      objectTypes = argObjectTypes;
    }
    public virtual void SetTotalCount(int argTotalCount)
    {
      totalCount = argTotalCount;
    }
    public virtual void SetAdminFolders(int[] folders)
    {
      if (null != folders)
      {
        adminFolders = folders;
      }
    }
    public virtual void SetDirFolders(int[] folders)
    {
      if (null != folders)
      {
        dirFolders = folders;
      }
    }
    public virtual void SetAdvancedPropertyConstraints(XPArrayList constraints,
     bool booleanOperator)
    {
      advPropertyConstraints = constraints;
      topLevelSearchCriteriaOperatorAND = booleanOperator;
    }
    public virtual void SetIsAdvancedSearch(bool value)
    {
      _isAdvancedSearch = value;
    }
    public virtual void SetSpellCheck(bool globalValue, bool value)
    {
      if (globalValue)
      {
        //global spellchecking turned on, so the setting of the customer can be used
        _isSpellCheck = value;
      }
    }
  }
}
//do nothing if it's false since _isSpellCheck is set to false
