using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.securitymatrix
{
  /// <summary>
  /// This is class is used to display an empty DP during the save process.
  /// </summary>
  /// <author>RickyW</author>
  public class ABOBlankSelectDP : EditorDP
  {
    
    /// <summary>
    /// class name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ABOBlankSelectDP";
    
    /// <summary>
    /// Editor Repost Control Name 
    /// </summary>
    private String m_strRepostControlName = SecurityMatrixRepostControl.STR_MVC_CLASS_NAME;
    
    /// <summary>
    /// Customizes the spacing on the left and right sides of the content
    /// table.  The default value is 15.  Set to 0 if you don't want views
    /// to be indented.
    /// </summary>
    public ABOBlankSelectDP() : base()
    {
      base.SetContentTableCellSpacing("15");
    }
    
    /// <summary>
    /// Sets the editor repost control to be used in this display page.
    /// If this method is not called the default is the SecurityMatrixRepostControl.
    /// </summary>
    /// <param name="_strEditorRepostControl">An EditorRepostControl's name.</param>
    public virtual void SetRepostControlName(String _strEditorRepostControl)
    {
      m_strRepostControlName = _strEditorRepostControl;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(1699, "ptmsgs_portaladminmsgs");
    }
    /* */
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This blank page does not have any HTML.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      return new HTMLElementCollection();
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      // create script container for return
      HTMLScriptCollection myScriptCollection = base.DisplayJavaScriptFromChild();
      // create our script
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(200);
      // create new URL for our pop-up
      ASURL ABOPopUp = new ASURL(m_asOwner);
      ABOPopUp.SetLinkGetCachedSpace(m_asOwner);
      ABOPopUp.SetControl(m_strRepostControlName);
      ABOPopUp.SetDisplayPage(ABOPopupSelectDP.STR_MVC_CLASS_NAME);
      // open a pop-up window to the URL
      sb.Append("window.open(\'").Append(ABOPopUp.GetURLAsString()).Append("\', \'_blank1\', \'location=no,menubar=no, scrollbars=yes, resizable=yes, height=200,width=510\');\n");
      myScript.AddInnerHTMLString(sb.ToString());
      myScriptCollection.AddInnerHTMLElement(myScript);
      return myScriptCollection;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()"></seealso>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return new HTMLElementCollection();
    }
  }
}