using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.securitymatrix
{
  /// <author>rickyw</author>
  /// <author>
  /// marks
  /// This is the pop-up page where we ask the user whether he wants to have his
  /// changes made instantly or scheduled as a job so that he won't have to wait.
  /// </author>
  public class ABOPopupSelectView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.securitymatrix.ABOPopupSelectView");
    
    /// <summary>
    /// object class name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ABOPopupSelectView";
    
    /// <summary>
    /// html name - apply now button 
    /// </summary>
    public const String HTMLBUTTON_APPLY = "in_bu_Apply";
    
    /// <summary>
    /// html name - cancel changes button 
    /// </summary>
    public const String HTMLBUTTON_CANCEL_ALL_CHANGES = "in_bu_CancelAllChanges";
    
    /// <summary>
    /// js constant - apply 
    /// </summary>
    public const String JAVASCRIPT_APPLY_ON_OPENER = "applyOnOpener";
    
    /// <summary>
    /// js constant - cancel 
    /// </summary>
    public const String JAVASCRIPT_CANCEL_ALL_CHANGES = "cancelAllChanges";
    
    /// <summary>
    /// html name - apply options 
    /// </summary>
    public const String HTMLRADIO_APPLY_OPTIONS = "in_ra_ApplyOptions";
    
    /// <summary>
    /// apply only this folder 
    /// </summary>
    public const String APPLY_ONLY_THIS_FOLDER = "applyOnlyThisFolder";
    
    /// <summary>
    /// apply recursively 
    /// </summary>
    public const String APPLY_RECURSIVELY = "applyRecursively";
    
    /// <summary>
    /// member mvc objects 
    /// </summary>
    protected AActivitySpace m_asOwner;
    protected IFolderSecurityABOModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ABOPopupSelectView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement result = new HTMLElementCollection();
      HTMLSpan mySpan;
      HTMLTable myTable;
      HTMLInput myInput;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        // create table
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("10");
        // add title
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2543, "ptmsgs_portaladminmsgs"));
        // add paragraph 1
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2444, "ptmsgs_portaladminmsgs"));
        //add "Changes will be applied by a job and may not..."
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2546, "ptmsgs_portaladminmsgs"));
        HTMLBr myBr = new HTMLBr();
        mySpan.AddInnerHTMLElement(myBr);
        mySpan.AddInnerHTMLElement(myBr);
        //add "Changes will be applied by a job and may not..."
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        HTMLB myBold = new HTMLB();
        mySpan.AddInnerHTMLElement(myBold);
        myBold.AddInnerHTMLString(m_asOwner.GetString(2545, "ptmsgs_portaladminmsgs"));
        // add buttons - create table
        // add buttons - add new row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myRow.AddInnerHTMLElement(myCell);
        // add buttons - add apply to all button (apply later)
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_APPLY, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(2547, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick(JAVASCRIPT_APPLY_ON_OPENER + "(true); return false;");
        // add spacer between buttons
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // add buttons - add apply to all button (apply later)
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_APPLY, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(2628, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick(JAVASCRIPT_APPLY_ON_OPENER + "(false); return false;");
        // add spacer between buttons
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // add buttons - add merge within folder button (apply now)
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL_ALL_CHANGES,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(2548, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick(JAVASCRIPT_CANCEL_ALL_CHANGES + "(); return false;");
        //add end row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myRow.AddInnerHTMLElement(myCell);
      }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to create warnings.");
      }
      // TODO better error handling here
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      // javascript to route buttons to controls 
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(300);
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_APPLY_ON_OPENER).Append("(bPropagate)\n");
      sb.Append("{\n");
      sb.Append("if ( bPropagate ){").Append("\n").Append("  opener.").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(SecurityMatrixRepostControl.POSTTOSELF_ACTION_APPLY_RECURSIVELY).Append(");\n").Append("  window.close();\n").Append("}\n").Append("else {").Append("\n").Append("  opener.").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(SecurityMatrixRepostControl.POSTTOSELF_ACTION_APPLY_ONLY_THIS_FOLDER).Append(");\n").Append("  window.close();\n").Append("}\n").Append("}\n");
      sb.Append("function ").Append(JAVASCRIPT_CANCEL_ALL_CHANGES).Append("()\n");
      sb.Append("{\n");
      sb.Append("  opener.").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(SecurityMatrixRepostControl.POSTTOSELF_ACTION_CANCEL_ALL_CHANGES).Append(");\n");
      sb.Append("  window.close();\n");
      sb.Append("}\n");
      sb.Append("\n");
      try
      {
        // Add script
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to create javascript.");
        // TODO: handle this
        return null;
      }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      m_asModel = (IFolderSecurityABOModelRO) model;
    }
  }
}