using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portaluiinfrastructure.securitymatrix
{
  /// <summary>
  /// This class handles the repost actions for the
  /// Multi Security page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class MultiObjectsSecurityControl : ExpListControl
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MultiObjectsSecurity";
    
    /// <summary>
    /// Will clear all the changes and redisplay the matrix as it was when we first displayed it. 
    /// </summary>
    public const int POSTTOSELF_ACTION_RESET = 40;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MultiObjectsSecurityControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Calls the method associated to the repost action.
    /// Editors using this framework need to call that method from
    /// the PerformRepostAction method of the main RepostControl.
    /// </summary>
    /// <param name="_nAction"></param>
    /// <param name="_htFormData"></param>
    public override void PerformRepostAction(int _nAction, XPHashtable _htFormData)
    {
      base.PerformRepostAction(_nAction, _htFormData);
      if (_nAction == ((MultiObjectsSecurityModel) m_model).GetUniqueInt(POSTTOSELF_ACTION_RESET))
      {
        ((MultiObjectsSecurityModel) m_model).ResetSettings();
      }
    }
  }
}