using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.securitymatrix
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the the Select PTObject list.
  /// The Select PTObject is a list of objects.
  /// New objects can be added to the list by selecting
  /// them from the associated Object tree.
  /// The list is by default sorted by name ascending.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class MultiObjectsSecurityModel : ObjectSecurityModel,IMultiObjectsSecurityModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.securitymatrix.MultiObjectsSecurityModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MultiObjectsSecurity";
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String QS_MULTI_OBJ_SECURITY_IDS = "objectAndClassIDs";
    
    /// <summary>
    /// Array of objects we are editing the security for. 
    /// </summary>
    protected XPArrayList m_arrObjects;
    
    /// <summary>
    /// Array of column info. 
    /// </summary>
    protected int[] m_arrColumns;
    protected XPHashtable m_htObjectColumnKeys;
    
    /// <summary>
    /// Flag to know if we are Editing the Security on Admin Folders.
    /// If we are, we also need to display the ABO pop-up when the user clicks on Finish.
    /// </summary>
    private bool m_bEditAdminFolderSecurity = false;
    
    /// <summary>
    /// Array of Object IDs.
    /// </summary>
    private int[] m_arrObjectIDs;
    
    /// <summary>
    /// Helper method that adds a row to the list.
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <param name="_sName"></param>
    protected override void AddACLToList(int _nClassID, int _nObjectID, String _sName)
    {
      Object[] oNewRow = new Object[m_arrColumns.Length];
      oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
      m_nNextIndex++;
      oNewRow[EXPLIST_COL_CLASSID] = _nClassID;
      oNewRow[EXPLIST_COL_OBJECTID] = _nObjectID;
      oNewRow[EXPLIST_COL_STRING] = _sName;
      // JF- Defaut selected access level: read
      oNewRow[EXPLIST_COL_ACCESSLEVEL_ID] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT;
      oNewRow[EXPLIST_COL_ACCESSLEVEL_STRING] = GetAccessLevelString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
      // JF- By default the user has read/write access to the row
      oNewRow[EXPLIST_COL_ROWACCESS] = PT_ACCESS_LIST_ENTRY_READWRITE;
      // JF- By default the object is not mandatory
      oNewRow[EXPLIST_COL_MANDATORY] = MANDATORY_FALSE;
      // JF- By default there is no tree ID
      oNewRow[EXPLIST_COL_GROUPTREEASID] = "";
      int k = EXPLIST_COL_MAX;
      while (k < m_arrColumns.Length)
      {
        oNewRow[k] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT;
        oNewRow[k + 1] = GetAccessLevelString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
        oNewRow[k + 2] = PT_ACCESS_LIST_ENTRY_READWRITE;
        k = k + 3;
      }
      base.GetItems().AddRow(oNewRow);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MultiObjectsSecurityModel();
    }
    
    /// <summary>
    /// Saves the security settings into the IPTObject.
    /// </summary>
    public override void Finish()
    {
      for (int i = 0;i < m_arrObjects.GetSize();i++)
      {
        StoreSecurityOnObject((IPTObject) m_arrObjects.GetElement(i));
      }
    }
    
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <returns>int</returns>
    public virtual int GetACLIndex(int _nClassID, int _nObjectID)
    {
      int nIndex = -1;
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        if ((_nClassID == XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_COL_CLASSID))) && (_nObjectID == XPConvert.ToInteger(m_saData.GetItem(i,
         EXPLIST_COL_OBJECTID))))
        {
          nIndex = i;
          break;
        }
      }
      return nIndex;
    }
    
    /// <summary>
    /// Returns a flag to know whether any of the security settings on the matrix have changed
    /// (compare to what we have in the DB).
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool HasSecurityMatrixChanged()
    {
      for (int k = 0;k < m_arrObjects.GetSize();k++)
      {
        IPTObject ptObject = (IPTObject) m_arrObjects.GetElement(k);
        IPTServerContext ptscObject = (IPTServerContext) ptObject.GetInterfaces("IPTServerContext");
        IPTAccessList ptACL = ptscObject.GetACL();
        String sObjectKey = XPConvert.ToString(ptObject.GetClassID()) + XPConvert.ToString(ptscObject.GetObjectID());
        int nAccessLevelColumnID = GetObjectColumn(EXPLIST_COL_ACCESSLEVEL_ID + sObjectKey);
        // JF- Take the ACLs from the Object and make sure each of them is in the list.
        for (int i = 0;i < ptACL.GetCount();i++)
        {
          IPTAccessListEntry ptACLEntry = ptACL.GetItem(i);
          if (!IsACLInMatrixArray(ptACLEntry.GetClassID(), ptACLEntry.GetObjectID(),
           ptACLEntry.GetAccessLevel(), nAccessLevelColumnID))
          {
            return true;
          }
        }
        int nClassID;
        int nObjectID;
        int nAccessLevel;
        // JF- Take the ACLs from the list and make sure each of them is in the Object
        for (int i = 0;i < m_saData.GetCount();i++)
        {
          nClassID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_COL_CLASSID));
          nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_COL_OBJECTID));
          nAccessLevel = XPConvert.ToInteger(m_saData.GetItem(i, nAccessLevelColumnID));
          if ((PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE != nAccessLevel) && !IsMatrixRowInObjectACL(nClassID,
           nObjectID, nAccessLevel, ptACL))
          {
            return true;
          }
        }
      }
      return false;
    }
    
    /// <summary>
    /// Tells whether the Object ACL identified by the class ID, the object ID
    /// and the Access Level ID in argument is in the list or no.
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <param name="_nAccessLevel"></param>
    /// <param name="_nAccessLevelColumnID"></param>
    /// <returns>boolean</returns>
    private bool IsACLInMatrixArray(int _nClassID, int _nObjectID, int _nAccessLevel,
     int _nAccessLevelColumnID)
    {
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        if ((_nClassID == XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_COL_CLASSID))) && (_nObjectID == XPConvert.ToInteger(m_saData.GetItem(i,
         EXPLIST_COL_OBJECTID))) && (_nAccessLevel == XPConvert.ToInteger(m_saData.GetItem(i,
         _nAccessLevelColumnID))))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Tells whether the row identified by the class ID, the object ID
    /// and the Access Level ID in argument is in the Object ACL or no.
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <param name="_nAccessLevel"></param>
    /// <param name="_ptACL"></param>
    /// <returns>boolean</returns>
    protected virtual bool IsMatrixRowInObjectACL(int _nClassID, int _nObjectID,
     int _nAccessLevel, IPTAccessList _ptACL)
    {
      IPTAccessListEntry ptACLEntry;
      for (int i = 0;i < _ptACL.GetCount();i++)
      {
        ptACLEntry = _ptACL.GetItem(i);
        if ((_nClassID == ptACLEntry.GetClassID()) && (_nObjectID == ptACLEntry.GetObjectID()) && (_nAccessLevel == ptACLEntry.GetAccessLevel()))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Returns true if we are Editing Security on Amdin Folders.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsEdtingAdminFolderSecurity()
    {
      return m_bEditAdminFolderSecurity;
    }
    
    /// <returns>the current IPTAccessList of the folder whose security is being edited</returns>
    public virtual IPTAccessList GetCurrentFolderACL()
    {
      // can only edit one admin folder at a time so the first
      // element of the object array will be the folder we want 
      IPTAdminFolder ptFolder = (IPTAdminFolder) ((MultiObjectsSecurityModel) m_asOwner.GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).GetObjectArray().GetElement(0);
      IPTAdminFolder ptNewFolder = m_ptSession.GetAdminCatalog().OpenAdminFolder(((IPTServerContext) ptFolder.GetInterfaces("IPTServerContext")).GetObjectID(),
       false);
      // lock the folder for edit								
      IPTServerContext ptSC = (IPTServerContext) ptNewFolder.GetInterfaces("IPTServerContext");
      return ptSC.GetACL();
    }
    
    /// <param name="_ptOldACL">the IPTAccessList from before the ACLs were changed</param>
    /// <returns>true if an admin acl was added or an acl was changed to admin.</returns>
    public virtual bool IsAdminModifiedOnFolder(IPTAccessList _ptOldACL)
    {
      return GetCurrentFolderACL().IsAdminModified(_ptOldACL);
    }
    
    /// <summary>
    /// Returns the array of Object IDs.
    /// </summary>
    /// <returns>int[]</returns>
    public virtual int[] GetObjectIDs()
    {
      return m_arrObjectIDs;
    }
    
    /// <summary>
    /// Returns the String associated with the Access Level ID in argument.
    /// The ID has to be a PT_ACCESS_LEVELS constant.
    /// </summary>
    /// <param name="_nAccessLevelID"></param>
    /// <returns>String</returns>
    public override String GetAccessLevelString(int _nAccessLevelID)
    {
      String sAccessLevel = base.GetAccessLevelString(_nAccessLevelID);
      if (PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE == _nAccessLevelID)
      {
        sAccessLevel = m_asOwner.GetString(148, "ptmsgs_portalinfrastructure");
        }
      return sAccessLevel;
    }
    
    /// <summary>
    /// Returns the array of column info.
    /// </summary>
    /// <returns>int[]</returns>
    public virtual int[] GetColumns()
    {
      return m_arrColumns;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the array of Objects.
    /// </summary>
    /// <returns>XPArrayList</returns>
    public virtual XPArrayList GetObjectArray()
    {
      return m_arrObjects;
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_ptObject">Object being created or edited</param>
    /// <param name="_ptSession">User session</param>
    /// <returns>boolean Flag to know if the initialization was successful or no.</returns>
    public virtual bool InitializeMultiObjsSecurityPage(XPHashtable _htFormData,
     IPTSession _ptSession)
    {
      m_ptSession = _ptSession;
      String[] data;
      if (!_htFormData.ContainsKey(QS_MULTI_OBJ_SECURITY_IDS))
      {
        log.Error("The objectAndClassIDs parameter was not in the Query String.");
        throw new XPException("MultiObjectsSecurityModel::InitializeMultiObjsSecurityPage Unable to start the security matrix.");
        }
      data = (String[]) _htFormData.GetElement(QS_MULTI_OBJ_SECURITY_IDS);
      if ((null == data) || (0 == data.Length) || (null == data[0]))
      {
        log.Error("The objectAndClassIDs parameter was null or empty.");
        throw new XPException("MultiObjectsSecurityModel::InitializeMultiObjsSecurityPage Unable to start the security matrix.");
        }
      m_arrObjects = new XPArrayList();
      String sIDs = data[0];
      int nClassID;
      int nObjectID;
      bool bEditCommunitySecurity = false;
      while (0 != sIDs.Length)
      {
        // JF- Get class ID
        nClassID = XPConvert.ToInteger(XPStringUtility.Substring(sIDs, 0,
         XPStringUtility.IndexOf(sIDs, ",")));
        sIDs = XPStringUtility.Substring(sIDs, XPStringUtility.IndexOf(sIDs,
         ",") + 1);
        if (-1 != XPStringUtility.IndexOf(sIDs, ","))
        {
          // JF- Get object ID
          nObjectID = XPConvert.ToInteger(XPStringUtility.Substring(sIDs,
           0, XPStringUtility.IndexOf(sIDs, ",")));
          sIDs = XPStringUtility.Substring(sIDs, XPStringUtility.IndexOf(sIDs,
           ",") + 1);
        } else
        {
          // JF- Get object ID
          nObjectID = XPConvert.ToInteger(sIDs);
          sIDs = "";
        }
        // JF- Open the Object and add it to the array
        // JF- Open the Object and add it to the array
        if (PT_CLASSIDS.PT_CATALOGFOLDER_ID == nClassID)
        {
          m_arrObjects.Add(m_ptSession.GetCatalog().OpenFolder(nObjectID,
           false));
          if (!_ptSession.GetCatalog().IsCatalogObjectAccessible(nClassID,
           nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN))
          {
            //Raise the error that the matrix could not be started
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, m_asOwner.GetString(433, "ptmsgs_portalinfrastructure"),
             null);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            return false;
          }
        } else
        if (PT_CLASSIDS.PT_CATALOGCARD_ID == nClassID)
        {
          m_arrObjects.Add(m_ptSession.GetCatalog().OpenCard(nObjectID, false));
          if (!_ptSession.GetCatalog().IsCatalogObjectAccessible(nClassID,
           nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN))
          {
            //Raise the error that the matrix could not be started
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, m_asOwner.GetString(434, "ptmsgs_portalinfrastructure"),
             null);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            return false;
          }
        } else
        if (PT_CLASSIDS.PT_ADMIN_FOLDER_ID == nClassID)
        {
          IPTAdminFolder ptAdminFolder = m_ptSession.GetAdminCatalog().OpenAdminFolder(nObjectID,
           false);
          if (PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER != ptAdminFolder.GetFolderType())
          {
            if (m_bEditAdminFolderSecurity)
            {
              //Raise the error that the matrix could not be started
              UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
               null, m_asOwner.GetString(432, "ptmsgs_portalinfrastructure"),
               null);
              UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
               m_asOwner.GetApplication());
              throw new XPException("MultiObjectsSecurityModel::InitializeMultiObjsSecurityPage You can only Edit Security settings on one Administrative Folder at the time.");
              } else
            {
              m_arrObjects.Add(ptAdminFolder);
              m_bEditAdminFolderSecurity = true;
              if (!_ptSession.GetAdminCatalog().IsAdminFolderAccessible(nObjectID,
               PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN))
              {
                //Raise the error that the matrix could not be started
                UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
                 null, m_asOwner.GetString(435, "ptmsgs_portalinfrastructure"),
                 null);
                UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
                 m_asOwner.GetApplication());
                return false;
              }
            }
          } else
          {
            bEditCommunitySecurity = true;
            log.Warn("InitializeMultiObjsSecurityPage Ignoring Community with ID: " + nObjectID + ". (The only way to edit the security of the Community" + " is to use the Edit this Community button).");
            }
        } else
        // JF- No ACL for Users
        // JF- The community ACL cannot be changed with the matrix.
        // (community is a special case, it doesn't get the ACl from the folder)
        if ((PT_CLASSIDS.PT_USER_ID != nClassID) && (!m_bEditAdminFolderSecurity))
        {
          try
          {
            m_arrObjects.Add(m_ptSession.GetObjectManagers(nClassID).Open(nObjectID,
             false));
            if (!_ptSession.GetObjectManagers(nClassID).IsObjectAccessible(nObjectID,
             _ptSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN))
            {
              //Raise the error that the matrix could not be started
              UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
               null, m_asOwner.GetString(436, "ptmsgs_portalinfrastructure"),
               null);
              UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
               m_asOwner.GetApplication());
              return false;
            }
          }
          catch (Exception e)
          {
            log.Warn("InitializeMultiObjsSecurityPage Unable to open object with class ID: " + nClassID + " and object ID: " + nObjectID + ". The following exception was thrown: " + e);
            }
        } else
        if (PT_CLASSIDS.PT_USER_ID == nClassID)
        {
          log.Warn("InitializeMultiObjsSecurityPage Ignoring User with ID: " + nObjectID + ". (Users don\'t have security).");
          } else
        if (m_bEditAdminFolderSecurity)
        {
          //Raise the error that the matrix could not be started
          UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
           null, m_asOwner.GetString(425, "ptmsgs_portalinfrastructure"),
           null);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          throw new XPException("MultiObjectsSecurityModel::InitializeMultiObjsSecurityPage You cannot edit security on Administrative Folders and Objects at the same time.");
          }
      }
      if (0 < m_arrObjects.GetSize())
      {
        // JF- Class ID of Objects to display on the tree
        m_arrObjectClassIDs = new int[]{PT_CLASSIDS.PT_USER_ID, PT_CLASSIDS.PT_USERGROUP_ID};
        // JF- We initialize the array of access levels with the contants from PT_ACCESS_LEVELS
        // and the associated Strings. This will be used by the Section to display the drop-down 
        // list on each row.
        InitAccessLevels();
        this.m_ptObject = (IPTObject) m_arrObjects.GetElement(0);
        // JF- Set the icon to display on each row.
        SetRowIconByClassID(PT_CLASSIDS.PT_USER_ID, PTImageType.ICON_USER);
        SetRowIconByClassID(PT_CLASSIDS.PT_USERGROUP_ID, PTImageType.ICON_GROUP);
        // JF- We initialize the m_bIsReadOnly flag (Only users with "Edit Object ACL" activity rights can edit this page).
        InitReadOnlyAccessFlag(_ptSession);
        base.InitializeExpandableList(m_asOwner.GetString(147, "ptmsgs_portalinfrastructure"),
         CreateColumnInfos(), PTImageType.ICON_GROUP, m_asOwner.GetString(106,
         "ptmsgs_portalinfrastructure"), 11);
        for (int i = 0;i < m_arrObjects.GetSize();i++)
        {
          IPTObject ptObject = (IPTObject) m_arrObjects.GetElement(i);
          InitListWithACLFromObject(ptObject);
        }
      } else
      {
        String sMessage;
        if (bEditCommunitySecurity)
        {
          sMessage = m_asOwner.GetString(452, "ptmsgs_portalinfrastructure");
          } else
        {
          sMessage = m_asOwner.GetString(424, "ptmsgs_portalinfrastructure");
          }
        //Raise the error that the matrix could not be started
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, sMessage, null);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        throw new XPException("MultiObjectsSecurityModel::InitializeMultiObjsSecurityPage Array of Objects is empty.");
        }
      return true;
    }
    
    /// <summary>
    /// Resets all the changes that were made so far.
    /// </summary>
    public virtual void ResetSettings()
    {
      m_saData.ClearArray();
      for (int i = 0;i < m_arrObjects.GetSize();i++)
      {
        IPTObject ptObject = (IPTObject) m_arrObjects.GetElement(i);
        InitListWithACLFromObject(ptObject);
      }
    }
    
    /// <summary>
    /// Creates the array of clolumn info.
    /// </summary>
    /// <returns>Object[][]</returns>
    protected virtual Object[][] CreateColumnInfos()
    {
      Object[][] arrExpListColInfo;
      // JF- Column mapping
      m_arrColumns = new int[EXPLIST_COL_MAX + (3 * m_arrObjects.GetSize())];
      m_arrColumns[0] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
      m_arrColumns[1] = EXPLIST_COL_CLASSID;
      m_arrColumns[2] = EXPLIST_COL_OBJECTID;
      m_arrColumns[3] = EXPLIST_COL_STRING;
      m_arrColumns[4] = EXPLIST_COL_ACCESSLEVEL_ID;
      m_arrColumns[5] = EXPLIST_COL_ACCESSLEVEL_STRING;
      m_arrColumns[6] = EXPLIST_COL_ROWACCESS;
      m_arrColumns[7] = EXPLIST_COL_MANDATORY;
      m_arrColumns[8] = EXPLIST_COL_GROUPTREEASID;
      m_htObjectColumnKeys = new XPHashtable();
      // JF- Create the the 2D array to give column information to the super class.
      arrExpListColInfo = new Object[m_arrObjects.GetSize() + 2][];
      for (int j2c_index = 0;j2c_index < m_arrObjects.GetSize() + 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      // First column: object name
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_STRING;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(103,
       "ptmsgs_portalinfrastructure");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "40%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      int k = EXPLIST_COL_MAX;
      int nCount = m_arrObjects.GetSize();
      m_arrObjectIDs = new int[nCount];
      for (int i = 0;i < nCount;i++)
      {
        IPTObject ptObject = (IPTObject) m_arrObjects.GetElement(i);
        IPTServerContext ptsc = (IPTServerContext) ptObject.GetInterfaces("IPTServerContext");
        String sObjectKey = XPConvert.ToString(ptObject.GetClassID()) + XPConvert.ToString(ptsc.GetObjectID());
        m_arrObjectIDs[i] = ptsc.GetObjectID();
        // Rights column
        arrExpListColInfo[i + 1][EXPLIST_COLUMN_ID] = EXPLIST_COL_ACCESSLEVEL_STRING + sObjectKey;
        arrExpListColInfo[i + 1][EXPLIST_COLUMN_TITLE] = XPHttpUtility.HtmlEncode(GeneralHelpers.TruncateLongString(ptObject.GetLocalizedName(),
         ObjEditorModel.OBJECT_NAME_TRUNCATE, false));
        arrExpListColInfo[i + 1][EXPLIST_COLUMN_WIDTH] = "15%";
        arrExpListColInfo[i + 1][EXPLIST_COLUMN_COLSPAN] = "1";
        arrExpListColInfo[i + 1][EXPLIST_COLUMN_ENABLESORT] = false;
        m_arrColumns[k] = k;
        m_htObjectColumnKeys.PutElement(EXPLIST_COL_ACCESSLEVEL_ID + sObjectKey,
         k);
        m_arrColumns[k + 1] = k + 1;
        m_htObjectColumnKeys.PutElement(EXPLIST_COL_ACCESSLEVEL_STRING + sObjectKey,
         k + 1);
        m_arrColumns[k + 2] = k + 2;
        m_htObjectColumnKeys.PutElement(EXPLIST_COL_ROWACCESS + sObjectKey,
         k + 2);
        k = k + 3;
      }
      arrExpListColInfo[nCount + 1][EXPLIST_COLUMN_ID] = -1;
      arrExpListColInfo[nCount + 1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(360,
       "ptmsgs_portalinfrastructure");
      arrExpListColInfo[nCount + 1][EXPLIST_COLUMN_WIDTH] = "15%";
      arrExpListColInfo[nCount + 1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[nCount + 1][EXPLIST_COLUMN_ENABLESORT] = false;
      return arrExpListColInfo;
    }
    
    /// <summary>
    /// Helper method to get the sort.
    /// </summary>
    /// <returns>int[]</returns>
    protected override int[] GetArrayOfColumns()
    {
      return m_arrColumns;
    }
    
    /// <summary>
    /// Inits the array of supported Access Levels.
    /// </summary>
    protected override void InitAccessLevels()
    {
      m_arrAccessLevels = new int[5];
      m_arrAccessLevels[0] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE;
      m_arrAccessLevels[1] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ;
      m_arrAccessLevels[2] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT;
      m_arrAccessLevels[3] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT;
      m_arrAccessLevels[4] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN;
    }
    
    /// <summary>
    /// Initializes the list with the ACL from the PTObject.
    /// </summary>
    /// <param name="_ptObject">Object being created or edited</param>
    protected virtual void InitListWithACLFromObject(IPTObject _ptObject)
    {
      IPTServerContext ptscObject = (IPTServerContext) _ptObject.GetInterfaces("IPTServerContext");
      IPTAccessListEntry ptACLEntry;
      Object[] oNewRow;
      m_arrLowAccessObjects = new XPArrayList();
      m_arrNoContentTree = new XPArrayList();
      // JF- Keep track of the items we are hiding in the tree
      XPArrayList arrTreeHiddenItems = new XPArrayList();
      SetWrapColumnHeaders(false);
      IPTAccessList ptACL = ptscObject.GetACL();
      String sObjectKey = XPConvert.ToString(_ptObject.GetClassID()) + XPConvert.ToString(ptscObject.GetObjectID());
      String strCurrentObjectColAccessLevelID = EXPLIST_COL_ACCESSLEVEL_ID + sObjectKey;
      String strCurrentObjectColAccessLevelString = EXPLIST_COL_ACCESSLEVEL_STRING + sObjectKey;
      String strCurrentObjectColRowAccess = EXPLIST_COL_ROWACCESS + sObjectKey;
      for (int i = 0;i < ptACL.GetCount();i++)
      {
        ptACLEntry = ptACL.GetItem(i);
        int nACLClassID = ptACLEntry.GetClassID();
        int nACLObjectID = ptACLEntry.GetObjectID();
        int nACLIndex = GetACLIndex(nACLClassID, nACLObjectID);
        if (-1 == nACLIndex)
        {
          oNewRow = new Object[m_arrColumns.Length];
          oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
          m_nNextIndex++;
          oNewRow[EXPLIST_COL_CLASSID] = nACLClassID;
          oNewRow[EXPLIST_COL_OBJECTID] = nACLObjectID;
          oNewRow[EXPLIST_COL_STRING] = ptACLEntry.GetName();
          oNewRow[EXPLIST_COL_ROWACCESS] = ptACLEntry.GetReadOnly();
          oNewRow[EXPLIST_COL_GROUPTREEASID] = "";
          int k = EXPLIST_COL_MAX;
          while (k < m_arrColumns.Length)
          {
            if (GetObjectColumn(strCurrentObjectColAccessLevelID) == k && GetObjectColumn(strCurrentObjectColAccessLevelString) == k + 1 && GetObjectColumn(strCurrentObjectColRowAccess) == k + 2)
            {
              oNewRow[k] = ptACLEntry.GetAccessLevel();
              oNewRow[k + 1] = GetAccessLevelString(ptACLEntry.GetAccessLevel());
              oNewRow[k + 2] = ptACLEntry.GetReadOnly();
            } else
            {
              oNewRow[k] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE;
              oNewRow[k + 1] = GetAccessLevelString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE);
              oNewRow[k + 2] = PT_ACCESS_LIST_ENTRY_READWRITE;
            }
            k = k + 3;
          }
          base.GetItems().AddRow(oNewRow);
        } else
        {
          m_saData.SetItem(nACLIndex, GetObjectColumn(strCurrentObjectColAccessLevelID),
           ptACLEntry.GetAccessLevel());
          m_saData.SetItem(nACLIndex, GetObjectColumn(strCurrentObjectColAccessLevelString),
           GetAccessLevelString(ptACLEntry.GetAccessLevel()));
          m_saData.SetItem(nACLIndex, GetObjectColumn(strCurrentObjectColRowAccess),
           ptACLEntry.GetReadOnly());
          if (PT_ACCESS_LIST_ENTRY_READONLY == ptACLEntry.GetReadOnly())
          {
            m_saData.SetItem(nACLIndex, EXPLIST_COL_ROWACCESS, PT_ACCESS_LIST_ENTRY_READONLY);
            }
        }
        if ((PT_ACCESS_LIST_ENTRY_READONLY == ptACLEntry.GetReadOnly()) && !arrTreeHiddenItems.Contains(nACLClassID + "" + nACLObjectID))
        {
          // JF- If this is a read only row, we also add it to the array of hidden 
          // objects, this way it won't be displayed in the tree.
          // (Otherwise it would be possible to remove it from the list by unchecking it in the tree)
          int[][] arrReadOnlyObjects = new int[1][];
          for (int j2c_index = 0;j2c_index < 1;j2c_index++)
          {
            arrReadOnlyObjects[j2c_index] = new int[2];
          }
          arrReadOnlyObjects[0][SelectPTObjectModel.READ_ONLY_ROW_CLASSID] = nACLClassID;
          arrReadOnlyObjects[0][SelectPTObjectModel.READ_ONLY_ROW_OBJECTID] = nACLObjectID;
          SetHiddenObjects(arrReadOnlyObjects);
          arrTreeHiddenItems.Add(nACLClassID + "" + nACLObjectID);
        } else
        {
          if (!m_arrLowAccessObjects.Contains(nACLClassID + "" + nACLObjectID) && !HasAccessRights(m_ptSession,
           nACLClassID, nACLObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
          {
            m_arrLowAccessObjects.Add(nACLClassID + "" + nACLObjectID);
          }
        }
        if ((PT_CLASSIDS.PT_USERGROUP_ID == nACLClassID) && !HasAccessRights(m_ptSession,
         nACLClassID, nACLObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
        {
          m_arrNoContentTree.Add(XPConvert.ToString(nACLObjectID));
        }
      }
    }
    
    /// <summary>
    /// Saves the access level for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      // JF- We need to save the privilege drop-downs.
      if (!m_bIsReadOnly)
      {
        int k = EXPLIST_COL_MAX;
        while (k < m_arrColumns.Length)
        {
          // JF- Save the privilege only if the user had rights to Edit this row.
          bool bCellAccess = XPConvert.ToBoolean(_saData.GetItem(_nRowIndex,
           m_arrColumns[k + 2]));
          // JF- We only save it if the user has write access to that particular cell.
          if (PT_ACCESS_LIST_ENTRY_READWRITE == bCellAccess)
          {
            // JF- We are building the select input name the same way we did 
            // in ObjectSecurityView when we displayed it.
            String sInputSelectName = GetUniqueString(MultiObjectsSecurityView.HTMLSELECT_ACCESS_LEVEL) + _nRowIndex + k;
            String[] data = (String[]) _htFormData.GetElement(sInputSelectName);
            if ((data != null) && (0 != data.Length) && (null != data[0]))
            {
              // JF- we set the new value in the access level ID and String columns.
              _saData.SetItem(_nRowIndex, m_arrColumns[k], XPConvert.ToInteger(data[0]));
              _saData.SetItem(_nRowIndex, m_arrColumns[k + 1], GetAccessLevelString(XPConvert.ToInteger(data[0])));
              } else
            {
              log.Error("MultiObjectsSecurityModel::SaveRow Error when trying to save the access level for row " + _nRowIndex + " with input name: " + sInputSelectName + ". The access level value posted by the form is: " + data);
              }
          }
          k = k + 3;
        }
      }
      int nObjectID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, EXPLIST_COL_OBJECTID));
      String sGroupTreeASID = (String) _saData.GetItem(_nRowIndex, EXPLIST_COL_GROUPTREEASID);
      // JF- We save the Group tree ID only if we don't already have it.
      if (("").Equals(sGroupTreeASID) && _htFormData.ContainsKey(GetUniqueString(ObjectSecurityView.HTMLINPUT_GROUPTREEASID) + nObjectID))
      {
        String[] data = (String[]) _htFormData.GetElement(GetUniqueString(ObjectSecurityView.HTMLINPUT_GROUPTREEASID) + nObjectID);
        if ((null != data) && !(0 == data.Length))
        {
          _saData.SetItem(_nRowIndex, EXPLIST_COL_GROUPTREEASID, data[0]);
          }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Saves the security settings into the IPTObject.
    /// </summary>
    protected virtual void StoreSecurityOnObject(IPTObject _ptObject)
    {
      IPTServerContext ptscObject = (IPTServerContext) _ptObject.GetInterfaces("IPTServerContext");
      int nClassID;
      int nObjectID;
      int nAccessLevel;
      bool bRowAccess;
      String sObjectName;
      String sObjectKey = XPConvert.ToString(_ptObject.GetClassID()) + XPConvert.ToString(ptscObject.GetObjectID());
      IPTAccessList ptACL = ptscObject.GetACL();
      // JF- First we remove all the users and groups from the Object ACL except the read-only ones.
      // (We loop through the ACL entry list in reverse order because we are removing items from 
      // the list inside the loop.)
      for (int i = ptACL.GetCount() - 1;i >= 0;i--)
      {
        if (PT_ACCESS_LIST_ENTRY_READWRITE == ptACL.GetItem(i).GetReadOnly())
        {
          try
          {
            ptACL.Remove(i);
          }
          catch (Exception e)
          {
            log.Error("MultiObjectsSecurityModel::StoreSecurityOnObject Error when trying to remove an ACL entry. " + "The following exception was thrown: " + e);
            }
        }
      }
      // JF- Then we go through all the users and groups from the list and we add 
      // them to the Object ACL (except the read only ones.)		
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        bRowAccess = XPConvert.ToBoolean(m_saData.GetItem(i, GetObjectColumn(EXPLIST_COL_ROWACCESS + sObjectKey)));
        nClassID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_COL_CLASSID));
        nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_COL_OBJECTID));
        if (PT_ACCESS_LIST_ENTRY_READWRITE == bRowAccess)
        {
          nAccessLevel = XPConvert.ToInteger(m_saData.GetItem(i, GetObjectColumn(EXPLIST_COL_ACCESSLEVEL_ID + sObjectKey)));
          if (PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE != nAccessLevel)
          {
            sObjectName = (String) m_saData.GetItem(i, EXPLIST_COL_STRING);
            try
            {
              ptACL.Add(nClassID, nObjectID, nAccessLevel, sObjectName, -1,
               bRowAccess);
            }
            catch (Exception e)
            {
              log.Error("MultiObjectsSecurityModel::StoreSecurityOnObject Error when trying to add a new ACL entry. " + "The following exception was thrown:" + e);
              }
          }
        }
      }
      try
      {
        ptscObject.LockObject();
        ptscObject.Store();
        ptscObject.UnlockObject();
      }
      catch (Exception e)
      {
        log.Error(e, "MultiObjectsSecurityModel::StoreSecurityOnObject Unable to store the Object.");
        }
    }
    private int GetObjectColumn(String strKey)
    {
      Object o = m_htObjectColumnKeys.GetElement(strKey);
      if (null != o)
      {
        return XPConvert.ToInteger(o);
      } else
      {
        log.Error("Object\'s column with key: " + strKey + " was not found.");
        throw new XPException("Object\'s column with key: " + strKey + " was not found.");
        }
    }
  }
}