using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.securitymatrix
{
  /// <summary>
  /// This is class is used to print out together the Views for
  /// the Multi objects security page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SecurityMatrixDP : EditorDP
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SecurityMatrix";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(151, "ptmsgs_portalinfrastructure");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for that Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).Display());
      result.AddInnerHTMLElement(CreateContentTable(views, null));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY).DisplayJavascript());
      return myScripts;
    }
    
    /// <summary>
    /// We don't want a help subheader here.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()"></seealso>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return null;
    }
  }
}