using System;
// Plumtree server
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.securitymatrix
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Misc Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SecurityMatrixEditorAS : PTEditorAS
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SecurityMatrixEditor";
    
    /// <summary>
    /// Storage name for Security Matrix.
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_MULTI_SECURITY = "MultiObjectsSecuritySecurityMatrixEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SecurityMatrixEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(151, "ptmsgs_portalinfrastructure"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (SecurityMatrixRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = SecurityMatrixModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(SecurityMatrixModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new SecurityMatrixDP());
      RegisterPage(new ABOBlankSelectDP());
      RegisterPage(new ABOPopupSelectDP());
      RegisterPage(new ABOBlankResultsDP());
      RegisterPage(new ABOPopupResultsDP());
      // Register Views
      RegisterView(ABOPopupSelectView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ABOPopupResultsView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(SecurityMatrixRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      SetCurrentPage(SecurityMatrixDP.STR_MVC_CLASS_NAME);
      // Register multi objects security pages
      RegisterModel(MultiObjectsSecurityModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_SECURITY);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel mySecModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_SECURITY);
      RegisterView(MultiObjectsSecurityView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_SECURITY,
       mySecModel);
      RegisterControl(MultiObjectsSecurityControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_SECURITY,
       mySecModel);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SecurityMatrixDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_EditSecurity");
      }
    }
  }
}