using System;
// Framework Imports
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portaluiinfrastructure.securitymatrix
{
  /// <summary>
  /// This class contains the additional repost actions.
  /// The ones specific to this Editor.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SecurityMatrixRepostControl : EditorRepostControl
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SecurityMatrixRepost";
    
    /// <summary>
    /// abo - apply changes now 
    /// </summary>
    public const int POSTTOSELF_ACTION_APPLY_ONLY_THIS_FOLDER = 21;
    
    /// <summary>
    /// abo - apply changes later 1 
    /// </summary>
    public const int POSTTOSELF_ACTION_APPLY_RECURSIVELY = 22;
    
    /// <summary>
    /// abo - cancel all changes 
    /// </summary>
    public const int POSTTOSELF_ACTION_CANCEL_ALL_CHANGES = 24;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SecurityMatrixRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="int"></param>
    protected override void PerformAction(int _nAction)
    {
      // abo - set false for non-normal finish
      bool doNormalFinish = true;
      // abo - where to go next page
      Redirect myRedirect = null;
      // abo - intercept done button. if there
      // were changes to security, then redirect 
      // to blank DP that presents ABO option.
      MultiObjectsSecurityModel securityModel = (MultiObjectsSecurityModel) m_asOwner.GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY);
      if ((_nAction == POSTTOSELF_ACTION_FINISH) && securityModel.HasSecurityMatrixChanged() && securityModel.IsEdtingAdminFolderSecurity())
      {
        if (securityModel.CanPropagateSecurity())
        {
          myRedirect = new Redirect();
          myRedirect.SetLinkGetCachedSpace(m_asOwner);
          myRedirect.SetDisplayPage(ABOBlankSelectDP.STR_MVC_CLASS_NAME);
          SetRedirect(myRedirect);
        } else
        {
          PerformApplySecurity(false, _nAction);
        }
        // bypass the normal finish
        doNormalFinish = false;
      }
      // abo - since pop-up shares the repost control and 
      // opens with no control, we want a bypass
      if (_nAction == POSTTOSELF_ACTION_UNDEFINED)
      {
        doNormalFinish = false;
      }
      // abo - cancel all changes
      if (_nAction == POSTTOSELF_ACTION_CANCEL_ALL_CHANGES || _nAction == POSTTOSELF_ACTION_CANCEL)
      {
        _nAction = POSTTOSELF_ACTION_CANCEL;
      }
      // abo - apply only this folder 
      if (_nAction == POSTTOSELF_ACTION_APPLY_ONLY_THIS_FOLDER)
      {
        PerformApplySecurity(false, _nAction);
      }
      // abo - apply all acls to child objects and subfolders
      if (_nAction == POSTTOSELF_ACTION_APPLY_RECURSIVELY)
      {
        PerformApplySecurity(true, _nAction);
      }
      if (doNormalFinish)
      {
        base.PerformAction(_nAction);
        ((ExpListControl) m_asOwner.GetControl(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).PerformRepostAction(_nAction,
         m_htFormData);
        if ((RepostControl.POSTTOSELF_ACTION_FINISH == _nAction) || (RepostControl.POSTTOSELF_ACTION_CANCEL == _nAction))
        {
          myRedirect = new Redirect();
          myRedirect.SetLinkGetCachedSpace(m_asOwner);
          myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
          SetRedirect(myRedirect);
        }
      }
    }
    private void PerformApplySecurity(bool bPropagateAllACLs, int _nAction)
    {
      //  get the acl before it gets changed by finish, we need it to compare to the new acl
      IPTAccessList ptOldACL = ((SecurityMatrixModel) m_model).GetCurrentFolderACL();
      // manually save acls on the folders
      ((SecurityMatrixModel) m_model).Finish();
      bool bDisplayJobsPopup = false;
      if (bPropagateAllACLs || ((SecurityMatrixModel) m_model).IsAdminModifiedOnFolder(ptOldACL))
      {
        // now create the ABO job to update security
        ((SecurityMatrixModel) m_model).PropagateSecurityUsingABO(bPropagateAllACLs);
        bDisplayJobsPopup = true;
      }
      if (bDisplayJobsPopup)
      {
        // we now redirect to our blank page again
        // so that we can show our jobs pop-up
        Redirect myRedirect = new Redirect();
        myRedirect.SetLinkGetCachedSpace(m_asOwner);
        myRedirect.SetDisplayPage(ABOBlankResultsDP.STR_MVC_CLASS_NAME);
        SetRedirect(myRedirect);
      } else
      {
        ((ExpListControl) m_asOwner.GetControl(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).PerformRepostAction(_nAction,
         m_htFormData);
        Redirect myRedirect = new Redirect();
        myRedirect.SetLinkGetCachedSpace(m_asOwner);
        myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
        SetRedirect(myRedirect);
      }
    }
  }
}