/*
 * Created on Feb 26, 2003
 *
 * To change this generated comment go to
 * Window>Preferences>Java>Code Generation>Code Template
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.sso;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace.utils;
namespace com.plumtree.portaluiinfrastructure.sso.integrations
{
  /// <summary>
  /// A degenerate implementation of <c>ISSOIntegration</c>.
  /// </summary>
  /// <author>mikej</author>
  public class BasicSSO : ISSOIntegration
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_SSO),
     "com.plumtree.portaluiinfrastructure.sso.integrations.BasicSSO");
    private const String COOKIE_SETTING = "Cookie";
    private const String SECURE_HEADER = "SecureHeader";
    private const String NAME_HEADER = "NameHeader";
    private const String PREFIX_HEADER = "PrefixHeader";
    private const String PASSWORD_HEADER = "PasswordHeader";
    private const String USE_REMOTE_USER = "UseRemoteUser";
    private const String LOGOUT_URL = "LogoutURL";
    protected String[] s_asHeaders;
    protected String[] s_asCookies;
    protected String s_sNameHeader;
    protected String s_sPrefixHeader;
    protected String s_sPasswordHeader;
    protected String m_sLogoutURL;
    protected bool m_bUseRemoteUser;
    // mj: whether to use the basic auth header for name, prefix, and password
    protected bool s_bAuthName;
    protected bool s_bAuthPrefix;
    protected bool s_bAuthPassword;
    private const String AUTH_HEADER = "Authorization";
    
    /// <summary>
    /// Implementations of <c>ISSOIntegration</c> must have a default constructor.
    /// </summary>
    public BasicSSO()
    {
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Initialize(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public virtual bool Initialize(XPHashtable mapSettings)
    {
      XPArrayList list = (XPArrayList) mapSettings.GetElement(SECURE_HEADER);
      if (list != null && list.GetSize() > 0)
      {
        s_asHeaders = new String[list.GetSize()];
        s_asHeaders = (String[]) list.ToArray(s_asHeaders);
      } else
      {
        s_asHeaders = null;
      }
      list = (XPArrayList) mapSettings.GetElement(COOKIE_SETTING);
      if (list != null && list.GetSize() > 0)
      {
        s_asCookies = new String[list.GetSize()];
        s_asCookies = (String[]) list.ToArray(s_asCookies);
      } else
      {
        s_asCookies = null;
      }
      // TODO Refactor: extract method on these mapSettings if statements. Will the code do the right thing if some of these are omitted? (see bug# 42982)
      list = (XPArrayList) mapSettings.GetElement(NAME_HEADER);
      if (list != null && list.GetSize() > 0)
      {
        s_sNameHeader = (String) list.GetElement(0);
      }
      // mel: Workaround for bug# 42982, added guards around equalsIgnoreCase to avoid null ptr exception in .NET when setting is omitted
      if (s_sNameHeader != null)
      {
        s_bAuthName = XPStringUtility.EqualsIgnoreCase(AUTH_HEADER, s_sNameHeader);
        }
      list = (XPArrayList) mapSettings.GetElement(PREFIX_HEADER);
      if (list != null && list.GetSize() > 0)
      {
        s_sPrefixHeader = (String) list.GetElement(0);
      }
      if (s_sPrefixHeader != null)
      {
        s_bAuthPrefix = XPStringUtility.EqualsIgnoreCase(AUTH_HEADER, s_sPrefixHeader);
        }
      list = (XPArrayList) mapSettings.GetElement(PASSWORD_HEADER);
      if (list != null && list.GetSize() > 0)
      {
        s_sPasswordHeader = (String) list.GetElement(0);
      }
      if (s_sPasswordHeader != null)
      {
        s_bAuthPassword = XPStringUtility.EqualsIgnoreCase(AUTH_HEADER, s_sPasswordHeader);
        }
      list = (XPArrayList) mapSettings.GetElement(USE_REMOTE_USER);
      if (list != null && list.GetSize() > 0)
      {
        m_bUseRemoteUser = "1".Equals(list.GetElement(0));
      } else
      {
        m_bUseRemoteUser = false;
      }
      list = (XPArrayList) mapSettings.GetElement(LOGOUT_URL);
      if (list != null && list.GetSize() > 0)
      {
        m_sLogoutURL = (String) list.GetElement(0);
      }
      log.Info("Plumtree BasicSSO NameHeader: " + s_sNameHeader);
      log.Info("Plumtree BasicSSO PrefixHeader: " + s_sPrefixHeader);
      log.Info("Plumtree BasicSSO PasswordHeader: " + s_sPasswordHeader);
      log.Info("Plumtree BasicSSO SecureHeader: " + (s_asHeaders == null ? 0 : s_asHeaders.Length) + " entries");
      log.Info("Plumtree BasicSSO Cookie: " + (s_asCookies == null ? 0 : s_asCookies.Length) + " entries");
      log.Info("Plumtree BasicSSO UseRemoteUser: {0}", (m_bUseRemoteUser ? "true" : "false"));
      log.Info("Plumtree BasicSSO LogoutURL: " + m_sLogoutURL);
      if (s_sNameHeader == null && m_bUseRemoteUser == false)
      {
        log.Error("Plumtree BasicSSO can\'t work without specifying a username header <NameHeader> or enabling <UseRemoteUser>");
        return false;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetLoginInfo(com.plumtree.openfoundation.web.IXPRequest)"></seealso>
    public virtual SSOLoginInfo GetLoginInfo(IXPRequest request)
    {
      String sName = null;
      String sPassword = null;
      // If the admin set the UseRemoteUser flag, it takes precedence.
      if (m_bUseRemoteUser)
      {
        sName = request.GetRemoteUser();
        log.Debug("BasicSSO looked at the RemoteUser variable and found this username: {0}",
         sName);
      }
      if (null == sName || sName.Length == 0)
      {
        // Check if it's a basic auth name header
        if (s_bAuthName)
        {
          sName = GetAuthName(request);
          log.Debug("BasicSSO looked at basic auth header \'{0}\' and found this username: {1}",
           s_sNameHeader, sName);
        } else
        // Last resort is to look in the specified header.
        if (null != s_sNameHeader)
        {
          sName = request.GetHeader(s_sNameHeader);
          log.Debug("BasicSSO looked at username header \'{0}\' and found this username: {1}",
           s_sNameHeader, sName);
        } else
        // If we get here, then we are not finding any usernames anywhere.
        {
          log.Error("BasicSSO did not find a valid username in the request.");
          }
      }
      // mj: only look for a prefix if it's not already in the username
      if (s_sPrefixHeader != null)
      {
        String sPrefix = null;
        if (s_bAuthPrefix)
        {
          // mj: if we want both username and domain from auth header, it's already handled above.
          if (!s_bAuthName)
          {
            String sAuthName = GetAuthName(request);
            int nEnd = XPStringUtility.IndexOf(sAuthName, '\\');
            if (nEnd > 0)
            {
              sPrefix = XPStringUtility.Substring(sAuthName, 0, nEnd);
            }
          }
        } else
        {
          sPrefix = request.GetHeader(s_sPrefixHeader);
        }
        log.Debug("BasicSSO looked at the prefix header \'" + s_sPrefixHeader + "\' and found this prefix: " + sPrefix);
        if (sPrefix != null && sPrefix.Length > 0)
        {
          // mj: if there's already a prefix in the username, strip it out
          int nSlash = XPStringUtility.IndexOf(sName, '\\');
          if (nSlash > 0)
          {
            log.Debug("BasicSSO is stripping the prefix from the username \'" + sName + "\' and substituting this prefix from the header: " + sPrefix);
            sName = sPrefix + XPStringUtility.Substring(sName, nSlash);
          } else
          {
            sName = sPrefix + '\\' + sName;
          }
        }
        log.Debug("BasicSSO is using this combined prefix and username: " + sName);
        }
      if (s_sPasswordHeader != null)
      {
        if (s_bAuthPassword)
        {
          sPassword = GetAuthPassword(request);
        } else
        {
          sPassword = request.GetHeader(s_sPasswordHeader);
        }
        log.Debug("BasicSSO captured a password.");
      }
      return new SSOLoginInfo(sName, sPassword);
    }
    private static String GetAuthName(IXPRequest request)
    {
      String sAuth = request.GetHeader(AUTH_HEADER);
      if (sAuth == null || !XPStringUtility.StartsWith(XPStringUtility.ToUpperCase(sAuth),
       "BASIC "))
      {
        if (sAuth == null)
        {
          log.Debug("BasicSSO: Authentication header was null. Trying basic auth server variable instead.");
          } else
        {
          log.Debug("BasicSSO: Authentication header was invalid (didn\'t start with \"BASIC \". " + "Trying basic auth server variable instead. Header value was: " + sAuth);
          }
        return request.GetBasicAuthUserName();
      }
      log.Debug("BasicSSO is parsing the basic auth username.");
      sAuth = XPEncoding.GetString(XPBase64Coder.Decode(XPStringUtility.Substring(sAuth,
       6)), "utf-8");
      // mj: the basic auth header looks like 'domain\\username:password'.
      //     domain is optional. we return the whole username, and strip 
      //     the domain later if necessary.
      // TODO: what if the username has a colon in it?
      int nEnd = XPStringUtility.IndexOf(sAuth, ':');
      if (nEnd < 0)
      {
        return sAuth;
      }
      return XPStringUtility.Substring(sAuth, 0, nEnd);
    }
    private static String GetAuthPassword(IXPRequest request)
    {
      String sAuth = request.GetHeader(AUTH_HEADER);
      if (sAuth == null || !XPStringUtility.StartsWith(XPStringUtility.ToUpperCase(sAuth),
       "BASIC "))
      {
        if (sAuth == null)
        {
          log.Debug("BasicSSO: Authentication header was null. Trying basic auth server variable instead.");
          } else
        {
          log.Debug("BasicSSO: Authentication header was invalid (didn\'t start with \"BASIC \". " + "Trying basic auth server variable instead. Header value was: " + sAuth);
          }
        return request.GetBasicAuthPassword();
      }
      log.Debug("BasicSSO is parsing basic auth password.");
      sAuth = XPEncoding.GetString(XPBase64Coder.Decode(XPStringUtility.Substring(sAuth,
       6)), "utf-8");
      return XPStringUtility.Substring(sAuth, XPStringUtility.IndexOf(sAuth,
       ':') + 1);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSSOProductName()"></seealso>
    public virtual String GetSSOProductName()
    {
      return "Plumtree Basic SSO";
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureCookies()"></seealso>
    public virtual String[] GetSecureCookies()
    {
      return s_asCookies;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureHeaders()"></seealso>
    public virtual String[] GetSecureHeaders()
    {
      return s_asHeaders;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Logout(com.plumtree.openfoundation.web.IXPResponse,java.lang.String)"></seealso>
    public virtual bool OnLogout(IXPResponse response, String sReturnURL)
    {
      if (null != m_sLogoutURL && m_sLogoutURL.Length > 0)
      {
        String sURL = m_sLogoutURL;
        // If the logout URL ends with an equal sign, we append the portal return URL.  This allows us
        //	to pass a return URL to the SSO logout page in the query string by specifying an URL like:
        //		http://qweb2/gsroot/sso/redirect.asp?url=
        //
        if (XPStringUtility.EndsWith(m_sLogoutURL, "="))
        {
          sURL+=XPHttpUtility.UrlEncode(sReturnURL, "UTF-8");
        }
        // BT: Bug 7823597 - Set ptloginoccurred to false when logging out
        // in CustomSSO/Basic SSO mode.
        LoginHandlers.ClearLoginOccurredCookiePresent(response);
        log.Debug("BasicSSO is setting ptloginoccurred cookie to false");
        response.Redirect(sURL);
        log.Info("BasicSSO is redirecting to " + sURL);
        return true;
      }
      return false;
    }
  }
}