using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.sso;
namespace com.plumtree.portaluiinfrastructure.sso.integrations
{
  /// <summary>
  /// Handles SSO integration with Windows Integrated Authentication, aka NTLM.
  /// </summary>
  /// <author>Mike Jahr</author>
  public class WindowsIntegratedAuth : ISSOIntegration
  {
    private static readonly String[] HEADERS = null;
    private static readonly String[] COOKIES = null;
    private bool m_bUseDomain = true;
    
    /// <summary>
    /// Creates a new WindowsIntegratedAuth object.
    /// </summary>
    public WindowsIntegratedAuth()
    {
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetLoginInfo()"></seealso>
    public virtual SSOLoginInfo GetLoginInfo(IXPRequest request)
    {
      String sUserName;
      try
      {
        // Should use request.GetBasicAuthUserName(), but that returns AUTH_USER
        // instead of LOGON_USER.  AUTH_USER is only there if basic auth is turned
        // on.  If Windows integrated auth is turned on, only LOGON_USER will be
        // there.  Basic auth should have both AUTH_USER and LOGON_USER.
        // GetServerVariable() has been deprecated because XDK cannot guarantee
        // mapped behavior between Java and .NET.  However, WIA is typically used
        // in an IIS environment only.
        sUserName = XPConvert.ToString(request.GetServerVariable("LOGON_USER"));
        }
      catch (Exception e)
      {
        throw XPException.GetInstance(e);
      }
      if (!m_bUseDomain)
      {
        // mj: if there's no domain, this will just return the whole string
        sUserName = XPStringUtility.Substring(sUserName, XPStringUtility.IndexOf(sUserName,
         '\\') + 1);
      }
      return new SSOLoginInfo(sUserName, request.GetBasicAuthPassword());
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSSOProductName()"></seealso>
    public virtual String GetSSOProductName()
    {
      return "Windows Integrated Authentication";
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureCookies()"></seealso>
    public virtual String[] GetSecureCookies()
    {
      return COOKIES;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureHeaders()"></seealso>
    public virtual String[] GetSecureHeaders()
    {
      return HEADERS;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Initialize()"></seealso>
    public virtual bool Initialize(XPHashtable mapSettings)
    {
      XPArrayList list = (XPArrayList) mapSettings.GetElement("UseDomain");
      if (list != null && list.GetSize() > 0)
      {
        m_bUseDomain = "1".Equals(list.GetElement(0));
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Logout()"></seealso>
    public virtual bool OnLogout(IXPResponse response, String sReturnURL)
    {
      return false;
    }
  }
}