using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.statichelpers
{
  /// <summary>
  /// This class contains helper methods to get variables from the PTconfigVarPack
  /// and configVarPack.
  /// </summary>
  /// <author>Don Hayler</author>
  public class PTConfigHelper : ConfigHelper
  {
    
    /// <summary>
    /// Helper method to access an int variable from x_config.xml.
    /// </summary>
    /// <param name="strSection">strSection</param>
    /// <param name="strSubSection">strSubSection</param>
    /// <param name="strAttribute">strAttribute</param>
    /// <param name="space">the current space</param>
    /// <returns>int the requested variable</returns>
    public static int GetConfigVariableAsInt(String strSection, String strSubSection,
     String strAttribute, AActivitySpace space)
    {
      return ((PTConfigVarPack) space.GetApplication().GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsInt(strSection,
       strSubSection, strAttribute);
    }
    
    /// <summary>
    /// Helper method to access a String variable from x_config.xml.
    /// </summary>
    /// <param name="strSection">strSection</param>
    /// <param name="strSubSection">strSubSection</param>
    /// <param name="strAttribute">strAttribute</param>
    /// <param name="space">the current space</param>
    /// <returns>String the requested variable</returns>
    public static String GetConfigVariableAsString(String strSection, String strSubSection,
     String strAttribute, AActivitySpace space)
    {
      return ((PTConfigVarPack) space.GetApplication().GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsString(strSection,
       strSubSection, strAttribute);
    }
    
    /// <summary>
    /// Helper method to access a String variable from x_config.xml.
    /// </summary>
    /// <param name="strSection">strSection</param>
    /// <param name="strSubSection">strSubSection</param>
    /// <param name="strAttribute">strAttribute</param>
    /// <param name="application">the current IApplication</param>
    /// <returns>String the requested variable</returns>
    public static String GetConfigVariableAsString(String strSection, String strSubSection,
     String strAttribute, IApplication app)
    {
      return ((PTConfigVarPack) app.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsString(strSection,
       strSubSection, strAttribute);
    }
    
    /// <summary>
    /// Helper method to access a String variable from x_config.xml.
    /// </summary>
    /// <param name="strSection">strSection</param>
    /// <param name="strSubSection">strSubSection</param>
    /// <param name="strAttribute">strAttribute</param>
    /// <param name="space">the current space</param>
    /// <returns>String the requested variable</returns>
    public static Object[] GetConfigVariables(String strSection, String strSubSection,
     String strAttribute, AActivitySpace space)
    {
      return ((PTConfigVarPack) space.GetApplication().GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValues(strSection,
       strSubSection, strAttribute);
    }
    
    /// <summary>
    /// Helper method to access a String variable from x_config.xml.
    /// </summary>
    /// <param name="strSection">strSection</param>
    /// <param name="strSubSection">strSubSection</param>
    /// <param name="strAttribute">strAttribute</param>
    /// <param name="space">the current space</param>
    /// <returns>String the requested variable</returns>
    public static Object[] GetConfigVariables(String strSection, String strSubSection,
     String strAttribute, IApplication application)
    {
      return ((PTConfigVarPack) application.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValues(strSection,
       strSubSection, strAttribute);
    }
    
    /// <summary>
    /// This method returns the PT class type description manager.
    /// </summary>
    public static ClassTypeDescManager GetPTClassTypeDescrManager()
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      return (ClassTypeDescManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
      }
    
    /// <summary>
    /// Returns the SSO relative URL ending with a question mark. E.g.:
    /// SSOLoginPage?
    /// </summary>
    /// <returns>String</returns>
    public static String GetSSORelativeURL()
    {
      IApplication application;
      String sSSORelativeURL;
      application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      sSSORelativeURL = ((PTConfigVarPack) application.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetSSORelativeURL();
      return sSSORelativeURL + "?";
    }
    
    /// <summary>
    /// Returns the SSO base URL ending with a question mark. E.g.:
    /// /SSOLoginPage?
    /// </summary>
    /// <returns>String</returns>
    public static String GetSSOBaseURL()
    {
      IApplication application;
      String sSSOBaseURL;
      application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      sSSOBaseURL = ((PTConfigVarPack) application.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetSSOBaseURL();
      return sSSOBaseURL + "?";
    }
    
    /// <summary>
    /// Checks whether the classId supports friendly URLs
    /// </summary>
    /// <param name="classId"></param>
    /// <returns></returns>
    public static bool UseFriendlyURLS(int classId)
    {
      // Friendly URL defined for a particular classId if there are friendly url token defined 
      return UseFriendlyURLS(classId, null);
    }
    
    /// <summary>
    /// Checks whether the classId supports friendly URLs
    /// </summary>
    /// <param name="classId"></param>
    /// <param name="queryStringArgs"></param>
    /// <returns></returns>
    public static bool UseFriendlyURLS(int classId, String queryStringArgs)
    {
      // Friendly URL defined for a particular classId if there are friendly url token defined 
      String res = ((IFriendlyURLManager) PTConfigHelper.GetTypeDescrManager()).LookupFriendlyURLKeyFromClassId(XPConvert.ToString(classId));
      bool useFriendly = true;
      useFriendly = (res == null) ? false : true;
      // check for specific cases when we shouldn't use friendly URLs
      if (useFriendly && queryStringArgs != null)
      {
        // directory edit mode button, we don't have access to the directory constants since they are defined in portalpages
        // project, DirMode of 2 means edit mode
        if (XPStringUtility.IndexOf(queryStringArgs, "DirMode=2") != -1)
        {
          useFriendly = false;
        }
      }
      return useFriendly;
    }
  }
}