using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.interpreter.filter.utils;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.statichelpers
{
  /// <summary>
  /// This class contains static helper functions to be used with
  /// the Plumtree API.
  /// </summary>
  public class PlumtreeHelpers
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.statichelpers.PlumtreeHelpers");
    private static bool s_bInitialized = false;
    
    /// <summary>
    /// The default style sheet should only be used by the common code
    /// that determines style sheets.
    /// </summary>
    public static String s_strDefaultStyleSheet;
    
    /// <summary>
    /// Small Image 
    /// </summary>
    public const String SMALL_IMAGE = "sml";
    
    /// <summary>
    /// Large Image 
    /// </summary>
    public const String LARGE_IMAGE = "lrg";
    
    /// <summary>
    /// Gif type 
    /// </summary>
    public const String GIF_TYPE = ".gif";
    
    /// <summary>
    /// Portal image page 
    /// </summary>
    public const String PORTAL_IMAGE_PAGE = "portal/public/img/";
    
    /// <summary>
    /// Chinese locale code 
    /// </summary>
    private const String CHINESE_LOCALE_CODE = "zh";
    
    /// <summary>
    /// 508 mode style sheet prefix 
    /// </summary>
    public const String STYLE_PREFIX_508 = "d_";
    
    /// <summary>
    /// Name of the session flag indicating being in the default profile
    /// editor.  Defined in the gateway so that the AppDataObject can access it too.
    /// This is stored on the persistent session.
    /// </summary>
    public static readonly String DPROFILE_EDITOR_SESSION_FLAG = GatewayHandlers.DPROFILE_EDITOR_SESSION_FLAG;
    
    /// <summary>
    /// Helper function to retrieve an HTML image, large or small.  Alt is not specified
    /// </summary>
    /// <param name="strImageName">- The image name</param>
    /// <param name="bSmallImage">- True for a small image</param>
    /// <returns>HTMLImg</returns>
    public static HTMLImg GetHTMLImage(String strImageName, bool bSmallImage)
    {
      return GetHTMLImage(strImageName, bSmallImage, "");
    }
    
    /// <summary>
    /// Helper function to retrieve an image and specify the Alt
    /// </summary>
    /// <param name="strImageName">- The image name</param>
    /// <param name="bSmallImage">- True if a small image</param>
    /// <param name="strAlt">- The alt tag</param>
    /// <returns>HTMLImg</returns>
    public static HTMLImg GetHTMLImage(String strImageName, bool bSmallImage,
     String strAlt)
    {
      if (null == strImageName)
      {
        return null;
      }
      String strFullImagePath = PORTAL_IMAGE_PAGE + (bSmallImage ? SMALL_IMAGE : LARGE_IMAGE) + XPStringUtility.ToLowerCase(strImageName) + GIF_TYPE;
      HTMLImg myImg = new HTMLImg(strFullImagePath, strAlt);
      return myImg;
    }
    
    /// <summary>
    /// Helper function to retrieve the spacer image with specified dimensions
    /// </summary>
    /// <param name="strWidth">Width of the spacer image</param>
    /// <param name="strHeight">Height of the spacer image</param>
    /// <returns>				The spacer image</returns>
    public static HTMLImg GetSpacerImage(String strWidth, String strHeight)
    {
      HTMLImg spaceImg = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER).GetHTMLElement();
      spaceImg.SetWidth(strWidth);
      spaceImg.SetHeight(strHeight);
      spaceImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      spaceImg.SetBorder(CommonHTMLStrings.ZERO);
      spaceImg.SetAlt("");
      return spaceImg;
    }
    
    /// <summary>
    /// Makes a simple link that creates an object in the parent window - passing
    /// in the added arguments.
    /// </summary>
    /// <author>- JohnH</author>
    /// <param name="nCLASSID">- The classID for the objecdt</param>
    /// <param name="strProviderCLSID">- If it is an extensibility object the CLSID</param>
    /// <param name="nObjectID">
    /// - The parent admin folder id in create mode, or the
    /// objectID in Edit mode
    /// </param>
    /// <param name="strLink">- The text for the anchor</param>
    /// <param name="asOwner">- The activity space owner</param>
    /// <param name="intOpenerMode">
    /// - The opener mode - IPTOpenerConstants.
    /// OPENER_MODE_CREATE or IPTOpenerConstants.OPENER_MODE_EDIT
    /// </param>
    /// <param name="strArgs">- Optional querystring arguments</param>
    /// <param name="bCloseWindowOnExit">- Close the window on exit?</param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public static HTMLElement MakeCreateObjectLink(int nCLASSID, String strProviderCLSID,
     int nObjectID, String strLink, AActivitySpace asOwner, int intOpenerMode,
     String strArgs, bool bCloseWindowOnExit)
    {
      String strURL;
      HTMLAnchor myAnchor = new HTMLAnchor("#");
      if ((null != strProviderCLSID) && (0 < strProviderCLSID.Length))
      {
        ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
        String strProvEnglishName = ptClassTypeDescManager.GetProviderEnglishNameGivenCLSID(strProviderCLSID);
        if (intOpenerMode == IPTOpenerConstants.OPENER_MODE_CREATE)
        {
          // explicitly return to the space before this space.
          strURL = PTOpenerLinks.GetOpenerURLCreateExt(nCLASSID, nObjectID,
           strProvEnglishName, -1, -1, asOwner, asOwner.GetParentSpaceName(),
           asOwner.GetParentSpaceID(), null);
        } else
        {
          // explicitly return to the space before this space.
          strURL = PTOpenerLinks.GetOpenerURLOpenObjID(nCLASSID, nObjectID,
           intOpenerMode, asOwner, asOwner.GetParentSpaceName(), asOwner.GetParentSpaceID(),
           null);
        }
      } else
      {
        if (intOpenerMode == IPTOpenerConstants.OPENER_MODE_CREATE)
        {
          // explicitly return to the space before this space.
          strURL = PTOpenerLinks.GetOpenerURLCreate(nCLASSID, nObjectID, asOwner,
           asOwner.GetParentSpaceName(), asOwner.GetParentSpaceID(), null);
          } else
        {
          // explicitly return to the space before this space.
          strURL = PTOpenerLinks.GetOpenerURLOpenObjID(nCLASSID, nObjectID,
           intOpenerMode, asOwner, asOwner.GetParentSpaceName(), asOwner.GetParentSpaceID(),
           null);
        }
      }
      //AGC- Add the args.
      if (null != strArgs)
      {
        strURL+="&" + strArgs;
      }
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("window.opener.location = \'");
      sb.Append(strURL + "\';");
      if (bCloseWindowOnExit)
      {
        sb.Append("window.close();");
      }
      sb.Append(" return false;");
      myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(sb.ToString());
      myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strLink));
      return myAnchor;
    }
    
    /// <summary>
    /// Makes a simple link that creates an object in the parent window - passing
    /// in the added arguments.  This version of the function defaults to create
    /// mode
    /// </summary>
    /// <param name="nCLASSID">- The classID for the objecdt</param>
    /// <param name="strProviderCLSID">- If it is an extensibility object the CLSID</param>
    /// <param name="nFolderID">- The parent admin folder id</param>
    /// <param name="strLink">- The text for the anchor</param>
    /// <param name="asOwner">- The activity space owner</param>
    /// <param name="strArgs">- Optional querystring arguments</param>
    /// <param name="bCloseWindowOnExit">- Close the window on exit?</param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public static HTMLElement MakeCreateObjectLink(int nCLASSID, String strProviderCLSID,
     int nFolderID, String strLink, AActivitySpace asOwner, String strArgs,
     bool bCloseWindowOnExit)
    {
      return MakeCreateObjectLink(nCLASSID, strProviderCLSID, nFolderID, strLink,
       asOwner, IPTOpenerConstants.OPENER_MODE_CREATE, strArgs, bCloseWindowOnExit);
      }
    
    /// <summary>
    /// Returns true if the everyone group is on the ACL for the object passed
    /// in, false otherwise
    /// </summary>
    /// <param name="ptObject"></param>
    /// <returns>boolean</returns>
    public static bool EveryoneHasAccess(IPTServerContext ptObject)
    {
      IPTAccessList myACL;
      IPTAccessListEntry myEntry;
      myACL = ptObject.GetACL();
      myEntry = myACL.Find(PT_CLASSIDS.PT_USERGROUP_ID, PT_INTRINSICS.PT_USERGROUP_EVERYONE);
      if (null != myEntry)
      {
        return true;
      } else
      {
        return false;
      }
    }
    
    /// <summary>
    /// Returns a simple queryfilter based on three parameters
    /// </summary>
    /// <author>JohnH</author>
    /// <param name="int">nOperand - the Plumtree PropID operand (of type PT_PROPIDS)</param>
    /// <param name="int">nOperator - the Plumtree Operator (of type PT_FILTEROPS)</param>
    /// <param name="Object">objValue - the value to be filtered on (Integer, String, [], etc...)</param>
    public static Object[][] GetQueryFilter(int nOperand, int nOperator, Object objValue)
    {
      Object[][] ptqf = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        ptqf[j2c_index] = new Object[1];
      }
      ptqf[0][0] = nOperand;
      ptqf[1][0] = nOperator;
      ptqf[2][0] = objValue;
      return ptqf;
    }
    
    /// <summary>
    /// Returns a PTStyleSheetLink.  A style sheet is named "stylesheetname-
    /// language", for instance "mainstyle12-en".  This function creates a valid
    /// PTStyleSheetLink by collecting the style sheet name from the user's
    /// subportal, and the user's language from the activity space, then forming a
    /// PTStyleSheetLink object from this information.
    /// </summary>
    /// <deprecated>
    /// Use AActivitySpace.GetStyleSheetLinks() or LoginHelper.INSTANCE.GetStyleSheetLinks instead.
    /// This method is just here for backwards compatibility.  AActivitySpace now
    /// has a base implementation that returns the appropriate style sheets, and
    /// LoginHelper also has a method that returns the style sheets.
    /// </deprecated>
    /// <param name="Pass">
    /// in the ptSession, this function will look up the stylesheet name
    /// from the user's subportal.
    /// </param>
    /// <param name="Pass">
    /// in the ActivitySpace, this function will look up the current
    /// user's language.
    /// </param>
    public static HTMLElementCollection GetStyleSheetLinks(IPTSession ptSession,
     AActivitySpace asOwner)
    {
      return LoginHelper.INSTANCE.GetStyleSheetLinks(ptSession, asOwner);
      }
    
    /// <summary>
    /// Initializes global language and stylesheet settings using the given config settings.
    /// Can only be called once globally.
    /// </summary>
    /// <param name="varpack">a <c>PTConfigVarPack</c></param>
    public static void StaticInit(PTConfigVarPack varpack)
    {
      if (s_bInitialized)
      {
        log.Warn("PlumtreeHelpers.StaticInit reinitializing.");
      }
      // bjf -- get the default stylesheet.  Used by GetStyleSheetLink.
      s_strDefaultStyleSheet = varpack.GetConfigValueAsString(PTConfigConstants.STYLE_SECTION,
       "StyleSheetName", "value");
      s_bInitialized = true;
    }
    
    /// <summary>
    /// Inxight languages are specified as a two character string (like "en" or "fr"),
    /// with the exception of the chinese languages which can be "zh-TW" or "zh-CN"
    /// </summary>
    public static String TrimCardLanguage(String strLanguage)
    {
      if (null == strLanguage)
      {
        return "";
      }
      if (strLanguage.Length == 2)
      {
        return XPStringUtility.ToLowerCase(strLanguage);
      } else
      if (strLanguage.Length > 2)
      {
        String strFirstTwoCharacters = XPStringUtility.Substring(strLanguage,
         0, 2);
        if (0 == XPStringUtility.CompareIgnoreCase(strFirstTwoCharacters,
         CHINESE_LOCALE_CODE))
        {
          return strLanguage;
        } else
        {
          return XPStringUtility.ToLowerCase(strFirstTwoCharacters);
        }
      } else
      {
        return strLanguage;
      }
    }
    
    /// <summary>
    /// Checks to see whether or not the user is in the Administrators group,
    /// using cached session's list of groups. 
    /// </summary>
    /// <param name="_ptSession">Current session</param>
    /// <returns>True if user is in the Administrators group. Otherwise false.</returns>
    public static bool CheckCurrentUserIsAdmin(IPTSession _ptSession)
    {
      return _ptSession.GetSessionInfo().CheckCurrentUserIsAdmin();
    }
    
    /// <summary>
    /// To execute a javascript function when you press enter in a input field, set the
    /// onkeypress attribute of the input equal to "return executeViaEnter(event)".
    /// Also include the HTMLScript returned by GetExecuteViaEnterJScript in your page.
    /// Example: myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
    /// </summary>
    public const String STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER = "executeViaEnter";
    
    /// <summary>
    /// To execute a javascript function when you press enter in a input field, set the
    /// onkeypress attribute of the input equal to "return executeViaEnter(event)".
    /// Also include the HTMLScript returned by GetExecuteViaEnterJScript in your page.
    /// Example: myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
    /// </summary>
    /// <returns>myScript </returns>
    public static HTMLScript GetExecuteViaEnterJScript(String strValidateFunction)
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder();
      try
      {
        sb.Append("function ").Append(STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER).Append("(evt)\n");
        sb.Append("{\n");
        sb.Append("\tevt = (evt) ? evt : event;\n");
        sb.Append("\tvar charCode = (evt.charCode) ? evt.charCode : ((evt.which) ? evt.which : evt.keyCode);\n");
        sb.Append("\tif (charCode == 13 || charCode == 3)\n");
        sb.Append("\t{\n");
        sb.Append("\t\treturn ").Append(strValidateFunction).Append("();\n");
        sb.Append("\t}\n");
        sb.Append("\treturn true;\n");
        sb.Append("}\n");
        sb.Append("\n");
        sb.Append("if (document.layers)\n");
        sb.Append("{\n");
        sb.Append("\tdocument.captureEvents(Event.KEYPRESS)\n");
        sb.Append("\tdocument.onkeypress=").Append(STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER).Append(";\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        return myScript;
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element.");
        return null;
      }
    }
    
    /// <summary>
    /// Determines if this is a gues session or not as part of checking basic access.
    /// </summary>
    /// <param name="AActivitySpace">current space</param>
    /// <returns>boolean true if guest</returns>
    public static bool IsGuestSession(AActivitySpace asOwner)
    {
      if (asOwner == null)
      {
        return false;
      }
      return LoginHelper.INSTANCE.GetIsGuestUser(asOwner.GetUserSession());
      }
    
    /// <summary>
    /// This helper function sets a UI Error with the messages specified, and optionally
    /// throws an exception.  The UI Error will contain the strings specified only, but the
    /// Debug log entry will also contain the text of the exception (e.getMessage())
    /// </summary>
    /// <author>- JohnH</author>
    /// <param name="asOwner">- The activity space in which the error was thrown</param>
    /// <param name="strFunctionName">- The function that trapped the error (e.g. MyModel::CheckEditorAccessAndStart)</param>
    /// <param name="uiComponent">- The UI component in which the error occurred, e.g. OpenLogService.GetComponent("Portal_UI_Infrastructure")</param>
    /// <param name="e">- The exception that has been thrown</param>
    /// <param name="bThrow">- Throw an XPException in addition to setting the error?</param>
    /// <param name="uiErrorLevel">- The error level (e.g. UIErrorLevel.SERIOUS)</param>
    /// <param name="strErrorMessage">- The error message string to be displayed</param>
    public static void SetUIError(AActivitySpace asOwner, OpenLogComponent uiComponent,
     String strFunctionName, Exception e, bool bThrow, UIErrorLevel uiErrorLevel,
     String strErrorMessage)
    {
      XPStringBuilder sbShortMsg = new XPStringBuilder(100);
      XPStringBuilder sbLongMsg = new XPStringBuilder(150);
      //Build the error string
      sbShortMsg.Append(strErrorMessage);
      if (null != e)
      {
        sbLongMsg.Append(strErrorMessage).Append(": ").Append(e.Message);
        } else
      {
        sbLongMsg.Append(strErrorMessage);
      }
      //Raise the UI error
      UIError myError = new UIError(uiErrorLevel, UIErrorScope.CURRENT_USER,
       null, sbShortMsg.ToString(), sbLongMsg.ToString());
      UIErrorHandler.RaiseError(myError, asOwner.GetSubSession(), asOwner.GetApplication());
      //Add the exception text and trace it
      log.Error(e, strFunctionName + sbShortMsg.ToString());
      //Optionally throw the exception
      if (bThrow)
      {
        if (null != e)
        {
          throw new XPException(strErrorMessage, e);
        } else
        {
          throw new XPException(strErrorMessage);
        }
      }
    }
    
    /// <summary>
    /// This helper function returns a localized new object name based on a classID.  
    /// It is used by the editor framework to suggest object names for newly created
    /// objects.
    /// </summary>
    /// <param name="intClassID">- The classID of the object</param>
    /// <param name="asOwner">- The activity space this is being called from</param>
    /// <returns>String - The new object name</returns>
    public static String GetNewObjectName(int intClassID, AActivitySpace asOwner)
    {
      String strTemp = "";
      switch (intClassID){
      // security
      case PT_CLASSIDS.PT_USER_ID:
      strTemp = asOwner.GetString(369, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_USERGROUP_ID:
      strTemp = asOwner.GetString(370, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_AUTHSOURCE_ID:
      strTemp = asOwner.GetString(371, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_ACTIVITY_ID:
      strTemp = asOwner.GetString(372, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_PROFILESOURCE_ID:
      strTemp = asOwner.GetString(373, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_SUBPORTAL_ID:
      strTemp = asOwner.GetString(374, "ptmsgs_portalinfrastructure");
      break;
      // catalog
      case PT_CLASSIDS.PT_CATALOG_ID:
      strTemp = asOwner.GetString(375, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
      strTemp = asOwner.GetString(412, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_CATALOGCARD_ID:
      strTemp = asOwner.GetString(376, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_ADMIN_CATALOG_ID:
      strTemp = asOwner.GetString(377, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
      strTemp = asOwner.GetString(378, "ptmsgs_portalinfrastructure");
      break;
      // portal objects
      case PT_CLASSIDS.PT_FILTER_ID:
      strTemp = asOwner.GetString(379, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_SAVEDSEARCH_ID:
      strTemp = asOwner.GetString(380, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_DATASOURCE_ID:
      strTemp = asOwner.GetString(381, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_PROPERTY_ID:
      strTemp = asOwner.GetString(382, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_DOCUMENTTYPE_ID:
      strTemp = asOwner.GetString(383, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_CRAWLER_ID:
      strTemp = asOwner.GetString(384, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_DOCUMENTTYPEMAP_ID:
      strTemp = asOwner.GetString(385, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_PROPERTYMAP_ID:
      strTemp = asOwner.GetString(386, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_TAXONOMIST_ID:
      strTemp = asOwner.GetString(387, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_GADGET_ID:
      strTemp = asOwner.GetString(388, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_GADGETTEMPLATE_ID:
      strTemp = asOwner.GetString(419, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_INVITATION_ID:
      strTemp = asOwner.GetString(389, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_ACLSYNCMAP_ID:
      strTemp = asOwner.GetString(390, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_FEDERATEDPORTAL_ID:
      strTemp = asOwner.GetString(391, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID:
      strTemp = asOwner.GetString(392, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_USERINTERFACE_ID:
      strTemp = asOwner.GetString(394, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID:
      strTemp = asOwner.GetString(395, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_GADGETBUNDLE_ID:
      strTemp = asOwner.GetString(396, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_PAGETEMPLATE_ID:
      strTemp = asOwner.GetString(397, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_WEBSERVICE_ID:
      strTemp = asOwner.GetString(398, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_EXTOPERATION_ID:
      strTemp = asOwner.GetString(399, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_COMMUNITY_ID:
      strTemp = asOwner.GetString(404, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_PAGE_ID:
      strTemp = asOwner.GetString(406, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_SITEMAPFOLDER_ID:
      strTemp = asOwner.GetString(407, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_SITEMAPLINK_ID:
      strTemp = asOwner.GetString(408, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
      strTemp = asOwner.GetString(409, "ptmsgs_portalinfrastructure");
      break;
      // profile layout elements
      case PT_CLASSIDS.PT_PROFILEPAGE_ID:
      strTemp = asOwner.GetString(400, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_PROFILESECTION_ID:
      strTemp = asOwner.GetString(401, "ptmsgs_portalinfrastructure");
      break;
      // scheduler objects
      case PT_CLASSIDS.PT_JOB_ID:
      strTemp = asOwner.GetString(402, "ptmsgs_portalinfrastructure");
      break;
      case PT_CLASSIDS.PT_SCHEDULE_ID:
      strTemp = asOwner.GetString(403, "ptmsgs_portalinfrastructure");
      break;
      // Search update agent (used to allow concurrent SUA)
      case PT_CLASSIDS.PT_SEARCHUPDATE_CLASSID:
      strTemp = asOwner.GetString(410, "ptmsgs_portalinfrastructure");
      break;
      // Search repair (used to control search repair)
      case PT_CLASSIDS.PT_WEEKLYHOUSEKEEPING_CLASSID:
      strTemp = asOwner.GetString(411, "ptmsgs_portalinfrastructure");
      break;
      default:
      strTemp = asOwner.GetString(420, "ptmsgs_portalinfrastructure");
      break;
      }
      return strTemp;
    }
    
    /// <summary>
    /// Reads a String value from a property bag. Returns strDefault if the value
    /// was not found or an error occurred.
    /// Copied from ModelHelpers in PortalPages.  We may want to put this and 
    /// other property bag helpers into their own class, or unifying class.
    /// </summary>
    /// <param name="sPropID"></param>
    /// <param name="ptPropBag"></param>
    /// <param name="strDefault"></param>
    /// <returns>String</returns>
    public static String PBReadString(IXPPropertyBag ptPropBag, String sPropID,
     String strDefault)
    {
      String strReturn = strDefault;
      try
      {
        strReturn = ptPropBag.ReadAsString(sPropID);
        if (null == strReturn)
        {
          return strDefault;
        }
        return strReturn;
      }
      catch (Exception e)
      {
        log.Warn(e, "ModelHelper::PBReadString: Unable to Read String from property bag, returning default (" + sPropID + ").");
        return strDefault;
      }
    }
    
    /// <summary>
    /// This method checks whether or not the current session is editing a
    /// default profile user.
    /// </summary>
    /// <param name="space"></param>
    /// <returns>True implies the current user is edting a default profile.</returns>
    public static bool IsEditingDefaultProfile(AActivitySpace space)
    {
      return IsEditingDefaultProfile(space.GetPersistentSubSession());
    }
    
    /// <summary>
    /// This method checks whether or not the current session is editing a
    /// default profile user.
    /// </summary>
    /// <param name="_persistentSubSession"></param>
    /// <returns>True implies the current user is edting a default profile.</returns>
    public static bool IsEditingDefaultProfile(ISessionManager _persistentSubSession)
    {
      return (null != _persistentSubSession.GetAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG));
      }
  }
}