using System;
// Framework imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
namespace com.plumtree.portaluiinfrastructure.statichelpers
{
  /// <summary>
  /// Helper static methods for the XUI.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class XUIHelperMethods
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.statichelpers.XUIHelperMethods");
    
    /// <summary>
    /// XUI Editor Type: Authentication Source 
    /// </summary>
    public const String XUI_AUTHSOURCE_SERVICEID = "plumtree-com:rap:auth";
    
    /// <summary>
    /// XUI Editor Type: Crawler 
    /// </summary>
    public const String XUI_CRAWLER_SERVICEID = "plumtree-com:cws:crawl";
    
    /// <summary>
    /// XUI Editor Type: Card 
    /// </summary>
    public const String XUI_DOCUMENT_SERVICEID = "plumtree-com:cws:card";
    
    /// <summary>
    /// XUI Editor Type: Data Source 
    /// </summary>
    public const String XUI_DATASOURCE_SERVICEID = "plumtree-com:cws:ds";
    
    /// <summary>
    /// XUI Editor Type: Profile Source 
    /// </summary>
    public const String XUI_PROFILESOURCE_SERVICEID = "plumtree-com:pws:profile";
    
    /// <summary>
    /// XUI Editor Type: Search 
    /// </summary>
    public const String XUI_SEARCH_SERVICEID = "plumtree-com:sws:search";
    
    /// <summary>
    /// XUI Editor Type: Migration Import 
    /// </summary>
    public const String XUI_MIGRATION_IMPORT_SERVICEID = "plumtree-com:mws:import";
    
    /// <summary>
    /// XUI Editor Type: Migration Export 
    /// </summary>
    public const String XUI_MIGRATION_EXPORT_SERVICEID = "plumtree-com:mws:export";
    
    /// <summary>
    /// Time out for the XUI requests to the remote server 
    /// </summary>
    public const int XUI_TIMEOUT_IN_SECONDS = 90;
    
    /// <summary>
    /// name of the XSL transformer file 
    /// </summary>
    public const String XUI_XSL_TRANSFORMER = "XUI.xsl";
    
    /// <summary>
    /// Query String param: web service ID 
    /// </summary>
    public const String QS_XUI_WEBSERVICE_ID = "webServiceID";
    
    /// <summary>
    /// Query String param: data source ID 
    /// </summary>
    public const String QS_XUI_DATASOURCE_ID = "dataSourceID";
    
    /// <summary>
    /// Returns the Data Source ID from the QS.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public static int GetDataSourceIDFromQS(XPHashtable _htFormData)
    {
      int nDataSourceID = -1;
      if (!_htFormData.ContainsKey(QS_XUI_DATASOURCE_ID))
      {
        log.Error("XUIHelperMethods::GetDataSourceIDFromQS The data source ID was " + "not found in the Query String. The Editor cannot be started.");
        } else
      {
        String[] data = (String[]) _htFormData.GetElement(QS_XUI_DATASOURCE_ID);
        try
        {
          nDataSourceID = XPConvert.ToInteger(data[0]);
        }
        catch (Exception e)
        {
          log.Error("XUIHelperMethods::GetDataSourceIDFromQS The data source ID was invalid: " + data + ". The Editor cannot be started. The following exception happened:" + e);
          }
      }
      return nDataSourceID;
    }
  }
}