using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.subscribematrix
{
  /// <author>
  /// rickyw
  /// This is the pop-up page where we let the user see his ABO link.
  /// </author>
  public class ABOSubPopupResultsView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.subscribematrix.ABOSubPopupResultsView");
    
    /// <summary>
    /// object class name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ABOSubPopupResultsView";
    
    /// <summary>
    /// html object names 
    /// </summary>
    public const String HTMLBUTTON_CLOSE = "in_bu_Close";
    
    /// <summary>
    /// javascript constants 
    /// </summary>
    public const String JAVASCRIPT_CLOSE = "closeAndRefreshParent";
    
    /// <summary>
    /// job name not localized at server so we hardcode it here 
    /// </summary>
    public const String JOBNAME_PREFIX = "Async operation for ";
    
    /// <summary>
    /// member mvc objects 
    /// </summary>
    protected AActivitySpace m_asOwner;
    protected IMultiObjectsSubscribeModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ABOSubPopupResultsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      String strErrors = "";
      HTMLElement result = new HTMLElementCollection();
      HTMLSpan mySpan;
      HTMLTable myTable;
      HTMLInput myInput;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        // table for everything
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("10");
        // add link to created job
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        int nID = m_asModel.GetJobID();
        String sName = m_asModel.GetJobName();
        // that is, if the job was created
        if (nID != -1 && !(("").Equals(sName)))
        {
          // If the job was created and we have access to its name.
          mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(2473,
           "ptmsgs_portaladminmsgs"), XPHttpUtility.HtmlEncode(sName), XPHttpUtility.HtmlEncode(m_asModel.GetJobFolderName())));
          } else
        if (nID != -1)
        {
          // If the job was created and we do not have access to its name.
          mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(2633,
           "ptmsgs_portaladminmsgs"), XPConvert.ToString(nID)));
        }
        // Add buttons
        result.AddInnerHTMLElement(new HTMLComment("Begin: Footer buttons table"));
        // 1st Row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // add buttons - add close button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1693, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick(JAVASCRIPT_CLOSE + "(); return false;");
        result.AddInnerHTMLElement(new HTMLComment("End: Footer buttons table"));
        }
      catch (HTMLException he)
      {
        log.Error(he, m_asOwner.GetString(2198, "ptmsgs_portaladminmsgs"));
        strErrors+=m_asOwner.GetString(2198, "ptmsgs_portaladminmsgs") + SubscribeMatrixModel.BR_ELEMENT;
        }
      // if error, raise to ui
      if (!"".Equals(strErrors))
      {
        RaiseError(strErrors);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      String strErrors = "";
      // create our own functions
      XPStringBuilder sb = new XPStringBuilder(300);
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_CLOSE).Append("()\n");
      sb.Append("{\n");
      sb.Append("  opener.").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(SubscribeMatrixRepostControl.POSTTOSELF_ACTION_CANCEL).Append(");\n");
      sb.Append("  window.close();\n");
      sb.Append("}\n");
      sb.Append("\n");
      HTMLScript myScript = null;
      try
      {
        // add our functions
        myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, m_asOwner.GetString(2197, "ptmsgs_portaladminmsgs"));
        strErrors+=m_asOwner.GetString(2197, "ptmsgs_portaladminmsgs") + SubscribeMatrixModel.BR_ELEMENT;
        }
      // if error, raise to ui
      if (!"".Equals(strErrors))
      {
        RaiseError(strErrors);
      }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      m_asModel = (IMultiObjectsSubscribeModelRO) model;
    }
    public virtual void RaiseError(String strError)
    {
      UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       strError, strError);
      myError.SetActivitySpace(m_asOwner.GetName());
      myError.SetDisplayOnSeparatePage(false);
      myError.SetClearWithActivitySpaceChange(true);
      myError.SetImmediateClear(true);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      }
  }
}