using System;
// Foundation Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.subscribematrix
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the Select PTObject list.
  /// Is constains the HTML to display the object Array.
  /// It gets the data to display from SelectPTObjectModel.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class MultiObjectsSubscribeView : SelectPTObjectView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.subscribematrix.MultiObjectsSubscribeView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MultiObjectsSubscribe";
    
    /// <summary>
    /// HTML Object name: subscribe checkbox 
    /// </summary>
    public const String HTMLCHECKBOX_SUBSCRIBE = "in_cb_Subscribe";
    
    /// <summary>
    /// HTML Object set row value 
    /// </summary>
    public const String HTMLINPUT_SETROW = "in_hi_SetRow";
    
    /// <summary>
    /// HTML Object set column value 
    /// </summary>
    public const String HTMLINPUT_SETCOLUMN = "in_hi_SetColumn";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MultiObjectsSubscribeView();
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      int[] arrColumns = ((IMultiObjectsSubscribeModelRO) m_model).GetColumns();
      int k = MultiObjectsSubscribeModel.EXPLIST_COL_MAX;
      while (k < arrColumns.Length)
      {
        int nRowAccessLevelIDToSelect = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
         arrColumns[k]));
        String sInputName = ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLCHECKBOX_SUBSCRIBE) + _nRowIndex + k;
        result.AddInnerHTMLElement(GetHTMLForAccessLevelCell(sInputName, nRowAccessLevelIDToSelect));
        k = k + 3;
      }
      HTMLTableCell myCell;
      HTMLImg myImage;
      PTConstruct myConstruct;
      HTMLAnchor myAnchor;
      HTMLInput myInput;
      // Row icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_CHECK_ROW,
       true, m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(m_asOwner.GetString(522, "ptmsgs_portalinfrastructure"));
      myImage.SetAlign("absmiddle");
      myCell = new HTMLTableCell();
      myCell.SetHeight("30");
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("SetRow(" + _nRowIndex + "); return false;");
      myAnchor.AddInnerHTMLElement(myImage);
      myCell.AddInnerHTMLElement(myAnchor);
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_SETROW + _nRowIndex,
       "");
      myInput.SetValue("1");
      myCell.AddInnerHTMLElement(myInput);
      result.AddInnerHTMLElement(myCell);
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the Access Level drop-down cell.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForAccessLevelCell(String _sInputName,
     int _nRowAccessLevelIDToSelect)
    {
      HTMLTableCell myCell;
      HTMLInput myCheckBox;
      myCell = new HTMLTableCell();
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      if (_nRowAccessLevelIDToSelect < PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ)
      {
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      } else
      {
        myCheckBox = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE, _sInputName,
         "checkbox1");
        myCheckBox.SetValue("1");
        myCheckBox.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        myCell.AddInnerHTMLElement(myCheckBox);
      }
      return myCell;
    }
    
    /// <summary>
    /// No Action Bar for bulk subscribe
    /// </summary>
    protected override HTMLTable GetHTMLForActionBar()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the last row of the main table.
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableRow GetHTMLForBottomRow()
    {
      HTMLTableRow myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      HTMLTableCell myCell;
      HTMLImg myImage;
      PTConstruct myConstruct;
      HTMLInput myInput;
      HTMLAnchor myAnchor;
      // Column icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_CHECK_COLUMN,
       true, m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(m_asOwner.GetString(521, "ptmsgs_portalinfrastructure"));
      myImage.SetAlign("absmiddle");
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      myCell.AddInnerHTMLString(m_asOwner.GetString(361, "ptmsgs_portalinfrastructure"));
      int[] arrColumns = ((IMultiObjectsSubscribeModelRO) m_model).GetColumns();
      int k = MultiObjectsSubscribeModel.EXPLIST_COL_MAX;
      // JF- We loop through the column array and print out each one
      while (k < (arrColumns.Length - 2))
      {
        // Row 1 - Cell i
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetHeight("20");
        myCell.SetNoWrap(true);
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick("SetColumn(" + k + "); return false;");
        myAnchor.AddInnerHTMLElement(myImage);
        myCell.AddInnerHTMLElement(myAnchor);
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_SETCOLUMN + k,
         "");
        myInput.SetValue("1");
        myCell.AddInnerHTMLElement(myInput);
        k = k + 3;
      }
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      return myRow;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the space below the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      HTMLTable myTable = new HTMLTable();
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
      myCell.AddInnerHTMLString(m_asOwner.GetString(516, "ptmsgs_portalinfrastructure"));
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("0");
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myCell.SetVAlign(CommonHTMLStrings.TOP);
      myCell.SetAlign(CommonHTMLStrings.RIGHT);
      HTMLAnchor help = HTMLConstructHelpers.GetHelpAnchor(m_asOwner);
      myCell.AddInnerHTMLElement(help);
      return myTable;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      XPStringBuilder sb;
      int[] arrColumns = ((IMultiObjectsSubscribeModelRO) m_model).GetColumns();
      try
      {
        sb = new XPStringBuilder(200);
        sb.Append("function SetRow(varRowID)\n");
        sb.Append("{\n");
        sb.Append("  var i = " + MultiObjectsSubscribeModel.EXPLIST_COL_MAX + ";\n");
        sb.Append("  var intNewVal = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETROW + "\" + varRowID + \".value\");\n");
        sb.Append("  \n");
        sb.Append("  while (i < " + (arrColumns.Length - 2) + ") \n");
        sb.Append("  {\n");
        sb.Append("    var strCheckBoxName = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLCHECKBOX_SUBSCRIBE) + "\" + varRowID + i); ");
        sb.Append("    if (strCheckBoxName) {\n");
        sb.Append("      strCheckBoxName.checked = (1==intNewVal) ? true : false;\n");
        sb.Append("    }\n");
        sb.Append("    i = i + 3;\n");
        sb.Append("  }\n");
        sb.Append("  UpdateInputValue(eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETROW + "\" + varRowID));\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(200);
        sb.Append("function SetColumn(varColumnID)\n");
        sb.Append("{\n");
        sb.Append("  var i = 0;\n");
        sb.Append("  var intNewVal = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETCOLUMN + "\" + varColumnID + \".value\");\n");
        sb.Append("  \n");
        sb.Append("  while (i < " + ((IMultiObjectsSubscribeModelRO) m_model).GetReadOnlyItems().GetCount() + ") \n");
        sb.Append("  {\n");
        sb.Append("    var strCheckBoxName = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLCHECKBOX_SUBSCRIBE) + "\" + i + varColumnID); ");
        sb.Append("    if (strCheckBoxName) {\n");
        sb.Append("      strCheckBoxName.checked = (1==intNewVal) ? true : false;\n");
        sb.Append("    }\n");
        sb.Append("    i = i + 1;\n");
        sb.Append("  }\n");
        sb.Append("  UpdateInputValue(eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETCOLUMN + "\" + varColumnID));\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(200);
        sb.Append("function UpdateInputValue(varInput)\n");
        sb.Append("{\n");
        sb.Append("  if (1 == varInput.value) \n");
        sb.Append("  {\n");
        sb.Append("    varInput.value = 0;\n");
        sb.Append("  }\n");
        sb.Append("  else \n");
        sb.Append("  {\n");
        sb.Append("    varInput.value = 1;\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "MultiObjectsSecurityView::DisplayJavascript An error occured when trying to display the JavaScript.");
        }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForSubHeader()"></seealso>
    protected override HTMLTableRow GetHTMLForSubHeader()
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      HTMLInput myInput;
      HTMLImg myImage;
      PTConstruct myConstruct;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      Object[][] oArrExpListColInfo = ((IExpListModelRO) m_model).GetArrExpListColInfo();
      int nColumnID;
      // JF- We loop through the column array and print out each one
      for (int i = 0;i < oArrExpListColInfo.Length;i++)
      {
        // Row 1 - Cell i
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_WIDTH]);
        myCell.SetColSpan((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
        myCell.SetHeight("20");
        myCell.SetNoWrap(((IExpListModelRO) m_model).GetWrapColumnHeaders());
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.AddInnerHTMLString(SPACE);
        // JF- Print out the column title with information we get from the array (oArrExpListColInfo)
        if (XPConvert.ToBoolean(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ENABLESORT]))
        {
          // JF- If the sort is enabled for this column we need to know what to display:
          // - If the list is not sorted by this column, we display just a link to sort by this column
          // - If the list is currently sorted by this column, we display an arrow that shows the current 
          //   sort direction and a link to reverse the sort.
          nColumnID = XPConvert.ToInteger(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID]);
          // JF- The list is currently sorted by this column
          if (nColumnID == ((IExpListModelRO) m_model).GetMainColumnSort())
          {
            // JF- We build the link to reverse the sort
            myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick("postToSelf(\'" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_REVERSESORT) + "\'); return false;");
            myCell.AddInnerHTMLElement(myAnchor);
            myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
            // JF- We figure out the sort direction to know which arrow to display
            if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IExpListModelRO) m_model).GetMainColumnSortDirection())
            {
              myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
               true, this.m_asOwner);
              myImage = (HTMLImg) myConstruct.GetHTMLElement();
              myImage.SetAlt(m_asOwner.GetString(55, ResourceConstants.INFRASTRUCTURE));
              myImage.SetAlign("absmiddle");
              myAnchor.AddInnerHTMLElement(myImage);
            } else
            {
              myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
               true, this.m_asOwner);
              myImage = (HTMLImg) myConstruct.GetHTMLElement();
              myImage.SetAlt(m_asOwner.GetString(54, ResourceConstants.INFRASTRUCTURE));
              myImage.SetAlign("absmiddle");
              myAnchor.AddInnerHTMLElement(myImage);
            }
          } else
          // JF- The list is currently NOT sorted by this column
          {
            // JF- We build the link to sort by this column
            myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("SortBy") + "(\'" + oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID] + "\'); return false;");
            myCell.AddInnerHTMLElement(myAnchor);
            myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
            }
        } else
        // JF- The sort was not enabled, just print out the title
        // (we don't need to worry about the link or the arrows)
        {
          PTImageType img = (PTImageType) oArrExpListColInfo[i][MultiObjectsSubscribeModel.EXPLIST_COLUMN_IMG];
          if (null != img)
          {
            HTMLImg htmlImg = (HTMLImg) img.GetHTMLElement();
            htmlImg.SetAlt((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
            myCell.AddInnerHTMLElement(htmlImg);
          }
          myCell.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
          }
      }
      return myRow;
    }
  }
}