using System;
// Plumtree server
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portaluiinfrastructure.subscribematrix
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Misc Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>Michael DeCourcey</author>
  public class SubscribeMatrixEditorAS : PTEditorAS
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubscribeMatrixEditor";
    
    /// <summary>
    /// Storage name for Security Matrix.
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE = "MultiObjectsSubscribeSubscribeMatrixEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SubscribeMatrixEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(517, "ptmsgs_portalinfrastructure"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (SubscribeMatrixRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = SubscribeMatrixModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(SubscribeMatrixModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new SubscribeMatrixDP());
      RegisterPage(new ABOSubBlankResultsDP());
      RegisterPage(new ABOSubPopupResultsDP());
      // Register Controls
      RegisterControl(SubscribeMatrixRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      SetCurrentPage(SubscribeMatrixDP.STR_MVC_CLASS_NAME);
      // Register multi objects security pages
      RegisterModel(MultiObjectsSubscribeModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel mySecModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE);
      // Register Views
      RegisterView(ABOSubPopupResultsView.STR_MVC_CLASS_NAME, mySecModel);
      RegisterView(MultiObjectsSubscribeView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE,
       mySecModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE,
       mySecModel);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SubscribeMatrixDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_BulkAdd");
      }
    }
  }
}