using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portaluiinfrastructure.subscribematrix
{
  /// <summary>
  /// This class keeps an up-to-date state of all the settings.
  /// This class is used by the Section and by the Repost Control.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SubscribeMatrixModel : EditorModel,IObjEditorModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.subscribematrix.SubscribeMatrixModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubscribeMatrix";
    public const String BR_ELEMENT = "<BR>";
    private bool m_bHasExecutedFinish;
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      m_bHasExecutedFinish = false;
      return ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).InitializeMultiObjsSubscribePage(_htFormData,
       (IPTSession) m_asOwner.GetUserSession());
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SubscribeMatrixModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).Finish();
      if (-1 == ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).GetJobID())
      {
        // display error
        RaiseError(m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) + BR_ELEMENT);
        }
      m_bHasExecutedFinish = true;
    }
    
    /// <returns>true if Finish() has been executed already</returns>
    public virtual bool HasExecutedFinish()
    {
      return m_bHasExecutedFinish;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      if (_sPageName.Equals(SubscribeMatrixDP.STR_MVC_CLASS_NAME))
      {
        ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).SaveSection(_htFormData);
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <returns>the current IPTAccessList of the folder whose security is being edited</returns>
    public virtual IPTAccessList GetCurrentFolderACL()
    {
      return ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).GetCurrentFolderACL();
      }
    // helper classes
    public virtual void RaiseError(String strError)
    {
      UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       strError, strError);
      myError.SetActivitySpace(m_asOwner.GetName());
      myError.SetDisplayOnSeparatePage(false);
      myError.SetClearWithActivitySpaceChange(true);
      myError.SetImmediateClear(true);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetClassID()
     */
     
    public virtual int GetClassID()
    {
      // XXX Auto-generated method stub
      return 0;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObject()
     */
     
    public virtual IPTObject GetObject()
    {
      // XXX Auto-generated method stub
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectDescription()
     */
     
    public virtual String GetObjectDescription()
    {
      // XXX Auto-generated method stub
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectID()
     */
     
    public virtual int GetObjectID()
    {
      // XXX Auto-generated method stub
      return 0;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectName()
     */
     
    public virtual String GetObjectName()
    {
      // XXX Auto-generated method stub
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetParentFolderPath()
     */
     
    public virtual String GetParentFolderPath()
    {
      // XXX Auto-generated method stub
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetPTSession()
     */
     
    public virtual IPTSession GetPTSession()
    {
      // XXX Auto-generated method stub
      return null;
    }
  }
}