using System;
// Framework Imports
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portaluiinfrastructure.subscribematrix
{
  /// <summary>
  /// This class contains the additional repost actions.
  /// The ones specific to this Editor.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SubscribeMatrixRepostControl : EditorRepostControl
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubscribeMatrixRepost";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SubscribeMatrixRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="int"></param>
    protected override void PerformAction(int _nAction)
    {
      // abo - set false for non-normal finish
      bool doNormalFinish = false;
      // abo - where to go next page
      Redirect myRedirect = null;
      ((ExpListControl) m_asOwner.GetControl(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).PerformRepostAction(_nAction,
       m_htFormData);
      // abo - intercept done button. if there
      // were subscriptions, then redirect 
      // to blank DP that presents ABO option.
      if (_nAction == POSTTOSELF_ACTION_FINISH)
      {
        if (((SubscribeMatrixModel) m_model).HasExecutedFinish())
        {
          // execute regular finish
          doNormalFinish = true;
        } else
        {
          // call the finish manually
          ((SubscribeMatrixModel) m_model).Finish();
          if (((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).HaveSubscriptionsBeenMade())
          {
            // redirect to a blank page that will
            // popup the results of the created job
            myRedirect = new Redirect();
            myRedirect.SetLinkGetCachedSpace(m_asOwner);
            myRedirect.SetDisplayPage(ABOSubBlankResultsDP.STR_MVC_CLASS_NAME);
            SetRedirect(myRedirect);
          }
        }
      }
      if ((doNormalFinish && POSTTOSELF_ACTION_FINISH == _nAction) || (POSTTOSELF_ACTION_CANCEL == _nAction))
      {
        myRedirect = new Redirect();
        myRedirect.SetLinkGetCachedSpace(m_asOwner);
        myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
        SetRedirect(myRedirect);
      }
    }
  }
}