using System;
namespace com.plumtree.portaluiinfrastructure.tags
{
  /// <summary>
  /// This enumeration specifies the type of the tag.
  /// <p />
  /// SIMPLE tags call ProcessTagBody at most once,
  /// whereas LOOPING tags can call it multiple times.
  /// NO_BODY tags do not display any tags or HTML
  /// nested inside them.
  /// </summary>
  public class TagType
  {
    
    /// <summary>
    /// Does not ever call ProcessTagBody.
    /// </summary>
    public static readonly TagType NO_BODY = new TagType();
    
    /// <summary>
    /// Calls ProcessTagBody 0 or 1 times.
    /// </summary>
    public static readonly TagType SIMPLE = new TagType();
    
    /// <summary>
    /// Calls ProcessTagBody 0, 1 or more times.
    /// </summary>
    public static readonly TagType LOOPING = new TagType();
    
    /// <summary>
    /// Private constructor to ensure that instances of
    /// this class form a specific enumeration of values.
    /// </summary>
    private TagType()
    {
    }
  }
}