using System;
using com.plumtree.portaluiinfrastructure.tags;
namespace com.plumtree.portaluiinfrastructure.tags.common
{
  /// <summary>
  /// This class contains constants that are used by multiple
  /// pagination data tags to ensure consistency.
  /// </summary>
  public class PaginationDataConstants
  {
    public const String TAG_NAME = "paginationdata";
    // NOTE: Pagination Data Tags should also use the common ID and
    // Scope attributes from CommonTagAttributeConstants
    // Data for the pages list attribute
    public const String ATTRIB_PAGESLIST_NAME = "pageslist";
    public const String ATTRIB_PAGESLIST_DESCRIPTION = "The list of pagination pages.";
    // Data for the number of pages attribute
    public const String ATTRIB_NUM_PAGES_NAME = "pagestodisplay";
    public const String ATTRIB_NUM_PAGES_DEFAULT = "2";
    public static readonly String ATTRIB_NUM_PAGES_DESCRIPTION = "The number of pages to display " + "before and after the current page (if there are any). The default is " + ATTRIB_NUM_PAGES_DEFAULT + ".";
    // variables for the main data object
    public const String TOTAL_RESULTS = "total";
    public const String NUM_PER_PAGE = "numperpage";
    public const String PREVIOUS_URL = "previousurl";
    public const String NEXT_URL = "nexturl";
    public const String LAST_PAGE = "lastpage";
    public const String FIRST_PAGE_URL = "firstpageurl";
    public const String LAST_PAGE_URL = "lastpageurl";
    // variables shared between the main data object and the pages objects
    public const String START_COUNT = "start";
    public const String END_COUNT = "end";
    // variables for the pages objects
    public const String PAGINATION_URL = "url";
    public const String PAGE_NUMBER = "number";
    // Strings for the main data
    public const String MAIN_DESCRIPTION_PREFIX = "Generates the data for the pagination links for ";
    public static readonly String MAIN_DESCRIPTION_SUFFIX = ATag.EncodeForTagDoc("and stores it in memory using the variable name specified by the " + "<code>" + CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. ");
    public static readonly String MAIN_DATA_DESCRIPTION = ATag.EncodeForTagDoc("The main data is stored as a DataObject with the following variables:<br>" + "<ul>" + "<li> <code>" + TOTAL_RESULTS + "</code> - The total number of results." + "<li> <code>" + NUM_PER_PAGE + "</code> - The number of results to display per page." + "<li> <code>" + START_COUNT + "</code> - The first result displayed on the current page." + "<li> <code>" + END_COUNT + "</code> - The last result displayed on the current page." + "<li> <code>" + LAST_PAGE + "</code> - The index of the last page." + "<li> <code>" + PREVIOUS_URL + "</code> - The URL to the previous page." + "<li> <code>" + NEXT_URL + "</code> - The URL to the next page." + "<li> <code>" + FIRST_PAGE_URL + "</code> - The URL to the first page." + "<li> <code>" + LAST_PAGE_URL + "</code> - The URL to the last page." + "</ul>");
    // Strings for the page list data
    public static readonly String PAGES_DATA_DESCRIPTION = ATag.EncodeForTagDoc("Additionally, the list of page links to display is stored in memory using the " + "variable name specified by the <code>" + ATTRIB_PAGESLIST_NAME + "</code> attribute. " + "Each result is a DataObject with the following variables:<br>" + "<ul>" + "<li> <code>" + PAGE_NUMBER + "</code> - The index of the page." + "<li> <code>" + START_COUNT + "</code> - The first result displayed on the page." + "<li> <code>" + END_COUNT + "</code> - The last result displayed on the page." + "<li> <code>" + PAGINATION_URL + "</code> - The URL to the page; will not be " + "present if the page is the current page." + "</ul>" + "Use tags from the Logic tags library to iterate over the list and display the results.");
    // TODO: Add example
    
    /// <summary>
    /// This example should be displayed after the pagination data tag is displayed. 
    /// </summary>
    public const String EXAMPLE = null;
  }
}