using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.tags.data
{
  /// <summary>
  /// This class is wrapper around XPHashtable that allows it
  /// to be used as a data collection in Tag memory.
  /// </summary>
  public class HashtableDataObject : IHierarchicalDataObject
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject");
    
    /// <summary>
    /// The underlying hashtable object.
    /// </summary>
    protected readonly XPHashtable m_hashtable;
    // only create this if needed
    protected XPHashtable m_hiertable = null;
    
    /// <summary>
    /// Default id for hierarchical data.
    /// NOTE: This definition should realy be in IHierarchicalDataObject but C# doesn't allow constant definitions on interfaces.
    /// </summary>
    public const String HIERDATA_DEFAULTKEY = "children";
    
    /// <summary>
    /// Constructor for the Hashtable wrapper data object that
    /// takes a pre-constructed hashtable.
    /// </summary>
    /// <param name="_hashtable">A pre-constructed hashtable.</param>
    public HashtableDataObject(XPHashtable _hashtable)
    {
      m_hashtable = _hashtable;
    }
    
    /// <summary>
    /// Constructor for the Hashtable wrapper data object.
    /// </summary>
    public HashtableDataObject()
    {
      m_hashtable = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(String)"></seealso>
    public virtual String GetData(String _strKey)
    {
      String strResult;
      try
      {
        strResult = (String) m_hashtable.GetElement(_strKey);
      }
      catch (Exception e)
      {
        log.Warn("Attempt to access data with key " + _strKey + " failed.  No such data exist.");
        strResult = null;
      }
      return strResult;
    }
    public virtual XPArrayList GetHierData(String _strKey)
    {
      if (m_hiertable == null)
      {
        return null;
      }
      return (XPArrayList) m_hiertable.GetElement(_strKey);
    }
    
    /// <summary>
    /// Sets a name value pair on the hashtable.
    /// </summary>
    /// <param name="_strKey">The name used to store the value.</param>
    /// <param name="_strValue">The value to be stored.</param>
    public virtual void SetData(String _strKey, String _strValue)
    {
      m_hashtable.PutElement(_strKey, _strValue);
    }
    
    /// <summary>
    /// Sets hierarchical data  
    /// NOTE: The value is not displayable from tags, this is just used
    /// for hierarchical data tags. 
    /// </summary>
    /// <param name="_strKey"></param>
    /// <param name="_strValue"></param>
    public virtual void SetHierData(String _strKey, XPArrayList list)
    {
      if (m_hiertable == null)
      {
        m_hiertable = new XPHashtable(3);
      }
      m_hiertable.PutElement(_strKey, list);
    }
    
    /// <summary>
    /// Get the underlying hashtable object.
    /// </summary>
    /// <returns>XPHashtable The underlying hashtable object.</returns>
    public virtual XPHashtable GetHashTable()
    {
      return m_hashtable;
    }
  }
}