using System;
namespace com.plumtree.portaluiinfrastructure.tags.data
{
  /// <summary>
  /// Data objects are used to store collections of variables
  /// in Tag memory so that they can be accessed automatically
  /// using attribute value replacement.
  /// <p />
  /// For instance, if an IDataObject is stored in memory
  /// (ATag.SetVariable or SetSharedVariable) under the key
  /// "links" and has data stored in it under the keys "url"
  /// and "name", it could be used as follows:
  /// <p />
  /// &lt;pt:core.html pt:tag="a" href="$url" title="$name"&gt;
  /// <br />
  /// &lt;pt:logic.value value="$links.name"/&gt;
  /// <br />
  /// &lt;/pt:core.html&gt;
  /// </summary>
  public interface IDataObject
  {
    
    /// <summary>
    /// Gets the data stored with a particular key.
    /// </summary>
    /// <param name="_strKey">The key for the requested data</param>
    /// <returns>String The requested data</returns>
    String GetData(String _strKey);
  }
}