/*
 * Created on Jun 1, 2005
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
namespace com.plumtree.portaluiinfrastructure.tags.data
{
  /// <summary>
  /// Helper object that defines and provides a protocol for setting single or a list of PTURL DO data
  /// in different Tag Scopes.
  /// </summary>
  public class TagDataSetterPTURLDOData
  {
    // TODOCR DONH: Why is this list called PTURLDOData?  There's nothing in
    // it that's specific to PTURLDO's.  It seems like this should either be
    // generalized, or moved into one of the nav tag libraries if it's nav
    // specific.  It doesn't seem like it belongs here.  It's not part of the
    // framework.  This is something specifically for the nav taglibs, right?
    public static readonly Scope DEFAULT_TAGSCOPE = Scope.PORTLET_REQUEST;
    
    /// <summary>
    /// Use an instance of the Getter *
    /// </summary>
    internal TagDataGetterPTURLDOList m_ptURLGetter = null;
    internal Scope m_scope = null;
    public TagDataSetterPTURLDOData()
    {
      m_scope = DEFAULT_TAGSCOPE;
      m_ptURLGetter = new TagDataGetterPTURLDOList(m_scope);
    }
    public TagDataSetterPTURLDOData(Scope scope)
    {
      m_ptURLGetter = new TagDataGetterPTURLDOList(scope);
      m_scope = scope;
    }
    
    /// <summary>
    /// Sets the Tag scope to set PTURL data on 
    /// </summary>
    /// <param name="scope"></param>
    public virtual void SetScope(Scope scope)
    {
      m_scope = scope;
    }
    
    /// <summary>
    /// Sets provided list on the Tag Scope. 
    /// The list is added  onto any existing list already on the tag Tag Scope.
    /// </summary>
    /// <param name="tag"></param>
    /// <param name="tagAttrib"></param>
    /// <param name="xpList"></param>
    public virtual void SetDataCollectionOnTagScope(ITagState state, String strKey,
     IXPList xpList)
    {
      // Don't need to add anything if the list is empty
      if (null == xpList || xpList.GetSize() == 0)
      {
        return;
      }
      IXPList memList = m_ptURLGetter.GetMemoryData(state, strKey);
      if (null == memList)
      {
        memList = CreateMemoryData(state, strKey);
      }
      // Note that we add the list to the existing list, not replacing it
      memList.AddRange(xpList);
    }
    
    /// <summary>
    /// Sets the provided IPTURL object on the Tag Scope.
    /// The IPTURL entry is appended to any existing list already on the Tag Scope.
    /// </summary>
    /// <param name="state"></param>
    /// <param name="strKey"></param>
    /// <param name="obj"></param>
    public virtual void SetDataEntryOnTagScope(ITagState state, String strKey,
     IPTURL obj)
    {
      if (null == obj)
      {
        return;
      }
      IXPList memList = m_ptURLGetter.GetMemoryData(state, strKey);
      if (null == memList)
      {
        memList = CreateMemoryData(state, strKey);
      }
      memList.Add(obj);
    }
    
    /// <summary>
    /// Method to create new data instance into Tag Scope
    /// </summary>
    /// <param name="tag"></param>
    /// <param name="tagAttrib"></param>
    /// <returns></returns>
    internal virtual IXPList CreateMemoryData(ITagState state, String strKey)
    {
      XPArrayList memList = new XPArrayList();
      state.SetSharedVariable(strKey, memList, m_scope, true);
      return memList;
    }
  }
}