using System;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.tags.displaytree
{
  /// <summary>
  /// This is the base class for the different kinds of display
  /// elements that are used when processing tags.
  /// This is a framework only class and should not be
  /// used by external developers.
  /// </summary>
  /// <author>donh</author>
  public interface IDisplayElement
  {
    
    /// <summary>
    /// Displays this element and it's child elements and
    /// returns the result.
    /// </summary>
    /// <param name="_tagVisitor"></param>
    /// <returns>HTMLElement The result of displaying this element</returns>
    HTMLElement Display(TagVisitor _tagVisitor);
    
    /// <summary>
    /// This method is called to release any data that needs
    /// special handling before being allowed to go out of
    /// scope.
    /// </summary>
    void Release();
    
    /// <summary>
    /// This method searches for child tags of the current tag and
    /// fills in the results array with an Object if the tag has
    /// been found.
    /// This method will not work if _results is not an array of null
    /// objects of the same length as _childTags.
    /// </summary>
    /// <param name="_childTags">
    /// An array of ITagMetaData objects for each child
    /// tag to search for.
    /// </param>
    /// <param name="_results">
    /// An array of null Objects.  On execution, when a child
    /// tag is found, the location in the _results array that corresponds to
    /// the location of the tag in the _ChildTags array will be filled in with an
    /// Integer containing the positive depth of the child tag.
    /// </param>
    /// <param name="_library">The Tag Library of the tags to look for.</param>
    /// <param name="_nCurrentDepth">The depth of the current tag.</param>
    /// <returns>boolean implies that all of the Child Tags have been found.</returns>
    bool HasChildElements(ITagMetaData[] _childTags, Object[] _results, TagLibraryMetaData _library,
     int _nCurrentDepth);
    
    /// <summary>
    /// This method searches for a parent tag of the current tag.
    /// </summary>
    /// <param name="_ParentTag">The ITagMetaData of the tag to look for.</param>
    /// <param name="_library">The Tag Library of the tag to look for.</param>
    /// <returns>
    /// int 0 implies the parent tag was not found and a
    /// positive integer implies that the parent tag was found n
    /// levels above the current tag.
    /// </returns>
    int HasParentElement(ITagMetaData _parentTag, TagLibraryMetaData _library);
    }
}