using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.tags.displaytree
{
  /// <summary>
  /// This class handles preprocessing the markup list to
  /// ensure that the HEAD element is in the proper format.
  /// It also adds the HeadIncludes tag to the markup.
  /// </summary>
  public interface IHeadPreprocessor
  {
    
    /// <summary>
    /// This function pre-processes the head element of this HTML
    /// document to make sure it is in the proper format.  If
    /// necessary, this will add the HeadIncludes tag as well as
    /// create the HEAD element if it does not exist.
    /// This should only be called for main pages.
    /// NOTE: PreprocessHead needs to be called at least once per request,
    /// otherwise the shared JavaScript will not be added to the page.
    /// Otherwise, the GetSharedJavaScriptForMultipleMarkupAsElement
    /// method needs to be called or the shared JavaScript will not be
    /// displayed.
    /// </summary>
    /// <param name="Object[][]">_objArrMarkup An Object[][] of markup</param>
    /// <param name="ISessionManager">_Session</param>
    /// <param name="IEnvironment">_Environment</param>
    /// <param name="boolean">
    /// _bForceHead Whether or not to force the
    /// markup array list to include a head element, regardless
    /// of other factors.
    /// </param>
    /// <returns>Object[][] objArrMarkup the new Object[][] markup.</returns>
    Object[][] PreprocessHead(Object[][] _objArrMarkup, ISessionManager _Session,
     IEnvironment _Environment, bool _bForceHead);
    
    /// <summary>
    /// This function pre-processes the head element of this HTML
    /// document to make sure it is in the proper format.  If
    /// necessary, this will add the HeadIncludes tag as well as
    /// create the HEAD element if it does not exist.
    /// This should only be called for main pages.
    /// NOTE: PreprocessHead needs to be called at least once per request,
    /// otherwise the shared JavaScript will not be added to the page.
    /// Otherwise, the GetSharedJavaScriptForMultipleMarkupAsElement
    /// method needs to be called or the shared JavaScript will not be
    /// displayed.
    /// </summary>
    /// <param name="XPArrayList">_markupList A list of IMarkupFragments</param>
    /// <param name="ISessionManager">_Session</param>
    /// <param name="IEnvironment">_Environment</param>
    /// <param name="boolean">
    /// _bForceHead Whether or not to force the
    /// markup array list to include a head element, regardless
    /// of other factors.
    /// </param>
    void PreprocessHead(XPArrayList _markupList, ISessionManager _Session,
     IEnvironment _Environment, bool _bForceHead);
  }
}