using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portaluiinfrastructure.tags.helper
{
  /// <summary>
  /// Class to store data for a tag cache entry
  /// </summary>
  /// <author>rozhang</author>
  public class TagCacheEntry
  {
    
    /// <summary>
    /// Cache value *
    /// </summary>
    protected Object m_cacheData = null;
    
    /// <summary>
    /// The time when this entry expires *
    /// </summary>
    protected XPDateTime m_expiration = null;
    
    /// <summary>
    /// Constructor
    /// </summary>
    /// <param name="cacheData"></param>
    /// <param name="expiration"></param>
    public TagCacheEntry(Object cacheData, XPDateTime expiration)
    {
      m_cacheData = cacheData;
      m_expiration = expiration;
      if (m_expiration == null)
      {
        throw new XPIllegalArgumentException("No expiration time was provided!");
        }
    }
    
    /// <summary>
    /// Expire entry by setting the expiration time to 1hr ago.
    /// </summary>
    public virtual void ExpireEntry()
    {
      XPDateTime now = new XPDateTime();
      XPDateTime expired = new XPDateTime(now.GetTimeInMilliSeconds() - (long) (1000 * 60 * 60));
      m_expiration = expired;
    }
    
    /// <summary>
    /// Check if entry expired
    /// </summary>
    /// <returns></returns>
    public virtual bool IsEntryExpired()
    {
      XPDateTime now = new XPDateTime();
      return now.After(m_expiration);
    }
    
    /// <summary>
    /// Get the cached value
    /// </summary>
    /// <returns></returns>
    public virtual Object GetCacheData()
    {
      return m_cacheData;
    }
  }
}