using System;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.tags.helper
{
  /// <summary>
  /// This class is used to traverse the tag display tree
  /// and pass common data to each element as it is displayed.
  /// </summary>
  /// <author>donh</author>
  public class TagVisitor
  {
    protected TagState m_TagState;
    protected IEnvironment m_Environment;
    protected TagDisplayElement m_CurrentTag;
    protected HTMLElementCollection m_SharedJavascript;
    
    /// <summary>
    /// Constructor for TagVisitor.  This should only be
    /// called by the tag framework.
    /// </summary>
    /// <param name="_tagState">
    /// The TagState object for this
    /// portlet request.
    /// </param>
    /// <param name="_environment">
    /// The environment for this HTTP
    /// request.
    /// </param>
    public TagVisitor(TagState _tagState, IEnvironment _environment, HTMLElementCollection _sharedJavaScript)
    {
      m_TagState = _tagState;
      m_Environment = _environment;
      m_CurrentTag = null;
      m_SharedJavascript = _sharedJavaScript;
    }
    
    /// <summary>
    /// The environment for the current HTTP request.
    /// </summary>
    /// <returns>
    /// IEnvironment The environment for the
    /// current HTTP request. 
    /// </returns>
    public virtual IEnvironment GetEnvironment()
    {
      return m_Environment;
    }
    
    /// <summary>
    /// The TagState for the current portlet request.
    /// </summary>
    /// <returns>
    /// TagState The TagState for the current
    /// portlet request.
    /// </returns>
    public virtual TagState GetState()
    {
      return m_TagState;
    }
    
    /// <summary>
    /// The Shared JavaScript collection for the current
    /// http request.
    /// </summary>
    /// <returns>
    /// HTMLElementCollection The Shared JavaScript
    /// collection.
    /// </returns>
    public virtual HTMLElementCollection GetJavaScriptCollection()
    {
      return m_SharedJavascript;
    }
    
    /// <summary>
    /// Sets the current Tag Display Element from the display
    /// tree so the TagVisitor can search the tree.
    /// </summary>
    /// <param name="_currentTag">
    /// The current TagDisplayElement in
    /// the display tree.
    /// </param>
    public virtual void SetCurrentTag(TagDisplayElement _currentTag)
    {
      m_CurrentTag = _currentTag;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#HasParentElement(ITagMetaData,TagLibraryMetaData)"></seealso>
    public virtual int HasParentTag(ITagMetaData _parentTag, TagLibraryMetaData _library)
    {
      // This method check for a matching parent tag above the current tag.
      return m_CurrentTag.HasParentTag(_parentTag, _library);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#HasChildElements(ITagMetaData[],Object[],TagLibraryMetaData)"></seealso>
    public virtual bool HasChildTags(ITagMetaData[] _childTags, Object[] _results,
     TagLibraryMetaData _library)
    {
      // This method checks for matching child tags below the current tag.
      return m_CurrentTag.HasChildTags(_childTags, _results, _library, 0);
      }
  }
}