using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
namespace com.plumtree.portaluiinfrastructure.tags.manager
{
  public interface ITagLibManager
  {
    
    /// <summary>
    /// Create the requested Tag. (Use this method where the library version is specified
    /// where possible as it is more efficient.)
    /// This method should not be called by developers.  It is only for
    /// the Tag Framework.
    /// </summary>
    /// <param name="String">_strTagName The name of the requested tag</param>
    /// <param name="String">
    /// _strLibraryName The name of the library that
    /// contains the requested tag
    /// </param>
    /// <param name="_dLibraryVersion">
    /// The version of the library that contains
    /// the requested tag
    /// </param>
    /// <returns>ATag The requested tag, null on failure</returns>
    ATag GetTag(String _strTagName, String _strLibraryName, double _dLibraryVersion);
    
    /// <summary>
    /// Create the requested Tag. (Avoid this method where the library version is 
    /// not specified where possible as it is less efficient.)
    /// This method should not be called by developers.  It is only for
    /// the Tag Framework.
    /// </summary>
    /// <param name="String">_strTagName The name of the requested tag</param>
    /// <param name="String">
    /// _strLibraryName The name of the library that
    /// contains the requested tag
    /// </param>
    /// <returns>ATag The requested tag, null on failure</returns>
    ATag GetTag(String _strTagName, String _strLibraryName);
    
    /// <summary>
    /// Return true if the tag specified by the parameters exists otherwise return false.
    /// Use this method specifying the library version rather than not where possible
    /// as it is much more efficient.
    /// </summary>
    /// <param name="String">_strTagName The name of the requested tag</param>
    /// <param name="String">
    /// _strLibraryName The name of the library that
    /// contains the requested tag
    /// </param>
    /// <param name="_dLibraryVersion">
    /// The version of the library that contains
    /// the requested tag
    /// </param>
    /// <returns>true if the tag exists otherwise false.</returns>
    bool HasTag(String _strTagName, String _strLibraryName, double _dLibraryVersion);
    
    /// <summary>
    /// Return true if the tag specified by the parameters exists otherwise return false.
    /// Use the method specifying the library version rather than this where possible
    /// as it is much more efficient.
    /// </summary>
    /// <param name="String">_strTagName The name of the requested tag</param>
    /// <param name="String">
    /// _strLibraryName The name of the library that
    /// contains the requested tag
    /// </param>
    /// <returns>true if the tag exists otherwise false.</returns>
    bool HasTag(String _strTagName, String _strLibraryName);
    
    /// <summary>
    /// This method initializes the TagLibManager and should only be called by
    /// the Application Warmup.  This method can only be called once.
    /// </summary>
    /// <param name="strLibDir">The file directory where jars and dlls can be found</param>
    /// <param name="strConfigFile">the name of the config file</param>
    void LoadClasses(String strLibDir, String strConfigFile);
    
    /// <summary>
    /// This method initializes the TagLibManager with custom tags
    /// to overwrite the original ones and should only be called by the
    /// the Application Warmup.
    /// </summary>
    /// <param name="strLibDir">The file directory where jars and dlls can be found</param>
    /// <param name="strConfigFile">the name of the custom config file</param>
    void LoadCustomClasses(String strLibDir, String strConfigFile);
    
    /// <summary>
    /// Return a data structure holding name and version number of all libraries
    /// loaded.
    /// TODO this may not be the form we really want to return this data in
    /// that's still being figured out - CVN
    /// </summary>
    XPHashtable GetLibraries();
    
    /// <summary>
    /// Return library meta data on a specific library and version.
    /// TODO this may not be the form we really want to return this data in
    /// that's still being figured out - CVN
    /// </summary>
    TagLibraryMetaData GetTagLibMetadata(String _sLibname, double _dVersion);
    
    /// <summary>
    /// Return tag info for a specific library
    /// TODO this may not be the form we really want to return this data in
    /// that's still being figured out - CVN
    /// </summary>
    XPArrayList GetLibraryTagList(String _sLibname, double _dVersion);
    
    /// <summary>
    /// Return all tags in library
    /// TODO this may not be the form we really want to return this data in
    /// that's still being figured out - CVN
    /// </summary>
    XPArrayList GetLibraryTags(String _sLibname, double _dVersion);
    
    /// <summary>
    /// Return metadata or something on all tags in library
    /// TODO not yet implemented cvn
    /// </summary>
    void GetTagMetadata(String _sLibname, double _dVersion, String _sTagname);
    
    /// <summary>
    /// This method reloads a particular version of a tag library from
    /// the same library file (i.e. jar or dll) that it was originally
    /// loaded from.
    /// </summary>
    /// <param name="_sLibname">String The name of the library to reload (not display name).</param>
    /// <param name="_dVersion">double The version number of the library to reload.</param>
    void ReloadTagLibrary(String _sLibname, double _dVersion);
    
    /// <summary>
    /// This method reloads both the standard and custom tag libraries
    /// from the config files.
    /// </summary>
    void ReloadAllTagLibraries();
    
    /// <summary>
    /// This method returns the number of custom Tag Libraries
    /// currently loaded.  This number is reset every time
    /// custom objects are loaded.
    /// </summary>
    /// <returns>The number of custom Tag Libraries currently loaded.</returns>
    int GetNumCustomTagLibraries();
    
    /// <summary>
    /// This method returns the number of custom Tags
    /// currently loaded.  This number is reset every time
    /// custom objects are loaded.
    /// </summary>
    /// <returns>The number of custom Tagss currently loaded.</returns>
    int GetNumCustomTags();
  }
}