using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sorted;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager
{
  /// <summary>
  /// This model extends the SortedMultiColumnListModel to 
  /// set the width of the Version column to a smaller size.
  /// </summary>
  /// <author>DonH</author>
  public class TagLibListModel : SortedMultiColumnListModel
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "TagLibList";
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_bEnableSort">for each column</param>
    /// <param name="_nDefaultSortColumn">the zero based column id for the default column to sort by.</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on the same
    /// DP, they should have a different key (otherwise, just set it to
    /// 1).
    /// </param>
    public override void InitializeMultiColumnList(String _sSectionTitle,
     String[] _sSectionSubTitle, bool[] _bEnableSort, int _nDefaultSortColumn,
     PTImageType _imgAddIcon, String _sAddLabel, int _nListKey)
    {
      // Set the width based on the number of columns
      // Last column is small, so don't include it.
      int intColWidth = 100 / (m_intNumColumns - 1);
      XPStringBuilder sb = new XPStringBuilder(5);
      sb.Append(intColWidth).Append("%");
      m_nDefaultSortColumn = _nDefaultSortColumn;
      Object[][] arrExpListColInfo = new Object[m_intNumColumns][];
      for (int j2c_index = 0;j2c_index < m_intNumColumns;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      for (int i = 0;i < m_intNumColumns;i++)
      {
        arrExpListColInfo[i][EXPLIST_COLUMN_ID] = i + 1;
        arrExpListColInfo[i][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle[i];
        arrExpListColInfo[i][EXPLIST_COLUMN_WIDTH] = sb.ToString();
        arrExpListColInfo[i][EXPLIST_COLUMN_COLSPAN] = "1";
        arrExpListColInfo[i][EXPLIST_COLUMN_ENABLESORT] = _bEnableSort[i];
        }
      // Explicitly set the last column width to a smaller number
      arrExpListColInfo[m_intNumColumns - 1][EXPLIST_COLUMN_WIDTH] = "80";
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TagLibListModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}