using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sorted;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager
{
  /// <summary>
  /// Display each tag library.
  /// </summary>
  /// <author>DonH</author>
  public class TagLibListView : MultiColumnListView
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "TagLib";
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex. Each row contains just an icon
    /// and input text for each column.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      int intColWidth = 100 / ((IMultiColumnListModelRO) m_model).GetNumColumns();
      XPStringBuilder sbColPercent = new XPStringBuilder(5);
      sbColPercent.Append(intColWidth).Append("%");
      myCell = new HTMLTableCell();
      myCell.SetWidth(sbColPercent.ToString());
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // row icon
      PTImageType imgRowIcon = ((IMultiColumnListModelRO) m_model).GetRowIcon();
      if (null != imgRowIcon)
      {
        myCell.AddInnerHTMLElement(GetHTMLForIcon(imgRowIcon));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      for (int i = 1;i <= ((IMultiColumnListModelRO) m_model).GetNumColumns();
      i++)
      {
        //Only add a new cell if this isn't the first one
        if (i > 1)
        {
          myCell = new HTMLTableCell();
          myCell.SetWidth(sbColPercent.ToString());
          myCell.SetHeight("30");
          myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
          myCell.SetNoWrap(true);
        }
        myCell.AddInnerHTMLString((String) _saData.GetItem(_nRowIndex, i));
        result.AddInnerHTMLElement(myCell);
      }
      if (((IMultiColumnListModelRO) m_model).GetEnableMoveRowActions())
      {
        result.AddInnerHTMLElement(base.GetHTMLForMoveRowActions(_nRowIndex));
        }
      // input text
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    protected override HTMLTable GetHTMLForActionBar()
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myTable = new HTMLTable();
      myTable.SetBorder("0");
      myTable.SetCellPadding("0");
      myTable.SetCellSpacing("0");
      // 1st Row begin (there is only one row)
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      // Reload button cell
      myRow.AddInnerHTMLElement(GetHTMLForReloadAction());
      // Empty Cell
      myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
      // Reload all button cell
      myRow.AddInnerHTMLElement(GetHTMLForReloadAllAction());
      // Empty Cell
      myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
      // Last Empty Cell
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetHeight("25");
      myCell.AddInnerHTMLString(SPACE);
      // 1st Row ends
      return myTable;
    }
    
    /// <summary>
    /// Returns the HTML for the reload cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    protected virtual HTMLTableCell GetHTMLForReloadAction()
    {
      SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_REFRESH,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      // Reload
      myAddIcon.SetAlt(m_asOwner.GetString(773, ResourceConstants.PORTALCOMMONMSGS));
      myAddIcon.SetAlign("absmiddle");
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.AddInnerHTMLString(SPACE);
      myAnchor.SetOnClick("if(0 != " + myMultiColumnListModel.GetUniqueString("CountCheckedRows") + "()){postToSelf(\'" + TagLibRepostControl.POSTTOSELF_ACTION_RELOAD + "\');}else{" + "alert(\'" + 
      // Please select at least one library to reload.
      m_asOwner.GetString(775, ResourceConstants.PORTALCOMMONMSGS) + "\');} return false;");
      myAnchor.AddInnerHTMLElement(myAddIcon);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label - Reload
      mySpan.AddInnerHTMLString(m_asOwner.GetString(773, ResourceConstants.PORTALCOMMONMSGS));
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the reload all cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    protected virtual HTMLTableCell GetHTMLForReloadAllAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_REFRESH,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      // Reload All
      myAddIcon.SetAlt(m_asOwner.GetString(774, ResourceConstants.PORTALCOMMONMSGS));
      myAddIcon.SetAlign("absmiddle");
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.AddInnerHTMLString(SPACE);
      myAnchor.SetOnClick("postToSelf(\'" + TagLibRepostControl.POSTTOSELF_ACTION_RELOAD_ALL + "\'); return false;");
      myAnchor.AddInnerHTMLElement(myAddIcon);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label - Reload All
      mySpan.AddInnerHTMLString(m_asOwner.GetString(774, ResourceConstants.PORTALCOMMONMSGS));
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      return myCell;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TagLibListView();
    }
  }
}