using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager
{
  /// <summary>
  /// This class is used to display the currently loaded tag libraries.
  /// </summary>
  /// <author>donh</author>
  public class TagLibManagerAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tags.manager.taglibutility.TagLibEditorAS");
    public const String STR_MVC_CLASS_NAME = "TagLib";
    private const String sClassName = "com.plumtree.portaluiinfrastructure.tags.manager.taglibutility.TagLibEditorAS";
    public const String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "TagLibList";
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      // Tag Library Manager
      return GetString(771, ResourceConstants.PORTALCOMMONMSGS);
    }
    
    /// <summary>
    /// Returns the class name of the tag lib manager Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (TagLibRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = TagLibModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(TagLibModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new TagLibDP());
      // Register Controls
      RegisterControl(TagLibRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Register the Section, the Model and the Control
      // used by the multi column array.
      RegisterModel(TagLibListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myMultiColumnListModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      RegisterView(TagLibListView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST,
       myMultiColumnListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST,
       myMultiColumnListModel);
      // Set default page
      SetCurrentPage(TagLibDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      // BEGIN Sub menu "Tag Library Manager"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(771, ResourceConstants.PORTALCOMMONMSGS));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, TagLibDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Tag Library Manager"
      // Help Topic
      SetHelpTopic("PT_TagLibraryManager");
      // TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 147;
          int iTipId = 148;
          int iSecondaryTipId = 149;
          // Tag Libraries
          tm.SetTipTitle(GetString(iTitleId, ResourceConstants.TIPS));
          // Main tip
          tm.SetTip(new HTMLGenericElement(GetString(iTipId, ResourceConstants.TIPS)));
          // Secondary tip
          tm.SetSecondarTip(new HTMLGenericElement(GetString(iSecondaryTipId,
           ResourceConstants.TIPS)));
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TagLibManagerAS();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}