using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sorted;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager
{
  /// <summary>
  /// This is the Model class for the Tag Lib Editor.
  /// </summary>
  /// <author>donh</author>
  public class TagLibModel : EditorModel,IEditorModelRO
  {
    public const String STR_MVC_CLASS_NAME = "TagLib";
    
    /// <summary>
    /// The display name column ID.
    /// </summary>
    public const int DISPLAY_NAME = 0;
    
    /// <summary>
    /// The version column ID.
    /// </summary>
    public const int VERSION = 1;
    
    /// <summary>
    /// The name column ID.
    /// </summary>
    public const int NAME = 2;
    
    /// <summary>
    /// The original data for the list.
    /// </summary>
    internal String[][] m_strArrLibs = null;
    
    /// <summary>
    /// Inits the Model with the Activity Space.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      // Set to read only so we only get finish button
      m_bIsEditorReadOnly = true;
      base.Init(parent);
    }
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>
    /// boolean Is true if the current user has the rights to access
    /// this Editor.
    /// </returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      if (!PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) m_asOwner.GetUserSession()))
      {
        return false;
      }
      if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      StartTagLibList();
      return true;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      if (_sPageName.Equals(TagLibDP.STR_MVC_CLASS_NAME))
      {
        ((MultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST)).SaveSection(_htFormData);
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Helper method to start the Growable List.
    /// </summary>
    public virtual void StartTagLibList()
    {
      SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      String strHostName = ConfigHelper.GetConfigVariableAsString(ConfigConstants.SYSTEM_PROPERTIES_SECTION,
       ConfigConstants.MACHINE_NAME_SUBSECTION, ConfigConstants.VALUE_ATTRIBUTE,
       m_asOwner.GetApplication());
      // Tag Libraries: Hostname: xxx
      String strListTitle = XPResourceManager.FormatMessage(m_asOwner.GetString(779,
       ResourceConstants.PORTALCOMMONMSGS), strHostName);
      myMultiColumnListModel.InitializeMultiColumnList(strListTitle, new String[]{
      // Name
      m_asOwner.GetString(776, ResourceConstants.PORTALCOMMONMSGS), 
      // Version
      m_asOwner.GetString(777, ResourceConstants.PORTALCOMMONMSGS)}, 
      // Turn on sorting for both columns
      new bool[]{true, true}, 
      // Sort by name by default
      0, 
      // Not used
      PTImageType.ICON_HOME, "", 
      // list key
      1);
      // Do we want a row icon?
      // Optional setting
      //     Use the method below to set the icon to display on each row before the input text.
      //     (By default there will be no icon.)
      //myGrowableListModel.SetRowIcon(PTImageType.PENCIL_SMALL);
      // Set list to readonly until bug#45342 is fixed - reload can
      // recycle the .net app, and doesn't really work in Java.
      // Read only lists don't display the action bar (reload buttons) or
      // the checkboxes.
      myMultiColumnListModel.SetIsListReadOnly(true);
      PopulateTagLibList();
    }
    
    /// <summary>
    /// Helper method to populate the Growable List.
    /// </summary>
    public virtual void PopulateTagLibList()
    {
      SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Populate the list
      XPArrayList displayNames = new XPArrayList();
      XPArrayList versions = new XPArrayList();
      XPArrayList names = new XPArrayList();
      XPHashtable libraries = TagLibManager.getInstance().GetLibraries();
      IXPEnumerator libraryNames = libraries.GetKeys();
      while (libraryNames.MoveNext())
      {
        String strLibName = (String) libraryNames.GetCurrent();
        XPArrayList libMetadataList = (XPArrayList) libraries.GetElement(strLibName);
        for (int i = 0;i < libMetadataList.GetSize();i++)
        {
          TagLibraryMetaData tagLibraryMetaData = (TagLibraryMetaData) libMetadataList.GetElement(i);
          displayNames.Add(tagLibraryMetaData.GetDisplayName());
          versions.Add(XPConvert.ToString(tagLibraryMetaData.GetVersion()));
          names.Add(tagLibraryMetaData.GetName());
        }
      }
      m_strArrLibs = new String[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        m_strArrLibs[j2c_index] = new String[displayNames.GetSize()];
      }
      String[][] strData = new String[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        strData[j2c_index] = new String[displayNames.GetSize()];
      }
      for (int i = 0;i < m_strArrLibs[0].Length;i++)
      {
        m_strArrLibs[DISPLAY_NAME][i] = (String) displayNames.GetElement(i);
        m_strArrLibs[VERSION][i] = (String) versions.GetElement(i);
        m_strArrLibs[NAME][i] = (String) names.GetElement(i);
        strData[DISPLAY_NAME][i] = (String) displayNames.GetElement(i);
        strData[VERSION][i] = (String) versions.GetElement(i);
      }
      // Pre populate the list (By default the list will be empty.).
      myMultiColumnListModel.AddRowsToList(strData);
      // Set the message and instructions to display when the list is empty.
      // message: There are no tag libraries loaded in this portal server.
      // instructions: To load a tag library, edit the tag library configuration
      // files and click the Reload All button.
      myMultiColumnListModel.SetEmptyListMessages(m_asOwner.GetString(780,
       ResourceConstants.PORTALCOMMONMSGS), m_asOwner.GetString(781, ResourceConstants.PORTALCOMMONMSGS));
      }
    
    /// <summary>
    /// Reload the selected libraries.
    /// </summary>
    /// <param name="_nRowsToReload">An int[] of the row IDs of the libraries to reload.</param>
    public virtual void ReloadCheckedLibraries(int[] _nRowsToReload)
    {
      SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      PTGrowableSortedArrayWrapper data = myMultiColumnListModel.GetItems();
      String[][] strData = new String[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        strData[j2c_index] = new String[_nRowsToReload.Length];
      }
      bool bFailedToReload = false;
      for (int i = 0;i < _nRowsToReload.Length;i++)
      {
        // The first column of the SAW is the row IDs.
        String strDisplayName = (String) data.GetItem(_nRowsToReload[i], DISPLAY_NAME + 1);
        String strLibVersion = (String) data.GetItem(_nRowsToReload[i], VERSION + 1);
        for (int j = 0;j < m_strArrLibs[0].Length;j++)
        {
          // Note: It is theoretically possible for two libraries to have the same
          // display name, in which case this will only reload the first one.
          if ((0 == XPStringUtility.Compare(strDisplayName, m_strArrLibs[DISPLAY_NAME][j])) && (0 == XPStringUtility.Compare(strLibVersion,
           m_strArrLibs[VERSION][j])))
          {
            String strLibName = m_strArrLibs[NAME][j];
            double dLibVersion = XPConvert.ToDouble(strLibVersion);
            TagLibManager.getInstance().ReloadTagLibrary(strLibName, dLibVersion);
            if (null != TagLibManager.getInstance().GetLibraryTags(strLibName,
             dLibVersion))
            {
              strData[DISPLAY_NAME][i] = strDisplayName;
              strData[VERSION][i] = strLibVersion;
            } else
            {
              bFailedToReload = true;
            }
            break;
          }
        }
      }
      data.RemoveRows(_nRowsToReload);
      if (bFailedToReload)
      {
        // Reset the tag lib list.
        this.StartTagLibList();
        throw new XPException("Unable to reload one or more tag libraries.  Resetting list.");
        }
      myMultiColumnListModel.AddRowsToList(strData);
    }
    
    /// <summary>
    /// Reload all tag libraries (standard and custom).
    /// </summary>
    public virtual void ReloadAllLibraries()
    {
      TagLibManager.getInstance().ReloadAllTagLibraries();
      SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      PTGrowableSortedArrayWrapper data = myMultiColumnListModel.GetItems();
      // Clear the list
      data.ClearArray();
      PopulateTagLibList();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TagLibModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}