using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager
{
  /// <summary>
  /// This is the RepostControl class for the Tag Lib Editor.
  /// It handles the Repost actions for that Editor.
  /// </summary>
  /// <author>donh</author>
  public class TagLibRepostControl : EditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tags.manager.taglibutility.TagLibRepostControl");
    public const String STR_MVC_CLASS_NAME = "TagLib";
    
    /// <summary>
    /// Will reload one or more tag libraries in the list. 
    /// </summary>
    public const int POSTTOSELF_ACTION_RELOAD = 50;
    
    /// <summary>
    /// Will reload all tag libraries. 
    /// </summary>
    public const int POSTTOSELF_ACTION_RELOAD_ALL = 51;
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformReadOnlyAction(int _nAction)
    {
      base.PerformReadOnlyAction(_nAction);
      // You need to call the PerformRepostAction on the multi column array control
      ((ExpListControl) m_asOwner.GetControl(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST)).PerformRepostAction(_nAction,
       m_htFormData);
      switch (_nAction){
      case POSTTOSELF_ACTION_RELOAD:
      ExpListModel myExpListModel = (ExpListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // We use the same mechanism as deleting rows.
      // Note: this will throw a null pointer exception if there are
      // no checked rows, so we check for this in javascript.
      int[] selectedItems = myExpListModel.GetArrayOfObjToDelete(m_htFormData);
      try
      {
        ((TagLibModel) m_model).ReloadCheckedLibraries(selectedItems);
      }
      catch (Exception e)
      {
        m_nPageStatus = PAGE_STATUS_INVALID;
        IXPEnumerator arrErrors = UIErrorHandler.GetErrors(m_asOwner.GetSubSession(),
         m_asOwner.GetApplication(), m_asOwner, true, true);
        if (!arrErrors.MoveNext())
        {
          GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
           "EditorRepostControl::PerformAction", e, false, UIErrorLevel.SERIOUS,
           
          // Unable to reload selected tag libraries.
          m_asOwner.GetString(782, ResourceConstants.PORTALCOMMONMSGS));
        } else
        {
          log.Error(e, "Unable to reload selected tag libraries.");
        }
      }
      break;
      case POSTTOSELF_ACTION_RELOAD_ALL:
      try
      {
        ((TagLibModel) m_model).ReloadAllLibraries();
      }
      catch (Exception e)
      {
        m_nPageStatus = PAGE_STATUS_INVALID;
        IXPEnumerator arrErrors = UIErrorHandler.GetErrors(m_asOwner.GetSubSession(),
         m_asOwner.GetApplication(), m_asOwner, true, true);
        if (!arrErrors.MoveNext())
        {
          GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
           "EditorRepostControl::PerformAction", e, false, UIErrorLevel.SERIOUS,
           
          // Unable to reload all tag libraries.
          m_asOwner.GetString(783, ResourceConstants.PORTALCOMMONMSGS));
        } else
        {
          log.Error(e, "Unable to reload all tag libraries.");
        }
      }
      break;
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TagLibRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}