using System;
namespace com.plumtree.portaluiinfrastructure.tags.metadata
{
  /// <summary>
  /// This class provides programmatic access to the
  /// tag meta data for name, description, and example.
  /// <p />
  /// Tag classes need to have exactly one public static final
  /// ITagMetaData member variable that provides the name,
  /// description, and example text for this Tag.
  /// <p />
  /// E.G.
  /// <br />
  /// &lt;pt:thistag/&gt;
  /// <br />
  /// would need
  /// <br />
  /// public static final ITagMetaData = new TagMetaData("thistag",
  /// "This tag displays some HTML ...");
  /// </summary>
  public interface ITagMetaData
  {
    
    /// <summary>
    /// Gets the name of the tag
    /// </summary>
    /// <returns>String The name of the tag</returns>
    String GetName();
    
    /// <summary>
    /// Gets the description of the tag
    /// </summary>
    /// <returns>String The description of the tag</returns>
    String GetDescription();
    
    /// <summary>
    /// Gets the example text for this tag
    /// <p />
    /// Note that example text containing HTML formatting must
    /// be in xml CDATA format
    /// </summary>
    /// <returns>String The example for this tag</returns>
    String GetExample();
  }
}