using System;
namespace com.plumtree.portaluiinfrastructure.tags.metadata
{
  /// <summary>
  /// This class provides programmatic access to the
  /// tag meta data for related child tags.
  /// <p />
  /// Tag classes need to have one public static final
  /// RelatedChildTag member variable for every related
  /// RelatedChildTag that should be in the documentation
  /// for this tag.  The related child tag must be in the
  /// same library as this tag.
  /// <p />
  /// Specifying related tags is simply a convenience
  /// to tell users of the main tag that it is designed
  /// to work with the child tag.  Any tag can be used
  /// inside any other tag, regardless of whether or not
  /// it is specified as a related child tag.
  /// </summary>
  public class RelatedChildTag : ARelatedTag
  {
    
    /// <summary>
    /// Creates a new related child tag meta data object.
    /// <p />
    /// Tag classes need to have one public static final
    /// RelatedChildTag member variable for every related
    /// RelatedChildTag that should be in the documentation for
    /// this tag.
    /// <p />
    /// Specifying related tags is simply a convenience
    /// to tell users of the main tag that it is designed
    /// to work with the child tag.  Any tag can be used
    /// inside any other tag, regardless of whether or not
    /// it is specified as a related child tag.
    /// </summary>
    /// <param name="_TagData">The related child tag data</param>
    public RelatedChildTag(ITagMetaData _TagData) : base(_TagData)
    {
    }
  }
}