using System;
namespace com.plumtree.portaluiinfrastructure.tags.metadata
{
  /// <summary>
  /// This class provides programmatic access to the
  /// tag meta data for required child tags.
  /// <p />
  /// Tag classes need to have one public static final
  /// RequiredChildTag member variable for every child
  /// tag that this tag requires.  The required child
  /// tag must be in the same library as this tag.
  /// <p />
  /// If this child tag is required to be present every
  /// time the main tag is used, and the child tag is
  /// not present, an error will be logged and the tag
  /// and its children will be skipped and not
  /// displayed.  An HTML Comment describing the tag and
  /// error will be displayed instead.
  /// <p />
  /// E.G. If parenttag requires childtag to be present,
  /// then
  /// <br />
  /// &lt;pt:parenttag&gt;&lt;pt:childtag/&gt;&lt;/pt:parenttag&gt;
  /// <br />
  /// will work, but
  /// <br />
  /// &lt;pt:parenttag&gt;text&lt;/pt:parenttag&gt;
  /// <br />
  /// will not work, because childtag is required to be
  /// inside of parenttag.
  /// </summary>
  public class RequiredChildTag : ARelatedTag
  {
    
    /// <summary>
    /// Creates a new required child tag meta data object.
    /// <p />
    /// Tag classes need to have one public static final
    /// RequiredChildTag member variable for every child
    /// tag that this tag requires.
    /// <p />
    /// If this child tag is required to be present every
    /// time the main tag is used, and the child tag is
    /// not present, an error will be logged and the tag
    /// and its children will be skipped and not
    /// displayed.  An HTML Comment describing the tag and
    /// error will be displayed instead.
    /// <p />
    /// E.G. If parenttag requires childtag to be present,
    /// then
    /// <br />
    /// &lt;pt:parenttag&gt;&lt;pt:childtag/&gt;&lt;/pt:parenttag&gt;
    /// <br />
    /// will work, but
    /// <br />
    /// &lt;pt:parenttag&gt;text&lt;/pt:parenttag&gt;
    /// <br />
    /// will not work, because childtag is required to be
    /// inside of parenttag.
    /// </summary>
    /// <param name="_TagData">The related child tag data</param>
    public RequiredChildTag(ITagMetaData _TagData) : base(_TagData)
    {
    }
  }
}