using System;
namespace com.plumtree.portaluiinfrastructure.tags.metadata
{
  /// <summary>
  /// This class provides programmatic access to the
  /// tag meta data for required parent tags.
  /// <p />
  /// If a tag class requires a specific parent tag
  /// in order to function, the class needs to have
  /// at least one public static final RequiredParentTag
  /// member variable that specifies the required parent
  /// tag.  The required parent tag must be in the same
  /// library as this tag.
  /// <p />
  /// If this tag is used outside of the required
  /// parent tag, an error will be logged and the tag
  /// and its children will be skipped and not
  /// displayed.  An HTML Comment describing the tag and
  /// error will be displayed instead.
  /// <p />
  /// If multiple required parent tags are specified, then
  /// at least one required parent tag must be present
  /// for the tag to function (but not all parent tags are
  /// required to be present).
  /// <p />
  /// E.G. If thistag requires parenttag to be present,
  /// then
  /// <br />
  /// &lt;pt:parenttag&gt;&lt;pt:thistag/&gt;&lt;/pt:parenttag&gt;
  /// <br />
  /// will work, but
  /// <br />
  /// &lt;pt:thistag/&gt;
  /// <br />
  /// will not work, because thistag is required to be
  /// inside of parenttag.
  /// </summary>
  public class RequiredParentTag : ARelatedTag
  {
    
    /// <summary>
    /// Creates a new required parent tag meta data object.
    /// <p />
    /// If a tag class requires a specific parent tag
    /// in order to function, the class needs to have
    /// at least one public static final RequiredParentTag
    /// member variable that specifies the required parent
    /// tag.
    /// <p />
    /// If this tag is used outside of the required
    /// parent tag, an error will be logged and the tag
    /// and its children will be skipped and not
    /// displayed.  An HTML Comment describing the tag and
    /// error will be displayed instead.
    /// <p />
    /// If multiple required parent tags are specified, then
    /// at least one required parent tag must be present
    /// for the tag to function.
    /// <p />
    /// I.E. If thistag requires parenttag to be present,
    /// then
    /// <br />
    /// &lt;pt:parenttag&gt;&lt;pt:thistag/&gt;&lt;/pt:parenttag&gt;
    /// <br />
    /// will work, but
    /// <br />
    /// &lt;pt:thistag/&gt;
    /// <br />
    /// will not work, because thistag is required to be
    /// inside of parenttag.
    /// </summary>
    /// <param name="_TagData">The related child tag data</param>
    public RequiredParentTag(ITagMetaData _TagData) : base(_TagData)
    {
    }
  }
}