using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
namespace com.plumtree.portaluiinfrastructure.tags.metadata
{
  /// <summary>
  /// This class also enforces all lower case for the names of tags.
  /// </summary>
  /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData"></seealso>
  public class TagMetaData : ITagMetaData
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData");
    protected String m_strName;
    protected String m_strDescription;
    protected String m_strExample;
    
    /// <summary>
    /// This constructor takes the name and description
    /// of the tag.  It also converts the name to all
    /// lower case for standards compliance. 
    /// </summary>
    /// <param name="String">_strName The name of the tag</param>
    /// <param name="String">_strDescription The description of the tag</param>
    public TagMetaData(String _strName, String _strDescription)
    {
      m_strName = XPStringUtility.ToLowerCase(_strName);
      m_strDescription = _strDescription;
      m_strExample = null;
      if (!m_strName.Equals(_strName))
      {
        log.Warn("Tag " + _strName + " uses uppercase letters " + "in its name, which are automatically converted to " + "lowercase.  This can cause confusion when using the " + "tag in HTML.");
        }
    }
    
    /// <summary>
    /// This constructor takes the name, description, and
    /// example text for this tag.  It also converts the name to
    /// all lower case for standards compliance. 
    /// <p />
    /// Note that example text containing HTML must enclose it in
    /// an xml CDATA tag:
    /// <br />
    /// "example blah &lt;![CDATA[&lt;mylib:mytag attr1=\"foo\"&gt;]]&gt; example"
    /// </summary>
    /// <param name="String">_strName The name of the tag</param>
    /// <param name="String">_strDescription The description of the tag</param>
    /// <param name="String">
    /// _strExample The example text for the tag.
    /// Note that example text containing HTML formatting must
    /// be in xml CDATA format
    /// </param>
    public TagMetaData(String _strName, String _strDescription, String _strExample)
    {
      m_strName = XPStringUtility.ToLowerCase(_strName);
      m_strDescription = _strDescription;
      m_strExample = _strExample;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetName()"></seealso>
    public virtual String GetName()
    {
      return m_strName;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetDescription()"></seealso>
    public virtual String GetDescription()
    {
      return m_strDescription;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetExample()"></seealso>
    public virtual String GetExample()
    {
      return m_strExample;
    }
  }
}