using System;
using com.plumtree.portaluiinfrastructure.tags.metadata;
namespace com.plumtree.portaluiinfrastructure.tags.metadata.legacy
{
  /// <summary>
  /// This class does not convert the name to all
  /// lower case for standards compliance, and is therefore
  /// suitable only for legacy Plumtree Transformer Tags.
  /// </summary>
  /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData"></seealso>
  public class LegacyTagMetaData : ITagMetaData
  {
    protected String m_strName;
    protected String m_strDescription;
    protected String m_strExample;
    
    /// <summary>
    /// This constructor takes the name and description
    /// of the tag.  It does not convert the name to all
    /// lower case for standards compliance, and is therefore
    /// suitable only for legacy Plumtree Transformer Tags. 
    /// </summary>
    /// <param name="String">_strName The name of the tag</param>
    /// <param name="String">_strDescription The description of the tag</param>
    public LegacyTagMetaData(String _strName, String _strDescription)
    {
      m_strName = _strName;
      m_strDescription = _strDescription;
      m_strExample = null;
    }
    
    /// <summary>
    /// This constructor takes the name, description, and
    /// example text of the tag.  It does not convert the name
    /// to all lower case for standards compliance, and is therefore
    /// suitable only for legacy Plumtree Transformer Tags. 
    /// </summary>
    /// <param name="String">_strName The name of the tag</param>
    /// <param name="String">_strDescription The description of the tag</param>
    /// <param name="String">
    /// _strExample The example text for the tag.
    /// Note that example text containing HTML formatting must
    /// be in xml CDATA format
    /// </param>
    public LegacyTagMetaData(String _strName, String _strDescription, String _strExample)
    {
      m_strName = _strName;
      m_strDescription = _strDescription;
      m_strExample = _strExample;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetName()"></seealso>
    public virtual String GetName()
    {
      return m_strName;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetDescription()"></seealso>
    public virtual String GetDescription()
    {
      return m_strDescription;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetExample()"></seealso>
    public virtual String GetExample()
    {
      return m_strExample;
    }
  }
}