using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.tags.tagdef
{
  /// <author>rozhang</author>
  public class TagOutputDefinitionManager
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.portaluiinfrastructure.tags.tagdef.TagOutputDefinitionManager");
    public const int TAGDEFINITION_WEBSERVICEID = 120;
    public const String TAGKEY_PREFIX = "$TAGDEF";
    public const String TAGDEF_MAP_KEY = "TagDefinitionStorage";
    private Object TAGDEF_MAP_CREATELOCK = new Object();
    
    /// <summary>
    /// Singleton
    /// </summary>
    protected static TagOutputDefinitionManager m_testInstance = null;
    
    /// <summary>
    /// Test Singleton
    /// </summary>
    protected static TagOutputDefinitionManager m_instance = new TagOutputDefinitionManager();
    
    /// <summary>
    /// Used by Unit test
    /// </summary>
    public static void SetTestInstance(TagOutputDefinitionManager testInstance)
    {
      m_testInstance = testInstance;
    }
    public static TagOutputDefinitionManager GetInstance()
    {
      if (m_testInstance == null)
      {
        return m_instance;
      } else
      {
        return m_testInstance;
      }
    }
    
    /// <param name="tagLibName"></param>
    /// <param name="tagName"></param>
    /// <param name="version"></param>
    /// <returns></returns>
    protected virtual String CreateTagDefKey(String defId, String version)
    {
      return TAGKEY_PREFIX + "-" + defId + "-" + version;
    }
    
    /// <param name="tagLibName"></param>
    /// <param name="tagName"></param>
    /// <param name="version"></param>
    /// <param name="def"></param>
    /// <param name="state"></param>
    /// <returns>false if an entry with the defid and version already exists and is read only, true if succesful</returns>
    public virtual bool StoreTagOutputDefinition(String defId, String version,
     bool readOnly, TagHelper tag)
    {
      XPHashtable map = GetTagDefMap(tag);
      String defKey = CreateTagDefKey(defId, version);
      TagOutputDefEntry oldEntry = (TagOutputDefEntry) map.GetElement(defKey);
      if (oldEntry != null && oldEntry.IsReadOnly())
      {
        return false;
      } else
      {
        XPArrayList bodyElements = tag.GetTagBodyElements();
        // @TODO find out the current webservice id/portlet file for where the template tag is run.
        // passing in empty values for now
        TagOutputDefEntry entry = new TagOutputDefEntry(bodyElements, readOnly,
         0, "");
        map.PutElement(defKey, entry);
        return true;
      }
    }
    
    /// <summary>
    /// Helper to get specified Tag definition
    /// </summary>
    /// <param name="defId"></param>
    /// <param name="version"></param>
    /// <param name="tag"></param>
    /// <returns></returns>
    protected virtual TagOutputDefEntry RetrieveTagDefinition(String defId,
     String version, TagHelper tag)
    {
      XPHashtable map = GetTagDefMap(tag);
      TagOutputDefEntry tagDef = (TagOutputDefEntry) map.GetElement(CreateTagDefKey(defId,
       version));
      return tagDef;
    }
    
    /// <summary>
    /// Retrieves Tag Definition and inserts it into current Tag body
    /// </summary>
    /// <param name="tagLibName"></param>
    /// <param name="tagName"></param>
    /// <param name="version"></param>
    /// <param name="state"></param>
    /// <returns></returns>
    public virtual HTMLElement RetrieveAndSetTagDefinition(String defId, String version,
     TagHelper tag)
    {
      XPHashtable map = GetTagDefMap(tag);
      TagOutputDefEntry tagDef = (TagOutputDefEntry) map.GetElement(CreateTagDefKey(defId,
       version));
      // if tag def entry wasn't found, reload tag definition files
      if (tagDef == null)
      {
        /* The commented out section is code to handle multiple tag definition files and cache the definitions on the application
         AActivitySpace space = (AActivitySpace)m_tagHelper.GetEnvironment();
         // @TODO cache tag def webservice ids on application for 15min or so
         int[] wsIds = RetrieveTagOutputDefWebServiceIds(space);
         log.Info("Reloading Tag Definition files.");
         ProcessTagDefinitions(wsIds, space, false);
         
         // now try find the entry again
         tagDef = (TagOutputDefEntry)map.GetElement(CreateTagDefKey(defId, version));
         if ( tagDef == null ) {
         // still not found after reloading tag defs, must be referencing an invalid tag definition, return null
         return null;
         }
         */
         
        /* Current approach: just allow on tag definition file with hardcoded webservice object id and cache the def on the request only (to avoid multiple tag def requests per page request) */
        // use int array, processtagdefinitions was original made to support requests to multiple webservice objects
        int[] wsIds = new int[]{TAGDEFINITION_WEBSERVICEID};
        AActivitySpace space = (AActivitySpace) tag.GetEnvironment();
        // Get the tag definition from tag definition file
        ProcessTagDefinitions(wsIds, space, false);
        tagDef = RetrieveTagDefinition(defId, version, tag);
        if (tagDef == null)
        {
          // to tag def exists for the requested id, version
          log.Warn("No Tag Definition exists for id: \'" + defId + "\' and version:" + version);
          return null;
        }
      }
      tag.InjectTagBody(tagDef.GetEntryValue());
      return tag.ProcessTagBody();
    }
    
    /// <summary>
    /// Gets the Tag Definition Map
    /// </summary>
    /// <param name="tag"></param>
    /// <returns></returns>
    protected virtual XPHashtable GetTagDefMap(TagHelper tag)
    {
      TagState state = tag.GetState();
      XPHashtable tdMap;
      Object value = state.GetSharedVariable(TAGDEF_MAP_KEY, Scope.HTTP_REQUEST);
      if (value == null)
      {
        tdMap = new XPHashtable();
        lock (TAGDEF_MAP_CREATELOCK) {
          // check again in case some other thread inserted between last check and here
          if (state.GetSharedVariable(TAGDEF_MAP_KEY, Scope.HTTP_REQUEST) == null)
          {
            state.SetSharedVariable(TAGDEF_MAP_KEY, tdMap, Scope.HTTP_REQUEST,
             true);
          }
        }
      } else
      {
        tdMap = (XPHashtable) value;
      }
      return tdMap;
    }
    
    /// <summary>
    /// Calls the Portlet Stack to retrieve markup from Tag Definition file and run Tag Definitions tags that sets
    /// the tag definitions in the request
    /// </summary>
    /// <TODO>might want to return some status code?</TODO>
    /// <param name="wsIds"></param>
    /// <param name="space"></param>
    /// <param name="testMode"></param>
    protected virtual void ProcessTagDefinitions(int[] wsIds, AActivitySpace space,
     bool testMode)
    {
      IPTSession ptSession = (IPTSession) space.GetUserSession();
      IPTWebServiceManager ptWebServiceManager = (IPTWebServiceManager) ptSession.GetWebServices();
      // DCA - getting app data state object to let the webservice know the state of the application
      // This is mostly for portlet settings, like what community the portlet is on, which doesn't really apply here since we're not 
      // really a portlet, but we're trying to reuse code instead of reinventing the wheel.
      /* Page Id */
      Object appDataStateObject = AppDataObjectFactory.GetInstance().GetAppDataObject(0,
       0, PTConfigHelper.GetMainServerApplicationURL(false), space);
      // We have to use the same states object for both calls.  If we get it again
      // from the session, it will be different and this won't work (for request mode,
      // which we use).
      IPTStates pStates = ptSession.GetStates();
      // 
      XPArrayList wsProvs = new XPArrayList();
      XPArrayList wsInfo = new XPArrayList();
      // Call BeginProcessing on all webservices 
      for (int i = 0;i < wsIds.Length;i++)
      {
        int currWsId = wsIds[i];
        try
        {
          IPTGadgetInfo ptWebServiceInfo = ptWebServiceManager.GetWebServiceInfo(currWsId);
          IPTAsyncGadgetProvider wsProvider = ptWebServiceManager.GetWebServiceProvider(currWsId,
           null);
          if (null == wsProvider)
          {
            throw new XPIllegalArgumentException("Unable to find Webservice with id: " + currWsId + ".");
            }
          // NOTE: We have to use state mode request because otherwise concurrent requests can
          // stomp on each other. Bug#65482
          // Just use the method that doesn't have the state mode, because that defaults to request mode.
          /* IPTUserInterface - not needed */
          wsProvider.BeginProcessing(PT_GADGET_MODES.PT_GADGETMODES_RUNTIME,
           ptSession, ptWebServiceInfo, pStates, null, appDataStateObject,
           null);
          wsProvs.Add(wsProvider);
          wsInfo.Add(ptWebServiceInfo);
        }
        catch (Exception e)
        {
          throw new XPIllegalStateException("Error receiving Tag Definition from Webservice with id: " + currWsId,
           e);
        }
      }
      // Get the markup content and process it from all webservices 
      for (int i = 0;i < wsProvs.GetSize();i++)
      {
        IPTAsyncGadgetProvider currProv = (IPTAsyncGadgetProvider) wsProvs.GetElement(i);
        IPTGadgetInfo currWSInfo = (IPTGadgetInfo) wsInfo.GetElement(i);
        /* IPTUserInterface */
        Object[][] tagDefMarkup = currProv.GetHTMLText(PT_GADGET_MODES.PT_GADGETMODES_RUNTIME,
         ptSession, currWSInfo, pStates, null, appDataStateObject, null);
        PortletErrorHelper errorHelper = new PortletErrorHelper();
        if (errorHelper.IsErrorContentArray(tagDefMarkup) && !testMode)
        {
          int nErrorCode = errorHelper.GetErrorCode(tagDefMarkup);
          String strError = errorHelper.GetErrorMessage(tagDefMarkup);
          throw new XPIllegalStateException("Tag Definition file with Webservice id: " + currWSInfo.GetObjectID() + " returned error code: " + nErrorCode + " and error message: " + strError);
          }
        try
        {
          // @TODO pass in current wsid to the activity space somehow?
          // Process tags that declare tag defs
          HTMLElement result = DisplayTree.ProcessTagMarkup(space, tagDefMarkup);
          if (result != null)
          {
            String resultStr = result.GetDisplayString();
            // log a warning and display the reeturn content if it contains the word Exception
            if (XPStringUtility.IndexOf(resultStr, "Exception") != -1)
            {
              // @TODO do all dot net exception have the word exception in it??
              log.Warn("Tag Definition file from Webservice id: " + currWSInfo.GetObjectID() + " returned unexpected content: " + resultStr);
              }
          }
        }
        catch (Exception e)
        {
          // ignore the exception and go on to next webservice
          log.Error("Error processesing Tag Definition markup from Webservice id: " + currWSInfo.GetObjectID(),
           e);
        }
      }
    }
  }
}