using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
namespace com.plumtree.portaluiinfrastructure.tags.tasks
{
  /// <summary>
  /// This is a helper class for TagState Tasks.
  /// <p />
  /// When debug mode is on, tags will display HTML comments before
  /// and after they are executed to aid in debugging.  Tags may
  /// also have custom behavior in debug mode.
  /// </summary>
  public class TagStateTasks
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tags.tasks.TagStateTasks");
    
    /// <summary>
    /// The key that the debug mode boolean is stored with
    /// in PORTLET_REQUEST scope.
    /// </summary>
    protected const String DEBUG_MODE_KEY = "bDebug";
    
    /// <summary>
    /// Check if the current tag is in debug mode.
    /// <p />
    /// When debug mode is on, tags will display HTML comments before
    /// and after they are executed to aid in debugging.  Tags may
    /// also have custom behavior in debug mode.
    /// </summary>
    /// <param name="ITagState">_state The current TagState object</param>
    /// <returns>boolean True implies debug mode</returns>
    public static bool GetIsDebugMode(ITagState _state)
    {
      try
      {
        Object oDebug = _state.GetSharedVariable(DEBUG_MODE_KEY, Scope.PORTLET_REQUEST);
        if (null != oDebug)
        {
          return XPConvert.ToBoolean(oDebug);
        }
      }
      catch (Exception e)
      {
        log.Warn(e, "Unable to properly get debug mode variable from portlet request scope.");
        }
      return false;
    }
    
    /// <summary>
    /// Set debug mode for the current PORTLET_REQUEST.
    /// <p />
    /// When debug mode is on, tags will display HTML comments before
    /// and after they are executed to aid in debugging.  Tags may
    /// also have custom behavior in debug mode.
    /// </summary>
    /// <param name="boolean">_bDebug True implies debug mode</param>
    /// <param name="ITagState">_state The current TagState object</param>
    public static void SetIsDebugMode(bool _bDebug, ITagState _state)
    {
      _state.SetSharedVariable(DEBUG_MODE_KEY, _bDebug, Scope.PORTLET_REQUEST,
       false);
    }
  }
}