using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.tags.xml
{
  /// <summary>
  /// This helper class converts IMarkupFragment lists to (evil) Object[][] markup arrays.
  /// </summary>
  public class FragmentListConverter
  {
    
    /// <summary>
    /// Converts an XPArrayList of IMarkupFragments to an (evil) Object[][] markup array.
    /// </summary>
    /// <param name="_fragments">an XPArrayList of IMarkupFragments</param>
    /// <returns>an (evil) Object[][] markup array</returns>
    public virtual Object[][] ConvertListToMarkup(XPArrayList _fragments)
    {
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[_fragments.GetSize()];
      }
      for (int i = 0;i < _fragments.GetSize();i++)
      {
        IMarkupFragment fragment = (IMarkupFragment) _fragments.GetElement(i);
        objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = fragment.GetFragmentType();
        // TODO: This probably means that I need to rework how this works
        // so I can make it smoother.  Plus, we probably just shouldn't be
        // converting a lot, since this needs to be performant.
        if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML)
        {
          objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = fragment.GetXMLFragment().GetObjectXML();
          } else
        {
          objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = fragment.GetFragment();
          }
      }
      return objArrMarkup;
    }
    
    /// <summary>
    /// Converts an (evil) Object[][] markup array to an XPArrayList of IMarkupFragments.
    /// </summary>
    /// <param name="_objArrMarkup">an (evil) Object[][] markup array</param>
    /// <returns>an XPArrayList of IMarkupFragments</returns>
    public virtual XPArrayList ConvertMarkupToList(Object[][] _objArrMarkup)
    {
      XPArrayList fragments = new XPArrayList();
      for (int i = 0;i < _objArrMarkup[0].Length;i++)
      {
        switch (XPConvert.ToInteger(_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i])){
        case PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED:
        fragments.Add(new TransformerMarkupFragment((String) _objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i]));
        break;
        case PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML:
        IXMLFragment xmlFragment = new XMLFragment((Object[][]) _objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i]);
        fragments.Add(new TransformerMarkupFragment(xmlFragment));
        break;
        default:
        fragments.Add(new TransformerMarkupFragment(XPConvert.ToInteger(_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i])));
        break;
        }
      }
      return fragments;
    }
  }
}