using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portaluiinfrastructure.tags.xml
{
  /// <summary>
  /// This interface is used to access data in a markup fragment.
  /// IMPORTANT: DO NOT ADD ANY SETTERS to the IMarkupFragment interface!
  /// i.e. do NOT add a method like SetFragmentValue(...)
  /// A shallow copy of markup array is put into the portlet content cache.
  /// This means that if an actual object (i.e. MarkupFragment) that's inside the array changes in PostProcess,
  /// then what's inside the cache changes as well! 
  /// So instead of having setters on a MarkupFragment, in PostProcess we create new MarkupFragments and place 
  /// them into the array that will be returned to the UI.
  /// This assures that the cached markup array will not be affected by PostProcess.
  /// </summary>
  public interface IMarkupFragment
  {
    
    /// <returns>int The fragment type (should be from PT_MARKUP_FRAGMENT_TYPES).</returns>
    int GetFragmentType();
    
    /// <summary>
    /// Get the string fragment.  This can only be called for Fragments of type
    /// PTMarkupFragmentTypes.PT_MARKUP_FRAGMENT_TYPE_FINISHED.
    /// </summary>
    /// <returns>the String.</returns>
    /// <throws>XPFormatException if the fragment is of the wrong type.</throws>
    String GetStringFragment();
    
    /// <summary>
    /// Get the xml fragment.  This can only be called for Fragments of type
    /// PTMarkupFragmentTypes.PT_MARKUP_FRAGMENT_TYPE_PT_XML.
    /// </summary>
    /// <returns>the XML Fragment.</returns>
    /// <throws>XPFormatException if the fragment is of the wrong type. </throws>
    IXMLFragment GetXMLFragment();
    
    /// <summary>
    /// Get the fragment.  This can be called for any type of Fragment.
    /// </summary>
    /// <returns>The underlying fragment object.</returns>
    Object GetFragment();
  }
}