using System;
namespace com.plumtree.portaluiinfrastructure.tags.xml
{
  /// <summary>
  /// This interface is used to access data in an xml markup fragment.
  /// IMPORTANT: DO NOT ADD ANY SETTERS to the IMarkupFragment interface!
  /// i.e. do NOT add a method like SetFragmentValue(...)
  /// A shallow copy of markup array is put into the portlet content cache.
  /// This means that if an actual object (i.e. MarkupFragment) that's inside the array changes in PostProcess,
  /// then what's inside the cache changes as well! 
  /// So instead of having setters on a MarkupFragment, in PostProcess we create new MarkupFragments and place 
  /// them into the array that will be returned to the UI.
  /// This assures that the cached markup array will not be affected by PostProcess.
  /// </summary>
  public interface IXMLFragment
  {
    
    /// <returns>int The XML type (should be from PT_XML_TYPES).</returns>
    int GetType(int _nRowIndex);
    
    /// <returns>The name of the tag or attribute.</returns>
    String GetName(int _nRowIndex);
    
    /// <returns>The value of an attribute.</returns>
    String GetValue(int _nRowIndex);
    
    /// <returns>The number of rows in the XML fragment.</returns>
    int GetNumberOfRows();
    
    /// <returns>The underlying object XML.</returns>
    Object[][] GetObjectXML();
  }
}