using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.tags.xml
{
  /// <summary>
  /// Implementation of IMarkupFragment.
  /// </summary>
  public class TransformerMarkupFragment : IMarkupFragment
  {
    private Object m_objFragment;
    // NOTE: This should be a 1.5 enum, but it's just an int now.
    private int m_eType;
    
    /// <summary>
    /// Construct a marker fragment with no body.
    /// </summary>
    /// <param name="_type">The type of the marker fragment.</param>
    public TransformerMarkupFragment(int _type)
    {
      m_eType = _type;
    }
    
    /// <summary>
    /// Construct a finished fragment.
    /// </summary>
    /// <param name="sMarkup">the markup</param>
    public TransformerMarkupFragment(String sMarkup)
    {
      m_objFragment = sMarkup;
      m_eType = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      }
    
    /// <summary>
    /// A parsed PT XML tag for later post-processing.
    /// </summary>
    /// <param name="tag"></param>
    public TransformerMarkupFragment(IXMLFragment tag)
    {
      m_objFragment = tag;
      m_eType = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
    }
    
    /// <seealso cref="com.plumtree.transformer.xml.IMarkupFragment#GetFragmentType()"></seealso>
    public virtual int GetFragmentType()
    {
      return m_eType;
    }
    
    /// <seealso cref="com.plumtree.transformer.xml.IMarkupFragment#GetStringFragment()"></seealso>
    public virtual String GetStringFragment()
    {
      if (PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED != m_eType)
      {
        throw new XPFormatException("Fragments of type " + m_eType + " cannot be converted to Strings. " + "Only finished fragments can be converted to strings.");
        }
      return (String) m_objFragment;
    }
    
    /// <seealso cref="com.plumtree.transformer.xml.IMarkupFragment#GetXMLFragment()"></seealso>
    public virtual IXMLFragment GetXMLFragment()
    {
      if (PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML != m_eType)
      {
        throw new XPFormatException("Fragments of type " + m_eType + " cannot be converted to xml fragments. " + "Only PT XML fragments can be converted to XML Fragment objects.");
        }
      return (IXMLFragment) m_objFragment;
    }
    
    /// <seealso cref="com.plumtree.transformer.xml.IMarkupFragment#GetFragment()"></seealso>
    public virtual Object GetFragment()
    {
      return m_objFragment;
    }
  }
}