using System;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <author>Don Hayler</author>
  public interface IObjectTreeModelRO : ITreeModelRO
  {
    
    /// <summary>
    /// This method returns the current access level.
    /// </summary>
    /// <returns>int access level</returns>
    int GetAccessLevel();
    
    /// <summary>
    /// This method returns the class IDs to be displayed in this tree.
    /// </summary>
    /// <returns>int[] the class IDs to display</returns>
    int[] GetDisplayedClassIDs();
    
    /// <summary>
    /// This method returns whether the tree is displaying search results, or
    /// just the normal tree.
    /// </summary>
    /// <returns>boolean true implies search results, false implies tree</returns>
    bool GetDisplayingSearchResults();
    
    /// <summary>
    /// This method returns the class ID of the folders in the tree.
    /// I.E.  admin folders or card catalogs.
    /// </summary>
    /// <returns>int class ID of folders in the tree.</returns>
    int GetFolderClassID();
    
    /// <summary>
    /// This method returns the values used in the gadget alignment query filter.
    /// </summary>
    int[] GetPortletAlignment();
    
    /// <summary>
    /// This method returns the values used in the gadget web service ID query filter.
    /// </summary>
    int[] GetPortletWebServiceID();
    
    /// <summary>
    /// This method returns the values used in the gadget type query filter.
    /// </summary>
    int[] GetPortletType();
    
    /// <summary>
    /// This method returns the user type values used in the user query filter.
    /// </summary>
    int[] GetUserTypeFilter();
    
    /// <summary>
    /// This method returns the CLSID values used in the web service/data
    /// source query filter.
    /// </summary>
    String[] GetFilterCLSID();
    
    /// <summary>
    /// This method returns the propid for the CLSID values used in the
    /// web service/data source query filter.
    /// </summary>
    int GetFilterCLSIDPropID();
    
    /// <summary>
    /// This method returns the class ID to be filtered.
    /// </summary>
    /// <returns>the class ID to apply the above filter to</returns>
    int GetFilterClassID();
    
    /// <summary>
    /// This method returns whether or not the given item should be displayed.
    /// </summary>
    /// <param name="int">nClassID</param>
    /// <param name="int">nObjectID</param>
    /// <returns>boolean true implies display the item</returns>
    bool GetItemDisplayed(int nClassID, int nObjectID);
    
    /// <summary>
    /// This method returns whether or not the given item should be selected.
    /// </summary>
    /// <param name="int">nClassID</param>
    /// <param name="int">nObjectID</param>
    /// <returns>boolean true implies the item is selected</returns>
    bool GetItemSelected(int nClassID, int nObjectID);
    
    /// <summary>
    /// This method returns whether or not a search has been started.
    /// This is used to tell whether or not there should be a tabbed link
    /// to the search view (no if it hasn't been started yet).
    /// </summary>
    /// <returns>boolean true implies should add link (search started).</returns>
    bool GetSearchStarted();
    
    /// <summary>
    /// This method returns whether or not search is enabled.
    /// Search will always be enabled except when displaying a pre-selected list.
    /// </summary>
    /// <returns>boolean true implies the search box should be displayed.</returns>
    bool GetSearchEnabled();
  }
}