using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <author>Don Hayler</author>
  public class ServerStartTreeControl : AStartTreeControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tree.ServerStartTreeControl");
    public const String STR_MVC_CLASS_NAME = "ServerStartTree";
    
    /// <summary>
    /// pass in the integer ID for the interface type you wish to display
    /// see ServerTreeModel for details.
    /// </summary>
    public const String INTERFACE_TYPE = "InterfaceType";
    
    /// <summary>
    /// generic initialization data for the Interface. 
    /// </summary>
    public const String INIT_DATA = "InitData";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // locations to hide
      String[] sValue = (String[]) arguments.GetElement(HIDDEN_ITEMS);
      if (sValue != null)
      {
        ((IServerTreeModel) m_asModel).SetLocationsToHide(sValue[0]);
      }
      Redirect result = base.CheckActionSecurityAndExecute(arguments);
      int nInterfaceType;
      sValue = (String[]) arguments.GetElement(INTERFACE_TYPE);
      if ((sValue != null) && (sValue[0] != null))
      {
        nInterfaceType = XPConvert.ToInteger(sValue[0]);
      } else
      {
        log.Error("Unable to find interface type in query string.");
        return result;
      }
      sValue = (String[]) arguments.GetElement(INIT_DATA);
      if ((sValue != null) && (sValue[0] != null))
      {
        ((ServerTreeModel) m_asModel).SetIterator(nInterfaceType, sValue[0]);
        } else
      {
        ((ServerTreeModel) m_asModel).SetIterator(nInterfaceType, null);
      }
      // locations to select
      sValue = (String[]) arguments.GetElement(SELECTED_ITEMS);
      if (sValue != null)
      {
        ((IServerTreeModel) m_asModel).SetLocationsToSelect(sValue[0]);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ServerStartTreeControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}