using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <summary>
  /// This control allows you to start either the Admin Tree or the Browsing Tree.
  /// </summary>
  /// <author>Don Hayler</author>
  public class StartTreeControl : AStartTreeControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tree.StartTreeControl");
    public const String STR_MVC_CLASS_NAME = "StartTree";
    
    /// <summary>
    /// pass in the object ID for the IPTAdminFolder you wish to display 
    /// </summary>
    public const String ROOT_ID = "RootID";
    
    /// <summary>
    /// pass in the ACCESS_LEVEL (ADMIN, EDIT, or READ -- default is SELECT) of
    /// objects to display.
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tree.IObjectTreeModel#SetAccessLevel(int)"></seealso>
    public const String ACCESS_LEVEL = "Access";
    
    /// <summary>
    /// add a query filter to a class ID.  This should be in the form of
    /// "nClassID,nPropID,nVal1,nVal2,nVal3,etc". This will set up an IN query
    /// filter for the nValx's.  There cannot be any 0s in this list.
    /// </summary>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tree.IObjectTreeModel#SetQueryFilter(int,int,int[])"></seealso>
    public const String QUERY_FILTER = "Filter";
    
    /// <summary>
    /// pass in the community mode (
    /// </summary>
    /// <seealso cref="IObjectTreeModelRO)"></seealso>
    public const String COMMUNITY_MODE = "CommunityMode";
    
    /// <summary>
    /// pass in the directory mode
    /// </summary>
    public const String DIRECTORY_MODE = "DirMode";
    
    /// <summary>
    /// pass in the community folder ID for THISCOMMUNITY mode (
    /// </summary>
    /// <seealso cref="IObjectTreeModelRO)"></seealso>
    public const String COMMUNITY_FOLDER_ID = "CommunityID";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // The model cannot be registered until run time because we don't know if
      // we want the object tree or the browsing tree (cards)
      if (m_asModel == null)
      {
        // Class ids to display
        String[] sClasses = (String[]) arguments.GetElement(CLASS_IDS_TO_DISPLAY);
        bool bObjectTree = true;
        if (sClasses != null)
        {
          int[] nClasses = GeneralHelpers.ConvertToInts(sClasses[0]);
          for (int i = 0;i < nClasses.Length;i++)
          {
            if ((nClasses[i] == PT_CLASSIDS.PT_CATALOGCARD_ID) || (nClasses[i] == PT_CLASSIDS.PT_CATALOGFOLDER_ID))
            {
              bObjectTree = false;
            }
          }
        }
        ((TreeAS) m_asOwner).RuntimeRegister(bObjectTree);
        if (m_asModel == null)
        {
          log.Error("Unable to register correct model");
          Redirect errorRedirect = new Redirect();
          errorRedirect.SetLinkGetCachedSpace(m_asOwner);
          errorRedirect.SetDisplayPage(ATreeAS.TREECLOSEPOPUP);
          return errorRedirect;
        }
      }
      Redirect result = base.CheckActionSecurityAndExecute(arguments);
      // Parse access level argument
      String[] sValues = (String[]) arguments.GetElement(ACCESS_LEVEL);
      if (sValues != null)
      {
        try
        {
          ((IObjectTreeModel) m_asModel).SetAccessLevel(XPConvert.ToInteger(sValues[0]));
          }
        catch (Exception e)
        {
          log.Error("Unable to parse access level: " + sValues[0]);
        }
      }
      // Parse query filter argument
      sValues = (String[]) arguments.GetElement(QUERY_FILTER);
      if (sValues != null)
      {
        XPStringTokenizer st = new XPStringTokenizer(sValues[0], ",");
        if (st.GetTokenCount() < 3)
        {
          log.Error("Query filter added with too few arguments: " + sValues[0]);
          } else
        {
          int nClassID = -1;
          // don't use 0 or -1 since they're valid propids
          int nPropID = -2;
          try
          {
            nClassID = XPConvert.ToInteger(st.GetNextToken());
            nPropID = XPConvert.ToInteger(st.GetNextToken());
          }
          catch (Exception e)
          {
            log.Warn("Bad data - expected numeric data separated by \',\'s, got : " + sValues[0]);
            }
          if ((-1 == nClassID) || (-2 == nPropID))
          {
            log.Error("Unable to get class and property ids: " + sValues[0]);
            } else
          {
            switch (nClassID){
            case PT_CLASSIDS.PT_USER_ID:
            case PT_CLASSIDS.PT_GADGET_ID:
            {
              // Get the Integer values for the filter
              int[] nFilterValues = new int[st.GetTokenCount()];
              int nIndex = 0;
              try
              {
                while (st.HasMoreTokens() && (nIndex < nFilterValues.Length))
                {
                  nFilterValues[nIndex] = XPConvert.ToInteger(st.GetNextToken());
                  nIndex++;
                }
              }
              catch (Exception e)
              {
                log.Warn("Bad data - expected numeric data separated by \',\'s, got : " + sValues[0]);
                }
              if (nIndex == nFilterValues.Length)
              {
                ((IObjectTreeModel) m_asModel).SetQueryFilter(nClassID, nPropID,
                 nFilterValues);
              }
              break;
            }
            case PT_CLASSIDS.PT_DATASOURCE_ID:
            case PT_CLASSIDS.PT_WEBSERVICE_ID:
            {
              // Get the String values for the filter
              String[] sFilterValues = new String[st.GetTokenCount()];
              int nIndex = 0;
              while (st.HasMoreTokens() && (nIndex < sFilterValues.Length))
              {
                sFilterValues[nIndex] = st.GetNextToken();
                nIndex++;
              }
              if (nIndex == sFilterValues.Length)
              {
                ((IObjectTreeModel) m_asModel).SetQueryFilter(nClassID, nPropID,
                 sFilterValues);
              }
              break;
            }
            default:
            log.Error("Expecting filter for portlet, data source, or webservice, but got " + nClassID);
            break;
            }
          }
        }
      }
      // Parse directory mode argument
      sValues = (String[]) arguments.GetElement(DIRECTORY_MODE);
      if (sValues != null)
      {
        int nDirMode = DirectoryTreeModel.EDIT_MODE;
        try
        {
          nDirMode = XPConvert.ToInteger(sValues[0]);
        }
        catch (Exception e)
        {
          log.Error("Unable to parse directory mode: " + sValues[0]);
        }
        // Check if mode is valid
        switch (nDirMode){
        case DirectoryTreeModel.BROWSE_MODE:
        case DirectoryTreeModel.EDIT_MODE:
        ((DirectoryTreeModel) m_asModel).SetDirectoryMode(nDirMode);
        break;
        default:
        log.Error("Invalid directory mode.  Ignored: " + nDirMode);
        break;
        }
      }
      // Parse community mode argument
      sValues = (String[]) arguments.GetElement(COMMUNITY_MODE);
      if (sValues != null)
      {
        int nMode = -1;
        try
        {
          nMode = XPConvert.ToInteger(sValues[0]);
        }
        catch (Exception e)
        {
          log.Error("Unable to parse community mode: " + sValues[0]);
        }
        int nID = -1;
        // Check if mode is valid
        switch (nMode){
        case AObjectTreeModel.NOCOMMUNITIES:
        case AObjectTreeModel.ALLCOMMUNITIES:
        break;
        case AObjectTreeModel.THISCOMMUNITY:
        // Get the community folder ID
        sValues = (String[]) arguments.GetElement(COMMUNITY_FOLDER_ID);
        if (sValues != null)
        {
          try
          {
            nID = XPConvert.ToInteger(sValues[0]);
          }
          catch (Exception e)
          {
            log.Error("Unable to parse community ID: " + sValues[0]);
          }
        } else
        {
          log.Error("Unable to find community ID in THISCOMMUNITY mode.");
          }
        break;
        default:
        nMode = -1;
        log.Error("Invalid community mode.  Ignored: " + nMode);
        break;
        }
        if (nMode != -1)
        {
          ((IObjectTreeModel) m_asModel).SetCommunityMode(nMode, nID);
        }
      }
      // Parse root folder ID argument
      sValues = (String[]) arguments.GetElement(ROOT_ID);
      if (sValues != null)
      {
        int nRootFolderID = -1;
        try
        {
          nRootFolderID = XPConvert.ToInteger(sValues[0]);
        }
        catch (Exception e)
        {
          log.Error("Unable to parse root folder ID: " + sValues[0]);
        }
        if (nRootFolderID == -1)
        {
          log.Error("Unable to get root folder ID: " + sValues[0]);
        } else
        {
          ((IObjectTreeModel) m_asModel).SetRootFolderID(nRootFolderID);
        }
      } else
      {
        log.Error("could not get root folder ID from query string.");
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new StartTreeControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}