using System;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <author>
  /// Don Hayler
  /// This Activity Space implements the Tree Control.
  /// </author>
  public class TreeAS : ATreeAS
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "Tree";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TreeAS();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      // This must be called first to get frames right
      base.Init();
      RegisterControl(StartTreeControl.STR_MVC_CLASS_NAME, null);
    }
    
    /// <param name="bObjectTree"></param>
    /// <returns></returns>
    public virtual IModel RuntimeRegister(bool bObjectTree)
    {
      // Tree objects
      if (bObjectTree)
      {
        RegisterModel(AdminTreeModel.STR_MVC_CLASS_NAME, TREEMODEL);
      } else
      {
        RegisterModel(DirectoryTreeModel.STR_MVC_CLASS_NAME, TREEMODEL);
      }
      IModel myModel = GetModel(TREEMODEL);
      // Set model on previously registered controls
      ((StartTreeControl) GetControl(StartTreeControl.STR_MVC_CLASS_NAME)).Init(myModel,
       this);
      RegisterAfterModel(myModel);
      return myModel;
    }
    protected virtual void RegisterAfterModel(IModel myModel)
    {
      RegisterView(TreeWithSearchBarView.STR_MVC_CLASS_NAME, TreeDP.TREE_BAR_STORAGE_NAME,
       myModel);
      RegisterView(TreeView.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(TreeSearchRepostControl.STR_MVC_CLASS_NAME, TreeRepostControl.STR_MVC_CLASS_NAME,
       myModel);
      RegisterControl(RefreshTreeControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(TreeSelectControl.STR_MVC_CLASS_NAME, myModel);
      // objects to handle both search and tree
      // Register this DP in place of the default tree frame DP.
      UnRegisterPage(TreeFrameDP.STR_MVC_CLASS_NAME);
      IDisplayPage myFrameSet = new TreeSearchFrameDP();
      RegisterPage(myFrameSet, TreeFrameDP.STR_MVC_CLASS_NAME);
      // This must be set explicitly so it is the default page
      SetCurrentPage(myFrameSet);
      // Register this DP in place of the default tree DP.
      UnRegisterPage(TreeDP.STR_MVC_CLASS_NAME);
      AFormDP myPage = (AFormDP) new TreeWithSearchDP();
      myPage.AddToValidationFunction(TreeView.JAVASCRIPT_SUBMIT_TO_PARENT);
      RegisterPage(myPage, TreeDP.STR_MVC_CLASS_NAME);
      // Register DP for selected items view in bottom frame
      RegisterPage(new TreeSelectDP());
      // These get registered with the tree model, not the search model.
      RegisterView(TreeSearchBoxView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(TreeSelectView.STR_MVC_CLASS_NAME, myModel);
      // Search objects
      // Call IntegratedSearchAS.RegisterSearchClasses to register search stuff.
      /*, TreeRepostControl.STR_MVC_CLASS_NAME */
      IntegratedSearchAS.RegisterSearchClasses(this);
      // Get our instance of SearchResultModel; the views that display
      // results will need it.
      IModel searchModel = GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
      // The search view needs both models
      RegisterView(TreeSearchView.STR_MVC_CLASS_NAME, searchModel);
      ((TreeSearchView) GetView(TreeSearchView.STR_MVC_CLASS_NAME)).InitTreeModel((IObjectTreeModelRO) myModel);
      }
  }
}