using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <summary>
  /// This repost control overrides the base tree repost control in order
  /// to switch back to browsing mode when the user closes the tree (if it
  /// is in search mode).
  /// </summary>
  /// <author>donh</author>
  public class TreeSearchRepostControl : TreeRepostControl
  {
    public const String STR_MVC_CLASS_NAME = "TreeSearchRepost";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      Redirect result = base.CheckActionSecurityAndExecute(arguments);
      if ((m_nAction == POSTTOSELF_ACTION_FINISH) || (m_nAction == POSTTOSELF_ACTION_CANCEL))
      {
        // If we are finishing out of the tree, reset it to browsing
        // mode.  This is so that if a user re-opens the tree, it is
        // in the default state rather than the search state, which
        // could be confusing.
        ((IObjectTreeModel) m_model).ResetToBrowsingMode();
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TreeSearchRepostControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}