using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <author>
  /// Don Hayler
  /// This view displays search results for the tree.
  /// </author>
  public class TreeSearchView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tree.TreeSearchView");
    
    /// <summary>
    /// name of this view 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "TreeSearchView";
    
    /// <summary>
    /// form input constants 
    /// </summary>
    public const String HTMLHIDDEN_SELECTEDIDS = "in_hi_SearchSelectedItems";
    
    /// <summary>
    /// internal data 
    /// </summary>
    protected AActivitySpace m_asOwner;
    protected IBaseSearchResultModelRO m_asSearchModel;
    protected IObjectTreeModelRO m_asTreeModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new TreeSearchView();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      try
      {
        HTMLElementCollection result = new HTMLElementCollection();
        SearchExecutionError error = m_asSearchModel.GetError();
        if (error != null)
        {
          result.AddInnerHTMLElement(new HTMLBr());
          HTMLSpan mySpan = new HTMLSpan();
          result.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
          mySpan.AddInnerHTMLString(error.GetMessage());
          result.AddInnerHTMLElement(error.GetComment());
          return result;
        }
        // Get number of displayable results from model
        int numResults = m_asSearchModel.GetNumDisplayableItems();
        // If no results
        if (0 == numResults)
        {
          result.AddInnerHTMLElement(new HTMLBr());
          // just say so 
          HTMLSpan mySpan = new HTMLSpan();
          result.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(413, "ptmsgs_portalinfrastructure"));
          return result;
        }
        SearchExecutionWarning warning = m_asSearchModel.GetWarning();
        if (warning != null)
        {
          result.AddInnerHTMLElement(new HTMLBr());
          HTMLSpan mySpan = new HTMLSpan();
          result.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
          mySpan.AddInnerHTMLString(warning.GetMessage());
          result.AddInnerHTMLElement(new HTMLBr());
        }
        ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
        // Store the previously selected items so we can check if the user
        // unchecked an item.
        XPStringBuilder sbSelectedItems = new XPStringBuilder(20);
        bool bMultiSelect = m_asTreeModel.GetMultipleSelect();
        int nClassID;
        int nObjectID;
        String strEncodedName;
        HTMLTableRow myRow;
        HTMLTableCell myCell;
        HTMLInput myInput;
        HTMLImg myImg;
        //JH-Add a table so things will line up properly
        // We can share the table across all children because all of
        // the columns are the same.
        // We only add this table to the result HTML if we display items
        HTMLTable innerTable = new HTMLTable();
        innerTable.SetBorder(CommonHTMLStrings.ZERO);
        // We need to keep track of the number of displayed items,
        // since we can have hidden items.
        int nDisplayedItems = 0;
        // Add radio buttons; each search result is one possibility
        for (int j = 0;j < numResults;j++)
        {
          nClassID = m_asSearchModel.GetResultClassID(j);
          nObjectID = m_asSearchModel.GetResultObjectID(j);
          if (m_asTreeModel.GetItemDisplayed(nClassID, nObjectID))
          {
            nDisplayedItems++;
            myRow = new HTMLTableRow();
            innerTable.AddInnerHTMLElement(myRow);
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            if (bMultiSelect)
            {
              // Check box
              myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, TreeView.HTMLBUTTON_CHECKBOX,
               TreeView.HTMLBUTTON_CHECKBOX);
            } else
            {
              // Radio button
              myInput = new HTMLInput(HTMLInputTypes.RADIO, TreeView.HTMLBUTTON_RADIO,
               TreeView.HTMLBUTTON_RADIO);
            }
            myCell.AddInnerHTMLElement(myInput);
            // return the index into the model
            myInput.SetValue(XPConvert.ToString(j));
            // This has already been parsed by the control for dangerous characters,
            // so we don't need to encode it.
            String strOnClick = m_asTreeModel.GetOnClickFunction();
            if (strOnClick != null)
            {
              myInput.SetOnClick("return " + strOnClick + "(this);");
            }
            strEncodedName = XPHttpUtility.HtmlEncode(m_asSearchModel.GetResultName(j));
            /*
             // This code is for when bug#20946 is fully coded in the search
             // server.
             if (nClassID == PT_CLASSIDS.PT_USER_ID)
             {
             strUserLoginName = m_asSearchModel.GetResultEODField(j, PT_PROPIDS.PT_PROPID_USER_LOGINNAME);
             if ((strUserLoginName != null) && (!"".equals(strUserLoginName)))
             {
             strEncodedName += "(" + XPHttpUtility.HtmlEncode(strUserLoginName) + ")";
             }
             }
             */
             
            //Add third cell in inner table
            myCell = new HTMLTableCell();
            myCell.SetWidth("20");
            myCell.SetAlign(CommonHTMLStrings.CENTER);
            myRow.AddInnerHTMLElement(myCell);
            // Add Object icon
            String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
             m_asOwner);
            myImg = ptClassTypeDescManager.GetDefaultIconForClassType(nClassID,
             strLangID);
            if (myImg != null)
            {
              myImg.SetAlt(strEncodedName);
            }
            myCell.AddInnerHTMLElement(myImg);
            //Add fourth cell in inner table
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            //Add the name of the leaf node
            HTMLSpan mySpan = new HTMLSpan();
            myCell.AddInnerHTMLElement(mySpan);
            mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
            mySpan.AddInnerHTMLString(strEncodedName);
            mySpan.SetTitle(strEncodedName);
            // Check if it's in the selected items list first
            if (m_asTreeModel.GetItemSelected(nClassID, nObjectID))
            {
              myInput.SetChecked(true);
              // Add this to the list of selected nodes
              if (sbSelectedItems.GetLength() != 0)
              {
                sbSelectedItems.Append(",");
              }
              sbSelectedItems.Append(j);
            }
          }
        }
        // If we didn't display any items (because they were all hidden)
        if (0 == nDisplayedItems)
        {
          result.AddInnerHTMLElement(new HTMLBr());
          // just say so 
          HTMLSpan mySpan = new HTMLSpan();
          result.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(413, "ptmsgs_portalinfrastructure"));
          return result;
        } else
        {
          result.AddInnerHTMLElement(innerTable);
          // Add pagination
          // TODO: Bug#44207 -- Fix this so it displays correctly if we have
          // some hidden items and some displayed items (because the pagination
          // view uses the search model and doesn't know about the hidden
          // items).
          result.AddInnerHTMLElement(PaginationView.DisplayPagination(m_asSearchModel,
           m_asOwner));
        }
        // Hidden input for already selected items.
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_SELECTEDIDS,
         "");
        myInput.SetValue(sbSelectedItems.ToString());
        result.AddInnerHTMLElement(myInput);
        return result;
      }
      catch (Exception e)
      {
        log.Error(e, "Could not display search results.");
        return new HTMLGenericElement(m_asOwner.GetString(414, "ptmsgs_portalinfrastructure"));
        }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      XPStringBuilder sb = new XPStringBuilder(300);
      ((TreeView) m_asOwner.GetView(TreeView.STR_MVC_CLASS_NAME)).DisplayFormValidationFunction(sb);
      HTMLScript result = new HTMLScript("text/javaScript");
      try
      {
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element.");
        return null;
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asSearchModel = (IBaseSearchResultModelRO) model;
      m_asOwner = parent;
    }
    
    /// <summary>
    /// This method is used to set the tree model on the view.
    /// </summary>
    /// <param name="IObjectTreeModelRO">the tree model</param>
    public virtual void InitTreeModel(IObjectTreeModelRO model)
    {
      m_asTreeModel = model;
    }
  }
}