using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <summary>
  /// This control is used to dynamically update the selected items list when
  /// the user de/selects an item.
  /// </summary>
  /// <author>DonH</author>
  public class TreeSelectControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tree.TreeSelectControl");
    
    /// <summary>
    /// class MVC name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "TreeSelect";
    
    /// <summary>
    /// Select or deselect 
    /// </summary>
    public const String SELECT = "Select";
    
    /// <summary>
    /// single id to select 
    /// </summary>
    public const String SELECTEDID = "SelectedID";
    
    /// <summary>
    /// tree model 
    /// </summary>
    protected IObjectTreeModel m_Model;
    
    /// <summary>
    /// owning activity space 
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // De/select a node in the tree
      bool bSelect = XPConvert.ToBoolean(((String[]) arguments.GetElement(SELECT))[0]);
      int nSelectedID = XPConvert.ToInteger(((String[]) arguments.GetElement(SELECTEDID))[0]);
      m_Model.SelectNode(nSelectedID, bSelect);
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      try
      {
        m_Model = (IObjectTreeModel) model;
      }
      catch (XPClassCastException e)
      {
        log.Error(e, "Error initializing TreeSelect control with model.");
        }
      m_asOwner = space;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new TreeSelectControl();
    }
  }
}