using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.tree
{
  /// <author>
  /// Don Hayler
  /// This displays the selected list in the bottom sub-frame of the tree pop-up
  /// For search integration only
  /// </author>
  public class TreeSelectDP : IDisplayPage
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tree.TreeSelectDP");
    
    /// <summary>
    /// Tree Select object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "TreeSelect";
    
    /// <summary>
    /// parent activity space 
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display(IWebData)"></seealso>
    public virtual void Display(IWebData webData)
    {
      HTMLPage myPage = new HTMLPage();
      // Set the HTMLPage as the data to be sent to the browser.
      webData.SetData(myPage);
      HTMLHead myHead = new HTMLHead();
      myPage.SetHead(myHead);
      HTMLBody myBody = new HTMLBody();
      myPage.SetBody(myBody);
      myBody.SetMarginHeight("0");
      myBody.SetMarginWidth("0");
      myBody.SetLeftMargin("0");
      myBody.SetTopMargin("0");
      myBody.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);
      try
      {
        myHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());
        myHead.AddInnerHTMLElement(m_asOwner.GetView(TreeSelectView.STR_MVC_CLASS_NAME).DisplayJavascript());
        myBody.AddInnerHTMLElement(m_asOwner.GetView(TreeSelectView.STR_MVC_CLASS_NAME).Display());
        }
      catch (Exception e)
      {
        log.Error(e, "Unable to display selected items in tree pop-up.");
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetParent()"></seealso>
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
    }
  }
}