using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.treeiterator;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portaluiinfrastructure.tree.commpages
{
  /// <summary>
  /// This class allows you to iterate through the Community hierarchy, choosing
  /// pages.
  /// </summary>
  /// <author>John Hogan</author>
  public class CommunityPageTreeIterator : IPTTreeIterator
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tree.commpages.CommunityPageTreeIterator");
    
    /// <summary>
    /// Admin Catalog 
    /// </summary>
    protected IPTAdminCatalog m_AdminCatalog;
    
    /// <summary>
    /// User's session. 
    /// </summary>
    protected IPTSession m_objSession;
    
    /// <summary>
    /// Current folder; can be NULL if we move to a folder that is inaccessible. 
    /// </summary>
    protected IPTAdminFolder m_objFolder;
    
    /// <summary>
    /// Root of the iteration. 
    /// </summary>
    protected IPTAdminFolder m_objRoot;
    
    /// <summary>
    /// Has the class been initialized. 
    /// </summary>
    protected bool m_bInitialized = false;
    
    /// <summary>
    /// Only 0 is recognized. 
    /// </summary>
    protected int m_nStyle = 0;
    
    /// <summary>
    /// Constructor for SiteMapTreeIterator.
    /// </summary>
    public CommunityPageTreeIterator() : base()
    {
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#Children(int,int)"></seealso>
    public virtual Object[][] Children(int arg0, int arg1)
    {
      //JH- Iterate through the admin folders hierarchy, displaying each folder.  If a folder
      //is a community (Communities are just a special type of admin folder in the API), query
      //for and display the pages as documents		
      if (!CheckInitialized())
      {
        return null;
      }
      if (m_objFolder == null)
      {
        return null;
      }
      int nNumFolderChildren;
      int nNumCommunityChildren;
      Object[][] objChildren;
      Object[] objChild;
      XPArrayList arrChildren = new XPArrayList();
      ASQueryResultWrapper qrFolders = new ASQueryResultWrapper(m_objFolder.QuerySubfolders(PT_PROPIDS.PT_PROPID_ALL,
       0, null, 0, -1, null));
      nNumFolderChildren = qrFolders.GetCount();
      //objChildren = new Object[10][nNumFolderChildren];
      for (int i = 0;i < nNumFolderChildren;i++)
      {
        String strName = (String) qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
        int lObjectID = XPConvert.ToInteger(qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
        String strObjectID = XPConvert.ToString(lObjectID);
        String strDesc = (String) qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_DESCRIPTION);
        objChild = new Object[10];
        objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME] = strName;
        objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_DESC] = strDesc;
        objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IDENTIFIER] = strObjectID;
        objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_TYPE] = PT_TREE_ITERATOR_CHILD_TYPES.PT_TREE_ITERATOR_CHILD_TYPE_CONTAINER;
        // -1 signifies that we don't know how many children we have
        objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_CHILDCOUNT] = -1;
        //Attach an image
        int intFolderType = XPConvert.ToInteger(qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_FOLDER_FOLDERTYPE));
        if (intFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER)
        {
          objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IMAGE_UUID] = PTImageType.ICON_FOLDER_COMMUNITY;
          objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_OPEN_IMAGE_UUID] = PTImageType.ICON_FOLDER_OPEN;
          } else
        {
          objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IMAGE_UUID] = PTImageType.ICON_FOLDER;
          objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_OPEN_IMAGE_UUID] = PTImageType.ICON_FOLDER_OPEN;
          }
        arrChildren.Add(objChild);
      }
      //If m_objFolder is a Community folder, we need to get the communities, then the pages for those
      //Communities
      if (PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER == m_objFolder.GetFolderType())
      {
        int intCommunityID = 0;
        //Open this community folder and query for its children (Communities), then IT'S children (pages)
        int intFolderID = ((IPTServerContext) m_objFolder.GetInterfaces("IPTServerContext")).GetObjectID();
        IPTAdminFolder myCommFolder = m_AdminCatalog.OpenAdminFolder(intFolderID,
         false);
        ASQueryResultWrapper qrCommunities = new ASQueryResultWrapper(myCommFolder.QueryObjects(false));
        //Get the community ID - need to cycle through the object returned and only get the object type that is a community
        for (int i = 0;i < qrCommunities.GetCount();i++)
        {
          int intClassID = XPConvert.ToInteger(qrCommunities.GetFields(i,
           PT_PROPIDS.PT_PROPID_CLASSID));
          if (PT_CLASSIDS.PT_COMMUNITY_ID == intClassID)
          {
            intCommunityID = XPConvert.ToInteger(qrCommunities.GetFields(i,
             PT_PROPIDS.PT_PROPID_OBJECTID));
            break;
          }
        }
        if (0 != intCommunityID)
        {
          //Open the community
          IPTCommunity myCommunity = (IPTCommunity) m_objSession.GetCommunities().Open(intCommunityID,
           false);
          //Query for its pages
          ASQueryResultWrapper qrPages = new ASQueryResultWrapper(myCommunity.QueryPages(0));
          nNumCommunityChildren = qrPages.GetCount();
          //objChildren = new Object[10][nNumFolderChildren + nNumCommunityChildren];				
          for (int j = 0;j < nNumCommunityChildren;j++)
          {
            //Build a string that contains the community folder ID followed by a comma, then the page id.  That allows us to retrieve
            //both things from the tree
            XPStringBuilder sb = new XPStringBuilder(20);
            // Child Location in the tree made of CommunityID,ObjectID only.
            sb.Append(intCommunityID).Append(",").Append(qrPages.GetFields(j,
             PT_PROPIDS.PT_PROPID_OBJECTID));
            objChild = new Object[10];
            objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME] = qrPages.GetFields(j,
             PT_PROPIDS.PT_PROPID_NAME);
            objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IDENTIFIER] = sb.ToString();
            objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_TYPE] = PT_TREE_ITERATOR_CHILD_TYPES.PT_TREE_ITERATOR_CHILD_TYPE_NODE;
            objChild[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IMAGE_UUID] = PTImageType.ICON_DOCUMENT;
            arrChildren.Add(objChild);
          }
        } else
        {
          //Something has gone wrong - no community is associated with the community folder
          arrChildren = new XPArrayList();
        }
      }
      objChildren = new Object[10][];
      for (int j2c_index = 0;j2c_index < 10;j2c_index++)
      {
        objChildren[j2c_index] = new Object[arrChildren.GetSize()];
      }
      for (int i = 0;i < arrChildren.GetSize();i++)
      {
        objChild = (Object[]) arrChildren.GetElement(i);
        objChildren[0][i] = objChild[0];
        objChildren[1][i] = objChild[1];
        objChildren[2][i] = objChild[2];
        objChildren[3][i] = objChild[3];
        objChildren[4][i] = objChild[4];
        objChildren[5][i] = objChild[5];
        objChildren[6][i] = objChild[6];
        objChildren[7][i] = objChild[7];
        objChildren[8][i] = objChild[8];
        objChildren[9][i] = objChild[9];
      }
      return objChildren;
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#CurrentLocInfo()"></seealso>
    public virtual Object[][] CurrentLocInfo()
    {
      if (!CheckInitialized())
      {
        return null;
      }
      if (m_objFolder == null)
      {
        return null;
      }
      IPTServerContext objSC = (IPTServerContext) m_objFolder.GetInterfaces("IPTServerContext");
      String strObjectID = XPConvert.ToString(objSC.GetObjectID());
      Object[][] objCurrentLocInfo = new Object[10][];
      for (int j2c_index = 0;j2c_index < 10;j2c_index++)
      {
        objCurrentLocInfo[j2c_index] = new Object[1];
      }
      objCurrentLocInfo[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME][0] = m_objFolder.GetLocalizedName();
      objCurrentLocInfo[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_DESC][0] = m_objFolder.GetLocalizedDescription();
      objCurrentLocInfo[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IDENTIFIER][0] = strObjectID;
      objCurrentLocInfo[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_TYPE][0] = PT_TREE_ITERATOR_CHILD_TYPES.PT_TREE_ITERATOR_CHILD_TYPE_CONTAINER;
      objCurrentLocInfo[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_CHILDCOUNT][0] = GetChildCount();
      return objCurrentLocInfo;
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#GetAtRoot()"></seealso>
    public virtual bool GetAtRoot()
    {
      if (!CheckInitialized())
      {
        return false;
      }
      if (m_objFolder == null)
      {
        return false;
      }
      IPTServerContext scFolder = (IPTServerContext) m_objFolder.GetInterfaces("IPTServerContext");
      IPTServerContext scRoot = (IPTServerContext) m_objRoot.GetInterfaces("IPTServerContext");
      return scFolder.GetObjectID() == scRoot.GetObjectID();
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#GetChildCount()"></seealso>
    public virtual int GetChildCount()
    {
      if (!CheckInitialized())
      {
        return 0;
      }
      if (m_objFolder == null)
      {
        return 0;
      }
      ASQueryResultWrapper qrFolders = new ASQueryResultWrapper(m_objFolder.QuerySubfolders(PT_PROPIDS.PT_PROPID_ALL,
       0, null, 0, -1, null));
      return qrFolders.GetCount();
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#GetLocation()"></seealso>
    public virtual String GetLocation()
    {
      if (!CheckInitialized())
      {
        return "";
      }
      if (m_objFolder == null)
      {
        String strZero = XPConvert.ToString(0);
        return strZero;
      }
      IPTServerContext objSC = (IPTServerContext) m_objFolder.GetInterfaces("IPTServerContext");
      String strObjectID = XPConvert.ToString(objSC.GetObjectID());
      return strObjectID;
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#GetStyle()"></seealso>
    public virtual int GetStyle()
    {
      return m_nStyle;
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#InitializeIterator(java.lang.Object)"></seealso>
    public virtual void InitializeIterator(Object arg0)
    {
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#MoveTo(java.lang.String)"></seealso>
    public virtual void MoveTo(String arg0)
    {
      if (!CheckInitialized())
      {
        return;
      }
      XPStringTokenizer myTokenizer = new XPStringTokenizer(arg0, ",");
      //Get the first token, the community folder ID
      int intCommunityFolderID;
      intCommunityFolderID = XPConvert.ToInteger(myTokenizer.GetNextToken());
      m_objFolder = (IPTAdminFolder) m_AdminCatalog.OpenAdminFolder(intCommunityFolderID,
       false);
      if (m_objFolder == null)
      {
        log.Warn("CommunityPageTreeIterator: Attempted to MoveTo a folder that does not exist, or this user does not have access to the folder.  Will set folder to null.");
        m_objFolder = null;
        return;
      }
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#MoveToParent()"></seealso>
    public virtual void MoveToParent()
    {
      if (!CheckInitialized())
      {
        return;
      }
      if (m_objFolder == null)
      {
        // this can happen if someone moved us to a folder we don't have access to, or that
        // failed to open.  so in this case, just send them to the root.
        m_objFolder = m_objRoot;
        return;
      }
      m_objFolder = (IPTAdminFolder) m_AdminCatalog.OpenAdminFolder(m_objFolder.GetParentFolderID(),
       false);
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#MoveToRoot()"></seealso>
    public virtual void MoveToRoot()
    {
      if (!CheckInitialized())
      {
        return;
      }
      m_objFolder = m_objRoot;
    }
    
    /// <summary>
    /// Use this function to initialize the Iterator.  Do not use
    /// InitializeIterator, which is on IPTTreeIterator, but does not meet the
    /// needs of this class.
    /// </summary>
    /// <param name="nSiteMapFolderID:">ID of SiteMapFolder to iterate.</param>
    /// <param name="objSession:">User's session.</param>
    public virtual void RealInitializeIterator(int nAdminFolderID, IPTSession objSession)
    {
      m_objSession = objSession;
      m_AdminCatalog = objSession.GetAdminCatalog();
      m_objRoot = (IPTAdminFolder) m_AdminCatalog.OpenAdminFolder(nAdminFolderID,
       false);
      // set the current folder equal to the root
      m_objFolder = m_objRoot;
      if ((m_objRoot == null) || (m_objSession == null) || (m_AdminCatalog == null))
      {
        log.Warn("CommunityPageTreeIterator: Iterator was initialized with null values.");
        return;
      }
      m_bInitialized = true;
    }
    
    /// <seealso cref="com.plumtree.server.treeiterator.IPTTreeIterator#SetStyle(int)"></seealso>
    public virtual void SetStyle(int nStyle)
    {
      m_nStyle = nStyle;
    }
    
    /// <summary>
    /// Test function.
    /// </summary>
    /// <param name="ptTreeIterator:">IPTTreeIterator to iterate.</param>
    /// <param name="strIndent:">
    /// This function is called recursively, and adds spaces to
    /// strIndent for every level of recursion.  Pass in "" for the first call to
    /// the function.
    /// </param>
    public static void printTree(IPTTreeIterator ptTreeIterator, String strIndent)
    {
      Object[][] currentLocation = (Object[][]) ptTreeIterator.CurrentLocInfo();
      String parentName = (String) currentLocation[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME][0];
      log.Info(strIndent + parentName);
      Object[][] childNodes = (Object[][]) ptTreeIterator.Children(0, -1);
      if (null == childNodes)
      {
        return;
      }
      int numChildren = childNodes[0].Length;
      int parentType = XPConvert.ToInteger(currentLocation[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_TYPE][0]);
      if (PT_TREE_ITERATOR_CHILD_TYPES.PT_TREE_ITERATOR_CHILD_TYPE_CONTAINER == parentType)
      {
        for (int i = 0;i < numChildren;i++)
        {
          if (XPConvert.ToInteger(childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_TYPE][i]) == PT_TREE_ITERATOR_CHILD_TYPES.PT_TREE_ITERATOR_CHILD_TYPE_CONTAINER)
          {
            String childLocation = (String) childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IDENTIFIER][i];
            ptTreeIterator.MoveTo(childLocation);
            printTree(ptTreeIterator, strIndent + "  ");
          }
        }
      }
    }
    
    /// <summary>
    /// Check whether Initialized was called.
    /// </summary>
    /// <returns>True if initialized, False if not initialized.</returns>
    private bool CheckInitialized()
    {
      if (m_bInitialized == false)
      {
        log.Warn("CommunityPageTreeIterator: Iterator has not been initialized.");
        return false;
      } else
      {
        return true;
      }
    }
  }
}