using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portaluiinfrastructure.tree.template
{
  /// <author>michaeld</author>
  public class TemplateTreeAS : TreeAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portaluiinfrastructure.tree.template.TemplateTreeAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "TemplateTree";
    
    /// <summary>
    /// Inherit Page Temp plug in 
    /// </summary>
    public const String PLUGIN_INHERIT_TEMPLATE = "InheritTemplate";
    
    /// <summary>
    /// The name of the javascript array member variable for the class id 
    /// </summary>
    public const String INHERIT_OBJECT = "Inherit";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TemplateTreeAS();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      base.Init();
      RegisterModel(TemplateTreeModel.STR_MVC_CLASS_NAME, TREEMODEL);
      IModel myModel = GetModel(TREEMODEL);
      // Set model on previously registered controls
      ((StartTreeControl) GetControl(StartTreeControl.STR_MVC_CLASS_NAME)).Init(myModel,
       this);
      RegisterAfterModel(myModel);
      // objects to handle both search and tree
      // Register this DP in place of the default tree frame DP.
      UnRegisterPage(TreeFrameDP.STR_MVC_CLASS_NAME);
      IDisplayPage myFrameSet = new TemplateTreeFrameDP();
      RegisterPage(myFrameSet, TreeFrameDP.STR_MVC_CLASS_NAME);
      // This must be set explicitly so it is the default page
      SetCurrentPage(myFrameSet);
      // Header DP
      UnRegisterPage(TreeHeaderDP.STR_MVC_CLASS_NAME);
      AFormDP myHeader = new TemplateTreeHeaderDP();
      myHeader.AddToValidationFunction(TemplateTreeHeaderDP.JAVASCRIPT_SUBMIT_TREE);
      RegisterPage(myHeader, TreeHeaderDP.STR_MVC_CLASS_NAME);
      RegisterControl(TemplateTreeRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Inherit Template plug in
      RegisterModel(InheritTemplateModel.STR_MVC_CLASS_NAME, PLUGIN_INHERIT_TEMPLATE);
      myModel = GetModel(PLUGIN_INHERIT_TEMPLATE);
      RegisterPage(new InheritTemplateDP());
      RegisterView(InheritTemplateView.STR_MVC_CLASS_NAME, PLUGIN_INHERIT_TEMPLATE,
       myModel);
    }
    
    /// <summary>
    /// Override this method to attach additional information specific to your implementation of the tree.
    /// Below is an example of how to do this.
    /// XPStringBuilder sb = new XPStringBuilder();
    /// sb.Append("myArray[").Append(iSelectedItemIndex).Append("].")
    /// .Append(OBJECT_CLASS_ID).Append(" = '")
    /// .Append(((TreeLeafNode) mySelectedItems.GetElement(iSelectedItemIndex)).m_nClassID)
    /// .Append("';\n");
    /// return sb.ToString();
    /// </summary>
    /// <param name="index">of the selected Item</param>
    /// <returns>String</returns>
    public override String GetTreeSpecificArrayDataToAppend(int iSelectedItemIndex)
    {
      XPStringBuilder sb = new XPStringBuilder();
      sb.Append("myArray[").Append(iSelectedItemIndex).Append("].").Append(INHERIT_OBJECT).Append(" = \'").Append(XPConvert.ToString(((IInheritTemplateModelRO) GetModel(PLUGIN_INHERIT_TEMPLATE)).IsTemplateInherited())).Append("\';\n");
      return sb.ToString();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IFormAS#GetRepostControlName()"></seealso>
    public override String GetRepostControlName()
    {
      return TemplateTreeRepostControl.STR_MVC_CLASS_NAME;
    }
  }
}