using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portaluiinfrastructure.tree.template
{
  /// <author>michaeld</author>
  public class TemplateTreeModel : AdminTreeModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.browsing.editors.community.templatetree.TemplateTreeModel");
    
    /// <summary>
    /// MVC object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "TemplateTree";
    private bool m_bDisplayInheritTemplate = false;
    public virtual bool GetDisplayInheritTemplate()
    {
      return m_bDisplayInheritTemplate;
    }
    public virtual void SetDisplayInheritTemplate(bool _bDisplayInheritTemplate)
    {
      m_bDisplayInheritTemplate = _bDisplayInheritTemplate;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.tree.ITreeModel#ResetTree()"></seealso>
    public override void ResetTree()
    {
      base.ResetTree();
      ((InheritTemplateModel) m_asOwner.GetModel(TemplateTreeAS.PLUGIN_INHERIT_TEMPLATE)).ResetInheritTemplate();
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(java.lang.String,com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      log.Debug("Begin TemplateTreeModel.SavePage");
      int result = RepostControl.PAGE_STATUS_VALID;
      if ((InheritTemplateDP.STR_MVC_CLASS_NAME).Equals(_sPageName))
      {
        ((IRepostModel) m_asOwner.GetModel(TemplateTreeAS.PLUGIN_INHERIT_TEMPLATE)).SavePage(_sPageName,
         _htFormData);
        m_bDisplayInheritTemplate = false;
      } else
      {
        result = base.SavePage(_sPageName, _htFormData);
        // SE: Bug 57030 - Fix for Vodafone. We should only display the Inherit Template Page when we detect that
        // the user has selected a template.
        // TemplateTreeRepostControl.SetRepostAction determines whether or not to set the action to 
        // POSTTOSELF_ACTION_FINISH by checking if the action is POSTTOSELF_ACTION_SELECTTEMPLATE (action number 99) 
        // and if m_bDisplayInheritTemplate is true.
        // The POSTTOSELF_ACTION_FINISH action will close the pop-up window without calling the Inherit Template page first.
        // We should set m_bDisplayInheritTemplate to true only when we detect a POSTTOSELF_ACTION_SELECTTEMPLATE 
        // action from the form post data. This means the user has selected a template and clicked "Ok" and the Inherit Template
        // page should be displayed right after that.
        int nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
        if (_htFormData.ContainsKey(RepostControl.HTMLINPUT_POSTTOSELF))
        {
          String[] data = (String[]) _htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);
          if ((0 != data.Length) && (null != data[0]))
          {
            nAction = XPConvert.ToInteger(data[0]);
          }
        }
        if (TemplateTreeRepostControl.POSTTOSELF_ACTION_SELECTTEMPLATE == nAction)
        {
          m_bDisplayInheritTemplate = true;
          log.Debug("TemplateTreeRepostControl.POSTTOSELF_ACTION_SELECTTEMPLATE detected, display InheritTemplate page on next repost");
          }
      }
      log.Debug("End TemplateTreeModel.SavePage");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new TemplateTreeModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}