using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using ITaggingModel=com.plumtree.portaluiinfrastructure.pathways.tagging.ITaggingModel;
using PathwaysRestAPIService=com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysRestAPIService;
using PathwaysTagRestData=com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysTagRestData;
using com.plumtree.portaluiinfrastructure.search;
using PathwaysSearchResponse=com.plumtree.portaluiinfrastructure.search.pathways.PathwaysSearchResponse;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.mock.search
{
  /// <summary>
  /// Mock version of the search result model, for use in testing the search results
  /// page layout tags.
  /// </summary>
  /// <author>smahendr</author>
  public class MockSearchResultModel : ISearchResultModelRO,ISearchResultModel,
  ITaggingModel
  {
    private int numDisplayableItems = 0;
    private int firstDisplayableItem = 0;
    private String currentKey = null;
    private String searchString = null;
    private bool bAdvancedSearch = false;
    private bool bIncludeSubfolders = true;
    private XPHashtable hashReconstructionArgs = null;
    private int[] arrPortletRestrictions = null;
    private SearchSettingCollection removableSettings = null;
    private int nTotalItems = 0;
    private int nDrillDownDepth = 0;
    private bool bPathwaysSearch = true;
    private bool bTaggingEnabled = true;
    private XPHashtable hashTagCloud = null;
    private XPArrayList resultsList;
    
    /// <summary>
    /// Methods used to set up mock data *********
    /// </summary>
    public virtual void SetNumDisplayableItems(int numDisplayableItems)
    {
      this.numDisplayableItems = numDisplayableItems;
    }
    public virtual void SetFirstDisplayableItem(int firstDisplayableItem)
    {
      this.firstDisplayableItem = firstDisplayableItem;
    }
    public virtual void SetResultsList(XPArrayList resultsList)
    {
      this.resultsList = resultsList;
    }
    public virtual void SetCurrentKey(String currentKey)
    {
      this.currentKey = currentKey;
    }
    public virtual void SetSearchString(String searchString)
    {
      this.searchString = searchString;
    }
    public virtual void SetAdvancedSearch(bool bAdvancedSearch)
    {
      this.bAdvancedSearch = bAdvancedSearch;
    }
    public virtual void SetIncludeSubfolders(bool bIncludeSubfolders)
    {
      this.bIncludeSubfolders = bIncludeSubfolders;
    }
    public virtual void SetReconstructionArgs(XPHashtable hashReconstructionArgs)
    {
      this.hashReconstructionArgs = hashReconstructionArgs;
    }
    public virtual void SetRemovableSettings(SearchSettingCollection removableSettings)
    {
      this.removableSettings = removableSettings;
    }
    public virtual void SetPortletRestrictions(int[] arrPortletRestrictions)
    {
      this.arrPortletRestrictions = arrPortletRestrictions;
    }
    public virtual void SetTotalItems(int nTotalItems)
    {
      this.nTotalItems = nTotalItems;
    }
    public virtual void SetTagCloud(XPHashtable hashTagCloud)
    {
      this.hashTagCloud = hashTagCloud;
    }
    public virtual void IsTaggingEnabled(bool bTaggingEnabled)
    {
      this.bTaggingEnabled = bTaggingEnabled;
    }
    
    /// <summary>
    /// Return the mock number of displayable items set.
    /// </summary>
    public virtual int GetNumDisplayableItems()
    {
      return numDisplayableItems;
    }
    public virtual int GetFirstDisplayableItem()
    {
      return firstDisplayableItem;
    }
    public virtual String GetCurrentKey()
    {
      return currentKey;
    }
    public virtual String GetSearchString()
    {
      return searchString;
    }
    public virtual bool isAdvancedSearch()
    {
      return bAdvancedSearch;
    }
    public virtual bool GetIncludeSubfolders()
    {
      return bIncludeSubfolders;
    }
    public virtual XPHashtable GetReconstructionArgs()
    {
      return GetReconstructionArgs(true);
    }
    public virtual XPHashtable GetReconstructionArgs(bool pageContext)
    {
      return GetReconstructionArgs(SearchResultControl.RECONSTRUCTION_ARGS_PREFIX,
       pageContext);
    }
    public virtual XPHashtable GetReconstructionArgs(String prefix, bool wantPageContext)
    {
      return hashReconstructionArgs;
    }
    public virtual SearchSettingCollection GetRemovableSettings()
    {
      return removableSettings;
    }
    public virtual int[] GetPortletRestrictions()
    {
      return arrPortletRestrictions;
    }
    public virtual int GetTotalItems()
    {
      return nTotalItems;
    }
    public virtual bool IsPathwaysSearch()
    {
      return bPathwaysSearch;
    }
    public virtual XPHashtable GetTagCloud()
    {
      return this.hashTagCloud;
    }
    
    /// <summary>
    /// Not used in SearchResultModel
    /// </summary>
    public virtual IXPList GetObjectTags(int rank)
    {
      return null;
    }
    public virtual bool IsTaggingEnabled()
    {
      return bTaggingEnabled;
    }
    
    /// <summary>
    /// Methods used to retrieve mock result data *********
    /// </summary>
    public virtual String GetResultName(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getName();
      }
    public virtual HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup)
    {
      return GetResultClickthroughURL(rank, allowPopup, false, null);
    }
    public virtual HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup,
     bool editMode)
    {
      return GetResultClickthroughURL(rank, allowPopup, editMode, null);
    }
    public virtual HTMLAnchor GetResultClickthroughURL(int rank, bool allowPopup,
     bool editMode, String extraParameters)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getClickthroughURL();
      }
    public virtual HTMLAnchor GetResultPropertiesURL(int rank, bool allowPopup)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getPropertiesURL();
      }
    public virtual bool isResultBestBet(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).isBestBet();
      }
    public virtual String GetResultApp(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getApp();
    }
    public virtual int GetResultClassID(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getClassID();
      }
    public virtual int GetResultObjectID(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getObjectID();
      }
    public virtual int GetResultFolderID(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getFolderID();
      }
    public virtual Object GetResultIcon(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getIcon();
      }
    public virtual XPDateTime GetResultLastModified(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getLastModified();
      }
    public virtual String GetKWIC(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getKwic();
      }
    public virtual String GetResultContentLastPubUser(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getContentLastPubUser();
      }
    public virtual int[] GetResultContentPortletIDs(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getContentPortletIDs();
      }
    public virtual XPDateFormat GetDateFormat(AActivitySpace aspace)
    {
      XPLocale xpLocale = null;
      XPTimeZone xpTimeZone = null;
      xpLocale = XPLocale.GetDefault();
      xpTimeZone = XPTimeZone.GetCurrentTimeZone();
      return XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT, XPDateFormat.SHORT,
       xpLocale, xpTimeZone);
    }
    public virtual PathwaysTagRestData[] GetPathwaysResultTags(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getPathwaysResultTags();
      }
    public virtual double GetPathwaysResultScore(int rank)
    {
      return ((MockSearchResult) resultsList.GetElement(rank)).getPathwaysResultScore();
      }
    
    /// <summary>
    /// Unimplemented methods *********************
    /// </summary>
    public virtual String GetBreadcrumbKey(int step)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetBreadcrumbLabel(int step)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetCorrectionFrequency(int misspellingIndex, int correctionIndex)
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual int GetDrilldownDepth()
    {
      return nDrillDownDepth;
    }
    public virtual void SetDrilldownDepth(int _nDepth)
    {
      nDrillDownDepth = _nDepth;
    }
    public virtual Object GetGroupIcon(int group)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetGroupName(int group)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetLastGroupByField()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetMisspelledToken(int misspellingIndex)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetNumCorrections(int misspellingIndex)
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual int GetNumMisspelledTokens()
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual int GetNumResultGroups()
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual String GetPageMode()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetResultBestBetKey(int rank)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetResultCollabProjectName(int rank)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetResultCollabProjectURL(int rank)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual HTMLAnchor GetResultEditLink(int rank, bool allowPopup)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetResultRank(int groupNum, int resultNum)
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual int GetReturnedResultsInGroup(int group)
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual XPHashtable GetSearchAgainArgs(bool includeOptional)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetSpellingCorrection(int misspellingIndex, int correctionIndex)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetTotalResultsInGroup(int group)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual bool hasDrilledDownIntoSingleCategory(String orgType)
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual bool isEntireGroupReturned(int group)
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual bool wasSpellCorrected()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual SearchExecutionError GetError()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetResultAbsType(int rank)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual XPDateTime GetResultCreated(int rank)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetResultEODField(int rank, int propertyId)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetResultPath(int rank)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetResultPortletField(int rank, int fieldId)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetResultSize(int rank)
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual String GetResultSubType(int rank)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual SearchExecutionWarning GetWarning()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual bool IsInitialized()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual String GetName()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetItemsPerPage()
    {
      // TODO Auto-generated method stub
      return 10;
    }
    public virtual String GetSortOrder()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetAbstractTypeRestrictions()
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual int[] GetAdminFolderRestrictions()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetApplicationRestrictions()
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual int[] GetCollabProjectRestrictions()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetCommunityNameForID(int id)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int[] GetCommunityRestrictions()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int[] GetDocFolderRestrictions()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetFolderNameForID(int id, bool isAdmin)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetLanguageRestriction()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int[] GetObjectTypeRestrictions()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetPortletNameForID(int id)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetASConstraintOperator(int condition)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetASConstraintProperty(int condition)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual String GetASConstraintValue(int condition)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetASNumPropertyConstraints()
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual bool GetASPropertyClauseOperator()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual bool GetASTopLevelOperator()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual bool IsASTooComplexToSummarize()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual bool GetHasBeenSaved()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual int GetSavedSearchErrorCode()
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual String GetSavedSearchName()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual void Drilldown(String key, String groupByField, int category)
    {
    }
    // TODO Auto-generated method stub
    public virtual void RefreshResults(String keyOnPage)
    {
    }
    // TODO Auto-generated method stub
    public virtual void Reorganize(String key, String groupByField)
    {
    }
    // TODO Auto-generated method stub
    public virtual void RestoreFromBreadcrumb(String keyOfPageWhereLinkAppears,
     String keyToRestore)
    {
    }
    // TODO Auto-generated method stub
    public virtual void Search(String searchString, String basicFields, IPTFilter advancedFilter,
     SearchSettingCollection settings)
    {
    }
    // TODO Auto-generated method stub
    public virtual void Search(String searchString, String basicFields, IPTFilter advancedFilter,
     SearchSettingCollection allSettings, SearchSettingCollection removableSettings)
    {
    }
    // TODO Auto-generated method stub
    public virtual void SearchWithinResults(String key, String additionalQuery)
    {
    }
    // TODO Auto-generated method stub
    public virtual void SetError(SearchExecutionError e)
    {
    }
    // TODO Auto-generated method stub
    public virtual void SetPageMode(String pageMode)
    {
    }
    // TODO Auto-generated method stub
    public virtual void SetWarning(SearchExecutionWarning e)
    {
    }
    // TODO Auto-generated method stub
    public virtual void CleanupAllData()
    {
    }
    // TODO Auto-generated method stub
    public virtual void CleanupTempData()
    {
    }
    // TODO Auto-generated method stub
    public virtual void Init(AActivitySpace arg0)
    {
    }
    // TODO Auto-generated method stub
    public virtual Object Create()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual void GoToPage(String arg0, int arg1, int arg2, Object arg3)
    {
    }
    // TODO Auto-generated method stub
    public virtual void SetSavedSearchErrorCode(int code)
    {
    }
    // TODO Auto-generated method stub
    public virtual void SetSavedSearchName(String name)
    {
    }
    // TODO Auto-generated method stub
    public virtual String GetResultStyleClass(String subType)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual void Filter(String key, int filterId)
    {
    }
    // TODO Auto-generated method stub
    public virtual bool CollabInstalled()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual bool ContentInstalled()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public virtual void ChangeSortOrder(String sortOrder, Object additionalInfo)
    {
    }
    // TODO Auto-generated method stub
    public virtual int GetSelectedTypeFilter()
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual void AddRemoveObjectTag(String tagname, String strid, int action,
     String ptsource)
    {
    }
    public virtual void RenameObjectTag(String tagname, String strid, String ptsource,
     String renametag)
    {
    }
    public virtual XPException GetPathwaysTaggingError()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual void SetPathwaysTaggingError(XPException e)
    {
    }
    // TODO Auto-generated method stub
    public virtual String GetLocalizedSearchString()
    {
      // TODO Auto-generated method stub
      return searchString;
    }
  }
}