using System;
using com.plumtree.openfoundation.mockobjects;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.mock.httpmemorymanagement;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.mock.tags
{
  public class MockEnvironment : AActivitySpace,IEnvironment
  {
    public const String MOCK_I18N_FILE = "ptmsgs_mockstrings";
    public const int MOCK_I18N_STRING_ID = 12;
    public const String MOCK_I18N_STRING = "mock string";
    public const String MOCK_I18N_PLACEHOLDER_STRING = "localized placeholder string";
    public static String MOCK_BASE_URL = "http://mock.base.com/portal/server.pt?";
    public String m_asName = null;
    public String m_dpName = null;
    public IXPRequest m_request;
    public IXPResponse m_response;
    public MockPTSession m_userSession;
    public AActivitySpace m_parentSpace = null;
    public String m_MockI18NStringFile = null;
    public String m_MockI18NString = null;
    public int m_nMockI18NStringIndex;
    public int m_nLastI18NStringIndex = -1;
    public String m_strLastI18NStringFile = null;
    public AccessStyles m_accessStyle = AccessStyles.STANDARD;
    public XPHashtable m_models = new XPHashtable();
    public XPHashtable m_views = new XPHashtable();
    public MockEnvironment() : 
    // create parent space
    this(true)
    {
    }
    public MockEnvironment(bool createParentSpace)
    {
      m_request = XPRequestSimulator.CreateGetLocalhost();
      m_response = XPResponseSimulator.Create();
      setup(createParentSpace);
    }
    protected virtual void setup(bool createParentSpace)
    {
      m_userSession = new MockPTSession();
      base.SetUserSession(m_userSession);
      this.SetSubSession(new MockSessionManager());
      this.GetSubSession().SetAttribute(ASConstants.PREVIOUS_REQUEST_URL,
       MOCK_BASE_URL);
      this.GetSubSession().SetAttribute(ASConstants.PREVIOUS_REQUEST_IS_POST,
       false);
      this.SetPersistentSubSession(new MockSessionManager());
      this.SetApplication(new Application("", ""));
      // Create a parent space but dont have the parent space create a parent space
      if (createParentSpace)
      {
        m_parentSpace = new MockEnvironment(false);
      }
    }
    public override void SetCurrentPage(IDisplayPage idp)
    {
      base.SetTrackCurrentPage(true);
      base.SetCurrentPage(idp);
    }
    public override IModel GetModel(String arg0)
    {
      return (IModel) m_models.GetElement(arg0);
    }
    public override IView GetView(String arg0)
    {
      return (IView) m_views.GetElement(arg0);
    }
    public override bool GetModelExists(String strModelName)
    {
      return m_models.ContainsKey(strModelName);
    }
    public virtual void SetAccessStyle(AccessStyles _style)
    {
      m_accessStyle = _style;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetAccessStyle()
     */
     
    public override AccessStyles GetAccessStyle()
    {
      return m_accessStyle;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetCurrentHTTPRequest()
     */
     
    public override IXPRequest GetCurrentHTTPRequest()
    {
      return m_request;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetCurrentHTTPResponse()
     */
     
    public override IXPResponse GetCurrentHTTPResponse()
    {
      return m_response;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetCurrentNormalizedBaseURL()
     */
     
    public override String GetCurrentNormalizedBaseURL()
    {
      return MOCK_BASE_URL;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetCurrentRequestURL()
     */
     
    public override String GetCurrentRequestURL()
    {
      if (MOCK_BASE_URL != null)
      {
        return MOCK_BASE_URL;
      } else
      {
        return m_request.GetRequestURL();
      }
    }
    
    /// <summary>
    /// Sets the current Request URL and computes the normalized
    /// base url.
    /// This method must be called at the beginning of every request.
    /// </summary>
    /// <param name="the">current request url</param>
    public override void SetCurrentRequestURL(String strCurrentRequestURL)
    {
      base.SetCurrentRequestURL(strCurrentRequestURL);
      MOCK_BASE_URL = strCurrentRequestURL;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetErrorData()
     */
     
    //	public IErrorData[] GetErrorData()
    //	{
    //		// TODO Auto-generated method stub
    //		return new IErrorData[0];
    //	}
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetLanguage()
     */
     
    public override String GetLanguage()
    {
      // TODO Auto-generated method stub
      return "en";
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetLocale()
     */
     
    public override String GetLocale()
    {
      // TODO Auto-generated method stub
      return "en-us";
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetTimeZone()
     */
     
    public override String GetTimeZone()
    {
      // TODO Auto-generated method stub
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetString(int, java.lang.String)
     */
     
    public override String GetString(int _nID, String _strStringFile)
    {
      m_nLastI18NStringIndex = _nID;
      m_strLastI18NStringFile = _strStringFile;
      if (0 == XPStringUtility.Compare(_strStringFile, MOCK_I18N_FILE))
      {
        switch (_nID){
        case MOCK_I18N_STRING_ID:
        return MOCK_I18N_STRING;
        goto default;
        default:
        break;
        }
      }
      if ((m_MockI18NStringFile != null) && (0 == XPStringUtility.Compare(_strStringFile,
       m_MockI18NStringFile)) && (m_nMockI18NStringIndex == _nID))
      {
        return m_MockI18NString;
      }
      return MOCK_I18N_PLACEHOLDER_STRING;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#GetUserSession()
     */
     
    public override Object GetUserSession()
    {
      return m_userSession;
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#SetUserSession()
     */
     
    public override void SetUserSession(Object userSession)
    {
      m_userSession = (MockPTSession) userSession;
      base.SetUserSession(m_userSession);
    }
    /* (non-Javadoc)
     * @see com.plumtree.tags.IEnvironment#HasErrors()
     */
     
    public virtual bool HasErrors()
    {
      // TODO Auto-generated method stub
      return false;
    }
    public override IVarPack GetVarPack(String arg0)
    {
      // TODO Auto-generated method stub
      return null;
    }
    // Overridden methods from AActivitySpace
    public override AActivitySpace GetParentSpace()
    {
      // rob: this shouldn't be here, sometimes you want the parentspace to be null
      // but then if we initialize parentspace during creating we get into an infinite loop
      // with parentspaes creating their own parentspaces.
      // @TODO needs fixing somehow
      //		if (m_parentSpace == null)
      //		{
      //			m_parentSpace = new MockEnvironment();
      //		}
      return m_parentSpace;
    }
    // Abstract methods from AActivitySpace
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      // TODO Auto-generated method stub
      return false;
    }
    public override Object Create()
    {
      // TODO Auto-generated method stub
      return null;
    }
    public override String GetName()
    {
      return m_asName;
    }
  }
}