using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.server.impl.core;
using com.plumtree.server.mock.community;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener;
namespace com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes
{
  public class PTCommunitiesTest : TestCase
  {
    protected int communityId = 200;
    protected int pageId = 300;
    protected PTCommunities testObject = null;
    protected AActivitySpace asParent = null;
    protected MockPTSession userSession = null;
    public static String SPECIALCHARS_STRING = "!@#$%^&*<>()-=~?\';.,\"";
    public static String SPECIALCHARS_DENORMALIZED_STRING = FriendlyURL.DeNormalizeObjectName(SPECIALCHARS_STRING);
    public static String SPECIALCHARS_NORMALIZED_STRING = FriendlyURL.NormalizeObjectName(SPECIALCHARS_STRING);
    public PTCommunitiesTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      testObject = new PTCommunities();
      asParent = new BaseOpenerAS();
      userSession = new MockPTSession();
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      testObject = null;
      asParent = null;
      userSession = null;
    }
    
    /// <summary>
    /// DCA - test to handle community name
    /// </summary>
    public virtual void testGetRedirectViewObjectCommName()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/community_name/",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTCommunities.COMMUNITY_AS_NAME);
      String commId = redirect.GetControlArgument(PTCommunities.STR_COMMUNITY_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(commId),
       communityId);
      String pId = redirect.GetControlArgument(PTCommunities.STR_PAGE_ID);
      Assert.assertEquals("Redirect object has the wrong page Id.", XPConvert.ToInteger(pId),
       0);
    }
    
    /// <summary>
    /// DCA - test to handle community name with community Id
    /// </summary>
    public virtual void testGetRedirectViewObjectCommNameCommId()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/community_name/200/",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTCommunities.COMMUNITY_AS_NAME);
      String commId = redirect.GetControlArgument(PTCommunities.STR_COMMUNITY_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(commId),
       communityId);
      String pId = redirect.GetControlArgument(PTCommunities.STR_PAGE_ID);
      Assert.assertEquals("Redirect object has the wrong page Id.", XPConvert.ToInteger(pId),
       0);
    }
    
    /// <summary>
    /// DCA - test to handle community name with page name
    /// </summary>
    public virtual void testGetRedirectViewObjectCommNamePageName()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/community_name/page_name",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTCommunities.COMMUNITY_AS_NAME);
      String commId = redirect.GetControlArgument(PTCommunities.STR_COMMUNITY_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(commId),
       communityId);
      String pId = redirect.GetControlArgument(PTCommunities.STR_PAGE_ID);
      Assert.assertEquals("Redirect object has the wrong page Id.", XPConvert.ToInteger(pId),
       pageId);
    }
    
    /// <summary>
    /// DCA - test to handle community name with community Id and page name
    /// </summary>
    public virtual void testGetRedirectViewObjectCommNameCommIdPageName()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/community_name/200/page_name/",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTCommunities.COMMUNITY_AS_NAME);
      String commId = redirect.GetControlArgument(PTCommunities.STR_COMMUNITY_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(commId),
       communityId);
      String pId = redirect.GetControlArgument(PTCommunities.STR_PAGE_ID);
      Assert.assertEquals("Redirect object has the wrong page Id.", XPConvert.ToInteger(pId),
       pageId);
    }
    
    /// <summary>
    /// DCA - test to handle community name that returns 2 communities
    /// </summary>
    public virtual void testGetRedirectViewObject2CommName()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/2communities/",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, "SearchResult");
      String communityName = redirect.GetControlArgument(SearchResultControl.USER_QUERY);
      Assert.assertEquals("Redirect object has the search query.", communityName,
       "2communities");
    }
    
    /// <summary>
    /// DCA - test to handle community name that returns 2 communities where one has the page name specified
    /// </summary>
    public virtual void testGetRedirectViewObject2CommNamePageName()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/2communities/page_name/",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTCommunities.COMMUNITY_AS_NAME);
      String commId = redirect.GetControlArgument(PTCommunities.STR_COMMUNITY_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(commId),
       communityId);
      String pId = redirect.GetControlArgument(PTCommunities.STR_PAGE_ID);
      Assert.assertEquals("Redirect object has the wrong page Id.", XPConvert.ToInteger(pId),
       pageId);
    }
    
    /// <summary>
    /// DCA - test to handle community name that returns 2 communities and both have same page name
    /// </summary>
    public virtual void testGetRedirectViewObject2CommName2PageName()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/2communities/2pages/",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, "SearchResult");
      String communityName = redirect.GetControlArgument(SearchResultControl.USER_QUERY);
      Assert.assertEquals("Redirect object has the search query.", communityName,
       "2communities");
    }
    
    /// <summary>
    /// Test with special characters
    /// </summary>
    public virtual void testGetRedirectViewObjectWithSpecialCharacters()
    {
      String pageName = "Page 1";
      int origCommId = 300;
      int origPageId = 400;
      MockPTCommunityManager.SetCommunityMapping(SPECIALCHARS_STRING, new int[]{origCommId});
      MockPTCommunityManager.SetCommPageMapping(pageName, origPageId);
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + SPECIALCHARS_NORMALIZED_STRING + "/" + pageName + "/",
       "/", false);
      CommunityFriendlyURLParser cfURLParser = new CommunityFriendlyURLParser("community",
       XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTCommunities.COMMUNITY_AS_NAME);
      String commId = redirect.GetControlArgument(PTCommunities.STR_COMMUNITY_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", origCommId,
       XPConvert.ToInteger(commId));
      String pId = redirect.GetControlArgument(PTCommunities.STR_PAGE_ID);
      Assert.assertEquals("Redirect object has the wrong page Id.", origPageId,
       XPConvert.ToInteger(pId));
      MockPTCommunityManager.ClearDeprecatedStaticMockData();
    }
    
    /// <summary>
    /// Test that both server and ui uses same normalization functions
    /// </summary>
    public virtual void testServerAndUINormalization()
    {
      assertEquals("Server and UI denormalization functions are out of synch!",
       SPECIALCHARS_DENORMALIZED_STRING, ObjectIdFromNameCache.DeNormalizeObjectName(SPECIALCHARS_STRING));
      assertEquals("Server and UI denormalization functions are out of synch!",
       SPECIALCHARS_NORMALIZED_STRING, ObjectIdFromNameCache.NormalizeObjectName(SPECIALCHARS_STRING));
      }
  }
}