using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.friendlyurl;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.server.mock.community;
using com.plumtree.server.mock.core;
using com.plumtree.server.mock.directory;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes
{
  public class PTDocFoldersTest : TestCase
  {
    public const String DIRECTORYFOLDER_KEYWORD = "directory";
    protected PTDocFolders testObject = null;
    protected AActivitySpace space = null;
    protected MockPTSession userSession = null;
    public PTDocFoldersTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      testObject = new PTDocFolders();
      space = new BaseOpenerAS();
      userSession = new MockPTSession();
      space.SetUserSession(userSession);
      IApplication application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      XPHashtable htLookupTable = new XPHashtable();
      htLookupTable.PutElement(PT_CLASSIDS.PT_CATALOGFOLDER_ID + "", DIRECTORYFOLDER_KEYWORD);
      IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
      friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
      application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER,
       friendlyURLManager);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      testObject = null;
      space = null;
      userSession = null;
    }
    
    /// <summary>
    /// Test for url with just directory folder name
    /// </summary>
    public virtual void testGetRedirectViewObjectDocumentName()
    {
      // setup the mock object data
      int directoryId = 300;
      MockPTCatalog.setDirectoryMapping("Directory Folder", new int[]{directoryId});
      // setup mock tokenzier
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/directory_folder",
       "/", false);
      IFriendlyURLParser fURLParser = new FriendlyURLParser(DIRECTORYFOLDER_KEYWORD,
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
      // test
      Redirect redirect = testObject.GetRedirectViewObject(fURLParser, space,
       userSession);
      // check result
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTDocFolders.DIRECTORY_ASNAME);
      String dirId = redirect.GetControlArgument(PTDocFolders.DIRECTORY_PARAM_FOLDERID);
      Assert.assertEquals("Redirect object has the wrong directory Id.", XPConvert.ToInteger(dirId),
       directoryId);
    }
    
    /// <summary>
    /// Test for url with just directory folder name and id
    /// </summary>
    public virtual void testGetRedirectViewObjectDocumentNameAndId()
    {
      String strName = "Directory Folder";
      String strNormalizedName = FriendlyURL.NormalizeObjectName(strName);
      // setup the mock object data
      int directoryId = 300;
      // ROB: Object names are "normalized" to all lower case and space becomes _ in constructed urls
      MockPTCatalog.setDirectoryMapping(strName, new int[]{directoryId});
      // setup mock tokenizer
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + strNormalizedName + "/" + directoryId,
       "/", false);
      IFriendlyURLParser fURLParser = new FriendlyURLParser(DIRECTORYFOLDER_KEYWORD,
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
      // test
      Redirect redirect = testObject.GetRedirectViewObject(fURLParser, space,
       userSession);
      // check result
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTDocFolders.DIRECTORY_ASNAME);
      String dirId = redirect.GetControlArgument(PTDocFolders.DIRECTORY_PARAM_FOLDERID);
      Assert.assertEquals("Redirect object has the wrong directory Id.", XPConvert.ToInteger(dirId),
       directoryId);
    }
    
    /// <summary>
    /// Test for url with duplicate directory folder name  
    /// </summary>
    public virtual void testGetRedirectViewObjectDuplicateDocumentName()
    {
      String origDirName = "Folder";
      String strNormalizedName = FriendlyURL.NormalizeObjectName(origDirName);
      // setup the mock object data
      int directoryId1 = 300;
      int directoryId2 = 302;
      MockPTCatalog.setDirectoryMapping(origDirName, new int[]{directoryId1,
       directoryId2});
      // setup mock tokenzier
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + strNormalizedName,
       "/", false);
      IFriendlyURLParser fURLParser = new FriendlyURLParser(DIRECTORYFOLDER_KEYWORD,
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
      // test
      Redirect redirect = testObject.GetRedirectViewObject(fURLParser, space,
       userSession);
      // check result
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, "SearchResult");
      String dirName = redirect.GetControlArgument(SearchResultControl.USER_QUERY);
      // control arguments are lower cased
      Assert.assertEquals("Redirect object has the wrong directory name for search query.",
       dirName, XPStringUtility.ToLowerCase(origDirName));
    }
    
    /// <summary>
    /// Test for constructing a friendly URL
    /// </summary>
    public virtual void testURLConstruction()
    {
      int directoryId = 300;
      String directoryName = "My Directory Folder";
      MockPTCatalog.setDirectoryMapping(directoryName, new int[]{directoryId});
      FriendlyURL url = new FriendlyURL(PT_CLASSIDS.PT_CATALOGFOLDER_ID, 300);
      String strURL = testObject.ConstructFriendlyURL(url, space);
      Assert.assertEquals("/" + DIRECTORYFOLDER_KEYWORD + "/" + FriendlyURL.NormalizeObjectName(directoryName) + "/" + 300,
       strURL);
    }
    // object ids disabled code
    // Assert.assertEquals("/"+DIRECTORYFOLDER_KEYWORD+"/"+FriendlyURL.NormalizeObjectName(directoryName), strURL);
    
    /// <summary>
    /// Test with special characters
    /// </summary>
    public virtual void testGetRedirectViewObjectWithSpecialCharacters()
    {
      int origDocId = 300;
      MockPTCatalog.setDirectoryMapping(PTCommunitiesTest.SPECIALCHARS_NORMALIZED_STRING,
       new int[]{origDocId});
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + PTCommunitiesTest.SPECIALCHARS_NORMALIZED_STRING + "/",
       "/", false);
      KDFriendlyURLParser cfURLParser = new KDFriendlyURLParser("directory",
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, space,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTDocFolders.DIRECTORY_ASNAME);
      String docId = redirect.GetControlArgument(PTDocFolders.DIRECTORY_PARAM_FOLDERID);
      Assert.assertEquals("Redirect object has the wrong document folder Id.",
       origDocId, XPConvert.ToInteger(docId));
    }
  }
}