using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.friendlyurl;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using com.plumtree.server.mock.directory;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes
{
  public class PTDocumentsTest : TestCase
  {
    protected int documentId = 200;
    protected PTDocuments testObject = null;
    protected AActivitySpace asParent = null;
    protected MockPTSession userSession = null;
    protected String documentName = "Document Name.doc";
    public PTDocumentsTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      testObject = new PTDocuments();
      asParent = new BaseOpenerAS();
      userSession = new MockPTSession();
      asParent.SetUserSession(userSession);
      // DCA - set up MockPTCatalog
      int[] arrResult = new int[]{documentId};
      MockPTCatalog.setDocumentMapping(documentName, arrResult);
      IApplication application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      XPHashtable htLookupTable = new XPHashtable();
      htLookupTable.PutElement(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID),
       "document");
      IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
      friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
      application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER,
       friendlyURLManager);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      testObject = null;
      asParent = null;
      userSession = null;
    }
    
    /// <summary>
    /// DCA - test to handle document name
    /// </summary>
    public virtual void testGetRedirectViewObjectDocumentName()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/document name.doc/",
       "/", false);
      IFriendlyURLParser fURLParser = new DocumentFriendlyURLParser("document",
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTDocuments.DOCUMENT_AS_NAME);
      String docId = redirect.GetControlArgument(PTDocuments.STR_CARD_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(docId),
       documentId);
    }
    
    /// <summary>
    /// DCA - test to handle document Id
    /// </summary>
    public virtual void testGetRedirectViewObjectDocumentId()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + documentId + "/document name.doc/",
       "/", false);
      IFriendlyURLParser fURLParser = new DocumentFriendlyURLParser("document",
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTDocuments.DOCUMENT_AS_NAME);
      String docId = redirect.GetControlArgument(PTDocuments.STR_CARD_ID);
      Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(docId),
       documentId);
    }
    
    /// <summary>
    /// DCA - test to handle when a document is not found
    /// </summary>
    public virtual void testGetRedirectViewObjectNotFound()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/doc name/",
       "/", false);
      IFriendlyURLParser fURLParser = new DocumentFriendlyURLParser("document",
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       activityspace, PTDocuments.SEARCH_AS_NAME);
      String communityName = redirect.GetControlArgument(SearchResultControl.USER_QUERY);
      Assert.assertEquals("Redirect object has the wrong search query.", "doc name",
       communityName);
    }
    
    /// <summary>
    /// DCA - test ConstructFriendlyURL method
    /// </summary>
    public virtual void testConstructFriendlyURL()
    {
      FriendlyURL url = new FriendlyURL(PT_CLASSIDS.PT_CATALOGCARD_ID, documentId);
      String strURL = testObject.ConstructFriendlyURL(url, asParent);
      String strExpected = "/document/" + documentId + "/" + XPHttpUtility.UrlEncode(FriendlyURL.NormalizeObjectName(documentName),
       LinkConstants.UTF_8_ENCODING);
      Assert.assertEquals("URL constructed does not match expected.", strExpected,
       strURL);
    }
  }
}