using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using IFriendlyURLManager=com.plumtree.portaluiinfrastructure.classtypedescriptors.IFriendlyURLManager;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using MockApplicationManager=com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockApplicationManager;
using MockClassTypeDescManager=com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockClassTypeDescManager;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using Redirect=com.plumtree.uiinfrastructure.activityspace.Redirect;
using AppWarmUp=com.plumtree.uiinfrastructure.application.AppWarmUp;
using AppConstants=com.plumtree.uiinfrastructure.application.varpacks.AppConstants;
using BaseOpenerAS=com.plumtree.uiinfrastructure.opener.BaseOpenerAS;
using Application=com.plumtree.uiinfrastructure.web.Application;
using ApplicationManager=com.plumtree.uiinfrastructure.web.ApplicationManager;
using IApplication=com.plumtree.uiinfrastructure.web.IApplication;
namespace com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes
{
  public class PTMyPagesTest : TestCase
  {
    protected int communityId = 200;
    protected int pageId = 300;
    protected PTMyPages testObject = null;
    protected AActivitySpace asParent = null;
    protected MockPTSession userSession = null;
    public PTMyPagesTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      testObject = new PTMyPages();
      asParent = new BaseOpenerAS();
      userSession = new MockPTSession();
      asParent.SetUserSession(userSession);
      IApplication application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      XPHashtable htLookupTable = new XPHashtable();
      htLookupTable.PutElement(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID + "", "mypage");
      IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
      friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
      application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER,
       friendlyURLManager);
      int[] columns = {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME};
      Object[][] data = {new Object[]{200, "another page"}, new Object[]{pageId,
       "Test Page"}};
      // False means the data needs to be flipped.
      MockPTQueryResult.SetStaticData(columns, data, false);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      testObject = null;
      asParent = null;
      userSession = null;
      MockPTQueryResult.ClearStaticData();
    }
    public virtual void testConstructFriendlyURLWithPageName()
    {
      String pageName = "Test Page";
      FriendlyURL furl = new FriendlyURL(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID,
       500);
      furl.SetObjectName(pageName);
      furl.SetObjectId(pageId);
      String urlString = testObject.ConstructFriendlyURL(furl, asParent);
      assertEquals(urlString, "/mypage/test_page/" + pageId);
    }
    // object ids disabled
    //assertEquals(urlString, "/mypage/test_page");
    public virtual void testConstructFriendlyURLWithOutPageName()
    {
      FriendlyURL furl = new FriendlyURL(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID,
       500);
      furl.SetObjectId(pageId);
      String urlString = testObject.ConstructFriendlyURL(furl, asParent);
      assertEquals(urlString, "/mypage/test_page/" + pageId);
    }
    // object ids disabled
    //assertEquals(urlString, "/mypage/test_page");
    public virtual void testConstructFriendlyURLDefaultPageId()
    {
      FriendlyURL furl = new FriendlyURL(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID,
       500);
      furl.SetObjectId(0);
      String urlString = testObject.ConstructFriendlyURL(furl, asParent);
      assertEquals(urlString, "/mypage/another_page/" + 0);
    }
    // object ids disabled
    //assertEquals(urlString, "/mypage/another_page");
    public virtual void testGetRedirectViewObject()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/test_page/",
       "/", false);
      IFriendlyURLParser fURLParser = new FriendlyURLParser("mypage", XPConvert.ToString(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID),
       stURLTokens);
      Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent,
       userSession);
      String activityspace = redirect.GetSpaceName();
      Assert.assertTrue("Redirect object has the wrong activity space name.",
       XPStringUtility.EqualsIgnoreCase(activityspace, "mypage"));
      String id = redirect.GetControlArgument(PTMyPages.STR_PAGE_ID);
      Assert.assertTrue("Redirect object has the wrong object Id.", pageId == XPConvert.ToInteger(id));
      }
  }
}