using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using IFriendlyURLManager=com.plumtree.portaluiinfrastructure.classtypedescriptors.IFriendlyURLManager;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using MockApplicationManager=com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockApplicationManager;
using MockClassTypeDescManager=com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockClassTypeDescManager;
using com.plumtree.portaluiinfrastructure.mock.tags;
using PT_CLASSIDS=com.plumtree.server.PT_CLASSIDS;
using PT_INTRINSICS=com.plumtree.server.PT_INTRINSICS;
using com.plumtree.server.mock.community;
using com.plumtree.server.mock.core;
using Redirect=com.plumtree.uiinfrastructure.activityspace.Redirect;
using AppWarmUp=com.plumtree.uiinfrastructure.application.AppWarmUp;
using AppConstants=com.plumtree.uiinfrastructure.application.varpacks.AppConstants;
using Application=com.plumtree.uiinfrastructure.web.Application;
using ApplicationManager=com.plumtree.uiinfrastructure.web.ApplicationManager;
using IApplication=com.plumtree.uiinfrastructure.web.IApplication;
namespace com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes
{
  public class PTUserTestFriendlyURLs : TestCase
  {
    public MockEnvironment m_space = null;
    public MockPTSession m_session = null;
    protected PTUsers testObject = null;
    private const String SLASH = "/";
    private const String KEYWORD = "user";
    private const String CLASS_ID = "1";
    public const String SEARCH_AS_NAME = "SearchResult";
    public const String SEARCH_CONTROL_NAME = "advancedstart";
    public const String SEARCH_USER_QUERY = "in_tx_query";
    public const String SEARCH_REQD_OBJECT_TYPE = "in_hi_req_objtype";
    public const String USER_URL_PREFIX = "/user/";
    public const String ADMIN_NAME = "administrator";
    public const int PAGE_ID = 301;
    public const String PAGE_NAME = "page name";
    public PTUserTestFriendlyURLs(String name) : base(name)
    {
    }
    public override void setUp()
    {
      testObject = new PTUsers();
      m_session = new MockPTSession();
      m_space = new MockEnvironment();
      m_space.SetUserSession(m_session);
      IApplication application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      XPHashtable htLookupTable = new XPHashtable();
      htLookupTable.PutElement(XPConvert.ToString(PT_CLASSIDS.PT_USER_ID),
       "user");
      IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
      friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
      application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER,
       friendlyURLManager);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      testObject = null;
      m_space = null;
      m_session = null;
    }
    private UserFriendlyURLParser getParser(String strFriendlyURL)
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer(strFriendlyURL,
       SLASH, false);
      UserFriendlyURLParser userFriendlyURLParser = new UserFriendlyURLParser(KEYWORD,
       CLASS_ID, stURLTokens);
      return userFriendlyURLParser;
    }
    
    /// <summary>
    /// Test url /portal/server.pt/user/administrator/1
    /// Test should try to open community 2 with id 1
    /// </summary>
    public virtual void testFriendlyURLRedirectWithUserIDAndName()
    {
      String strURL = "/administrator/1";
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", PT_INTRINSICS.PT_USER_SYSADMIN,
       XPConvert.ToInteger(profileId));
    }
    
    /// <summary>
    /// Test url /portal/server.pt/user/administrator
    /// Test should try to open community 2 with id 1
    /// Because search is unavailable, this test won't work right
    /// </summary>
    public virtual void testFriendlyURLRedirectWithUserName()
    {
      String strURL = "/administrator";
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", PT_INTRINSICS.PT_USER_SYSADMIN,
       XPConvert.ToInteger(profileId));
    }
    
    /// <summary>
    /// Test url /portal/server.pt/user/matt
    /// Test should try to open search results because MockPTUserManager returns 2 object IDs
    /// Because search is unavailable, this test won't work right
    /// </summary>
    public virtual void testFriendlyURLRedirectWithDupeUserName()
    {
      String strURL = "/matt";
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       SEARCH_AS_NAME, activityspace);
      String cArg = redirect.GetControlArgument(SEARCH_USER_QUERY);
      Assert.assertEquals("Search results not properly set to \'matt\'", "matt",
       cArg);
      String searchType = redirect.GetControlArgument(SEARCH_REQD_OBJECT_TYPE);
      Assert.assertEquals("Search results not properly search for just users.",
       PT_CLASSIDS.PT_USER_ID, XPConvert.ToInteger(searchType));
    }
    
    /// <summary>
    /// Test url /portal/server.pt/admin/999
    /// Test should try to open community 2 with id 999
    /// </summary>
    public virtual void testFriendlyURLRedirectWithBadValue()
    {
      String strURL = "/admin/999";
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", 999,
       XPConvert.ToInteger(profileId));
    }
    
    /// <summary>
    /// Test url /portal/server.pt/administrator/1/foo/notanint
    /// Test should fail gracefully
    /// </summary>
    public virtual void testFriendlyURLRedirectWithBadPageIDFormat()
    {
      String strURL = "/administrator/1/foo/notanint";
      UserFriendlyURLParser ufParser = getParser(strURL);
      // NOTE: Since the page ID is invalid, the PTUser object will try to search for the
      // name, be unable to find it, and revert to the home page.
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", PT_INTRINSICS.PT_USER_SYSADMIN,
       XPConvert.ToInteger(profileId));
      String pageID = redirect.GetControlArgument("PageID");
      // Since we couldn't parse the page ID, it should just default to the home page
      Assert.assertEquals("Redirect object has the wrong page Id.", 0, XPConvert.ToInteger(pageID));
      }
    
    /// <summary>
    /// Test url /portal/server.pt/user/administrator/1/testpage/45
    /// Test should try to open community 2 with id 1 and page 45
    /// </summary>
    public virtual void testFriendlyURLRedirectWithUserIDAndNameAndPageIDAndName()
    {
      String strURL = "/administrator/1/testpage/45";
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", PT_INTRINSICS.PT_USER_SYSADMIN,
       XPConvert.ToInteger(profileId));
      String pageID = redirect.GetControlArgument("PageID");
      Assert.assertEquals("Redirect object has the wrong page Id.", 45, XPConvert.ToInteger(pageID));
      }
    
    /// <summary>
    /// Test url /portal/server.pt/user/administrator/testpage/45
    /// Test should try to open community 2 with id 1 and page 45
    /// </summary>
    public virtual void testFriendlyURLRedirectWithUserNameAndPageIDAndName()
    {
      String strURL = "/administrator/testpage/45";
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", PT_INTRINSICS.PT_USER_SYSADMIN,
       XPConvert.ToInteger(profileId));
      String pageID = redirect.GetControlArgument("PageID");
      Assert.assertEquals("Redirect object has the wrong page Id.", 45, XPConvert.ToInteger(pageID));
      }
    
    /// <summary>
    /// Test url /portal/server.pt/user/administrator/testpage
    /// Test should try to open community 2 with id 1 and page 400
    /// </summary>
    public virtual void testFriendlyURLRedirectWithUserNameAndPageName()
    {
      String strPageName = FriendlyURL.NormalizeObjectName(MockPTCommunityManager.PROFILE_PAGE_NAME);
      String strURL = "/administrator/" + strPageName;
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", PT_INTRINSICS.PT_USER_SYSADMIN,
       XPConvert.ToInteger(profileId));
      String pageID = redirect.GetControlArgument("PageID");
      Assert.assertEquals("Redirect object has the wrong page Id.", MockPTCommunityManager.PROFILE_PAGE_ID,
       XPConvert.ToInteger(pageID));
    }
    
    /// <summary>
    /// Test url /portal/server.pt/user/administrator/1/testpage
    /// Test should try to open community 2 with id 1 and page 400
    /// </summary>
    public virtual void testFriendlyURLRedirectWithUserIDAndNameAndPageName()
    {
      String strPageName = FriendlyURL.NormalizeObjectName(MockPTCommunityManager.PROFILE_PAGE_NAME);
      String strURL = "/administrator/1/" + strPageName;
      UserFriendlyURLParser ufParser = getParser(strURL);
      Redirect redirect = testObject.GetRedirectViewObject(ufParser, m_space,
       m_session);
      String activityspace = redirect.GetSpaceName();
      Assert.assertEquals("Redirect object has the wrong activity space name.",
       PTUsers.COMMUNITY_AS_NAME, activityspace);
      String commId = redirect.GetControlArgument("CommunityID");
      Assert.assertEquals("Redirect object has the wrong community Id.", PT_INTRINSICS.PT_PROFILE_COMMUNITY,
       XPConvert.ToInteger(commId));
      String profileId = redirect.GetControlArgument("ProfileID");
      Assert.assertEquals("Redirect object has the wrong profile Id.", PT_INTRINSICS.PT_USER_SYSADMIN,
       XPConvert.ToInteger(profileId));
      String pageID = redirect.GetControlArgument("PageID");
      Assert.assertEquals("Redirect object has the wrong page Id.", MockPTCommunityManager.PROFILE_PAGE_ID,
       XPConvert.ToInteger(pageID));
    }
    
    /// <summary>
    /// Check basic user URL.
    /// </summary>
    public virtual void testFriendlyURLGeneration()
    {
      FriendlyURL URL = new FriendlyURL(PT_CLASSIDS.PT_USER_ID, ADMIN_NAME,
       PT_INTRINSICS.PT_USER_SYSADMIN);
      String strURL = testObject.ConstructFriendlyURL(URL, null);
      Assert.assertEquals("URL incorrect.", USER_URL_PREFIX + ADMIN_NAME + "/" + PT_INTRINSICS.PT_USER_SYSADMIN,
       strURL);
    }
    
    /// <summary>
    /// Check user URL with page.
    /// </summary>
    public virtual void testFriendlyURLGenerationWithPage()
    {
      FriendlyURL URL = new FriendlyURL(PT_CLASSIDS.PT_USER_ID, ADMIN_NAME,
       PT_INTRINSICS.PT_USER_SYSADMIN);
      URL.SetChildId(PAGE_ID);
      URL.SetChildName(PAGE_NAME);
      String strURL = testObject.ConstructFriendlyURL(URL, null);
      Assert.assertEquals("URL incorrect.", USER_URL_PREFIX + ADMIN_NAME + "/" + PT_INTRINSICS.PT_USER_SYSADMIN + "/" + FriendlyURL.NormalizeObjectName(PAGE_NAME) + "/" + PAGE_ID,
       strURL);
    }
  }
}