using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.test.friendlyurl
{
  public class FriendlyGatewayURLFilterTest : TestCase
  {
    protected String FURL_KEYWORD_GATEWAY = "gw";
    protected String FURL_TYPEID_GATEWAY = "-1";
    protected String PORTLET_PREFIX = "pt";
    protected String WEBSERVICE_PREFIX = "ws";
    protected String BASEURL = "http://servername:8080/portal/server.pt";
    protected IFriendlyURLParserManager m_testMan = null;
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      // friendly url mapping setup
      XPHashtable htKeyToClassIdLookup = new XPHashtable();
      htKeyToClassIdLookup.PutElement(FURL_KEYWORD_GATEWAY, FURL_TYPEID_GATEWAY);
      m_testMan = FriendlyURLParserManager.getInstance();
      m_testMan.SetKeyToClassIdLookupTable(htKeyToClassIdLookup);
      // set up mock config helper 
      ConfigService.setTestInstance(new MockConfigHelper());
      // Set up mock application with friendly url mgr containing friendly gateway url keyword
      Application application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      XPHashtable htLookupTable = new XPHashtable();
      htLookupTable.PutElement(FriendlyURLConstants.FRIENDLY_GATEWAY_URL + "",
       "gw");
      IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
      friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
      application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER,
       friendlyURLManager);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
    }
    public virtual void testArgs()
    {
      GatewayFriendlyURLFilter filter = new GatewayFriendlyURLFilter();
      String friendlyGatewayUrl;
      String testUrl = null;
      String compareUrl = null;
      // webservice type w/o trailing slash
      friendlyGatewayUrl = BASEURL + "/gw/" + WEBSERVICE_PREFIX + "4000";
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 4000,
       0, 0, 0, PT_CLASSIDS.PT_WEBSERVICE_ID, 0, "");
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " found: " + testUrl + "\n",
       compareUrl, testUrl);
      // portlet type w/ trailing slash
      friendlyGatewayUrl = BASEURL + "/gw/" + PORTLET_PREFIX + "200/";
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 200,
       0, 0, 0, PT_CLASSIDS.PT_GADGET_ID, 0, "");
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " found: " + testUrl + "\n",
       compareUrl, testUrl);
      // with community and page arguments
      friendlyGatewayUrl = BASEURL + "/gw/" + PORTLET_PREFIX + "200_c200_p400/";
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 200,
       200, 400, 0, PT_CLASSIDS.PT_GADGET_ID, 0, "");
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " found: " + testUrl + "\n",
       compareUrl, testUrl);
      // with portlet preference type argument 
      friendlyGatewayUrl = BASEURL + "/gw/" + PORTLET_PREFIX + "200_r8/";
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 200,
       0, 0, 8, PT_CLASSIDS.PT_GADGET_ID, 0, "");
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " found: " + testUrl + "\n",
       compareUrl, testUrl);
      // with user id  
      friendlyGatewayUrl = BASEURL + "/gw/" + PORTLET_PREFIX + "200_r8_u40111/";
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 200,
       0, 0, 8, PT_CLASSIDS.PT_GADGET_ID, 40111, "");
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " found: " + testUrl + "\n",
       compareUrl, testUrl);
    }
    public virtual void testPaths()
    {
      GatewayFriendlyURLFilter filter = new GatewayFriendlyURLFilter();
      String friendlyGatewayUrl;
      String testUrl = null;
      String compareUrl = null;
      // with gateway path w/o baseurl
      String gatewayPath = "path1/path2/path3";
      friendlyGatewayUrl = BASEURL + "/gw/" + PORTLET_PREFIX + "200_c200_p400/" + gatewayPath;
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 200,
       200, 400, 0, PT_CLASSIDS.PT_GADGET_ID, 0, gatewayPath);
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " found: " + testUrl + "\n",
       compareUrl, testUrl);
      // with gateway path and query string
      String qstring = "?param1=value1&param2=value2&param3=value3";
      friendlyGatewayUrl = BASEURL + "/gw/ws2342/" + gatewayPath + qstring;
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 2342,
       0, 0, 0, PT_CLASSIDS.PT_WEBSERVICE_ID, 0, gatewayPath) + qstring;
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " Found:" + testUrl + "!\n",
       compareUrl, testUrl);
      // with gateway path w baseurl
      gatewayPath = "http://servername:9999/" + gatewayPath;
      // simulate the url being encoded 
      friendlyGatewayUrl = BASEURL + "/gw/ws2342/" + GatewayHelpers.CreateGatewayFriendlyURL(gatewayPath);
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      testUrl = GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY);
      compareUrl = GatewayHelpers.ConstructRegularGatewayURL(BASEURL, 2342,
       0, 0, 0, PT_CLASSIDS.PT_WEBSERVICE_ID, 0, gatewayPath);
      Assert.assertEquals("Generated gateway Url doesn\'t match. Expected: " + compareUrl + " Found:" + testUrl + "!\n",
       compareUrl, testUrl);
    }
    public virtual void testError()
    {
      // missing portlet/webservice id
      String friendlyGatewayUrl = BASEURL + "/gw/c200_p400/";
      Assert.assertEquals(GatewayHelpers.IsFriendlyGatewayURL(friendlyGatewayUrl,
       FURL_KEYWORD_GATEWAY), true);
      try
      {
        GatewayHelpers.ConvertToRegularGatewayURL(friendlyGatewayUrl, FURL_KEYWORD_GATEWAY);
        }
      catch (XPException e)
      {
        Assert.assertFalse("No exceptions are allowed from this method, should generate a url that fails in GatewayHandler.",
         true);
      }
    }
  }
}