using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.friendlyurl;
namespace com.plumtree.portaluiinfrastructure.test.friendlyurl
{
  public class RSSFriendlyURLParserTest : TestCase
  {
    protected RSSFriendlyURLParser testObject;
    protected String objectName = "object name";
    protected String objectNameNormalized = "object_name";
    protected int objectId = 200;
    
    /// <param name="name"></param>
    public RSSFriendlyURLParserTest(String name) : base(name)
    {
    }
    /* (non-Javadoc)
     * @see junit.framework.TestCase#setUp()
     */
     
    public override void setUp()
    {
      base.setUp();
    }
    /* (non-Javadoc)
     * @see junit.framework.TestCase#tearDown()
     */
     
    public override void tearDown()
    {
      base.tearDown();
    }
    
    /// <summary>
    /// Test parsing of a RSS KD Friendly URL. 
    /// </summary>
    public virtual void testGetKDObjectNameAndId()
    {
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/kd/directory/" + objectNameNormalized + "/" + objectId,
       "/", false);
      testObject = new RSSFriendlyURLParser("rss", XPConvert.ToString(FriendlyURLConstants.FRIENDLY_RSS_ID),
       stURLTokens);
      String name = testObject.GetObjectName(true);
      Assert.assertEquals("Wrong name was returned.", name, objectName);
      int id = testObject.GetObjectId();
      Assert.assertEquals("Wrong id was returned.", id, objectId);
    }
    
    /// <summary>
    /// Test parsing of a RSS Search Results Friendly URL.
    /// </summary>
    public virtual void testGetSearchResultsObjectNameAndId()
    {
      // Go through parser with search keyword and object id
      XPStringTokenizer stURLTokens = new XPStringTokenizer("/searchresults/search/" + objectId,
       "/", false);
      testObject = new RSSFriendlyURLParser("rss", XPConvert.ToString(FriendlyURLConstants.FRIENDLY_RSS_ID),
       stURLTokens);
      String name = testObject.GetObjectName(true);
      Assert.assertEquals("Wrong name was returned.", name, "searchresults");
      int id = testObject.GetObjectId();
      Assert.assertEquals("Wrong id was returned.", id, objectId);
      // Go through parser again without search object id in the URL
      stURLTokens = new XPStringTokenizer("/searchresults/search", "/", false);
      testObject = new RSSFriendlyURLParser("rss", XPConvert.ToString(FriendlyURLConstants.FRIENDLY_RSS_ID),
       stURLTokens);
      name = testObject.GetObjectName(true);
      Assert.assertEquals("Wrong name was returned.", name, "searchresults");
      id = testObject.GetObjectId();
      Assert.assertEquals("Wrong id was returned.", id, 0);
    }
  }
}