using System;
using junit.framework;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.server;
using com.plumtree.server.mock.core;
namespace com.plumtree.portaluiinfrastructure.test.layout
{
  public class LayoutChooserTest : TestCase
  {
    public MockPTConfigHelper m_helper;
    public ILayoutChooser m_chooser;
    public MockEnvironment m_environment;
    public const String FIRST_WS_NAME = "First Test Web Service";
    public const String FIRST_WS_DESC = "This is a test web service.";
    public const int FIRST_WS_ID = 1;
    public const String SECOND_WS_NAME = "Second Test Web Service";
    public const String SECOND_WS_DESC = "This is another test web service.";
    public const int SECOND_WS_ID = 41;
    public const String THIRD_WS_NAME = "Third Test Web Service";
    public const String THIRD_WS_DESC = "This is yet a third test web service.";
    public const int THIRD_WS_ID = 1276;
    public override void setUp()
    {
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      m_chooser = LayoutService.getChooserInstance();
      m_environment = new MockEnvironment();
    }
    public virtual void testLayoutDisabledGlobally()
    {
      // Disable globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "0");
      int nID = m_chooser.GetLayoutWebService(Layouts.BASE_PAGE, m_environment);
      assertEquals("Layouts should be disabled globally.", -1, nID);
    }
    public virtual void testLayoutDefaults()
    {
      MockPTSubPortalInfo info = (MockPTSubPortalInfo) ((IPTSession) m_environment.GetUserSession()).GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
      // Enable for the current experience definition
      info.SetLayoutEnabled(true);
      // Enable globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      int nID = m_chooser.GetLayoutWebService(Layouts.BASE_PAGE, m_environment);
      assertEquals("Default Base Page Layout should be Base Page.", PT_INTRINSICS.PT_WEBSERVICE_BASE_PAGE_LAYOUT,
       nID);
      nID = m_chooser.GetLayoutWebService(Layouts.PORTLET, m_environment);
      assertEquals("Default Portlet Layout should be Portlet.", -1, nID);
      nID = m_chooser.GetLayoutWebService(Layouts.KNOWLEDGE_DIRECTORY, m_environment);
      assertEquals("Default Knowledge Directory Layout should be Knowledge Directory.",
       PT_INTRINSICS.PT_WEBSERVICE_KNOWLEDGE_DIRECTORY_LAYOUT, nID);
    }
    public virtual void testLayoutPerXD()
    {
      // Enable globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      MockPTSubPortalInfo info = (MockPTSubPortalInfo) ((IPTSession) m_environment.GetUserSession()).GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
      // Enable for the current experience definition
      info.SetLayoutEnabled(true);
      int nID = m_chooser.GetLayoutWebService(Layouts.BASE_PAGE, m_environment);
      assertEquals("Layouts should be enabled for this Experience Definition.",
       PT_INTRINSICS.PT_WEBSERVICE_BASE_PAGE_LAYOUT, nID);
      // Disable for the current experience definition
      info.SetLayoutEnabled(false);
      nID = m_chooser.GetLayoutWebService(Layouts.BASE_PAGE, m_environment);
      assertEquals("Layouts should be disabled for this Experience Definition.",
       -1, nID);
    }
    public virtual void testGetAvailableLayoutSingle()
    {
      SetTestQueryData(1);
      IPTQueryResult result = m_chooser.GetAvailableWebServices(Layouts.BASE_PAGE,
       m_environment);
      assertEquals("Checking number of available base page web services.",
       1, result.RowCount());
      assertEquals("Checking ID of first result.", FIRST_WS_ID, result.ItemAsInt(0,
       PT_PROPIDS.PT_PROPID_OBJECTID));
      assertEquals("Checking name of first result.", FIRST_WS_NAME, result.ItemAsString(0,
       PT_PROPIDS.PT_PROPID_NAME));
      assertEquals("Checking description of first result.", FIRST_WS_DESC,
       result.ItemAsString(0, PT_PROPIDS.PT_PROPID_DESCRIPTION));
      ClearTestQueryData();
    }
    public virtual void testGetAvailableLayoutMultiple()
    {
      SetTestQueryData(3);
      IPTQueryResult result = m_chooser.GetAvailableWebServices(Layouts.BASE_PAGE,
       m_environment);
      assertEquals("Checking number of available base page web services.",
       3, result.RowCount());
      assertEquals("Checking ID of first result.", FIRST_WS_ID, result.ItemAsInt(0,
       PT_PROPIDS.PT_PROPID_OBJECTID));
      assertEquals("Checking name of first result.", FIRST_WS_NAME, result.ItemAsString(0,
       PT_PROPIDS.PT_PROPID_NAME));
      assertEquals("Checking description of first result.", FIRST_WS_DESC,
       result.ItemAsString(0, PT_PROPIDS.PT_PROPID_DESCRIPTION));
      assertEquals("Checking ID of second result.", SECOND_WS_ID, result.ItemAsInt(1,
       PT_PROPIDS.PT_PROPID_OBJECTID));
      assertEquals("Checking name of second result.", SECOND_WS_NAME, result.ItemAsString(1,
       PT_PROPIDS.PT_PROPID_NAME));
      assertEquals("Checking description of second result.", SECOND_WS_DESC,
       result.ItemAsString(1, PT_PROPIDS.PT_PROPID_DESCRIPTION));
      assertEquals("Checking ID of third result.", THIRD_WS_ID, result.ItemAsInt(2,
       PT_PROPIDS.PT_PROPID_OBJECTID));
      assertEquals("Checking name of third result.", THIRD_WS_NAME, result.ItemAsString(2,
       PT_PROPIDS.PT_PROPID_NAME));
      assertEquals("Checking description of third result.", THIRD_WS_DESC,
       result.ItemAsString(2, PT_PROPIDS.PT_PROPID_DESCRIPTION));
      ClearTestQueryData();
    }
    
    /// <param name="_nSize">how many items you want in the result.  0-3</param>
    public virtual void SetTestQueryData(int _nSize)
    {
      int[] columns = {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME,
       PT_PROPIDS.PT_PROPID_DESCRIPTION};
      Object[][] data = new Object[_nSize][];
      for (int j2c_index = 0;j2c_index < _nSize;j2c_index++)
      {
        data[j2c_index] = new Object[3];
      }
      if (_nSize >= 1)
      {
        data[0][0] = FIRST_WS_ID;
        data[0][1] = FIRST_WS_NAME;
        data[0][2] = FIRST_WS_DESC;
      }
      if (_nSize >= 2)
      {
        data[1][0] = SECOND_WS_ID;
        data[1][1] = SECOND_WS_NAME;
        data[1][2] = SECOND_WS_DESC;
      }
      if (_nSize >= 3)
      {
        data[2][0] = THIRD_WS_ID;
        data[2][1] = THIRD_WS_NAME;
        data[2][2] = THIRD_WS_DESC;
      }
      // False means the data needs to be flipped.
      MockPTQueryResult.SetStaticData(columns, data, false);
    }
    public virtual void ClearTestQueryData()
    {
      MockPTQueryResult.ClearStaticData();
    }
  }
}