using System;
using junit.framework;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.portaluiinfrastructure.test.tags;
using com.plumtree.server;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.test.layout
{
  public class LayoutDisplayTest : TestCase
  {
    public const String TEST_HTML_PREFIX = "<html><head/><body>";
    public const String TEST_HTML_CONTENT = "This is a test page.";
    public const String TEST_HTML_SUFFIX = "</body></html>";
    public const String TEST_TAG = "testtag";
    public const String TEST_LIBRARY = "testlibrary";
    public const String TEST_VALUE = "test value";
    public ILayoutDisplay m_layoutDisplay;
    public MockEnvironment m_MockSpace;
    public override void setUp()
    {
      m_layoutDisplay = LayoutService.getFactoryInstance().CreateDisplay();
      m_MockSpace = new MockEnvironment();
      MockTagLibManager manager = new MockTagLibManager();
      manager.SetTag(new TestSimpleTag(), TEST_TAG, TEST_LIBRARY);
      TagLibManager.setTestInstance(manager);
    }
    public virtual void testHTML()
    {
      Object[][] fragments = new Object[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS][];
      for (int j2c_index = 0;j2c_index < PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS;
      j2c_index++)
      {
        fragments[j2c_index] = new Object[3];
      }
      int i = 0;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_PREFIX;
      i++;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_CONTENT;
      i++;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_SUFFIX;
      i++;
      HTMLElement result = m_layoutDisplay.ProcessLayout(fragments, m_MockSpace);
      assertEquals("Checking transformed simple HTML content.", TEST_HTML_PREFIX + TEST_HTML_CONTENT + TEST_HTML_SUFFIX,
       result.GetDisplayString());
    }
    public virtual void testTagTransformation()
    {
      Object[][] fragments = new Object[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS][];
      for (int j2c_index = 0;j2c_index < PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS;
      j2c_index++)
      {
        fragments[j2c_index] = new Object[3];
      }
      int i = 0;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_PREFIX;
      i++;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] valueTagXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT, PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE},
       new Object[]{TEST_LIBRARY + "." + TEST_TAG, TestSimpleTag.TESTATTRIBUTE.GetName(),
       null}, new Object[]{null, TEST_VALUE, null}};
      // Add a singleton tag
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = valueTagXML;
      i++;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_SUFFIX;
      i++;
      HTMLElement result = m_layoutDisplay.ProcessLayout(fragments, m_MockSpace);
      assertEquals("Checking transformed tag content.", TEST_HTML_PREFIX + TEST_VALUE + TEST_HTML_SUFFIX,
       result.GetDisplayString());
    }
  }
}