using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using com.plumtree.server.mock.webservice;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portaluiinfrastructure.test.layout
{
  public class LayoutManagerTest : TestCase
  {
    private AActivitySpace m_MockSpace;
    private int m_nWebServiceId;
    private Object[][] m_objResult;
    private MockWebServiceProvider m_wsProvider;
    public override void setUp()
    {
      // Set the Layout Service to test mode, but to use a real LayoutManager.
      LayoutService.setManagerTestInstance(null);
      m_nWebServiceId = 40;
      MockWebServiceInfo wsInfo = new MockWebServiceInfo(m_nWebServiceId);
      m_objResult = new Object[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS][];
      for (int j2c_index = 0;j2c_index < PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS;
      j2c_index++)
      {
        m_objResult[j2c_index] = new Object[2];
      }
      m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0] = "mock markup";
      m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1] = "array data";
      m_wsProvider = new MockWebServiceProvider();
      m_wsProvider.m_HTMLText = m_objResult;
      // CR DLH: Setting static information on the mock web svc mgr could lead to
      // a situation where another test uses a new mgr, expecting it to be empty, but gets
      // data from this test.  I would prefer if you got the actual instance of the mgr from
      // the new mock pt session and set the data on that so there was no possibility of test
      // contamination/dependencies.  They're super hard to track down.
      // DCA - I do reset the info below in the tearDown() method so that everything is cleared at the end of each test
      // The reason I did it this way is that I didn't want to change the way the IPTSession works in that every time
      // an object manager is retrieved, it creates a new one.
      MockPTWebServiceManager.m_htWSInfos.PutElement(XPConvert.ToString(m_nWebServiceId),
       wsInfo);
      MockPTWebServiceManager.m_htWSProviders.PutElement(XPConvert.ToString(m_nWebServiceId),
       m_wsProvider);
      MockPTSession session = new MockPTSession();
      m_MockSpace = new MockEnvironment();
      m_MockSpace.SetUserSession(session);
      AppDataObjectFactory.SetTestInstance(new MockAppDataObjectFactory());
      }
    public override void tearDown()
    {
      MockPTWebServiceManager.m_htWSInfos = new XPHashtable();
      MockPTWebServiceManager.m_htWSProviders = new XPHashtable();
      m_MockSpace = null;
      m_nWebServiceId = 0;
      m_objResult = null;
      AppDataObjectFactory.SetTestInstance(null);
    }
    public virtual void testGetLayout()
    {
      // NOTE: Make sure we initialize the service to test mode, but with
      // a real Manager, otherwise this will set it to production mode for all the tests.
      ILayoutManager layoutManager = LayoutService.getManagerInstance();
      Object[][] layout = layoutManager.GetLayout(m_nWebServiceId, m_MockSpace);
      Assert.assertEquals("Incorrect layout type returned for first item.",
       m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0], layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0]);
      Assert.assertEquals("Incorrect layout data returned for first item.",
       m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0],
       layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0]);
      Assert.assertEquals("Incorrect layout type returned for second item.",
       m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1], layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1]);
      Assert.assertEquals("Incorrect layout data returned for second item.",
       m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1],
       layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1]);
    }
    public virtual void testGetLayoutCached()
    {
    }
  }
}
// NOTE: Make sure we initialize the service to test mode, but with
// a real Manager, otherwise this will set it to production mode for all the tests.
// DCA - commenting out this test for now since we don't want to cache layouts indefinitely
/*ILayoutManager layoutManager = LayoutService.getManagerInstance();
 
 Object[][] layout = layoutManager.GetLayout(m_nWebServiceId, m_MockSpace);
 
 String oldValue = (String) m_wsProvider.m_HTMLText[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0];
 
 // DCA - we are now going to change the value of the layout in the provider;
 // this is simulating the customer changing the xml layout file, but the cache hasn't timed out
 // so what we'll get is the old cached version
 String changedValue = "new value";
 m_wsProvider.m_HTMLText[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0] = changedValue;
 
 layout = layoutManager.GetLayout(m_nWebServiceId, m_MockSpace);
 Assert.assertEquals("Incorrect layout type returned for first item.",
 m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0],
 layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0]);
 // DCA - this should be the old value since we changed the xml layout and comparing it to the cache version.
 Assert.assertEquals("Incorrect layout data returned for first item. Should be modified data.",
 oldValue,
 layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0]);
 Assert.assertEquals("Incorrect layout type returned for second item.",
 m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1],
 layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1]);
 Assert.assertEquals("Incorrect layout data returned for second item.",
 m_objResult[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1],
 layout[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1]);*/
 
