using System;
using XPConvert=com.plumtree.openfoundation.util.XPConvert;
using XPHashtable=com.plumtree.openfoundation.util.XPHashtable;
using MockTaggingModel=com.plumtree.portaluiinfrastructure.mock.pathways.tagging.MockTaggingModel;
using TaggingControl=com.plumtree.portaluiinfrastructure.pathways.tagging.TaggingControl;
using PathwaysConstants=com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysConstants;
using TestCase=junit.framework.TestCase;
namespace com.plumtree.portaluiinfrastructure.test.pathways.tagging
{
  /// <author>Ravi Tunuguntla</author>
  public class TaggingControlTest : TestCase
  {
    /*
     * Tests Adding the tag and verifying if the Tag is added successfully.
     */
     
    public virtual void testAddTag()
    {
      TaggingControl control = new TaggingControl();
      MockTaggingModel model = new MockTaggingModel();
      control.Init(model, null);
      // Adding Tagging Control Args for Processing
      XPHashtable controlArgs = new XPHashtable();
      controlArgs.PutElement(TaggingControl.QS_ACTION, new String[]{XPConvert.ToString(TaggingControl.ACTION_ADD_TAG)});
      controlArgs.PutElement(TaggingControl.QS_TAG, new String[]{"test tag"});
      controlArgs.PutElement(TaggingControl.QS_OBJECTID, new String[]{"18_999"});
      controlArgs.PutElement(TaggingControl.QS_SOURCE, new String[]{PathwaysConstants.PTSOURCE_PORTAL});
      control.CheckActionSecurityAndExecute(controlArgs);
      assertTrue("Adding Tag should be successful", model.m_bTagged);
    }
    /*
     * Tests Adding the tag and verifying if the Tag is Removed successfully.
     */
     
    public virtual void testRemoveTag()
    {
      TaggingControl control = new TaggingControl();
      MockTaggingModel model = new MockTaggingModel();
      control.Init(model, null);
      // Adding Tagging Control Args for Processing
      XPHashtable controlArgs = new XPHashtable();
      controlArgs.PutElement(TaggingControl.QS_ACTION, new String[]{XPConvert.ToString(TaggingControl.ACTION_DELETE_TAG)});
      controlArgs.PutElement(TaggingControl.QS_TAG, new String[]{"test tag"});
      controlArgs.PutElement(TaggingControl.QS_OBJECTID, new String[]{"18_999"});
      controlArgs.PutElement(TaggingControl.QS_SOURCE, new String[]{PathwaysConstants.PTSOURCE_PORTAL});
      control.CheckActionSecurityAndExecute(controlArgs);
      assertTrue("Removing Tag should be successful", model.m_bUnTagged);
      }
    /*
     * Tests Renaming the tag and verifying if the old tag has been renamed to the new tag successfully.
     */
     
    public virtual void testRenameTag()
    {
      TaggingControl control = new TaggingControl();
      MockTaggingModel model = new MockTaggingModel();
      control.Init(model, null);
      // Adding Tagging Control Args for Processing
      XPHashtable controlArgs = new XPHashtable();
      controlArgs.PutElement(TaggingControl.QS_ACTION, new String[]{XPConvert.ToString(TaggingControl.ACTION_RENAME_TAG)});
      controlArgs.PutElement(TaggingControl.QS_TAG, new String[]{"originalTag"});
      controlArgs.PutElement(TaggingControl.QS_OBJECTID, new String[]{"18_999"});
      controlArgs.PutElement(TaggingControl.QS_SOURCE, new String[]{PathwaysConstants.PTSOURCE_PORTAL});
      controlArgs.PutElement(TaggingControl.QS_RENAME_TAG, new String[]{"renamedTag"});
      control.CheckActionSecurityAndExecute(controlArgs);
      assertTrue("Renaming Tag should be successful", model.m_bTagged);
    }
  }
}