using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.server.impl.portlet.providers;
using com.plumtree.server.mock.community;
using com.plumtree.server.mock.webservice;
namespace com.plumtree.portaluiinfrastructure.test.server.portlet.providers
{
  public class PageletProviderConfigTest : TestCase
  {
    internal String[] portletParams = new String[]{"portlet1", "portlet2",
     "portlet3"};
    internal String[] commParams = new String[]{"comm1", "comm2", "comm3"};
    internal String[] adminParams = new String[]{"admin1", "admin2", "admin3"};
    internal String[] portletValues = new String[]{"portletvalue1", "portletvalue2",
     "portletvalue3"};
    internal String[] commValues = new String[]{"commvalue1", "commvalue2",
     "valuevalue3"};
    internal String[] adminValues = new String[]{"adminvalue1", "adminvalue2",
     "adminvalue3"};
    
    /// <summary>
    /// Tests that the pagelet config provider constructs the correct URL to retrieve pagelet content
    /// </summary>
    public virtual void testURL()
    {
      PageletProviderConfig config = new PageletProviderConfig();
      MockPTGadgetContentServer server = new MockPTGadgetContentServer();
      server.m_URL = "http://test.com";
      IXPPropertyBag bag = new XPPropertyBag();
      // set library name and pagelet name
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PAGELET_LIBRARY,
       "testlibrary");
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PAGELET_NAME,
       "testname");
      // set parameter mappings
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER,
       new String[]{});
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM,
       new String[]{});
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN,
       new String[]{});
      MockPTMyPortalGadgetInfo gadgetInfo = new MockPTMyPortalGadgetInfo();
      String strURL = config.CreatePageletURL(gadgetInfo, bag, server);
      assertNotNull("URL should be non-null", strURL);
      assertEquals("Loaded path does not match the expected path.", "http://test.com/inject/v2/portlet/testlibrary/testname?content-type=iframe&csapi=true",
       strURL);
    }
    
    /// <summary>
    /// Tests that the pagelet config provider constructs the correct URL to retrieve pagelet content
    /// and sets pagelet parameters properly
    /// </summary>
    public virtual void testURLWithParams()
    {
      PageletProviderConfig config = new PageletProviderConfig();
      MockPTGadgetContentServer server = new MockPTGadgetContentServer();
      server.m_URL = "http://test.com";
      IXPPropertyBag bag = new XPPropertyBag();
      // set library name and pagelet name
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PAGELET_LIBRARY,
       "testlibrary");
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PAGELET_NAME,
       "testname");
      // set parameter mappings
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER,
       portletParams);
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM,
       commParams);
      bag.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN,
       adminParams);
      // set preferences
      MockPTMyPortalGadgetInfo gadgetInfo = new MockPTMyPortalGadgetInfo();
      gadgetInfo.m_portletPrefs.PutElement(portletParams[0], portletValues[0]);
      gadgetInfo.m_portletPrefs.PutElement(portletParams[1], portletValues[1]);
      gadgetInfo.m_portletPrefs.PutElement(portletParams[2], portletValues[2]);
      gadgetInfo.m_commPrefs.PutElement(commParams[0], commValues[0]);
      gadgetInfo.m_commPrefs.PutElement(commParams[1], commValues[1]);
      gadgetInfo.m_commPrefs.PutElement(commParams[2], commValues[2]);
      gadgetInfo.m_adminPrefs.PutElement(adminParams[0], adminValues[0]);
      gadgetInfo.m_adminPrefs.PutElement(adminParams[1], adminValues[1]);
      gadgetInfo.m_adminPrefs.PutElement(adminParams[2], adminValues[2]);
      String strURL = config.CreatePageletURL(gadgetInfo, bag, server);
      assertNotNull("URL should be non-null", strURL);
      assertNotNull("URL with trailing slash should be non-null", strURL);
      String queryString = XPStringUtility.Substring(strURL, XPStringUtility.IndexOf(strURL,
       "?"), strURL.Length);
      //		assertEquals("Loaded path with trailing slash does not match the expected path.",
      //			"http://test.com/inject/v2/pagelet/testlibrary/testname", strURL);
      assertTrue("Did not find all portlet preferences as pagelet parameters",
       ParamsExistInQS(queryString, portletParams, portletValues));
      assertTrue("Did not find all community portlet preferences as pagelet parameters",
       ParamsExistInQS(queryString, commParams, commValues));
      assertTrue("Did not find all admin portlet preferences as pagelet parameters",
       ParamsExistInQS(queryString, adminParams, adminValues));
    }
    protected virtual bool ParamsExistInQS(String qs, String[] names, String[] values)
    {
      bool result = true;
      for (int i = 0;i < names.Length;i++)
      {
        String paramEntry = names[i] + "=" + values[i];
        if (XPStringUtility.IndexOf(qs, paramEntry) == -1)
        {
          result = false;
          break;
        }
      }
      return result;
    }
  }
}