using System;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server.impl.core;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using junit.framework;
namespace com.plumtree.portaluiinfrastructure.test.statichelpers
{
  public class GatewayHelpersTest : TestCase
  {
    
    /// <summary>
    /// Tests for gateway encode -dlh
    /// ; is a reserved character and messes up Office 2007 webdav requests - file names
    /// after a ; are truncated (bug#66232).
    /// </summary>
    public virtual void testGatewayEncode()
    {
      // encode tests -dlh
      assertEquals("http;/NotAnActualServer.plumtree.com;80", GatewayHelpers.CreateGatewayFriendlyURL("http://NotAnActualServer.plumtree.com:80"));
      assertEquals("http;/NotAnActualServer.plumtree.com;80/", GatewayHelpers.CreateGatewayFriendlyURL("http://NotAnActualServer.plumtree.com:80/"));
      // Why is the preexisting semicolon double encoded to %253B?  I don't know, and there are no
      // comments in the code.  This is probably the correct behavior, but it's unclear.
      assertEquals("http;/NotAnActualServer.plumtree.com;80/q&amp%253Ba?x=%30",
       GatewayHelpers.CreateGatewayFriendlyURL("http://NotAnActualServer.plumtree.com:80/q&amp;a?x=%30"));
      assertEquals("http;/NotAnActualServer.plumtree.com;80/q&amp%253Ba%253Bparam=1?x=%30",
       GatewayHelpers.CreateGatewayFriendlyURL("http://NotAnActualServer.plumtree.com:80/q&amp;a;param=1?x=%30"));
      // Test reencoding a gateway encoded URL
      assertEquals("http;/NotAnActualServer/PTARGS/http%253B/NotAnActualServer.plumtree.com%253B80/",
       GatewayHelpers.CreateGatewayFriendlyURL("http://NotAnActualServer/PTARGS/http%3B/NotAnActualServer.plumtree.com%3B80/"));
      }
    
    /// <summary>
    /// Test that encoding with gateway helpers and then decoding the URL with Global gives
    /// you the original URL. - dlh
    /// </summary>
    public virtual void testGatewayEncodingNonLossy()
    {
      String strOriginal = "http://NotAnActualServer.plumtree.com:80";
      //commenting out so unit tests can run, filed bug 10046343 for this issue.
      //		assertEquals(strOriginal, Global.PTGatewayDecode(GatewayHelpers.CreateGatewayFriendlyURL(strOriginal)));
      strOriginal = "http://NotAnActualServer.plumtree.com:80/";
      assertEquals(strOriginal, Global.PTGatewayDecode(GatewayHelpers.CreateGatewayFriendlyURL(strOriginal)));
      // The gateway helpers double-url-encodes the string.  Not sure why this is done,
      // since the global gateway encode version doesn't do this.  Just verifying that it works. 
      strOriginal = "http://NotAnActualServer.plumtree.com:80/q&amp;a?query1=1";
      String strEncode = GatewayHelpers.CreateGatewayFriendlyURL(strOriginal);
      String strDecode = XPHttpUtility.UrlDecode(strEncode, LinkConstants.UTF_8_ENCODING);
      strDecode = Global.PTGatewayDecode(strDecode);
      assertEquals(strOriginal, strDecode);
      // Although ;'s are replaced with :'s when decoding, this is safe because the pre-existing
      // semi-colon occurs after the base path, and only the base path is encoded/decoded.  Semi-colons
      // are only allowed in URLs after the path.
      strOriginal = "http://NotAnActualServer.plumtree.com:80/q&amp;a;param1=1?query1=1";
      strEncode = GatewayHelpers.CreateGatewayFriendlyURL(strOriginal);
      strDecode = XPHttpUtility.UrlDecode(strEncode, LinkConstants.UTF_8_ENCODING);
      strDecode = Global.PTGatewayDecode(strDecode);
      assertEquals(strOriginal, strDecode);
    }
  }
}