using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.test.tags
{
  /// <summary>
  /// This abstract tag class provides various helper
  /// methods useful for testing.
  /// </summary>
  public abstract class ATestTag : ATag
  {
    protected HTMLElement m_displayHTML = null;
    protected HTMLScriptCollection m_sharedJavascript = null;
    protected bool m_bSupportAllAccessStyles = false;
    protected TagType m_tagType = TagType.SIMPLE;
    
    /// <summary>
    /// Helper method to set HTML for this tag to display.
    /// </summary>
    /// <param name="_displayHTML"></param>
    public virtual void SetDisplayHTML(HTMLElement _displayHTML)
    {
      m_displayHTML = _displayHTML;
    }
    
    /// <summary>
    /// Helper method to set shared javascript for this tag to display.
    /// </summary>
    /// <param name="_collection"></param>
    public virtual void SetSharedJavaScript(HTMLScriptCollection _collection)
    {
      m_sharedJavascript = _collection;
    }
    
    /// <summary>
    /// Helper method to set whether or not to support all access styles.
    /// </summary>
    /// <param name="_bSupportAll"></param>
    public virtual void SetSupportAllAccessStyles(bool _bSupportAll)
    {
      m_bSupportAllAccessStyles = _bSupportAll;
    }
    
    /// <summary>
    /// Helper method to set the tag type.
    /// </summary>
    /// <param name="__type"></param>
    public virtual void SetTagType(TagType _type)
    {
      m_tagType = _type;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      return m_displayHTML;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()
     */
     
    public override HTMLScriptCollection DisplaySharedJavascript()
    {
      // Display the specified shared javascript.
      return m_sharedJavascript;
    }
    
    /// <summary>
    /// Override ATag implementation. 
    /// </summary>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      if (m_bSupportAllAccessStyles)
      {
        // This tag supports all styles.
        return true;
      }
      // Support only Standard style.
      return base.SupportsAccessStyle(_style);
    }
    
    /// <summary>
    /// Override ATag method. 
    /// </summary>
    public override TagType GetTagType()
    {
      return m_tagType;
    }
    public abstract override ATag Create();
  }
}