using System;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.server;
using junit.framework;
namespace com.plumtree.portaluiinfrastructure.test.tags.displaytree
{
  /// <summary>
  /// Test for the display tree classes.
  /// </summary>
  /// <author>donh</author>
  public class DisplayTreeTest : TestCase
  {
    
    /// <summary>
    /// Constructor.
    /// </summary>
    public DisplayTreeTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// This tests building the display tree from
    /// Markup data.
    /// </summary>
    public static void testBuildDisplayTree()
    {
      // Can't put this directly as an argument because of jump issues.
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[6];
      }
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0] = "<span>";
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] singletonTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT, PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE},
       new Object[]{"testtagname", "testintattr", null}, new Object[]{null,
       "57", null}};
      // Add a singleton tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1] = singletonTagObjXML;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][2] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][2] = "</span>";
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][3] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] nestedOpenTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT}, new Object[]{"testnestedtagname",
       "testintattr"}, new Object[]{null, "57"}};
      // Add a nested open tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][3] = nestedOpenTagObjXML;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][4] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][4] = "nested test data";
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][5] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] nestedCloseTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE},
       new Object[]{"testnestedtagname"}, new Object[]{null}};
      // Add a nested close tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][5] = nestedCloseTagObjXML;
      IDisplayElement tree = DisplayTree.BuildDisplayTree(objArrMarkup);
      assertNotNull("Parsing Markup array into tag display tree.", tree);
      // TODO: This is a bad error that doesn't prove anything.  Should we
      // even be testing for errors if they're not part of an API?
      // We should probably put in bad data and test that it still doesn't fail.
      // Null out the objXML for a tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][5] = null;
      bool bFailed = false;
      try
      {
        // Parse the bad XML into a tree
        tree = DisplayTree.BuildDisplayTree(objArrMarkup);
      }
      catch (Exception e)
      {
        // Expected exception
        bFailed = true;
      }
      assertTrue("Parsing invalid markup array should fail.", bFailed);
    }
  }
}