using System;
using junit.framework;
using com.plumtree.openfoundation.mockobjects;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.xml;
using com.plumtree.server;
using com.plumtree.server.impl.portlet.providers;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portaluiinfrastructure.test.tags.displaytree
{
  public class HeadPreprocessorTest : TestCase
  {
    public const String HTML_OPEN_HTML_FRAGMENT = "<html>";
    public const String HEAD_OPEN_HTML_FRAGMENT = "<head>";
    public const String HEAD_CLOSE_HTML_FRAGMENT = "</head>";
    public const String TEXT_DATA_FRAGMENT = "test data";
    public const String JAVASCRIPT_DATA_FRAGMENT = "var test1value = \"JS test value\";";
    public const String FAKE_TAG_NAME = "fake tag name";
    public const String DEFAULT_LOCALE = "en-us";
    public IEnvironment m_environment;
    public ISessionManager m_subSession;
    public FragmentListConverter m_converter;
    
    /// <summary>
    /// Constructor.
    /// </summary>
    public HeadPreprocessorTest(String name) : base(name)
    {
    }
    public override void setUp()
    {
      m_environment = new MockEnvironment();
      m_subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
      m_converter = new FragmentListConverter();
    }
    
    /// <summary>
    /// This tests preprocessing an HTML document that
    /// doesn't need any preprocessing.  Nothing should change.
    /// </summary>
    public virtual void testNonHTMLDocument()
    {
      // Setup the input
      XPArrayList fragments = new XPArrayList();
      fragments.Add(new TransformerMarkupFragment(JAVASCRIPT_DATA_FRAGMENT));
      // Preprocess the markup fragments.
      HeadPreprocessor processor = new HeadPreprocessor();
      processor.PreprocessHead(fragments, m_subSession, m_environment, false);
      // Check the results.
      IMarkupFragment fragment;
      int i = 0;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the Javascript data.", JAVASCRIPT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      assertEquals("There should be " + i + " elements in markup list.", i,
       fragments.GetSize());
    }
    
    /// <summary>
    /// This tests preprocessing an HTML document that
    /// is missing the head element.
    /// </summary>
    public virtual void testNoHTMLNoHeadForced()
    {
      // Setup the input
      XPArrayList fragments = new XPArrayList();
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      // Preprocess the markup fragments.
      HeadPreprocessor processor = new HeadPreprocessor();
      // true means force the head to be added, even though there are no tags present.
      processor.PreprocessHead(fragments, m_subSession, m_environment, true);
      // Check the results.
      IMarkupFragment fragment;
      int i = 0;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the begin head html element.",
       HEAD_OPEN_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       HeadPreprocessor.HEAD_INCLUDES_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE, fragment.GetXMLFragment().GetType(1));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the end head html element.",
       HEAD_CLOSE_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      assertEquals("There should be " + i + " elements in markup list.", i,
       fragments.GetSize());
    }
    
    /// <summary>
    /// This tests preprocessing an HTML document that
    /// is missing the head element.
    /// </summary>
    public virtual void testNoHTMLNoHead()
    {
      // Setup the input
      XPArrayList fragments = new XPArrayList();
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      // Add a fake tag to trigger adding the head element
      fragments.Add(new TransformerMarkupFragment(GetFakeXMLTag()));
      // Preprocess the markup fragments.
      HeadPreprocessor processor = new HeadPreprocessor();
      processor.PreprocessHead(fragments, m_subSession, m_environment, false);
      // Check the results.
      IMarkupFragment fragment;
      int i = 0;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the begin head html element.",
       HEAD_OPEN_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       HeadPreprocessor.HEAD_INCLUDES_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE, fragment.GetXMLFragment().GetType(1));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the end head html element.",
       HEAD_CLOSE_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a fake xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the fake tag data.", FAKE_TAG_NAME,
       fragment.GetXMLFragment().GetName(0));
      i++;
      assertEquals("There should be " + i + " elements in markup list.", i,
       fragments.GetSize());
    }
    
    /// <summary>
    /// This tests preprocessing an HTML document that
    /// is missing the head element.
    /// </summary>
    public virtual void testNoHead()
    {
      // Setup the input
      XPArrayList fragments = new XPArrayList();
      fragments.Add(new TransformerMarkupFragment(HTML_OPEN_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML));
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      // Add a fake tag to trigger adding the head element
      fragments.Add(new TransformerMarkupFragment(GetFakeXMLTag()));
      // Preprocess the markup fragments.
      // Preprocess the markup fragments.
      HeadPreprocessor processor = new HeadPreprocessor();
      processor.PreprocessHead(fragments, m_subSession, m_environment, false);
      // Check the results.
      IMarkupFragment fragment;
      int i = 0;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be an open html tag.", HTML_OPEN_HTML_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin html marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the begin head html element.",
       HEAD_OPEN_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       HeadPreprocessor.HEAD_INCLUDES_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE, fragment.GetXMLFragment().GetType(1));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the end head html element.",
       HEAD_CLOSE_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a fake xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the fake tag data.", FAKE_TAG_NAME,
       fragment.GetXMLFragment().GetName(0));
      i++;
      assertEquals("There should be " + i + " elements in markup list.", i,
       fragments.GetSize());
    }
    
    /// <summary>
    /// This tests preprocessing an HTML document that
    /// already includes a head element.
    /// </summary>
    public virtual void testHead()
    {
      // Setup the input
      XPArrayList fragments = new XPArrayList();
      fragments.Add(new TransformerMarkupFragment(HTML_OPEN_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML));
      fragments.Add(new TransformerMarkupFragment(HEAD_OPEN_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD));
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD));
      fragments.Add(new TransformerMarkupFragment(HEAD_CLOSE_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      // Add a fake tag to trigger adding the head element
      fragments.Add(new TransformerMarkupFragment(GetFakeXMLTag()));
      // Preprocess the markup fragments.
      HeadPreprocessor processor = new HeadPreprocessor();
      processor.PreprocessHead(fragments, m_subSession, m_environment, false);
      // Check the results.
      IMarkupFragment fragment;
      int i = 0;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be an open html tag.", HTML_OPEN_HTML_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin html marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be an html head tag.", HEAD_OPEN_HTML_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be the head includes ptxml tag.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the head includes ptxml tag.",
       HeadPreprocessor.HEAD_INCLUDES_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should be a singleton head includes ptxml tag.",
       PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE, fragment.GetXMLFragment().GetType(1));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be a close html head tag.",
       HEAD_CLOSE_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a fake xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the fake tag data.", FAKE_TAG_NAME,
       fragment.GetXMLFragment().GetName(0));
      i++;
      assertEquals("There should be " + i + " elements in markup list.", i,
       fragments.GetSize());
    }
    
    /// <summary>
    /// This tests preprocessing an HTML document that
    /// already includes a head element.
    /// </summary>
    public virtual void testMoveJSTransformToHead()
    {
      // Setup the input
      XPArrayList fragments = new XPArrayList();
      fragments.Add(new TransformerMarkupFragment(GetFakeXMLTag(AutoJSTransformTagConstants.TAG_FULL_NAME)));
      fragments.Add(new TransformerMarkupFragment(HTML_OPEN_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML));
      fragments.Add(new TransformerMarkupFragment(HEAD_OPEN_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD));
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD));
      fragments.Add(new TransformerMarkupFragment(HEAD_CLOSE_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      // Add a fake tag to trigger adding the head element
      fragments.Add(new TransformerMarkupFragment(GetFakeXMLTag()));
      // Preprocess the markup fragments.
      HeadPreprocessor processor = new HeadPreprocessor();
      processor.PreprocessHead(fragments, m_subSession, m_environment, false);
      // Check the results.
      IMarkupFragment fragment;
      int i = 0;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be an open html tag.", HTML_OPEN_HTML_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin html marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be an html head tag.", HEAD_OPEN_HTML_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a ptui include xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be a ptui include xml tag.",
       HeadPreprocessor.JS_INCLUDE_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should have the jsinclude attribute.",
       HeadPreprocessor.JS_INCLUDE_TAG_NAME_ATTR, fragment.GetXMLFragment().GetName(1));
      assertEquals("Fragment " + i + " should have the jsinclude attribute specifying the jsportlet code.",
       ConfigHelper.JSCOMPONENT_JSPORTLET, fragment.GetXMLFragment().GetValue(1));
      assertEquals("Fragment " + i + " should have the jsinclude locale attribute.",
       HeadPreprocessor.JS_INCLUDE_LOCALE_ATTR, fragment.GetXMLFragment().GetName(2));
      assertEquals("Fragment " + i + " should have a jsinclude locale attribute of en.",
       DEFAULT_LOCALE, fragment.GetXMLFragment().GetValue(2));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an AutoJSTransform xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the AutoJSTransform xml tag.",
       AutoJSTransformTagConstants.TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be the head includes ptxml tag.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the head includes ptxml tag.",
       HeadPreprocessor.HEAD_INCLUDES_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should be a singleton head includes ptxml tag.",
       PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE, fragment.GetXMLFragment().GetType(1));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be a close html head tag.",
       HEAD_CLOSE_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a fake xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the fake tag data.", FAKE_TAG_NAME,
       fragment.GetXMLFragment().GetName(0));
      i++;
      assertEquals("There should be " + i + " elements in markup list.", i,
       fragments.GetSize());
    }
    
    /// <summary>
    /// This tests preprocessing an HTML document that
    /// is missing the head element.
    /// </summary>
    public virtual void testNoHeadMoveJSTransform()
    {
      // Setup the input
      XPArrayList fragments = new XPArrayList();
      fragments.Add(new TransformerMarkupFragment(GetFakeXMLTag(AutoJSTransformTagConstants.TAG_FULL_NAME)));
      fragments.Add(new TransformerMarkupFragment(HTML_OPEN_HTML_FRAGMENT));
      fragments.Add(new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML));
      fragments.Add(new TransformerMarkupFragment(TEXT_DATA_FRAGMENT));
      // Add a fake tag to trigger adding the head element
      fragments.Add(new TransformerMarkupFragment(GetFakeXMLTag()));
      // Preprocess the markup fragments.
      // Preprocess the markup fragments.
      HeadPreprocessor processor = new HeadPreprocessor();
      processor.PreprocessHead(fragments, m_subSession, m_environment, false);
      // Check the results.
      IMarkupFragment fragment;
      int i = 0;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be an open html tag.", HTML_OPEN_HTML_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin html marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the begin head html element.",
       HEAD_OPEN_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a begin head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a ptui include xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be a ptui include xml tag.",
       HeadPreprocessor.JS_INCLUDE_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should have the jsinclude attribute.",
       HeadPreprocessor.JS_INCLUDE_TAG_NAME_ATTR, fragment.GetXMLFragment().GetName(1));
      assertEquals("Fragment " + i + " should have the jsinclude attribute specifying the jsportlet code.",
       ConfigHelper.JSCOMPONENT_JSPORTLET, fragment.GetXMLFragment().GetValue(1));
      assertEquals("Fragment " + i + " should have the jsinclude locale attribute.",
       HeadPreprocessor.JS_INCLUDE_LOCALE_ATTR, fragment.GetXMLFragment().GetName(2));
      assertEquals("Fragment " + i + " should have a jsinclude locale attribute of en.",
       DEFAULT_LOCALE, fragment.GetXMLFragment().GetValue(2));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an AutoJSTransform xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the AutoJSTransform xml tag.",
       AutoJSTransformTagConstants.TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       HeadPreprocessor.HEAD_INCLUDES_TAG_FULL_NAME, fragment.GetXMLFragment().GetName(0));
      assertEquals("Fragment " + i + " should be the head includes ptxml singleton tag.",
       PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE, fragment.GetXMLFragment().GetType(1));
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head marker fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD, fragment.GetFragmentType());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an end head html fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the end head html element.",
       HEAD_CLOSE_HTML_FRAGMENT, fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be an html fragment.", PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED,
       fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the test data.", TEXT_DATA_FRAGMENT,
       fragment.GetStringFragment());
      i++;
      fragment = (IMarkupFragment) fragments.GetElement(i);
      assertEquals("Fragment " + i + " should be a fake xml tag fragment.",
       PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML, fragment.GetFragmentType());
      assertEquals("Fragment " + i + " should be the fake tag data.", FAKE_TAG_NAME,
       fragment.GetXMLFragment().GetName(0));
      i++;
      assertEquals("There should be " + i + " elements in markup list.", i,
       fragments.GetSize());
    }
    public virtual IXMLFragment GetFakeXMLTag()
    {
      return GetFakeXMLTag(FAKE_TAG_NAME);
    }
    public virtual IXMLFragment GetFakeXMLTag(String _strName)
    {
      XPArrayList tagAttributes = new XPArrayList();
      tagAttributes.Add(new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI, _strName,
       null});
      tagAttributes.Add(new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE,
       null, null});
      return new XMLFragment(tagAttributes);
    }
  }
}