using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.test.tags;
using com.plumtree.server;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.test.tags.features
{
  /// <summary>
  /// Test for the Attribute Value Replacement feature.
  /// I.E.  $var and $data.var in tag attributes.
  /// This uses the TagHelper and TagState, so it is in a
  /// separate class from both.
  /// </summary>
  /// <author>DonH</author>
  public class AttributeValueReplacementTest : TestCase
  {
    public const String XHTML_ATTRIBUTE = "testxhtmlattr";
    public const String STRING_VALUE = "test value";
    public const int INT_VALUE = 456;
    protected TestTag m_TestTag;
    
    /// <summary>
    /// Constructor.
    /// </summary>
    public AttributeValueReplacementTest(String name) : base(name)
    {
      // Initialize the meta data for the test tags.
      // This is normally done by the TagLibManager.
      m_TestTag = new TestTag();
      TagMetaDataHelper testMetaDataHelper = new TagMetaDataHelper();
      testMetaDataHelper.Init(m_TestTag, new TagLibraryMetaData("Test Tag Library",
       "testtaglibrary", "Test tag library description", 1.0));
      m_TestTag.SetTagMetaDataHelper(testMetaDataHelper);
    }
    
    /// <summary>
    /// This tests attribute value replacement (I.E. converting
    /// $var and $data.var in attributes to their respective
    /// variable values).
    /// </summary>
    public virtual void testTagAttributeValueReplacement()
    {
      // Can't put this directly as an argument because of jump issues.
      Object[][] objXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT, PT_XML_TYPES.PT_XML_TYPES_XHTML_ATT},
       new Object[]{TestTag.TESTATTRIBUTE.GetName(), TestTag.TESTINTATTRIBUTE.GetName(),
       XHTML_ATTRIBUTE}, new Object[]{"$var", "$data.var", "$var"}};
      ATag tag = GetNewTestTagInstance();
      TagHelper helper = new TagHelper(objXML, null, tag);
      TagState state = new TagState(null, null, null, new XPHashtable());
      TagVisitor visitor = new TagVisitor(state, null, new HTMLElementCollection());
      helper.SetTagVisitor(visitor);
      state.EnterTag(tag);
      // Set variables on state
      // We have to make sure to set our variables in tag
      // or portlet request scope (non-shared), otherwise
      // Tag State will throw a null pointer exception when
      // it searches for the variables in the session, which
      // we did not provide.
      state.SetVariable("var", STRING_VALUE, Scope.PORTLET_REQUEST);
      String strTest;
      // Test $var replacement in a PT attribute (pt:attr)
      strTest = helper.GetAttributeAsString(TestTag.TESTATTRIBUTE);
      Assert.assertEquals("Getting replaced value for test pt attribute $var.",
       STRING_VALUE, strTest);
      // Test $var replacement in an XHTML attribute (attr)
      strTest = helper.GetXMLAttribute(XHTML_ATTRIBUTE);
      Assert.assertEquals("Getting replaced value for test xhtml attribute $var.",
       STRING_VALUE, strTest);
      // Set up the data object
      HashtableDataObject dataSet = new HashtableDataObject();
      XPHashtable dataSetHashtable = dataSet.GetHashTable();
      dataSetHashtable.PutElement("var", XPConvert.ToString(INT_VALUE));
      // Store the data collection
      state.SetVariable("data", dataSet, Scope.PORTLET_REQUEST);
      int nTest;
      // Test $data.var replacement
      nTest = helper.GetAttributeAsInt(TestTag.TESTINTATTRIBUTE);
      Assert.assertEquals("Getting replaced value for test attribute $data.var.",
       INT_VALUE, nTest);
      state.ExitTag();
      helper.ReleaseTagVisitor();
    }
    
    /// <summary>
    /// This helper method creates and initializes a new TestTag instance.
    /// This would normally be handled by the TagLibManager.
    /// </summary>
    /// <returns> A new TestTag instance.</returns>
    public virtual TestTag GetNewTestTagInstance()
    {
      TestTag result = new TestTag();
      result.SetTagMetaDataHelper(m_TestTag.GetTagMetaDataHelper());
      return result;
    }
  }
}