using System;
using junit.framework;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.test.tags;
using com.plumtree.server;
namespace com.plumtree.portaluiinfrastructure.test.tags.features
{
  /// <summary>
  /// Tests the Tag Context Validation framework.
  /// </summary>
  /// <author>donh</author>
  public class TagContextValidationTest : TestCase
  {
    protected TestTag m_TestTag;
    
    /// <summary>
    /// Constructor.
    /// </summary>
    public TagContextValidationTest(String name) : base(name)
    {
      // Initialize the meta data for the test tags.
      // This is normally done by the TagLibManager.
      m_TestTag = new TestTag();
      TagMetaDataHelper testMetaDataHelper = new TagMetaDataHelper();
      testMetaDataHelper.Init(m_TestTag, new TagLibraryMetaData("Test Tag Library",
       "testtaglibrary", "Test tag library description", 1.0));
      m_TestTag.SetTagMetaDataHelper(testMetaDataHelper);
    }
    
    /// <summary>
    /// This tests required attribute validation failure.
    /// </summary>
    public virtual void testRequiredAttributeValidationFailure()
    {
      // Can't put this directly as an argument because of jump issues.
      Object[][] missingObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT}, new Object[]{"testintattr", "testbadintattr"},
       new Object[]{"1", "garbageint"}};
      TagHelper helper = new TagHelper(missingObjXML, null, GetNewTestTagInstance());
      Assert.assertNotNull("Context validation for TestTag missing a required attribute should fail.",
       helper.ValidateRequiredAttributes());
      // Can't put this directly as an argument because of jump issues.
      Object[][] badObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT, PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT},
       new Object[]{"testreqintattr", "testattr", "testbadintattr"}, new Object[]{"fail",
       "1", "garbageint"}};
      helper = new TagHelper(badObjXML, null, GetNewTestTagInstance());
      Assert.assertNotNull("Context validation for TestTag with an invalid required attribute should fail.",
       helper.ValidateRequiredAttributes());
    }
    
    /// <summary>
    /// This tests required attribute validation success.
    /// </summary>
    public virtual void testRequiredAttributeValidationSuccess()
    {
      // Can't put this directly as an argument because of jump issues.
      Object[][] objXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT, PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT},
       new Object[]{"testattr", "testreqintattr", "testbadintattr"}, new Object[]{"test",
       "1", "garbageint"}};
      TagHelper helper = new TagHelper(objXML, null, GetNewTestTagInstance());
      Assert.assertNull("Context validation for TestTag should succeed.",
       helper.ValidateRequiredAttributes());
    }
    
    /// <summary>
    /// This helper method creates and initializes a new TestTag instance.
    /// This would normally be handled by the TagLibManager.
    /// </summary>
    /// <returns> A new TestTag instance.</returns>
    protected virtual TestTag GetNewTestTagInstance()
    {
      TestTag result = new TestTag();
      result.SetTagMetaDataHelper(m_TestTag.GetTagMetaDataHelper());
      return result;
    }
  }
}