using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.test.tags;
using junit.framework;
namespace com.plumtree.portaluiinfrastructure.test.tags.helper
{
  /// <summary>
  /// Test for the TagMetaDataHelper class.
  /// </summary>
  /// <author>DonH</author>
  public class TagMetaDataHelperTest : TestCase
  {
    
    /// <summary>
    /// Constructor.
    /// </summary>
    public TagMetaDataHelperTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// This tests the error handling for invalid meta data.
    /// </summary>
    public static void testTagMetaDataErrorHandling()
    {
      // Test a tag with missing meta data
      ATag testBadTag = new BadMetaDataTag();
      TagMetaDataHelper testMetaDataHelper = new TagMetaDataHelper();
      Assert.assertFalse("Initializing BadMetaDataTag with invalid meta data.",
       testMetaDataHelper.Init(testBadTag, new TagLibraryMetaData("testlib",
       "Test Library", "Test library description.", 1.0)));
    }
    
    /// <summary>
    /// This tests that the correct meta data is loaded.
    /// </summary>
    public static void testValidTagMetaData()
    {
      // Test a tag with functional meta data
      ATag testTag = new TestTag();
      TagMetaDataHelper testTagHelper = new TagMetaDataHelper();
      Assert.assertTrue("Initializing TestTag meta data.", testTagHelper.Init(testTag,
       new TagLibraryMetaData("testlib", "Test Library", "Test library description.",
       1.0)));
      // Check Tag meta data
      Assert.assertEquals("Getting Tag meta data for TestTag.", TestTag.TAG,
       testTagHelper.GetTagMetaData());
      // Check RequiredTagAttributes
      RequiredTagAttribute[] testRequiredTagAttributes = testTagHelper.GetRequiredTagAttributes();
      Object[] actualRequiredTagAttributes = new Object[]{TestTag.TESTATTRIBUTE,
       TestTag.TESTREQINTATTRIBUTE};
      Assert.assertEquals("Checking number of RequiredTagAttributes.", actualRequiredTagAttributes.Length,
       testRequiredTagAttributes.Length);
      Assert.assertEquals("Checking for number of maches between calculated RequiredTagAttributes and actual RequiredTagAttributes.",
       actualRequiredTagAttributes.Length, GetNumberOfMatches(testRequiredTagAttributes,
       actualRequiredTagAttributes));
      // Check OptionalTagAttributes
      OptionalTagAttribute[] testOptionalTagAttributes = testTagHelper.GetOptionalTagAttributes();
      Object[] actualOptionalTagAttributes = new Object[]{TestTag.TEST2ATTRIBUTE,
       TestTag.TESTBADINTATTRIBUTE, TestTag.TESTINT2ATTRIBUTE, TestTag.TESTINTATTRIBUTE};
      Assert.assertEquals("Checking number of OptionalTagAttributes.", actualOptionalTagAttributes.Length,
       testOptionalTagAttributes.Length);
      Assert.assertEquals("Checking for number of maches between calculated OptionalTagAttributes and actual OptionalTagAttributes.",
       actualOptionalTagAttributes.Length, GetNumberOfMatches(testOptionalTagAttributes,
       actualOptionalTagAttributes));
      // Check RequiredParentTag -- pointing to itself currently
      Assert.assertEquals("Getting number of RequiredParentTags for TestTag.",
       2, testTagHelper.GetRequiredParentTags().Length);
      Assert.assertEquals("Getting first RequiredParentTag meta data for TestTag.",
       TestTag.TAG, testTagHelper.GetRequiredParentTags()[0]);
      Assert.assertEquals("Getting second RequiredParentTag meta data for TestTag.",
       TestTag.TAG, testTagHelper.GetRequiredParentTags()[0]);
      // CheckRequiredChildTags
      ITagMetaData[] testRequiredTagChildren = testTagHelper.GetRequiredChildTags();
      Object[] actualRequiredTagChildren = new Object[]{TestTag.REQUIRED_CHILDREN_FOR_TEST[0],
       TestTag.REQUIRED_CHILDREN_FOR_TEST[1]};
      Assert.assertEquals("Checking number of RequiredChildTags.", actualRequiredTagChildren.Length,
       testRequiredTagChildren.Length);
      Assert.assertEquals("Checking for number of maches between calculated RequiredChildTags and actual RequiredChildTags.",
       actualRequiredTagChildren.Length, GetNumberOfMatches(testRequiredTagChildren,
       actualRequiredTagChildren));
    }
    
    /// <summary>
    /// This helper method calculates the number of object == matches between two arrays.
    /// </summary>
    /// <param name="_firstArray">The first array.</param>
    /// <param name="_secondArray">The second array.</param>
    /// <returns>int The number of matches.</returns>
    protected static int GetNumberOfMatches(Object[] _firstArray, Object[] _secondArray)
    {
      int nMatches = 0;
      for (int i = 0;i < _firstArray.Length;i++)
      {
        for (int j = 0;j < _secondArray.Length;j++)
        {
          if (_firstArray[i] == _secondArray[j])
          {
            nMatches++;
            break;
          }
        }
      }
      return nMatches;
    }
  }
}