using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.mock.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.utils
{
  /// <author>rozhang</author>
  public class TagTestHelper
  {
    
    /// <summary>
    /// Sets up mock environment for tag unit tests 
    /// </summary>
    /// <returns></returns>
    public static MockEnvironment SetupTagTestEnvironment()
    {
      IApplication mockApp = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       mockApp);
      MockConfigHelper mockConfig = new MockConfigHelper();
      ConfigService.setTestInstance(mockConfig);
      MockPTConfigHelper mockPTConfig = new MockPTConfigHelper();
      mockPTConfig.m_bUseAllFriendlyURLs = true;
      PTConfigService.setTestPTInstance(mockPTConfig);
      MockClassTypeDescManager classTypeMgr = new MockClassTypeDescManager();
      mockPTConfig.m_classTypeManager = classTypeMgr;
      MockEnvironment env = new MockEnvironment();
      mockPTConfig.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      return env;
    }
    
    /// <summary>
    /// Call this before running a tag to setup a mock tag state instance where tag variables are set
    /// </summary>
    /// <returns></returns>
    public static TagStateTestHelper GetMockTagStateInstance()
    {
      TagStateTestHelper state = new TagStateTestHelper();
      return state;
    }
    
    /// <summary>
    /// Registers a single tag for use in unit tests.
    /// NOTE don't call this method repeatedly to create multiple tags in same taglib!
    /// Use the CreateTestTags method to create multiple tags in same taglib
    /// </summary>
    /// <param name="libName"></param>
    /// <param name="tagName"></param>
    /// <param name="tagInstance"></param>
    public static void CreateTestTag(String libName, String tagName, ATag tagInstance)
    {
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(tagInstance, tagName, libName);
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// Registers multiple tags for use in unit tests.
    /// </summary>
    /// <param name="libName"></param>
    /// <param name="tagName"></param>
    /// <param name="tagInstance"></param>
    public static void CreateTestTags(String libName, String[] tagName, ATag[] tagInstance)
    {
      MockTagLibManager tagLib = new MockTagLibManager();
      for (int i = 0;i < tagName.Length;i++)
      {
        tagLib.SetTag(tagInstance[i], tagName[i], libName);
        TagLibManager.setTestInstance(tagLib);
      }
    }
    
    /// <summary>
    /// Executes a single tag without nested child tags in a portlet request context. Note that multiple calls to this method will run
    /// in separate portlet request contexts
    /// </summary>
    /// <param name="tagAttribNames">Names of the attributes passed to the tag (index of entries must match up with the tagAttribValues list</param>
    /// <param name="tagAttribValues">Values of the attributes passed to the tag (index of entries must match up with the tagAttribNames list</param>
    /// <returns></returns>
    public static HTMLElement RunSingleTag(String tagLibName, String tagName,
     XPArrayList tagAttribNames, XPArrayList tagAttribValues, MockEnvironment env)
    {
      return RunSingleTag(tagLibName, tagName, (String[]) tagAttribNames.ToArray(new String[]{}),
       (String[]) tagAttribValues.ToArray(new String[]{}), env);
    }
    
    /// <summary>
    /// Executes a single tag without nested child tags in a portlet request context. Note that multiple calls to this method will run
    /// in separate portlet request contexts
    /// </summary>
    /// <param name="tagAttribNames">Names of the attributes passed to the tag (index of entries must match up with the tagAttribValues list</param>
    /// <param name="tagAttribValues">Values of the attributes passed to the tag (index of entries must match up with the tagAttribNames list</param>
    /// <returns></returns>
    public static HTMLElement RunSingleTag(String tagLibName, String tagName,
     String[] tagAttribNames, String[] tagAttribValues, MockEnvironment env)
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(tagLibName,
       tagName);
      for (int i = 0;i < tagAttribNames.Length;i++)
      {
        helper.AddPTAttribute(tagAttribNames[i], tagAttribValues[i]);
      }
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
      return result;
    }
    
    /// <summary>
    /// Executes a single tag without nested child tags in a portlet request context. Note that multiple calls to this method will run
    /// in separate portlet request contexts
    /// </summary>
    /// <param name="attributes">A map with entries where the key is the name of the attribute and the value is the attribute value as string</param>
    /// <returns></returns>
    public static HTMLElement RunSingleTag(String tagLibName, String tagName,
     XPHashtable attributes, MockEnvironment env)
    {
      return RunSingleTagWithNestedHTML(tagLibName, tagName, attributes, null,
       env);
    }
    
    /// <summary>
    /// Runs a tag with HTML body
    /// </summary>
    /// <param name="tagLibName"></param>
    /// <param name="tagName"></param>
    /// <param name="attributes">Map of attribute name/value pairs. Attribute names prefixed with '-' are treated as XML attributes (not prefixed with pt:)</param>
    /// <param name="nestedHTML"></param>
    /// <param name="env"></param>
    /// <returns></returns>
    public static HTMLElement RunSingleTagWithNestedHTML(String tagLibName,
     String tagName, XPHashtable attributes, String nestedHTML, MockEnvironment env)
    {
      XMLFragmentTestHelper helper = XMLFragmentTestHelper.CreateTag(tagLibName,
       tagName, attributes);
      if (nestedHTML != null)
      {
        helper.AddContent(nestedHTML);
      }
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
      return result;
    }
    
    /// <summary>
    /// Runs a tag with a tag body containing nested tag 
    /// </summary>
    /// <param name="tagLibName"></param>
    /// <param name="tagName"></param>
    /// <param name="attHashtable">A map with entries where the key is the name of the attribute and the value is the attribute value as string</param>
    /// <param name="nestedTag"></param>
    /// <param name="env"></param>
    /// <returns></returns>
    public static HTMLElement RunNestedTags(String tagLibName, String tagName,
     XPHashtable attributes, XMLFragmentTestHelper nestedTag, MockEnvironment env)
    {
      XMLFragmentTestHelper helper = XMLFragmentTestHelper.CreateTag(tagLibName,
       tagName, attributes);
      if (nestedTag != null)
      {
        helper.AddContent(nestedTag);
      }
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
      return result;
    }
    
    /// <param name="tagLibName"></param>
    /// <param name="tagName"></param>
    /// <param name="attributesA">map with entries where the key is the name of the attribute and the value is the attribute value as string</param>
    /// <param name="nestedTag"></param>
    /// <param name="env"></param>
    /// <returns></returns>
    public static HTMLElement RunNestedTags(String tagLibName, String tagName,
     XPHashtable attributes, XMLFragmentTestHelper[] nestedTag, MockEnvironment env)
    {
      XMLFragmentTestHelper helper = XMLFragmentTestHelper.CreateTag(tagLibName,
       tagName, attributes);
      if (nestedTag != null)
      {
        for (int i = 0;i < nestedTag.Length;i++)
        {
          helper.AddContent(nestedTag[i]);
        }
      }
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
      return result;
    }
    
    /// <summary>
    /// Helper function to create hierarchical data structures
    /// Uses default child key of  
    /// </summary>
    /// <param name="children"></param>
    /// <returns></returns>
    public static HashtableDataObject CreateHierDataHelper(int numChildren)
    {
      // root list in the data tag variable
      XPArrayList children = new XPArrayList();
      for (int i = 0;i < numChildren;i++)
      {
        children.Add(new HashtableDataObject());
      }
      HashtableDataObject topEntry = new HashtableDataObject();
      topEntry.SetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY, children);
      return topEntry;
    }
    
    /// <summary>
    /// Adds empty child HashtableDataObjects to the provided data object.
    /// Returns the list of created children.   
    /// </summary>
    /// <param name="numChildren"></param>
    /// <param name="hierData"></param>
    /// <returns></returns>
    public static XPArrayList SetHierDataChildren(int numChildren, IHierarchicalDataObject hierData)
    {
      // root list in the data tag variable
      XPArrayList children = new XPArrayList();
      for (int i = 0;i < numChildren;i++)
      {
        children.Add(new HashtableDataObject());
      }
      hierData.SetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY, children);
      return children;
    }
    
    /// <summary>
    /// Returns the immediate child element from the provided hierarchical data at the specified index
    /// </summary>
    /// <param name="index"></param>
    /// <returns></returns>
    public static IHierarchicalDataObject GetHierDataChildAtIndex(int index,
     IHierarchicalDataObject hierData)
    {
      XPArrayList children = hierData.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
      return (IHierarchicalDataObject) children.GetElement(index);
    }
    
    /// <summary>
    /// Helper function to return the dataobject in the hierarchy as specified by the indexLst argument
    /// </summary>
    /// <param name="indexList">List of comma separated numbers representing list index at each level of the hierarchy. First number is the top level, next the level below, etc.</param>
    /// <param name="rootData">Data structure to traverse through. List of IHierarchicalDataObject with child elements containing further lists of IHierarchicalDataObject and so forth.</param>
    /// <returns>The IHierarchicalDataObject at specified location in the hierarchy</returns>
    public static IHierarchicalDataObject GetDataObjAtIndex(String indexList,
     XPArrayList rootData)
    {
      XPStringTokenizer tok = new XPStringTokenizer(indexList, ",");
      IHierarchicalDataObject currData = null;
      XPArrayList currList = rootData;
      for (int i = 0;tok.HasMoreTokens();i++)
      {
        currList = (i == 0) ? rootData : (XPArrayList) currData.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
        if (currList == null)
        {
          XPSystem.Out.WriteLine("getDataObjAtIndex - No child data found for data at level: " + i + " in the index list: " + indexList);
          return null;
        }
        int currIndex = XPConvert.ToInteger(tok.GetNextToken());
        if (currIndex >= currList.GetSize())
        {
          XPSystem.Out.WriteLine("getDataObjAtIndex - Index: " + currIndex + " at level: " + i + " in the index list: " + indexList + " is greater than the list size");
          }
        currData = (IHierarchicalDataObject) currList.GetElement(currIndex);
        if (currData == null)
        {
          XPSystem.Out.WriteLine("getDataObjAtIndex - No element found at index: " + currIndex + " at level: " + i + " in the index list: " + indexList);
          return null;
        }
      }
      return currData;
    }
    
    /// <summary>
    /// Verifies that result from data tag is empty. HTML returned from data tag always contains errors  
    /// </summary>
    /// <param name="result"></param>
    /// <returns></returns>
    public static bool VerifyNoTagContent(HTMLElement result)
    {
      return result == null || "".Equals(result.GetDisplayString());
    }
    
    /// <summary>
    /// Checks that generated tag content include the provided string  
    /// </summary>
    /// <param name="tagContent"></param>
    /// <param name="expectedContentPart"></param>
    /// <returns></returns>
    public static bool VerifyTagReturnedContent(HTMLElement tagContent, String expectedContentPart)
    {
      return !TagTestHelper.VerifyNoTagContent(tagContent) && XPStringUtility.IndexOf(tagContent.GetDisplayString(),
       expectedContentPart) != -1;
    }
  }
}