package com.plumtree.portaluiinfrastructure.application;

import com.plumtree.analytics.openusage.*;
import com.plumtree.analytics.openusage.impl.Logger;
import com.plumtree.openfoundation.io.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.portaluiinfrastructure.condition.interpreterfilter.*;
import com.plumtree.portaluiinfrastructure.error.*;
import com.plumtree.portaluiinfrastructure.failover.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.navtype.*;
import com.plumtree.portaluiinfrastructure.sso.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.notification.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.httpcompression.*;
import com.plumtree.uiinfrastructure.login.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.config.*;

/**
 * This class provides the portal specific jumpable initialization code
 * so it can be separate from the servlet and .aspx code, as well as the
 * base app initialization code.
 */
public class PTAppWarmUpHelper implements IAppWarmUpHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.application.PTAppWarmUpHelper");

	private PTAnalyticsVarPack vpAnalytics = null;
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.application.AAppWarmUpHelper#LoadConfigVarPacks(String, String)
	 */
    public ConfigVarPack LoadConfigVarPack(String strSettingsConfigFolder, String strPlatform)
    {
    	ConfigVarPack vpConfig = null;
		try
		{
			vpConfig = new PTConfigVarPack(strPlatform);
			vpConfig.LoadVarPack(strSettingsConfigFolder);
		}
		catch (Exception e)
		{
			
				log.Fatal(e, "Error creating custom x_config.xml var pack.");
			

			throw XPException.GetInstance(e);
		}

		return vpConfig;
	}

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.application.IAppWarmUpHelper#InitializeVarPacks(VarPackManager, String, String)
     */
    public ReturnValue InitializeVarPacks(VarPackManager vpmVarPackManager,
    	String strSettingsConfigFolder, String strPlatform)
    {     
		ReturnValue retVal = new ReturnValue(PT_STARTUP_RESULTCODES.OK,"InitializeVarPacks successful.",
		        null);

		try {
			vpAnalytics = new PTAnalyticsVarPack();
			vpAnalytics.LoadVarPack(strSettingsConfigFolder);
			vpmVarPackManager.AddVariablePackage(vpAnalytics);
		}
		catch (Throwable te)
		{
			log.Warn(te, "Failed to load the analytics var pack.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.WARN,"InitializeVarPacks: Failed to initialize the analytics var pack",
			        XPException.GetInstance(te));			
		}
	
		return retVal;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.application.IAppWarmUpHelper#LoadVarPacks(VarPackManager, String, String)
     */
    public ReturnValue LoadVarPacks(VarPackManager vpmVarPackManager,
    	String strSettingsConfigFolder, String strPlatform)
	{
		ReturnValue retVal = new ReturnValue(PT_STARTUP_RESULTCODES.OK,"InitializeVarPacks successful.",
		        null);
        
		// Load Search Languages -- This must occur after language resource files
		// have been loaded.  This var pack has to be loaded here because it's
		// XML file is stored in a different location from the other var packs.

		log.Info("Creating search languages var pack.");

		String strFileSeparator = XPFileSystemObject.GetPathSeparator();
		PTSearchLocaleVarPack vpPTSearchLocales;

		try
		{
			String strSharedPath = "";
			strSharedPath = ConfigPathResolver.GetOpenConfigPath();

			strSharedPath += strFileSeparator + "common";
			
			strSharedPath = GeneralHelpers.FormatPath(strSharedPath, strFileSeparator, false);

			vpPTSearchLocales = new PTSearchLocaleVarPack();
			vpPTSearchLocales.LoadVarPack(strSharedPath);
			vpmVarPackManager.AddVariablePackage(vpPTSearchLocales);
		}
		catch (Throwable te)
		{
			log.Fatal(te, "Failed to load the search languages var pack.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,"LoadVarPacks: Failed to load the search languages var pack",
			        XPException.GetInstance(te));
		}
		
		return retVal;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.application.AAppWarmUpHelper#InitObjects(ConfigVarPack, String, String, String, CachingManager)
	 */
	public ReturnValue InitializeObjects(ConfigVarPack vpConfig, String strApplicationName,
		String strImageServerBaseURL, String strSecureImageServerBaseURL,
		CachingManager cmCachingManager)
	{		
		ReturnValue retVal = new ReturnValue(PT_STARTUP_RESULTCODES.OK,"InitializeObjects successful.",
		        null);
	    
		try 
		{
			// Initialize the login helper
			LoginHelper.StaticInit(new PTLoginHelper());
			
		} 
		catch (Exception e) 
		{
			log.Fatal(e, "Failed to init the login helper.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "InitializeObjects: Failed to init the login helper",
			        XPException.GetInstance(e));
			return retVal;
		}
		
		// ES - initialize the replication cache, if enabled
		try 
		{
			// check if replication cache is enabled
			String strClusterName = ((PTConfigVarPack) vpConfig).GetConfigValueAsString(
									"Failover", "ClusterName", "value");

			// if there is a non-empty cluster name, it means failover is enabled.
			if (null != strClusterName && 0 != strClusterName.compareToIgnoreCase("")) {
				ReplicationCache.SetEnabled(true);
				// Initialize the replication cache
				ReplicationCache.StaticInit((PTConfigVarPack) vpConfig);
				log.Info("Failover is enabled. Cache initialized.  ClusterName = " + strClusterName);

			} else {
				ReplicationCache.SetEnabled(false);
				log.Info("Failover is disabled.");
			}
		} 
		catch (Exception e) 
		{
		    log.Error(e, "Failed to init the replication cache.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "InitializeObjects: Failed to init the replication cache.",
			        XPException.GetInstance(e));
			return retVal;
		}
		
		try 
		{
			
			SSOHelper.StaticInit(new SSOIntegrator());
		
		} 
		catch (Exception e) 
		{
			log.Fatal(e, "Failed to init the SSO helper.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "InitializeObjects: Failed to init the SSO helper.",
			        XPException.GetInstance(e));
			return retVal;
		}

		try 
		{
			// Initialize the performance counters
			// TODOCR: DonH -- Perhaps Init() should be removed from the interface
			// and the custom PT perf counter code should be initialized as follows:
			PTPerfCounters myPTPerfCounters = new PTPerfCounters();
			myPTPerfCounters.Init();
			PerfCounters.StaticInit(myPTPerfCounters);
//			PerfCounters.StaticInit(new PTPerfCounters());
		} 
		catch (Exception e) 
		{
			log.Fatal(e, "Failed to init the Perf Counter helper.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "InitializeObjects: Failed to init the Perf Counter helper.",
			        XPException.GetInstance(e));
			return retVal;
		}

		try
		{
			// Initialize the UI error handler with a helper class to handle
			// determining how to display admin errors
			UIErrorHandler.StaticInit(new PTErrorHandler());
		} 
		catch (Exception e)
		{
			log.Fatal(e, "Failed to initialize UIErrorHandler.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "InitializeObjects: Failed to initialize UIErrorHandler.",
			        XPException.GetInstance(e));
			return retVal;
		}
        
        try
        {
            // Initialize Compression Settings Matrix
            CompressionSettings.INSTANCE.Init();
        } 
        catch (Exception e)
        {
            log.Fatal(e, "Failed to initialize Compression Settings.");
            retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
                    "InitializeObjects: Failed to initialize Compression Settings.",
                    XPException.GetInstance(e));
            return retVal;
        }
		
        try {
        	boolean initAnalytics = false;

        	if (null != vpAnalytics) 
        	{
        		// Check if analytics is enabled
        		if (vpAnalytics.GetConfigValueAsBoolean(PTConfigConstants.ANALYTICS_ENABLED_SETTING)) 
        		{	
        			// Map logging level from String type to int type        			
        			String strLogLevel = vpAnalytics.GetConfigValueAsString(PTConfigConstants.ANALYTICS_LOGGING_LEVEL_SETTING);
        			int logLevel = Logger.INFO;
        			
        			if (null != strLogLevel)
        			{
        				if (ASEventConstants.LOGGING_LEVEL_DEBUG.equals(strLogLevel)) 
        				{
        					logLevel = Logger.DEBUG;
        				} 
        				else if (ASEventConstants.LOGGING_LEVEL_INFO.equals(strLogLevel)) 
        				{
        					logLevel = Logger.INFO;
        				}
        				else if (ASEventConstants.LOGGING_LEVEL_WARN.equals(strLogLevel)) 
        				{
        					logLevel = Logger.WARN;
        				}
        				else if (ASEventConstants.LOGGING_LEVEL_ERROR.equals(strLogLevel)) 
        				{
        					logLevel = Logger.ERROR;
        				}
        			}

        			//log.Debug("Analytics logging level is " + strLogLevel);
        			
        			// Check if clustering is enabled
        			if (vpAnalytics.GetConfigValueAsBoolean(PTConfigConstants.ANALYTICS_CLUSTERING_ENABLED_SETTING)) {
        				// clustering is enabled
        				ASEventFactory.setConfig(
       						vpAnalytics.GetConfigValueAsString(PTConfigConstants.ANALYTICS_CLUSTER_NAME_SETTING),
       						vpAnalytics.GetConfigValueAsInt(PTConfigConstants.ANALYTICS_CLUSTER_TIMEOUT_SETTING),
           					vpAnalytics.GetConfigValueAsInt(PTConfigConstants.ANALYTICS_CLUSTER_PORT_SETTING),
           					logLevel, 
           					vpAnalytics.GetConfigValueAsBoolean(PTConfigConstants.ANALYTICS_CONSOLE_LOGGING_SETTING));

        				initAnalytics = true;
        			} else {
        				// clustering is disabled
        				ASEventFactory.setConfig(
        					vpAnalytics.GetConfigValueAsString(PTConfigConstants.ANALYTICS_COLLECTOR_HOST_SETTING),
        					vpAnalytics.GetConfigValueAsInt(PTConfigConstants.ANALYTICS_COLLECTOR_PORT_SETTING), 
        					logLevel, 
        					vpAnalytics.GetConfigValueAsBoolean(PTConfigConstants.ANALYTICS_CONSOLE_LOGGING_SETTING),
        					vpAnalytics.GetConfigValueAsBoolean(PTConfigConstants.ANALYTICS_UNICAST_ENABLED_SETTING));

        				initAnalytics = true;
        			}
        		}        		
        	}        	
        	        	
        	// If the above fails, use the default setConfig()
        	if (!initAnalytics) {
        		ASEventFactory.setConfig();
        	}
        } catch (Exception e) {
            log.Warn(e, "Failed to initialize Anaylytics Event Factory.");
            retVal = new ReturnValue(PT_STARTUP_RESULTCODES.WARN,
                    "InitializeObjects: Failed to initialize Anaylytics Event Factory.",
                    XPException.GetInstance(e));
            return retVal;
        }
		return retVal;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.application.AAppWarmUpHelper#InitObjects(ConfigVarPack, String, String, String, CachingManager)
	 */
	public ReturnValue LoadObjects(ConfigVarPack vpConfig, String strApplicationName,
		String strImageServerBaseURL, String strSecureImageServerBaseURL,
		CachingManager cmCachingManager)
	{		
		ReturnValue retVal = new ReturnValue(PT_STARTUP_RESULTCODES.OK,"LoadObjects successful.",
		        null);

		try
		{
			// bjf -- initialize PlumtreeHelpers so that it can get default information for the
			// style sheet URL.
			PlumtreeHelpers.StaticInit((PTConfigVarPack)vpConfig);

			// Load ClassTypeDescManager

			log.Info("Loading the PT class type descriptor.");

			// LoadSettings and the Resouces must be called before ClassTypeDescManager is instantiated	
			ClassTypeDescManager ptClassDescMgr = new ClassTypeDescManager(cmCachingManager);
			// Override the base class description manager with the PT version.
			cmCachingManager.SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, ptClassDescMgr);
		} 
		catch (Exception e)
		{
			log.Fatal(e, "Failed to load PT ClassTypeDescManager!");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "LoadObjects: Failed to load PT ClassTypeDescManager!",
			        XPException.GetInstance(e));
			return retVal;
		}

		try 
		{
			// Initialize the ExpressionEngineFilter (interpreter filter)
			log.Debug("Initialize the ExpressionEngineFilter (interpreter filter)");

			com.plumtree.uiinfrastructure.interpreter.filter.ExpressionEngineFilter.StaticInit(
				new PTExpressionEngineFilter());
			
		} 
		catch (Exception e) 
		{
			log.Fatal(e, "Failed to init the expression engine interpreter filter.");		
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "LoadObjects: Failed to init the expression engine interpreter filter.",
			        XPException.GetInstance(e));
			return retVal;
		}

		try
		{
            // initialize ConditionTypeManager
            log.Info("Initializing the ConditionTypeManager.");
            ConditionTypeManager.GetInstance().Init(cmCachingManager);
            
			// Add the ConditionTypeManager into the CachingManager as an IExpressionEvaluator
			log.Info("Adding the ConditionTypeManager into the CachingManager.");
			cmCachingManager.SetEntry("ExpressionEvaluator", ConditionTypeManager.GetInstance());
		} 
		catch (Exception e)
		{
			log.Fatal(e, "Failed to add the ConditionTypeManager into the CachingManager!");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "LoadObjects: Failed to add the ConditionTypeManager into the CachingManager!",
			        XPException.GetInstance(e));
			return retVal;
		}	
		
		return retVal;
	}

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.application.IAppWarmUpHelper#InitializeManagers(String, String)
     */
    public ReturnValue InitializeManagers(String strLibHomePath, String strBaseConfigDirectory)
    {
		ReturnValue retVal = new ReturnValue(PT_STARTUP_RESULTCODES.OK,"InitializeManagers successful.",
		        null);
		try
		{
		    log.Info("Initializing AS with NavManager.");

			String strActivitySpacesXMLFile = AppWarmUp.GetSettingValueAsString(AppWarmUp.KEY_FILE_ACTIVITY_SPACES);

		    if (null != strActivitySpacesXMLFile)
		    {
		        NavManager.INSTANCE.LoadClasses(strLibHomePath, strActivitySpacesXMLFile);
		    }
		    
		    log.Info("NavManager initialized.");
		}
		catch (Exception e)
		{
			log.Fatal(e, "Error initializing AS with NavManager.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "InitializeManagers: Error initializing AS with NavManager.",
			        XPException.GetInstance(e));
			return retVal;
		}

		try
		{
			log.Info("Initializing TagLibManager.");

			if (null != strBaseConfigDirectory)
			{
				String strTagXMLFile = GeneralHelpers.FormatPath(strBaseConfigDirectory +
					"Tags.xml", AppWarmUp.PATH_SEPARATOR, false);

				TagLibManager.getInstance().LoadClasses(strLibHomePath, strTagXMLFile);
			}
		    
			log.Info("TagLibManager initialized.");
		}
		catch (Exception e)
		{
			log.Fatal(e, "Error initializing TagLibManager.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "InitializeManagers: Error initializing TagLibManager.",
			        XPException.GetInstance(e));
			return retVal;
		}
		
		return retVal;		
    }

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.application.IAppWarmUpHelper#LoadCustomManagers(String, String)
     */
    public ReturnValue LoadManagers(String strLibHomePath, String strBaseConfigDirectory)
    {
		ReturnValue retVal = new ReturnValue(PT_STARTUP_RESULTCODES.OK,"LoadManagers successful.",
		        null);
		try
		{
			log.Info("Loading AS into NavManager.");
		    
			String strCustomActivitySpacesXMLFile = AppWarmUp.GetSettingValueAsString(AppWarmUp.KEY_FILE_CUSTOM_ACTIVITY_SPACES);

			if (null != strCustomActivitySpacesXMLFile)
			{
				NavManager.INSTANCE.LoadCustomClasses(strLibHomePath, strCustomActivitySpacesXMLFile);
			}
		    
			log.Info("NavManager loading complete.");
		}
		catch (Exception e)
		{
			log.Fatal(e, "Error loading AS into NavManager.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "LoadManagers: Error loading AS into NavManager.",
			        XPException.GetInstance(e));
			return retVal;
		}

		try
		{
			log.Info("Loading Custom Tags in TagLibManager.");
		    
			if (null != strBaseConfigDirectory)
			{
				String strCustomTagXMLFile = GeneralHelpers.FormatPath(strBaseConfigDirectory +
					"CustomTags.xml", AppWarmUp.PATH_SEPARATOR, false);

				TagLibManager.getInstance().LoadCustomClasses(strLibHomePath, strCustomTagXMLFile);
			}
		    
			log.Info("TagLibManager loading complete.");
		}
		catch (Exception e)
		{
			log.Fatal(e, "Error loading Custom Tags in TagLibManager.");
			retVal = new ReturnValue(PT_STARTUP_RESULTCODES.FATAL,
			        "LoadManagers: Error loading Custom Tags in TagLibManager.",
			        XPException.GetInstance(e));
			return retVal;
		}
		
		return retVal;		
    }
}

