package com.plumtree.portaluiinfrastructure.application.varpacks;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This VarPack contains the localized names for all the installed locales.
 *
 * @author Stephen Chang
 */
public class PTDirPrefsVarPack extends BaseVarPack
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.application.varpacks.PTDirPrefsVarPack");

	/** The string ID of this variable package. */
	public static final String VARPACK_ID = "PTDirPrefsVarPack";
//	private static final String POPULAR_YES = "yes";
//	private static final String POPULAR     = "popular";
	// See DirConstants.DIR_FOLD_DESC_NONE
	private String m_strDocDescriptionType    = "DA"; // DF, DA, DN
	private String m_strFolderDescriptionType = "FN"; // FF, FA, FN

	/** The path to the folder in which SearchLocales.xml resides. */
	private XPArrayList m_xpPropColumns = null;

	private int m_nBrowseBy		    = 1; // 1,2  (search, db)
	private int m_nDefaultDocType   = 107;
	private int m_nNumDocsPerPage   = 20; // 1-99999
	private int m_nNumFolderColumns = 3; // 1 to 8
	private int m_nNumSubSubFolders = 5; // 1 to 5
	private int m_nRelatedResourcesPlacement = 1; // 1,2,3,4 (left, right, top, bottom)

	/** 
	 * SCC- This XPArrayList contains all server config setting ids that are stored in this varpack
	 * We need it for the Memory Debug page where we need to be able to iterate through the keys to display all the values.
	 */
	private XPArrayList m_xpKeys;


	/**
	 * Constructor for PTDirPrefsVarPack.
	 */
	public PTDirPrefsVarPack()
	{
		super();

		CreateKeysArrayList();
	}

	protected void CreateKeysArrayList()
	{
		m_xpKeys = new XPArrayList();
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE));
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS));
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS));
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE));
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE));
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE));
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY));
		m_xpKeys.Add(XPConvert.ToString(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE));
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetBrowseBy()
	{
		return m_nBrowseBy;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetDefaultDocType()
	{
		return m_nDefaultDocType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetDocDescriptionType()
	{
		return m_strDocDescriptionType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetFolderDescriptionType()
	{
		return m_strFolderDescriptionType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumDocsPerPage()
	{
		return m_nNumDocsPerPage;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumFolderColumns()
	{
		return m_nNumFolderColumns;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumSubSubFolders()
	{
		return m_nNumSubSubFolders;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public XPArrayList GetPropColumns()
	{
		return m_xpPropColumns;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetRelatedResourcesPlacement()
	{
		return m_nRelatedResourcesPlacement;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()
	 */
	public String GetVarPackID()
	{
		return VARPACK_ID;
	}

	/**
	 * This method will return an enumeration of the top level nodes in the XML
	 * tree that is SearchLocales.xml.
	 *
	 * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()
	 */
	public IXPEnumerator GetVarPackKeys()
	{
		return m_xpKeys.GetEnumerator();
	}

	/**
	 * You cannot expire the settings content. You can only reload it. This
	 * method does nothing.
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()
	 */
	protected void ExpireContent()
	{
	}

	/**
	 * @see com.plumtree.xpsupport.web.BaseVarPack#GetValue(String)
	 */
	protected Object GetValue(String strServerConfigID)
	{
		if(null == strServerConfigID)
			return "";
		
		int nServerConfigID = XPConvert.ToInteger(strServerConfigID);
		
		switch(nServerConfigID)
		{
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE:
				return "FolderDescriptionType: " + GetFolderDescriptionType();
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS:
				return "NumSubSubFolders: " + GetNumSubSubFolders();
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS:
				return "NumFolderColumns: " + GetNumFolderColumns();
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE:
				return "NumDocsPerPage: " + GetNumDocsPerPage();
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE:
				return "DocDescriptionType: " + GetDocDescriptionType();
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE:
				return "RelatedResourcesPlacement: " + GetRelatedResourcesPlacement();
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY:
				return "BrowseBy: " + GetBrowseBy();
			case PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE:
				return "DefaultDocType: " + GetDefaultDocType();
			default:
				return "No value for this setting.";
		}
	}

	/**
	 * This method loads the DirPrefs settings from the PTServerConfig table into memory.
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Load()
	 */
	protected void Load()
	{
		// This is the first place during startup that uses com.plumtree.server,
		// so it can take a while for this call to return, since it has to
		// initialize the core server.
		log.Info("Initializing Core Plumtree Server.");
		IPTSession ptGuestSession = PortalObjectsFactory.CreateSession();
		log.Info("Done Initializing Core Plumtree Server.");

		// Guest login -- The guest user password check is bypassed,
		// so we don't need to pass in the password.
		ptGuestSession.Connect(PT_INTRINSICS.PT_USER_GUEST, null, null);

		IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) ptGuestSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
				false);

		// Load Current Settings
		Object oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE);

		if (null != oValue)
		{
			m_strFolderDescriptionType = (String) oValue;
		}
		else
		{
			
				log.Error("Unable to retrieve folder description type.");
			
		}

		oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS);

		if (null != oValue)
		{
			m_nNumSubSubFolders = XPConvert.ToInteger(oValue);
		}
		else
		{
			
				log.Error("Unable to retrieve number of sub sub folders.");
			
		}

		oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS);

		if (null != oValue)
		{
			m_nNumFolderColumns = XPConvert.ToInteger(oValue);
		}
		else
		{
			
				log.Error("Unable to retrieve number of folder columns.");
			
		}

		oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE);

		if (null != oValue)
		{
			m_nNumDocsPerPage = XPConvert.ToInteger(oValue);
		}
		else
		{
			
				log.Error("Unable to retrieve number of docs per page.");
			
		}

		oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE);

		if (null != oValue)
		{
			m_strDocDescriptionType = (String) oValue;
		}
		else
		{
			
				log.Error("Unable to retrieve document description type.");
			
		}

		oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE);

		if (null != oValue)
		{
			m_nRelatedResourcesPlacement = XPConvert.ToInteger(oValue);
		}
		else
		{
			
				log.Error("Unable to retrieve related resources placement.");
			
		}

		oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY);

		if (null != oValue)
		{
			m_nBrowseBy = XPConvert.ToInteger(oValue);
		}
		else
		{
			
				log.Error("Unable to retrieve browse by.");
			
		}

		oValue = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE);

		if (null != oValue)
		{
			m_nDefaultDocType = XPConvert.ToInteger(oValue);
		}
		else
		{
			
				log.Error("Unable to retrieve default document type.");
			
		}

		LoadPropColumns(ptSCS);
	}

	/**
	 * This method reloads the DirPrefs settings. It delegates to Load().
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Reload()
	 */
	protected void Reload()
	{
		Load();
	}

	/**
	 * 
	 *
	 * @param _tSCS 
	 */
	private void LoadPropColumns(IPTServerConfigSettings _tSCS)
	{
		Object oValue = _tSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PROP_COLUMNS);

		m_xpPropColumns = new XPArrayList();

		if (null != oValue)
		{
			String strAllProps = (String) oValue;

			if (0 == strAllProps.length())
			{
				return;
			}

			XPStringTokenizer st = new XPStringTokenizer(strAllProps, " ");

			try
			{
				for (int i = 0; st.HasMoreTokens(); i++)
				{
					int nProp = XPConvert.ToInteger(st.GetNextToken());
					m_xpPropColumns.Add(new Integer(nProp));
				}
			}
			catch (Exception e)
			{
				
					log.Error(e, "Unable to load property columns.");
				
			}
		}
	}

	/** We share the logger for efficiency. */
	/**
	 * pre-determining which levels are enabled allows the jvm to avoid
	     */
}

