package com.plumtree.portaluiinfrastructure.application.varpacks;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.openkernel.config.*;

/**
 * Varpack to load navigation sepcific settings.
 *
 * @author Robert Zhang
 */
public class PTNavSettingsVarPack extends BaseVarPack
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.application.varpacks.PTNavSettingsVarPack");

	/** The string ID of this variable package. */
	public static final String VARPACK_ID = "NavigationSettingsVarPack";

	/** Constants for settings defined in the file **/
	public static final String INTISCDROPDOWNMENU_TRUNCATION_WIDTH  	= "intISCDropDownMenuTruncationWidth";
	public static final String INTISCDROPDOWNMENU_WIDTH  				= "intISCDropDownMenuWidth";
	public static final String INTHORIZONTALNAVTAB_TRUNCATION_WIDTH 	= "intHorizontalNavTabTruncationWidth";
	public static final String INTHORIZONTALNAVTAB_WIDTH 				= "intHorizontalNavTabWidth";
	public static final String INTMYPORTLETPREFBUTTON_IN_PORTLETHEADER 	= "intMyPortletPrefButtonInPortletHeader";
	
	public static final String INTPLUMTREEDPTABLESPACING 		= "intPlumtreeDPTableSpacing";
	public static final String INTPLUMTREEDPLEFTWIDTH 			= "intPlumtreeDPLeftWidth";
	public static final String INTPLUMTREEDPRIGHTWIDTH 			= "intPlumtreeDPRightWidth";
	public static final String INTPLUMTREEDPLEFTWIDTHALONE  	= "intPlumtreeDPLeftWidthAlone";
	public static final String INTPLUMTREEDPRIGHTWIDTHALONE  	= "intPlumtreeDPRightWidthAlone";

	// OpenConfig component type
	public static final String PORTAL_NAVIGATION_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/navigation";

	/** Table for storing the navigation settings **/
	private XPHashtable m_htNavigationSettings = null;

	/**
	 * Get the varpack ID.
	 * 
	 * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()
	 */
	public String GetVarPackID()
	{
		return VARPACK_ID;
	}

	/**
	 * Returns the enumeration of the navigation setting keys. 
	 * null if nothing was loaded.
	 * 
	 * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()
	 */
	public IXPEnumerator GetVarPackKeys()
	{
		try
		{
			return m_htNavigationSettings.GetKeys();
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/**
	 * Not implemented.
	 * 
	 * @see com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()
	 */
	protected void ExpireContent()
	{
	}

	/**
	 * Get the value of the specified navigation settings.
	 * null if settings doesn't exist.
	 * 
	 * @see com.plumtree.xpsupport.web.BaseVarPack#GetValue(String)
	 */
	protected Object GetValue(String strNavSetting)
	{
		try
		{
			return m_htNavigationSettings.GetElement(strNavSetting);
		}
		catch (Exception e)
		{
			
				log.Warn("Unable to find the following NavigationSetting: " + strNavSetting);
			
			
			return null;
		}
	}

	/**
	 * This method loads the NavigationSettings.xml file into memory.
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Load()
	 */
	protected void Load()
	{
		log.Info("Loading Navigation Settings var pack...");

		m_htNavigationSettings = new XPHashtable();
				
		// Use OpenConfig to read the settings
		IOKContext configContext = AppWarmUp.GetOKConfigContext();
		IOKComponent component = null;
		
		component = configContext.getComponentByType(PORTAL_NAVIGATION_COMPONENT_TYPE);

		if (null == component)
		{
			log.Warn("Cannot retrieve component type: {0}", PORTAL_NAVIGATION_COMPONENT_TYPE);
			return;
		}			
			
		IOKSetting[] settings = component.querySettings();
		for(int j=0;j<settings.length;j++)
		{
			String strName = settings[j].getName();
			String strValue = null;
			
			//log.Info("Setting Loaded: " + strName);		        
			//log.Info("Setting type: " + settings[j].getDataType());
		        
			int nSettingType = settings[j].getDataType();
			switch(nSettingType)
			{
				case OKConfigDataTypes.TYPE_BOOLEAN:
					strValue = XPConvert.ToString(settings[j].getBooleanValue());
					break;
				case OKConfigDataTypes.TYPE_STRING:
					strValue = settings[j].getStringValue();
					break;
				case OKConfigDataTypes.TYPE_INTEGER:
					strValue = XPConvert.ToString(settings[j].getIntValue());
					break;
				case OKConfigDataTypes.TYPE_FLOAT:
					strValue = XPConvert.ToString(settings[j].getFloatValue());
					break;
				case OKConfigDataTypes.TYPE_DATE:
					strValue = XPConvert.ToString(settings[j].getDateValue());
					break;
				default:
					throw new XPException("Unknown data type:" + nSettingType);
			}

			//log.Info("Setting value: " + strValue);
				
			if ((null != strName) && (null != strValue))
			{			
				m_htNavigationSettings.PutElement(strName, strValue);
				
				log.Debug("Loading Navigation Settings: " + strName + " with value: "+ strValue);
			}				
		}
			
		/*
		String strFileSeparator = XPFileSystemObject.GetPathSeparator();
		
		String strNavSettingsPath = GetConfigPath() + strFileSeparator + "NavigationSettings.xml";
		strNavSettingsPath = GeneralHelpers.FormatPath(strNavSettingsPath, strFileSeparator, false);

		XPDocument xmlDoc = XPBuilder.LoadDocument(strNavSettingsPath);
		XPElement rootNode = xmlDoc.GetDocumentElement();
		XPNodeList nlSettings = rootNode.GetChildNodes();
		// Make the hashtable big enough
		m_htNavigationSettings = new XPHashtable(nlSettings.GetLength());

		for (int i = 0; i < nlSettings.GetLength(); i++)
		{
			String sKey = nlSettings.Item(i).GetNodeName();
			if (!sKey.startsWith("#"))
			{
				String sValue = ((XPElement) nlSettings.Item(i)).GetAttributeNode("value").GetNodeValue();
				m_htNavigationSettings.PutElement(sKey, sValue);
				
				
					log.Debug("Loading Navigation Settings: " + sKey + " with value: "+sValue);
					
			}
		}
		*/
	}

	/**
	 * Clears and reloads all settings from the xml fie.
	 * 
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Reload()
	 */
	protected void Reload()
	{
		m_htNavigationSettings = null;
		Load();
	}
}

