package com.plumtree.portaluiinfrastructure.application.varpacks;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openkernel.config.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This var pack contains the time zone information.
 *
 * @author SudhaS
 */
public class PTTimeZoneVarPack extends BaseVarPack
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.application.varpacks.PTTimeZoneVarPack");

	/** The string ID of this variable package. */
	public static final String VARPACK_ID = "PTTimeZoneVarPack";

	// OpenConfig component type
	public static final String PORTAL_TIMEZONES_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/timezones";

	private static final String TIMEZONE_ID_PREFIX = "TimezoneID";
	
	private XPHashtable m_htTimeZoneXMLSettings;

	/**
	 * This XPArrayList contains all Locales that are loaded
  	 * We need it for the Memory Debug page where we need to be able to iterate through the keys to display all the values.
  	 */
	private XPArrayList m_xpKeys;

	/**
	 * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackID()
	 */
	public String GetVarPackID()
	{
		return VARPACK_ID;
	}

	/**
	 * This method will return an enumeration of the top level nodes in the XML
	 * tree that is x_config.xml.
	 *
	 * @see com.plumtree.uiinfrastructure.web.IVarPack#GetVarPackKeys()
	 */
	public IXPEnumerator GetVarPackKeys()
	{
		// We need to use this array list rather than the hash table, because
		// the hash table values are stored as Integers, but GetValue takes
		// Strings.
		return m_xpKeys.GetEnumerator();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetVarPackLength()
	{
		if (m_htTimeZoneXMLSettings == null)
		{
			return 0;
		}

		return m_htTimeZoneXMLSettings.GetSize();
	}

	/**
	 * You cannot expire the x_config.xml content. You can only reload it. This
	 * method does nothing.
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#ExpireContent()
	 */
	protected void ExpireContent()
	{
	}

	/**
	 * This method will return a chunk of from one level under the PTConfig
	 * node.
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#GetValue(String)
	 */
	protected Object GetValue(String arg0)
	{
		if (m_htTimeZoneXMLSettings == null)
		{
			return null;
		}

		int index = XPConvert.ToInteger(arg0);

		return ((String) m_htTimeZoneXMLSettings.GetElement(new Integer(index)));
	}

	/**
	 * This method loads the x_config.xml file into memory.
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Load()
	 */
	protected void Load()
	{
		/*
		String strFileSeparator = XPFileSystemObject.GetPathSeparator();
		
		
		XPDocument xmlDoc = XPBuilder.LoadDocument(GetConfigPath() +
				strFileSeparator + "timezones.xml");
		*/
				
		LoadSettingsIntoHashtable();

	}

	private void LoadSettingsIntoHashtable()
	{
		m_htTimeZoneXMLSettings = new XPHashtable();
		m_xpKeys = new XPArrayList();
		
		// Use OpenConfig to read the settings
		IOKContext configContext = AppWarmUp.GetOKConfigContext();
		IOKComponent component = null;
		
		component = configContext.getComponentByType(PORTAL_TIMEZONES_COMPONENT_TYPE);

		if (null == component)
		{
			log.Warn("Cannot retrieve component type: {0}", PORTAL_TIMEZONES_COMPONENT_TYPE);
			return;
		}			
			
		IOKSetting[] settings = component.querySettings();
		
		for(int j=0;j<settings.length;j++)
		{
			String strName = settings[j].getName();
			String strValue = null;	
		        
			int nSettingType = settings[j].getDataType();
			if (OKConfigDataTypes.TYPE_STRING == nSettingType)
			{
				strValue = settings[j].getStringValue();

				if (null != strValue)
				{
					// parse the ID number from the name field				
					if ((null != strName) && (strName.length()> TIMEZONE_ID_PREFIX.length()))
					{
						try 
						{
							int nKey = XPConvert.ToInteger(XPStringUtility.Substring(strName, TIMEZONE_ID_PREFIX.length()));

							// log.Info("Timezone: " + nKey);		        
							// log.Info("Value: " + strValue);
														
							m_htTimeZoneXMLSettings.PutElement(new Integer(nKey), strValue);

							// Add the key as a String so MemDebug page can iterate through the
							// timezones.
							m_xpKeys.Add(XPConvert.ToString(nKey));							
						}
						catch (Exception e)
						{
							log.Warn(e, "Error adding timezone: {0}", strName);
						}
					} else 
					{
						log.Warn("Found invalid timezone ID: {0}", strName);
					}
				} else 
				{
					log.Warn("Found null value for timezone: {0}", strName);
				}
			}
			else 
			{
				log.Warn("Invalid data type for TimezoneID{0}", j);
			}
			
		}

	}

	/**
	 * This method reloads the x_config.xml file into memory. It clears the
	 * current data and then delegates to Load().
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Reload()
	 */
	protected void Reload()
	{
		Load();
	}
}