package com.plumtree.portaluiinfrastructure.classtypedescriptors;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * This class provides the contract for extensible PTClassTypes.
 * It provides basic implementations for GetRedirectCreateNew and
 * GetRedirectOpenObject, two of the modes of the Common Opener.
 * 
 * @author John Osborne
 */
public abstract class APTExtClassTypeDesc extends APTClassTypeDesc
{	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
	 */
	public abstract boolean AppearsInMainCreateNewClassMenu();

	/**
	 * Returns the name of the Activity Space that is used 
	 * to edit this class type.
	 *
	 * @param _strProvEnglishName The english name of the 
	 * provider that is being used for this class type.
	 *  
	 * @return The name of the Activity Space that is used 
	 * to edit this class type.
	 */
	public abstract String GetASNameForEditor(String _strProvEnglishName);

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
	 */
	public abstract int GetClassID();

	/**
	 * Returns the CLSID for this object. 
	 *
	 * @param _nObjectID The object ID.
	 * @param _ptSession The current session.
	 *
	 * @return The CLSID for this object.
	 */
	public abstract String GetCLSIDForExistingObject(int _nObjectID,
		IPTSession _ptSession);

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectCreateNew(XPHashtable _htArguments,
		AActivitySpace _asParent, Object _userSession)
	{
		Redirect resultingRedirect = new Redirect();
		
		ClassTypeDescManager ptClassTypeDescManager = 
			PTConfigHelper.GetPTClassTypeDescrManager();

		// retrieve the provider english name and folder id.
		String strProvEngName = HTTPHelpers.GetArgumentAsString(_htArguments,
			IPTOpenerConstants.QS_PROV_ENG_NAME, HTTPHelpers.GetArgumentAsString(
			_htArguments, IPTOpenerConstants.STR_QS_PROVIDER_ENG_NAME, null));		
		int nFolderID = HTTPHelpers.GetArgumentAsInt(_htArguments,
			IPTOpenerConstants.QS_FOLDERID, HTTPHelpers.GetArgumentAsInt(
			_htArguments, IPTOpenerConstants.STR_QS_FOLDERID, -1));
		boolean bFolderNotRequired = HTTPHelpers.GetArgumentAsBoolean(_htArguments, 
			IPTOpenerConstants.STR_QS_FOLDERNOTREQUIRED, false);

		// the server requires a folder id except for a special
		// case.  if we cannot get it, then throw an UI error. 
		// for the special case where it's not required.
		if ((nFolderID == -1) && (!bFolderNotRequired))
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,  
				null, _asParent.GetString(481, "ptmsgs_portalinfrastructure"), null);
			UIErrorHandler.RaiseError(myError, _asParent.GetSubSession(), 
				_asParent.GetApplication());
						
			throw new XPException("A folder ID argument is required in the Common" + 
				" Opener URL for this object in create mode.");
		}

		// the provider name is also required.  if we cannot 
		// get this, then we will also throw an UI error.		
		if ((null == strProvEngName) ||
			(null == ptClassTypeDescManager.
				GetRegisteredProvInfoGivenEnglishName(strProvEngName)))
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER, 
				null, _asParent.GetString(482, "ptmsgs_portalinfrastructure"), null);
			UIErrorHandler.RaiseError(myError, _asParent.GetSubSession(), 
				_asParent.GetApplication());			

			throw new XPException("A valid provider name argument is required" +
				" in the Common Opener URL for extensible objects in create mode.");							
		}		
						
		// open the correct Activity Space in create mode. 
		resultingRedirect.SetLinkCreateNewSpace(GetASNameForEditor(strProvEngName), _asParent);
		resultingRedirect.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
			XPConvert.ToString(GetClassID()));
		resultingRedirect.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
			XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_CREATE));
		resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID, 
			nFolderID);

		// pass on the subspace key if it exists.
		String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE, 
			HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE_INPUT, null));
		if (null != strSubSpaceKey)
		{
			resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
		}

		// pass on the ForceSaveInFolder flag if it exists.
		String sForceSaveInFolder = HTTPHelpers.GetArgumentAsString(_htArguments,
			IPTOpenerConstants.STR_QS_FORCESAVEINFOLDER, null);
		if (null != sForceSaveInFolder)
		{
			resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER,
				sForceSaveInFolder);
		}
		
		// pass on the CloseOnDone flag if it exists.
		String strCloseOnDone = HTTPHelpers.GetArgumentAsString(_htArguments, 
			IPTOpenerConstants.STR_QS_CLOSEPOPUPONDONE, null);
		if (null != strCloseOnDone)
		{
			resultingRedirect.AddControlArgument(EditorStartControl.QS_CLOSE_WINDOW_ON_DONE, 
				strCloseOnDone);
		}
		
		// pass on the XUI datasource if it exists.
		String strXUIDataSourceID = HTTPHelpers.GetArgumentAsString(_htArguments,
			XUIHelperMethods.QS_XUI_DATASOURCE_ID, null);
		if (null != strXUIDataSourceID)
		{
			resultingRedirect.AddControlArgument(XUIHelperMethods.QS_XUI_DATASOURCE_ID,
				strXUIDataSourceID);
		}

		// pass on the XUI webservice if it exists.
		String strXUIWebServiceID = HTTPHelpers.GetArgumentAsString(_htArguments,
			XUIHelperMethods.QS_XUI_WEBSERVICE_ID, null);
		if (null != strXUIWebServiceID)
		{
			resultingRedirect.AddControlArgument(XUIHelperMethods.QS_XUI_WEBSERVICE_ID,
				strXUIWebServiceID);
		}

		String strParentSpaceName = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.PARENTSPACENAME, 
			HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.PARENTSPACENAME_INPUT, null));

		// if a parentspace doesn't exist, then we will default to the
		// MyPage AS.  this is a precaution since everyone has access 
		// to this space, so we don't get errors after creation.
		if (null == strParentSpaceName)
		{
			_htArguments.PutElement(ASConstants.PARENTSPACENAME, new String[] {"MyPage"});
			_asParent.SetCurrentFormData(_htArguments);
		}

		return resultingRedirect;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectOpenObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectOpenObject(XPHashtable _htArguments,
		AActivitySpace _asParent, Object _userSession)
	{
		Redirect resultingRedirect = new Redirect();

		// retrieve the object id and provider name.
		int nObjectID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID, 
			HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID, -1));
		String strProvEngName = PTConfigHelper.GetPTClassTypeDescrManager().
			GetProviderEnglishNameForExistingObject(GetClassID(), nObjectID, (IPTSession) _userSession);
	
		// open the correct Activity Space in edit mode. 
		resultingRedirect.SetLinkCreateNewSpace(GetASNameForEditor(strProvEngName), _asParent);
		resultingRedirect.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		resultingRedirect.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
			XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
		resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
			XPConvert.ToString(GetClassID()));
		resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
			XPConvert.ToString(nObjectID));

		// pass on the display page name if it exists.
		String strDPName = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.PAGE,
			HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.PAGE_INPUT, null));
		if (null != strDPName)
		{
			resultingRedirect.AddControlArgument(ASConstants.PAGE, strDPName); 
		}

		// pass on the subspace key if it exists.
		String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE,
			HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE_INPUT, null));
		if (null != strSubSpaceKey)
		{
			resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
		}

		// pass on the CloseOnDone flag if it exists.
		String strCloseOnDone = HTTPHelpers.GetArgumentAsString(_htArguments, 
			IPTOpenerConstants.STR_QS_CLOSEPOPUPONDONE, null);
		if (null != strCloseOnDone)
		{
			resultingRedirect.AddControlArgument(EditorStartControl.QS_CLOSE_WINDOW_ON_DONE, 
				strCloseOnDone);				
		}

		return resultingRedirect;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#IsExtensible()
	 */
	public boolean IsExtensible()
	{
		return true;
	}
}