package com.plumtree.portaluiinfrastructure.classtypedescriptors;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.opener.types.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * Interface for PTClassTypeDesc.  
 * 
 * @author John Osborne
 */
public interface IPTClassTypeDesc extends IClassTypeDesc
{
	/**
	 * Returns a boolean that tells the client if this class 
	 * type should appear in the main create new object menu.
	 *
	 * @return A boolean that tells the client if this class 
	 * type should appear in the main create new object menu.
	 */
	public boolean AppearsInMainCreateNewClassMenu();

	/**
	 * Returns a boolean that tells the client if this class 
	 * type appears in the global object property map utility.
	 *
	 * @return A boolean that tells the client if this class 
	 * type appears in the global object property map utility
	 */
	public boolean AppearsInGlobalObjPropMap();
	
	/**
	 * Returns the class ID of the class type. Use the 
	 * PT_CLASSIDS constant to determine/reference IDs.
	 *
	 * @return The class ID of the class type.
	 */
	public int GetClassID();

	/**
	 * Returns the localized name for the class type. For example, 
	 * the name for users is "User" in English.
	 *
	 * @param _strLangID The language to retrieve the name for.
	 *
	 * @return The localized name for the class type.
	 */
	public String GetClassTypeLocalizedName(String _strLangID);

	/**
	 * Returns the default icon for items of this class type.
	 *
	 * @return The default icon for items of this class type.
	 */
	public HTMLImg GetDefaultIcon();

	/**
	 * This method lets you associate the class ID for this
	 * PTClassType with other class IDs.  One application 
	 * for this is at the end of the editor creation wizard,
	 * it provides shortcut links to create related objets.
	 * 
	 * Return NULL if there are no related class types.
	 *
	 * @return An array of related class IDs. May be NULL.
	 */
	public int[] GetRelatedClassTypeIDs();

	/**
	 * This method lets you specify what kind of PTClassTypes
	 * depend on this PTClassType.  One application 
	 * for this is to make sure to try to delete dependent
	 * items before deleting the main item, otherwise the
	 * delete may fail because there are dependent items.
	 * 
	 * This method should only return class types that are
	 * directly dependent on this class type.
	 * 
	 * For example, Remote Servers should return Web Services,
	 * but not Portlets.  Web Services should return Portlets.
	 * 
	 * Return NULL if there are no related class types.
	 *
	 * NOTE: This does not support circular loops of dependencies
	 * (I.E. A -> B -> C -> A).  This behavior is undefined, and
	 * will mostly likely cause deletes of those objects to fail.
	 *
	 * @return An array of dependent class IDs. May be NULL.
	 */
	public int[] GetDependentClassTypeIDs();

	/**
	 * Returns a boolean that tells the client if this class 
	 * type is on the global class type map.
	 *
	 * @return A boolean that tells the client if this class 
	 * type is on the global class type map.
	 */
	public boolean HasGlobalClassTypeMap();

	/**
	 * Returns a boolean that tells the client if this class 
	 * type is extensible.
	 *
	 * @return A boolean that tells the client if this class 
	 * type is extensible.
	 */
	public boolean IsExtensible();
    
    /**
     * Returns a boolean that tells the client if this class 
     * included/supported on the "Admin UI->Release Item Locks" page.
     * @return A boolean that tells the client if this class 
     * included/supported on the "Admin UI->Release Item Locks" page.
     */
    public boolean HasObjectLockManager();

    /**
     * Returns the localized name that will be displayed on the 
     * left navigation menu of "Admin UI->Release Item Locks" page.
     *
     * @param _strLangID The language to retrieve the name for.
     *
     * @return The localized name for the class type.
     */
    public String GetObjectLockManagerLocalizedName(String strLangID);
    
    /**
	 * This method is called by the Common Opener in the view
	 * mode.  Depending on what class type you are dealing with,
	 * the Common Opener will invoke the correct implemented 
	 * method.  Some class types may need to override this so
	 * that they can put additional control arguments in.
	 *
	 * @param _fURLParser contains the URL path.
	 * @param _asParent The parent activity space.
	 * @param _userSession The current session.
	 *
	 * @return A redirect that will bring you to the view 
	 * activity space for the particular class/object.
	 * 
	 * @exception An exception is thrown if the object to be viewed cannot be determined.
	 */
	public Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser,
			AActivitySpace _asParent, Object _userSession);
	
	/**
	 * Generates a friendly URL to the implementing class type. 
	 * 
	 * Ideally the object name is provided, otherwise if only the object id is provided, the method has to look up
	 * the object name.
	 * 
	 * If both are provided, both the object name and object id is used in the friendly url.
	 * 
	 * @param url FriendlyURL containing the information for the url 
	 * @return Returns the friendly part of the friendly Url, that is, just the part of the Url after server.pt
	 * including leading slash. 
	 */
	public String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space);
}

