package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common Opener Mode Description:
 * 1) Create - Admin folder editor in create mode (APTNonExtClassTypeDesc).
 * 2) Edit - Admin folder editor in edit mode (APTNonExtClassTypeDesc).
 * 3) View - Admin directory where folder exists (APTClassTypeDesc).
 * 4) Meta - View object properties page (APTClassTypeDesc).
 * 
 * @author John Osborne
 */
public class PTAdminFolders extends APTNonExtClassTypeDesc
{
    
    public PTAdminFolders() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 1994;
    }
    
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
	 */
	public boolean AppearsInMainCreateNewClassMenu()
	{
		return true;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
	 */
	public String GetASNameForEditor()
	{
		return "AdminFolderEditor";
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
	 */
	public int GetClassID()
	{
		return PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
	 */
	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(3, "ptmsgs_portalinfrastructure", _strLangID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
	 */
	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_ADMINFOLDERS;	
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
	 */
	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(
				PTImageType.ICON_FOLDER).GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
	 */
	public Redirect GetRedirectViewObject(XPHashtable _htArguments, AActivitySpace _asParent, Object _userSession)
	{	
		// create the redirect object.
		Redirect resultingRedirect = new Redirect();

		// we want to go to the object manager space.
		// Use a cached space if possible.
		resultingRedirect.SetLinkGetSpaceIfCached("ObjMgr", _asParent);
		// OpenSubFolderControl.STR_MVC_CLASS_NAME.
		resultingRedirect.SetControl("ObjMgrSettings"); 

		// pass on the subspace key if it exists.
		String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE, 
			HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE_INPUT, ""));
		resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
		
		// retrieve class and object ids.
		int nObjectID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID,
			HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID, -1));
		int nClassID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_CLASSID,
			HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_CLASSID, -1));

		// Retrieve currently expanded class IDs so that the Opener can be used
		// by the Admin Directory
		// TODO: don't use magic strings
		String strExpandedClassIDs = HTTPHelpers.GetArgumentAsString(_htArguments,
			"ObjectIDs", "");

		if (!strExpandedClassIDs.equals(""))
		{
			// ObjMgrSettingsControl.OBJECT_IDS
			resultingRedirect.AddControlArgument("ObjectIDs", strExpandedClassIDs);
		}

		// add class and object control arguments.
		resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID, nObjectID);
		resultingRedirect.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, nClassID);

		// add folder control argument.
		resultingRedirect.AddControlArgument("FolderID", nObjectID);
		
		return resultingRedirect;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetRelatedClassTypeIDs()
	{
		return null;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
	 */
	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
}

