package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.opener.plugins.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common Opener Mode Description:
 * 1) Create - Community editor in create mode (APTNonExtClassTypeDesc).
 * 2) Edit - Community editor in edit mode (APTNonExtClassTypeDesc).
 * 3) View - Goes to the community (PTCommunities).
 * 4) Meta - View object properties page (APTClassTypeDesc).
 * 
 * @author John Osborne
 * @author Dusting Ang
 * @author Robert Zhang
 */
public class PTCommunities extends APTNonExtClassTypeDesc
{	
	private static OpenLogger fulog = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_FRIENDLYURL),
			"com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.PTCommunities");
	
	public static final String COMMUNITY_AS_NAME = "CommunityPage";	
	public static final String COMMUNITY_CONTROL_NAME = "SetCommunity";	
	public static final String STR_COMMUNITY_ID = "CommunityID";	
	public static final String STR_PAGE_ID = "PageID";
	public static final String STR_QS_PAGEID = "PageID";
	public static final String COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID = "ctID";
	public static final String COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT = "inherit"; 

    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */ 
    public PTCommunities() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 1525;
    }

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
	 */
	public boolean AppearsInMainCreateNewClassMenu()
	{
		return true;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
	 */
	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_COMMUNITIES;	
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
	 */
	public String GetASNameForEditor()
	{
		return "CommunityEditor";
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
	 */
	public int GetClassID()
	{
		return PT_CLASSIDS.PT_COMMUNITY_ID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
	 */
	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(5, "ptmsgs_portalinfrastructure", _strLangID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
	 */
	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(
				PTImageType.ICON_COMMUNITY).GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, Object)
	 */
	public Redirect GetRedirectViewObject(XPHashtable _htArguments,
		AActivitySpace _asParent, Object _userSession)
	{
		Redirect resultingRedirect = new Redirect();

		int nCommunityID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID, 
			HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID, -1));

		int nPageID = HTTPHelpers.GetArgumentAsInt(_htArguments, STR_QS_PAGEID, 0);

		// in view mode, we go to the community.
		resultingRedirect.SetLinkCreateNewSpace(COMMUNITY_AS_NAME, _asParent);
		resultingRedirect.SetControl(COMMUNITY_CONTROL_NAME);
		resultingRedirect.AddControlArgument(STR_COMMUNITY_ID, nCommunityID);
		resultingRedirect.AddControlArgument(STR_PAGE_ID, nPageID);
		
		// no parent space or parent ID
		resultingRedirect.SetStripParentSpace(true);		

		return resultingRedirect;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.IClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectCreateNew(XPHashtable _htArguments, AActivitySpace _asParent, Object _userSession)
	{
		Redirect result = super.GetRedirectCreateNew(_htArguments, _asParent, _userSession);
		
		int nCommTemplateID = HTTPHelpers.GetArgumentAsInt(_htArguments, COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID, 0);
		if (0 != nCommTemplateID)
		{
			result.AddControlArgument(COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID, nCommTemplateID);
			result.AddControlArgument(COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT, HTTPHelpers.GetArgumentAsBoolean(_htArguments, COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT, (0 != nCommTemplateID)));
		}
		
		return result;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetRelatedClassTypeIDs()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
	 */
	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject()
	 * 
	 * CR rob - why isn't this a proper javadoc comment? Should start with /** instead of /*
	 * CR rob - what happens if there is excetions in any of the code? for example if there is an invalid friendly url 
	 * DCA - There is proper javadoc comment in the Interface: IPTClassTypeDesc
	 */
	public Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser, AActivitySpace _asParent, Object _userSession)
	{
		if (null == _fURLParser || null == _asParent || null == _userSession) {
			throw new PTException("Parameters cannot be null.", PT_RESULTCODES.PT_E_INVALIDARGUMENT);
		}
		
		Redirect resultingRedirect = new Redirect();
		//  DCA - used cached version if available in case it's a repost
		resultingRedirect.SetLinkGetSpaceIfCached(COMMUNITY_AS_NAME, _asParent);
		resultingRedirect.SetControl(COMMUNITY_CONTROL_NAME);
		
		String strCommunityName = _fURLParser.GetObjectName(true);
		int nCommunityId = _fURLParser.GetObjectId();
		String strPageName = _fURLParser.GetChildName(true);
		int nPageId = _fURLParser.GetChildId();
		IPTObjectManager ptCommunityManager = (IPTObjectManager) ((IPTSession) _userSession).GetCommunities();
		
		// DCA - figure out the community Id if we don't have it
		int[] arrCommunityIds = null;
		if (nCommunityId < 1) {
			arrCommunityIds = ptCommunityManager.LookupObjectIdFromName(strCommunityName);
			if (arrCommunityIds.length == 1) {
				nCommunityId = arrCommunityIds[0];
			}
		}
		
		if ( nPageId == 0 )
		{
			// DCA - figure out page id
			if (null != strPageName && nCommunityId > 0) {
				// DCA - map page name to page Id
				try {
					nPageId = ((IPTCommunityManager) ptCommunityManager).LookupPageIdFromCommunityPageName(nCommunityId, strPageName);
				} catch (XPException e) {
					// redirect to community home page
					fulog.Debug(e, "Could not find page with name: "+strPageName);
				}
			// look it up from the list of possible communities
			} else if (null != strPageName && null != arrCommunityIds) {
				nCommunityId = 0;
				int nTempPageId = 0;
				for (int i=0; i<arrCommunityIds.length; i++) {
					try {
						nTempPageId = ((IPTCommunityManager) ptCommunityManager).LookupPageIdFromCommunityPageName(arrCommunityIds[i], strPageName);
					} catch (Exception e) {
						// DCA - page was not found in this community
						nTempPageId = 0;
					}
					if (nTempPageId > 0 && nCommunityId <= 0) {
						// DCA - this may be the community they are talking about
						nCommunityId = arrCommunityIds[i];
						nPageId = nTempPageId;
					} else if (nTempPageId > 0 && nCommunityId > 0) {
						// DCA - we have 2 communities with the same page name specified
						// we're no longer sure which community they want
						nCommunityId = 0;
						break;
					}
				}
			} 
			// else we will go to the search result page
		}
		// 3 different possible routes from here:
		// 1. We have community and page id - success! Create and redirect
		// 2. We have community id but no page id, just go to the community home page (they'll be able to go to the right page from there)
		// 3. No community id, go to the search result page 
		if (nCommunityId > 0) {
			// case 1 and 2
			resultingRedirect.AddControlArgument(STR_COMMUNITY_ID, nCommunityId);
			fulog.Debug("PTCommunities:GetRedirectViewObject Redirecting to community with Id: " + nCommunityId + " and page Id: " + nPageId);
			resultingRedirect.AddControlArgument(STR_PAGE_ID, nPageId);
		} else {
			// case 3
			// DCA - nCommunityId <= 0 means there was more than one community w/ the same name
			// redirect to a search results querying for the community name
			fulog.Debug("PTCommunities:GetRedirectViewObject More than one community found. Redirecting to search.");
			resultingRedirect = new Redirect();
			resultingRedirect.SetLinkCreateNewSpace("SearchResult", _asParent);
			resultingRedirect.SetControl("advancedstart");
			resultingRedirect.AddControlArgument(SearchResultControl.USER_QUERY, strCommunityName);
			resultingRedirect.AddControlArgument("in_hi_req_objtype", PT_CLASSIDS.PT_COMMUNITY_ID);
			
		}
		return resultingRedirect;
	}
	
	/**
	 * @see IPTClassTypeDesc#ConstructFriendlyURL(String, int, String) 
	 * 
	 * Generates a friendly Url for Community or Community page
	 */
	public String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space)
	{
		String objectName = url.GetOjectName();
		String pageName = url.GetChildName();
		int pageId = url.GetChildId();
		int objectId = url.GetObjectId();
		
		if ( ("".equals(objectName) || objectName == null) && objectId <= 0 ) { 
			throw new PTException("Both object name and id are missing. At leaset one needs to be specified to create a friendly Url.", PT_RESULTCODES.PT_E_INVALIDARGUMENT); }
		
		XPStringBuilder buf = new XPStringBuilder(200);
		// Lookup the keyword for communities
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		IFriendlyURLManager ptFriendlyURLMgr = (IFriendlyURLManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
		String commKeyword = ptFriendlyURLMgr.LookupFriendlyURLKeyFromClassId(PT_CLASSIDS.PT_COMMUNITY_ID+"");
		if ( commKeyword == null ) {
			throw new PTException("No Friendly URL keyword was found for Communities. "+
					"Verify that a mapping entry exists in FriendlyURL.xml.", PT_RESULTCODES.PT_E_FAIL);
		}
		buf.Append("/").Append(commKeyword);
		
		IPTSession session = (IPTSession)space.GetUserSession();
		// need to lookup object name from object id. Use the community object cache
		if ( ("".equals(objectName) || objectName == null) ) {
			IPTCommunityInfo comm = null;
			try {
				comm = ((IPTCommunityManager)session.GetCommunities()).CachedOpenCommunityInfo(objectId, false);
			} catch (PTException e) {
				throw new PTException(e, 
						"Invalid community id provided: "+objectId+ " . The community does not exist or the user does not have access to it.", 
						PT_RESULTCODES.PT_E_INVALIDARGUMENT);
			}
			
			objectName = comm.GetPrimaryName();
		}
		// Add the community name to the url but massage the name first
		String normObjectName = FriendlyURL.NormalizeObjectName(objectName);
		// DCA - we're encoding in case it has non-ASCII chars
		normObjectName = XPHttpUtility.UrlEncode(normObjectName, LinkConstants.UTF_8_ENCODING);
		buf.Append("/").Append(normObjectName);

		// Add object id if there are more than one community with the same name
		// to dis-ambiguate
		
		// To handle special charactres in urls, always add object id and encode all special characters to underscores
		// we want to change any underscores to spaces so that search can find any ambigous entries 
		//objectName = FriendlyURL.DeNormalizeObjectName(objectName); 
		//int ids[] = session.GetCommunities().LookupObjectIdFromName(objectName);
		//if ( url.GetUseIdIfAvailable() || ids.length > 1) {
		//	buf.Append("/").Append(objectId);
		//}
		if ( FriendlyURLPlugin.UseObjectId() ) {
			buf.Append("/").Append(objectId);
		}
		
		// Do we need to add page to the url?
		if ( pageId != 0) 
		{
			// we don't have page name so look it up from the id
			if ( pageName == null ) {
				IPTPageInfo page = null;
				try {
					page = ((IPTPageManager)session.GetPages()).CachedOpenPageInfo(pageId, false, false);
				} catch (PTException e) {
					throw new PTException(e, 
							"Invalid page id provided: "+pageId+ " . The community page does not exist or the user does not have access to it.", 
							PT_RESULTCODES.PT_E_INVALIDARGUMENT);
				}
				pageName = page.GetName();
			}
			// normalize page name
			pageName = FriendlyURL.NormalizeObjectName(pageName);
			// DCA - we're encoding in case it has non-ASCII chars
			pageName = XPHttpUtility.UrlEncode(pageName, LinkConstants.UTF_8_ENCODING);
			buf.Append("/").Append(pageName);
			// check if we should add page id to disambiguate page names
			if ( FriendlyURLPlugin.UseObjectId() ) {
				buf.Append("/").Append(pageId);
			}
			
			
		}

		return buf.ToString();
	}
}