package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common Opener Mode Description:
 * 1) Create - Show error. (PTDocuments).
 * 2) Edit - Document editor in edit mode (APTExtClassTypeDesc).
 * 3) View - Clickthrough to document (PTDocuments).
 * 4) Meta - View object properties page (PTDocuments).
 *
 * @author John Osborne
 */
public class PTDocuments extends APTExtClassTypeDesc
{
	public static final String DOCUMENT_AS_NAME = "OpenDoc";	
	public static final String DOCUMENT_DP_NAME = "OpenDoc";
	public static final String DOCUMENT_CONTROL_NAME = "OpenDoc";
	public static final String STR_CARD_ID = "cardID";
	public static final String SEARCH_AS_NAME = "SearchResult";
	public static final String SEARCH_CONTROL_NAME = "advancedstart";
	public static final String STR_OBJTYPE = "in_hi_req_objtype";
	
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */ 
    public PTDocuments() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 1523;
    }
    
	public boolean AppearsInMainCreateNewClassMenu()
	{
		return false;
	}

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.IPTClassTypeDesc#AppearsInGlobalObjPropMap()
     */
    public boolean AppearsInGlobalObjPropMap()
    {
        return false;
    }

	public String GetASNameForEditor(String _strProvEnglishName)
	{
		return GetASNameForEditor();
	}

	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE;	
	}

	public String GetASNameForEditor()
	{
		return "CardEditor";
	}

	public int GetClassID()
	{
		return PT_CLASSIDS.PT_CATALOGCARD_ID;
	}

	public final String GetCLSIDForExistingObject(int _nObjectID,
		IPTSession _ptSession)
	{
		IPTCard ptDocument		   = (IPTCard) _ptSession.GetCatalog().OpenCard(_nObjectID, false);
		int nDataSourceID		   = ptDocument.GetDataSourceID();
		IPTDataSource ptDataSource = (IPTDataSource) _ptSession.GetDataSources()
			.Open(nDataSourceID, false);
		String sProviderCLSID	   = ptDataSource.GetDataSourceProviderCLSID();

		return sProviderCLSID;
	}

	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm     = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(11, "ptmsgs_portalinfrastructure", _strLangID);
	}

	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT)
				.GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectCreateNew(XPHashtable _htArguments,
			AActivitySpace _asParent, Object _userSession)
	{
		UIError myError = new UIError(UIErrorLevel.SERIOUS,
		UIErrorScope.CURRENT_USER, null, 
			_asParent.GetString(486, "ptmsgs_portalinfrastructure"), null);
		UIErrorHandler.RaiseError(myError,
			_asParent.GetSubSession(), _asParent.GetApplication());			

		throw new XPException("The Common Opener does not support create mode for this class type.");
	}
	
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectViewObject(XPHashtable _htArguments,
		AActivitySpace _asParent, Object _userSession)
	{
		int nCardID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID, 
			HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID, -1));

		IPTSession ptSession = (IPTSession) _userSession;

		try 
		{
			IPTCatalogStatistics ptCatalogStatistics = ptSession.GetCatalog().GetStatistics();
			ptCatalogStatistics.ReportCardAccess(nCardID);
		} 
		catch(Exception e)
		{
			// Don't prevent the opening of the card just because 
			// of an exception in the card popularity reporting.
		}
		
		Redirect resultingRedirect = new Redirect();

		resultingRedirect.SetLinkCreateNewSpace(DOCUMENT_AS_NAME, _asParent);

		// Spoof the sub-space key
		String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE,
			HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE_INPUT, ""));

		if (!strSubSpaceKey.equals(""))
		{
			resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
		}
		
		// STR_MVC_CLASS_NAME
		resultingRedirect.SetDisplayPage(DOCUMENT_DP_NAME);
		
		// DirConstants.QS_CARDID
		resultingRedirect.AddControlArgument(STR_CARD_ID, nCardID);
		 
		resultingRedirect.SetControl(DOCUMENT_CONTROL_NAME);

		return resultingRedirect;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObjectMetaData(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectViewObjectMetaData(XPHashtable _htArguments,
		AActivitySpace _asParent, Object _userSession)
	{
		// Create the Redirect Object
		Redirect resultingRedirect = new Redirect();

		resultingRedirect.SetLinkGetSpaceIfCached("Dir", _asParent);

		// Spoof the sub-space key
		String strSubSpaceKey = HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE,
			HTTPHelpers.GetArgumentAsString(_htArguments, ASConstants.SUBSPACE_INPUT, ""));

		if (!strSubSpaceKey.equals(""))
		{
			resultingRedirect.SetSubSpaceKey(strSubSpaceKey);
		}

		if(AccessStyles.STANDARD == _asParent.GetAccessStyle())
		{
			// DirCardPropertiesDP.STR_MVC_CLASS_NAME
			resultingRedirect.SetDisplayPage("DirCardProperties");
		}
		else
		{
			// DirCardPropertiesDP_D.STR_MVC_CLASS_NAME
			resultingRedirect.SetDisplayPage("DirCardPropertiesDP_D");
		}
		
		// DirRepostControl.STR_MVC_CLASS_NAME
		resultingRedirect.SetControl("DirRepost"); 

		int nCardID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID, 
			HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID, -1));

		// DirConstants.QS_CARDID
		resultingRedirect.AddControlArgument(STR_CARD_ID, nCardID); 

		return resultingRedirect;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetRelatedClassTypeIDs()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
	 */
	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject()
	 */
	public Redirect GetRedirectViewObject(IFriendlyURLParser _fURLParser, AActivitySpace _asParent, Object _userSession)
	{
		if (null == _fURLParser || null == _asParent || null == _userSession) {
			throw new PTException("Parameters cannot be null.", PT_RESULTCODES.PT_E_INVALIDARGUMENT);
		}
		
		Redirect resultingRedirect = new Redirect();
		IPTCatalog ptCatalog = (IPTCatalog) ((IPTSession) _userSession).GetCatalog();
		int nDocumentId = _fURLParser.GetObjectId();
		String strDocumentName = _fURLParser.GetObjectName(true);
		
		try {
			if (nDocumentId < 1) {
				// DCA - try to figure out document Id
				int[] arrDocumentIds = ptCatalog.LookupObjectIdFromName(strDocumentName, PT_CLASSIDS.PT_CATALOGCARD_ID);
				if (arrDocumentIds.length == 1) {
					nDocumentId = arrDocumentIds[0];
				} else {
					throw new PTException("More than one document found, returning search result.", PT_RESULTCODES.PT_E_FAIL);
				}
			}
			// TODO CR DLH: No magic strings - at least make them statics at the top of the file. (for all of them)
			// Or, are these magic strings cuz you don't have access to the opendoc space from here?
			// If so, I'd make them statics here, and then have the opendoc space use the ones from
			// here.  That way if you make a change it will be correctly propagated.
			// DCA - Changing the OpenDoc space to use the static strings here would be a pretty big change.
			//  DCA - used cached version if available in case it's a repost
			resultingRedirect.SetLinkGetSpaceIfCached(DOCUMENT_AS_NAME, _asParent);
			// STR_MVC_CLASS_NAME
			resultingRedirect.SetDisplayPage(DOCUMENT_DP_NAME);
			resultingRedirect.SetControl(DOCUMENT_CONTROL_NAME);
			// DirConstants.QS_CARDID
			resultingRedirect.AddControlArgument(STR_CARD_ID, nDocumentId);
		} catch (Exception e) {
			// DCA - no document with the exact name was found. Perhaps it was misspelled. Perform search.
			resultingRedirect.SetLinkCreateNewSpace(SEARCH_AS_NAME, _asParent);
			resultingRedirect.SetControl(SEARCH_CONTROL_NAME);
			resultingRedirect.AddControlArgument(SearchResultControl.USER_QUERY, strDocumentName);
			resultingRedirect.AddControlArgument(STR_OBJTYPE, PT_CLASSIDS.PT_CATALOGCARD_ID);
		}
		
		return resultingRedirect;
	}
	
	/**
	 * @see IPTClassTypeDesc#ConstructFriendlyURL(String, int, String) 
	 * 
	 * Generates a friendly Url for Documents
	 */
	public String ConstructFriendlyURL(FriendlyURL url, AActivitySpace space)
	{
		String objectName = url.GetOjectName();
		int objectId = url.GetObjectId();
		
		if ( ("".equals(objectName) || objectName == null) && objectId <= 0 ) { 
			throw new PTException("Both object name and id are missing. At least one needs to be specified to create a friendly Url.",
				PT_RESULTCODES.PT_E_INVALIDARGUMENT); 
		}

		// TODO CR DLH: Should this length be shared by default by all friendly URLs?  Maybe
		// stored in a common base class or something?
		XPStringBuilder buf = new XPStringBuilder(200);

		// DCA - get keyword mapping 
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		IFriendlyURLManager ptFriendlyURLMgr = (IFriendlyURLManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
		String docKeyword = ptFriendlyURLMgr.LookupFriendlyURLKeyFromClassId(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
		if ( docKeyword == null ) {
			throw new PTException("No Friendly URL keyword was found for Documents. "+
					"Verify that a mapping entry exists in FriendlyURL.xml.", PT_RESULTCODES.PT_E_FAIL);
		}
		buf.Append("/").Append(docKeyword);
		buf.Append("/").Append(objectId);

		// need to lookup object name from object id. Use the card object cache
		if ( ("".equals(objectName) || objectName == null) ) {
			IPTSession session = (IPTSession)space.GetUserSession();
			try {
				objectName = ((IPTCatalog)session.GetCatalog()).LookupNameFromObjectId(objectId, PT_CLASSIDS.PT_CATALOGCARD_ID);
			} catch (PTException e) {
				throw new PTException(e, 
						"Invalid document id provided: "+objectId+ " . The document does not exists or the user does not have access to it.", 
						PT_RESULTCODES.PT_E_INVALIDARGUMENT);
			}
		}
		String normalizedObjectName = FriendlyURL.NormalizeObjectName(objectName);
		// DCA - we're encoding in case it has non-ASCII chars
		objectName = XPHttpUtility.UrlEncode(normalizedObjectName, LinkConstants.UTF_8_ENCODING);
		// Add the name
		buf.Append("/").Append(objectName);
		
		// DCA - that's all we need to construct document URLs
		return buf.ToString();
	}
}