package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common Opener Mode Description:
 * 1) Create - Job editor in create mode (APTNonExtClassTypeDesc).
 * 2) Edit - Job editor in edit mode (APTNonExtClassTypeDesc).
 * 3) View - Redirect to Edit (APTClassTypeDesc).
 * 4) Meta - View object properties page (APTClassTypeDesc).
 * 
 * @author John Osborne
 */
public class PTJobs extends APTNonExtClassTypeDesc
{
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */ 
    public PTJobs() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 1533;
    }

	/** used internally to prepopulate operation on create mode */
	public static final String JOBOP_CLSID = "op_clsid";
	public static final String JOBOP_OBJID = "op_objid";

	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectCreateNew(XPHashtable _htArguments,
			AActivitySpace _asParent, Object _userSession) 
	{
		Redirect myRedirect = super.GetRedirectCreateNew(_htArguments, _asParent, _userSession);
		
		// job operation classid & objectid allows the operation to be prepopulated when 
		// this job is created from the "Object Saved" window. (or from anywhere, really)
		myRedirect.AddControlArgument(JOBOP_CLSID, HTTPHelpers.GetArgumentAsInt(_htArguments, JOBOP_CLSID, -1));
		myRedirect.AddControlArgument(JOBOP_OBJID, HTTPHelpers.GetArgumentAsInt(_htArguments, JOBOP_OBJID, -1));
		
		return myRedirect;
	}
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
	 */
	public boolean AppearsInMainCreateNewClassMenu()
	{
		return true;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
	 */
	public String GetASNameForEditor()
	{
		return "JobEditor";
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
	 */
	public int GetClassID()
	{
		return PT_CLASSIDS.PT_JOB_ID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
	 */
	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(16, "ptmsgs_portalinfrastructure", _strLangID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
	 */
	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_JOBS;	
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
	 */
	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(
				PTImageType.ICON_JOB).GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetRelatedClassTypeIDs()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
	 */
	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
}

