package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 1) Create - Networked search editor in create mode (PTNetworkedSearch).
 * 2) Edit - Networked search editor in edit mode (APTExtClassTypeDesc).
 * 3) View - Redirect to Edit (APTClassTypeDesc).
 * 4) Meta - View object properties page (APTClassTypeDesc).
 * 
 * @author John Osborne
 */
public class PTNetworkedSearches extends APTExtClassTypeDesc
{
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */ 
    public PTNetworkedSearches() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 1997;
    }
    
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
	 */
	public boolean AppearsInMainCreateNewClassMenu()
	{
		return true;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTExtClassTypeDesc#GetASNameForEditor(java.lang.String)
	 */
	public String GetASNameForEditor(String _strProvEnglishName)
	{
		String strBaseEditorASName = "NetworkSearchEditor";

		return _strProvEnglishName + strBaseEditorASName;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTExtClassTypeDesc#GetCLSIDForExistingObject(int, com.plumtree.server.IPTSession)
	 */
	public final String GetCLSIDForExistingObject(int _nObjectID,
		IPTSession _ptSession)
	{
		IPTFederatedPortal ptNetworkSearch = (IPTFederatedPortal) _ptSession.GetFederatedPortals()
			.Open(_nObjectID, false);
		String sProviderCLSID			   = ptNetworkSearch.GetSearchProviderCLSID();

		return sProviderCLSID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
	 */
	public int GetClassID()
	{
		return PT_CLASSIDS.PT_FEDERATEDPORTAL_ID;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
	 */
	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(17, "ptmsgs_portalinfrastructure", _strLangID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
	 */
	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_NETWORKSEARCHES;	
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectCreateNew(XPHashtable _htArguments,
		AActivitySpace _asParent, Object _userSession)
	{
		Redirect resultingRedirect = super.GetRedirectCreateNew(_htArguments, _asParent, _userSession);

		// retrieve the provider english name and provInfo object.						
		String strProvEngName =
			HTTPHelpers.GetArgumentAsString(_htArguments, IPTOpenerConstants.QS_PROV_ENG_NAME,
			HTTPHelpers.GetArgumentAsString(_htArguments, IPTOpenerConstants.STR_QS_PROVIDER_ENG_NAME, null));		
		IProvInfo myProv = PTConfigHelper.GetPTClassTypeDescrManager().
			GetRegisteredProvInfoGivenEnglishName(strProvEngName);
		ClassIDProvCLSIDPair myClassIDProvCLSIDPair = myProv.
			RequiresObjectChoiceOnStart(GetClassID());
			
		// if the provider requires a object choice on start,
		// we can check that it it's in our arguments list.
		if (null != myClassIDProvCLSIDPair)
		{
			// auth sources will only require webservice, 
			// so we will only check for that argument.
			if (myClassIDProvCLSIDPair.GetClassID() == PT_CLASSIDS.PT_WEBSERVICE_ID)
			{
				String strXUIWebServiceID = HTTPHelpers.GetArgumentAsString(_htArguments,
					XUIHelperMethods.QS_XUI_WEBSERVICE_ID, null);
						
				if (null == strXUIWebServiceID)
				{
					UIError myError = new UIError(UIErrorLevel.SERIOUS,
					UIErrorScope.CURRENT_USER, null, 
						_asParent.GetString(483, "ptmsgs_portalinfrastructure"), null);
					UIErrorHandler.RaiseError(myError,
						_asParent.GetSubSession(), _asParent.GetApplication());			

					throw new XPException("A web service ID argument is required in the Common Opener URL for this object in create mode.");
				}
			}
		}
		
		return resultingRedirect;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
	 */
	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(
				PTImageType.ICON_NETWORK_SEARCH).GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetRelatedClassTypeIDs()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
	 */
	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
}

