package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common Opener Mode Description:
 * 1) Create - Portlet editor in create mode (PTPortlets).
 * 2) Edit - Portlet editor in edit mode (APTNonExtClassTypeDesc).
 * 3) View - Portlet preview page (PTPortlets).
 * 4) Meta - View object properties page (APTClassTypeDesc).
 * 
 * This ClassType supports implements several extensible 
 * methods so that it can bring up the required objects
 * tree before opening the editor in the admin page. 
 * Since it doesn't need a provider, we treat it as non
 * extensible.  
 * 
 * @author John Osborne
 */
public class PTPortlets extends APTNonExtClassTypeDesc
{
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */ 
    public PTPortlets() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 1564;
    }

	/**
	 * Statics used to pass information to the 
	 * editor through Query String arguments.
	 */
	public static final String PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY = "forcomm";
	public static final String PORTLET_EDITOR_QS_INT_CREATOR_CLASSID = "creatorCLASSID";
	public static final String PORTLET_EDITOR_QS_INT_CREATOR_ID = "creatorID";

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
	 */
	public boolean AppearsInMainCreateNewClassMenu()
	{
		return true;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
	 */
	public String GetASNameForEditor()
	{
		return "PortMainPortletEditor";
	}

	/**
	 * Returns the name of the Activity Space that is used 
	 * to edit this class type.
	 *
	 * @param _strProvEnglishName The english name of the 
	 * provider that is being used for this class type.
	 *  
	 * @return The name of the Activity Space that is used 
	 * to edit this class type.
	 */
	public String GetASNameForEditor(String _strProvEnglishName) {
		return GetASNameForEditor();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
	 */
	public int GetClassID()
	{
		return PT_CLASSIDS.PT_GADGET_ID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
	 */
	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(20, "ptmsgs_portalinfrastructure", _strLangID);
	}

	/**
	 * Returns the CLSID for this object. 
	 *
	 * @param _nObjectID The object ID.
	 * @param _ptSession The current session.
	 *
	 * @return The CLSID for this object.
	 */
	public String GetCLSIDForExistingObject(int _nObjectID, IPTSession _ptSession) {
		IPTGadget ptGadget = (IPTGadget) _ptSession.GetGadgets()
			.Open(_nObjectID, false);
		String sProviderCLSID = ptGadget.GetGadgetProviderCLSID();

		return sProviderCLSID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
	 */
	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_PORTLETS;	
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
	 */
	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(
				PTImageType.ICON_PORTLET).GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectCreateNew(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectCreateNew(
		XPHashtable _htArguments,
		AActivitySpace _asParent,
		Object _userSession) 
	{
		Redirect rCreateNew = super.GetRedirectCreateNew(_htArguments, _asParent, _userSession);

		boolean bForCommunity = HTTPHelpers.GetArgumentAsBoolean(_htArguments, PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY, false);
		int nCreatorCLASSID = HTTPHelpers.GetArgumentAsInt(_htArguments, PORTLET_EDITOR_QS_INT_CREATOR_CLASSID, -1);
		int nCreatorID = HTTPHelpers.GetArgumentAsInt(_htArguments, PORTLET_EDITOR_QS_INT_CREATOR_ID, -1);
		
		//AGC- Pass along the arguments we may have gotten from the opening tree / editor.
		rCreateNew.AddControlArgument(PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY, bForCommunity);
		rCreateNew.AddControlArgument(PORTLET_EDITOR_QS_INT_CREATOR_CLASSID, nCreatorCLASSID);
		rCreateNew.AddControlArgument(PORTLET_EDITOR_QS_INT_CREATOR_ID, nCreatorID);
		 
		// if the provider requires a object choice on start,
		// we can check that it it's in our arguments list.
		// nCommunityID is not required.
			
		if ((-1 == nCreatorCLASSID) ||
			(-1 == nCreatorID))
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
			UIErrorScope.CURRENT_USER, null, 
				_asParent.GetString(490, "ptmsgs_portalinfrastructure"), null);
			UIErrorHandler.RaiseError(myError,
				_asParent.GetSubSession(), _asParent.GetApplication());			

			throw new XPException("Creator, and creator class ID arguments are required in the Common Opener URL for this object in create mode.");

		}
		
		// if creator class ID is not either web service  
		// or portlet template, we show a UI error.
		if ((nCreatorCLASSID != PT_CLASSIDS.PT_GADGETTEMPLATE_ID) &&
			(nCreatorCLASSID != PT_CLASSIDS.PT_WEBSERVICE_ID))
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
			UIErrorScope.CURRENT_USER, null, 
				_asParent.GetString(491, "ptmsgs_portalinfrastructure"), null);
			UIErrorHandler.RaiseError(myError,
				_asParent.GetSubSession(), _asParent.GetApplication());			

			throw new XPException("The creator class ID argument must refer to either the Web Service or Portlet Template class types.");
		}

		return rCreateNew; 
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRedirectViewObject(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.server.IPTSession)
	 */
	public Redirect GetRedirectViewObject(XPHashtable _htArguments,
		AActivitySpace _asParent, Object _userSession)
	{		
		int nGadgetID = HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.QS_OBJECTID, 
			HTTPHelpers.GetArgumentAsInt(_htArguments, IPTOpenerConstants.STR_QS_OBJECTID, -1));
		
		// AGC- Generate an URL to the preview page for gadgets.
		// We are re-using the URL generated for use in invitations for this purpose.
		// See Naveen for details.
		Redirect rPreview = new Redirect();
		rPreview.SetLinkCreateNewSpace("PreviewGadget" /*PreviewGadgetAS.STR_MVC_CLASS_NAME*/, _asParent);
		rPreview.SetControl(
			"PreviewGadget" /*PreviewGadgetControl.STR_MVC_CLASS_NAME*/);
		rPreview.SetDisplayPage(
			"PreviewGadget" /*PreviewGadgetDP.STR_MVC_CLASS_NAME*/);
		rPreview.AddControlArgument("PreviewType" /*PreviewGadgetControl.m_PreviewType*/,
			"4" /*PreviewGadgetModel.SEARCHHEADER*/);
		rPreview.AddControlArgument("GadgetID" /*PreviewGadgetControl.m_strGadgetParam*/,
			nGadgetID);

		return rPreview;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetRelatedClassTypeIDs()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
	 */
	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
}

