package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common Opener Mode Description:
 * 1) Create - Remote server editor in create mode (APTNonExtClassTypeDesc).
 * 2) Edit - Remote server editor in edit mode (APTNonExtClassTypeDesc).
 * 3) View - Redirect to Edit (APTClassTypeDesc).
 * 4) Meta - View object properties page (APTClassTypeDesc).
 * 
 * @author John Osborne
 */
public class PTRemoteServers extends APTNonExtClassTypeDesc
{
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */ 
    public PTRemoteServers() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 1566;
    }

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#AppearsInMainCreateNewClassMenu()
	 */
	public boolean AppearsInMainCreateNewClassMenu()
	{
		return true;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTNonExtClassTypeDesc#GetASNameForEditor()
	 */
	public String GetASNameForEditor()
	{
		return "RemoteServerEditor";
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassID()
	 */
	public int GetClassID()
	{
		return PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetClassTypeLocalizedName(java.lang.String)
	 */
	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(24, "ptmsgs_portalinfrastructure", _strLangID);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.APTClassTypeDesc#GetCreateActivityID()
	 */
	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_WEBSERVICE_INFRASTRUCTURE;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetDefaultIcon()
	 */
	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(
				PTImageType.ICON_REMOTE_SERVER).GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetRelatedClassTypeIDs()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#GetRelatedClassTypeIDs()
	 */
	public int[] GetDependentClassTypeIDs()
	{
		return new int[] { PT_CLASSIDS.PT_WEBSERVICE_ID };
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.classtypedescriptors.classframework.IPTClassTypeDesc#HasGlobalClassTypeMap()
	 */
	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
}

