package com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common Opener Mode Description:
 * 1) Create - Snapshot query editor in create mode (APTNonExtClassTypeDesc).
 * 2) Edit - Snapshot query editor in edit mode (APTNonExtClassTypeDesc).
 * 3) View - Redirect to Edit (APTClassTypeDesc).
 * 4) Meta - View object properties page (APTClassTypeDesc).
 * 
 * @author John Osborne
 */
public class PTSavedSearches extends APTNonExtClassTypeDesc
{
    /*
     * Setting two fields here as follows provides support for Admin UI->Release Locks
     * The Left Navigation Menu string will be loaded from "ptmsgs_portaladminmsgs" file using objectLockManagerMsgID
     * If it should be loaded from a different file, set objectLockManagerMsgFileName accordingly
     */ 
    public PTSavedSearches() {
        super();
        hasObjectLockManager = true;
        objectLockManagerMsgID   = 2002;
    }

	public boolean AppearsInMainCreateNewClassMenu()
	{
		return true;
	}

	public String GetASNameForEditor()
	{
		return "SavedSearchEditor";
	}

	public int GetClassID()
	{
		return PT_CLASSIDS.PT_SAVEDSEARCH_ID;
	}
	
	public String GetClassTypeLocalizedName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(25, "ptmsgs_portalinfrastructure", _strLangID);
	}

	public int GetCreateActivityID()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_SAVEDSEARCHES;	
	}

	public HTMLImg GetDefaultIcon()
	{
		try
		{
			HTMLImg imgIcon = (HTMLImg) UIConstructFactory.GetConstruct(
				PTImageType.ICON_SAVED_SEARCH).GetHTMLElement();

			return imgIcon;
		}
		catch (Exception e)
		{
			return null;
		}
	}

	public int[] GetRelatedClassTypeIDs()
	{
		return new int[] { PT_CLASSIDS.PT_GADGET_ID };
	}

	public boolean HasGlobalClassTypeMap()
	{
		return false;
	}
}

