package com.plumtree.portaluiinfrastructure.compoundlist;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * Class to hold components of an URL. Used by ASCompoundLists
 * 
 * @author robertz
 */
public class ListEntry
{
	protected PTImageType Image;
	protected PTImageType Image2;
	protected String Control;
	protected String EditorAS;
	protected String EditorPage;

	// Editor params
	protected String EditorType;

	// Misc params
	protected String FullURL;
	protected String ImageAltText;
//	protected String ImageHeight;
//	protected String ImageWidth;

	// Common params
	protected String Label;
	protected String m_strDescription;
	protected String[] m_paramNames;
	protected String[] m_paramValues;

	// MyPage/Community params
	protected int CommunityID;
	protected int FolderID;
	protected int m_nProfileID;
	
	// for site map in community preview
	protected boolean m_bIsPreview;

	// Directory params
	protected int Mode;
	protected int NewASType;
	protected int PageID;
	protected int Type;
	protected int m_nTruncateLength = 20;

	/**
	 * Creates a new ListEntry object.
	 *
	 * @param nType Link type
	 */
	public ListEntry(int nType)
	{
		Type = nType;
	}

	/**
	 * Gets the Community ID.
	 * @return Community integer ID
	 */
	public int GetCommunityID()
	{
		return CommunityID;
	}

	/**
	 * Gets the Control ID.
	 * @return Control String ID
	 */
	public String GetControl()
	{
		return Control;
	}

	/**
	 * Gets the Description
	 *
	 * @return Description String, empty String if none exists
	 */
	public String GetDescription()
	{
		if (m_strDescription == null)
		{
			return "";
		}

		return XPHttpUtility.HtmlEncode(m_strDescription);
	}

	/**
	 * Gets the Editor Activityspace ID
	 * @return Activityspace String ID
	 */
	public String GetEditorAS()
	{
		return EditorAS;
	}

	/**
	 * Gets the editorType.
	 * @return Editor int type
	 */
	public String GetEditorType()
	{
		return EditorType;
	}

	/**
	 * Gets the FolderID for Directory
	 * @return Folder int ID
	 */
	public int GetFolderID()
	{
		return FolderID;
	}

	/**
	 * Gets the Full URL
	 * @return Full URL String
	 */
	public String GetFullURL()
	{
		return FullURL;
	}

	/**
	 * Gets the image.
	 * @return Image construct
	 */
	public PTImageType GetImage()
	{
		return Image;
	}
	
	/**
	 * Gets the second image.
	 * @return Image construct
	 */
	public PTImageType GetImage2()
	{
		return Image2;
	}

	/**
	 * Gets the imageAltText.
	 * @return Image Alt String
	 */
	public String GetImageAltTextEncoded()
	{
		return XPHttpUtility.HtmlEncode(ImageAltText);
	}

	/**
	 * Gets the encoded and truncated label.
	 * @return Truncated and HTML encoded String
	 */
	public String GetLabel()
	{
		String formatLabel = GeneralHelpers.TruncateLongString(Label, m_nTruncateLength, false);
		// bjf -- fixed bug here, it was calling HtmlEncode on Label rather than formatLabel.
		formatLabel = XPHttpUtility.HtmlEncode(formatLabel);

		return formatLabel;
	}
	
	/**
	 * Gets the encoded but untruncated label.
	 * @return HTML encoded String
	 */
	public String GetOrigLabel()
	{
		String formatLabel = XPHttpUtility.HtmlEncode(Label);
		return formatLabel;
	}

	/**
	 * Gets the Mode
	 * @return int
	 */
	public int GetMode()
	{
		return Mode;
	}

	/**
	 * Gets the newASType.
	 * @return int
	 */
	public int GetNewASType()
	{
		return NewASType;
	}

	/**
	 * Gets the Editor Page
	 * @return Editor String Page
	 */
	public String GetPage()
	{
		return EditorPage;
	}

	/**
	 * Gets the Page ID.
	 * @return Page integer ID
	 */
	public int GetPageID()
	{
		return PageID;
	}

	/**
	 * Gets the parameter names array
	 *
	 * @return Array of parameter names
	 */
	public String[] GetParamNames()
	{
		return m_paramNames;
	}

	/**
	 * Gets the parameter value array
	 *
	 * @return Array of parameter values
	 */
	public String[] GetParamValues()
	{
		return m_paramValues;
	}

	/**
	 * Gets the editor type.
	 * @return integer type
	 */
	public int GetType()
	{
		return Type;
	}

	public boolean GetIsPreview()
	{
		return m_bIsPreview;	
	}

	/**
	 * Sets the communityID.
	 * @param communityID 		The community ID
	 */
	public void SetCommunityID(int communityID)
	{
		CommunityID = communityID;
	}

	/**
	 * Sets the control.
	 * @param control 			The String Control
	 */
	public void SetControl(String control)
	{
		Control = control;
	}

	/**
	 * Sets the description.
	 * @param strDescription 	The description
	 */
	public void SetDescription(String strDescription)
	{
		m_strDescription = strDescription;
	}

	/**
	 * Sets the editorAS.
	 * @param editorAS 			The Editor Activityspace
	 */
	public void SetEditorAS(String editorAS)
	{
		EditorAS = editorAS;
	}

	/**
	 * Sets the editorType.
	 * @param editorType 		The editorType
	 */
	public void SetEditorType(int editorType)
	{
		EditorType = XPConvert.ToString(editorType);
	}

	/**
	 * Set additional parameters
	 *
	 * @param paramNames 		Array of additional parameter names
	 * @param paramValues 		Array of additional parameter values
	 */
	public void SetExtraParams(String[] paramNames, String[] paramValues)
	{
		m_paramNames	  = paramNames;
		m_paramValues     = paramValues;
	}

	/**
	 * Sets the folderID for directory
	 * @param folderID 			The Folder ID
	 */
	public void SetFolderID(int folderID)
	{
		FolderID = folderID;
	}

	/**
	 * Sets the fullURL.
	 * @param fullURL 			The fullURL
	 */
	public void SetFullURL(String fullURL)
	{
		FullURL = fullURL;
	}

	/**
	 * Sets the image.
	 * @param image 			The image to set
	 */
	public void SetImage(PTImageType image)
	{
		Image = image;
	}
	
	/**
	 * Sets the image.
	 * @param image 			The second image to set
	 */
	public void SetImage2(PTImageType image)
	{
		Image2 = image;
	}

	/**
	 * Sets the imageAltText.
	 * @param imageAltText 		The imageAltText to set
	 */
	public void SetImageAltText(String imageAltText)
	{
		ImageAltText = imageAltText;
	}

	/**
	 * Sets the label.
	 * @param label 			The label to set
	 */
	public void SetLabel(String label)
	{
		Label = label;
	}

	/**
	 * Sets the Mode for directory
	 * @param mode 				The mode to set
	 */
	public void SetMode(int mode)
	{
		Mode = mode;
	}

	/**
	 * Sets the newASType.
	 * @param newASType 		The new activityspace type to set
	 */
	public void SetNewASType(int newASType)
	{
		NewASType = newASType;
	}

	/**
	 * Sets the editorPage.
	 * @param editorPage 		The editor page to set
	 */
	public void SetPage(String editorPage)
	{
		EditorPage = editorPage;
	}

	/**
	 * Sets the pageID.
	 * @param pageID 			The page ID to set
	 */
	public void SetPageID(int pageID)
	{
		PageID = pageID;
	}

	/**
	 * Sets the label truncation width
	 *
	 * @param nMax 				Character position to truncate at
	 * 
	 */
	public void SetTruncationLength(int nMax)
	{
		m_nTruncateLength = nMax;
	}

	/**
	 * Sets the type.
	 * @param type 				The type to set
	 */
	public void SetType(int type)
	{
		Type = type;
	}
	
	/**
	 * Sets if the current page is a preview
	 * 
	 * @param bIsPreview		Is the page a preview page
	 */
	public void SetIsPreview(boolean bIsPreview)
	{
		m_bIsPreview = bIsPreview;	
	}
	/**
	 * Gets the profile ID
	 * 
	 * @return					The profile ID
	 */
	public int GetProfileID() {
		return m_nProfileID;
	}

	/**
	 * Sets the profile ID
	 * @param 					Sets profile ID
	 */
	public void SetProfileID(int i) {
		m_nProfileID = i;
	}

}

