package com.plumtree.portaluiinfrastructure.editor;


// Framework imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author Julie Fournier
 */
public class ObjDependenciesView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView");

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectPopUpDependencies";

	/** HTML Object name: close button */
	public static final String HTMLBUTTON_CLOSE = "in_bu_Close";

	/**
	 * Parent AS.
	 */
	protected AActivitySpace m_asOwner;

	/**
	 * Associated read-only Model.
	 */
	protected IModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myMainTable;
		HTMLTable myTable;
		HTMLTableRow myMainTableRow;
		HTMLTableRow myRow;
		HTMLTableCell myMainTableCell;
		HTMLTableCell myCell;
		HTMLInput myInput;

		try
		{
			// Main table
			myMainTable = new HTMLTable();
			result.AddInnerHTMLElement(myMainTable);
			myMainTable.SetWidth("100%");
			myMainTable.SetHeight("575");
			myMainTable.SetBorder("0");
			myMainTable.SetCellPadding("0");
			myMainTable.SetCellSpacing("0");

			// Main table = row 1
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetHeight("60");
			myMainTableCell.SetWidth("100%");
			myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			// Main table = row 2
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetWidth("100%");
			myMainTableCell.SetHeight("380");
			myMainTableCell.SetVAlign("top");

			// Content table
			myTable = new HTMLTable();
			myMainTableCell.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("5");

			// Row 1 - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetColSpan("2");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_NOTICE_HEADER);

			myCell.AddInnerHTMLString(m_asOwner.GetString(127,
					"ptmsgs_portalinfrastructure"));
			myCell.AddInnerHTMLElement(new HTMLBr());

			// Row 1 - end
			// Dependency rows
			myTable.AddInnerHTMLElement(GetHTMLForDependencies());

			// Row 3 - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetColSpan("2");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
			myCell.AddInnerHTMLElement(new HTMLBr());

			// Button to close the window and redirect the main one.
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(130,
					"ptmsgs_portalinfrastructure"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick("CloseAndRedirect(); return false;");

			// Row 3 - end
			// Row 4 - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetColSpan("2");
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			// Row 4 - end
			// Main table = row 3
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetHeight("130");
			myMainTableCell.SetWidth("100%");
			myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			
			HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			myScript.AddInnerHTMLString("doOnLoad();\n");

			result.AddInnerHTMLElement(myScript);
		}
		catch (HTMLException e)
		{
			
				log.Error(e, "SaveObjectDependenciesView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(132,
					"ptmsgs_portalinfrastructure"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		try
		{
			// JF- We are done with the save pop-up window. We close it and redirect the main one.
			sb = new XPStringBuilder(200);
			sb.Append("function CloseAndRedirect()\n");
			sb.Append("{\n");
			sb.Append("  window.close(); \n");

			// JF- redirect the main window
			sb.Append("  window.opener.postToSelf('" +
				ObjEditorRepostControl.POSTTOSELF_ACTION_REDIRECT_AFTER_SAVEPOPUP +
				"'); \n");
			sb.Append("}\n");
			
			sb.Append("function doOnLoad()\n");
			sb.Append("{\n");
			sb.Append("var form = document.");
			sb.Append(AFormDP.HTMLFORM_NAME);
			sb.Append(";\n");
			sb.Append("form.");
			sb.Append(HTMLBUTTON_CLOSE);
			sb.Append(".focus();\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "SaveObjectDependenciesView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = model;
		m_asOwner     = parent;
	}

	/**
	 * Returns the HTML for an empty cell.
	 *
	 * @return HTMLTableCell
	 *
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetEmptyCell()

	{
		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
		myCell.SetWidth("50");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		return myCell;
	}

	/**
	 * Returns the HTML for the successfully created message.
	 * This message can be customized for each Object by extending
	 * this Section and overriding this method.
	 *
	 * @return HTMLElementCollection
	 */
	protected HTMLElementCollection GetHTMLForDependencies()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTableRow myRow;
		HTMLTableCell myCell;

		// Row 1 - begin
		myRow = new HTMLTableRow();
		result.AddInnerHTMLElement(myRow);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetColSpan("2");
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

		myCell.AddInnerHTMLEncodedString(XPResourceManager.FormatMessage(
				m_asOwner.GetString(128, "ptmsgs_portalinfrastructure"),
				GeneralHelpers.TruncateLongString(((IObjEditorModelRO) m_model).GetObjectName(), 
				ObjEditorModel.OBJECT_NAME_TRUNCATE, false)));
		myCell.AddInnerHTMLElement(new HTMLBr());
		// Row 1 - end
		
		// Row 2 - begin
		myRow = new HTMLTableRow();
		result.AddInnerHTMLElement(myRow);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetColSpan("2");
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
		
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		
		myCell.AddInnerHTMLString(m_asOwner.GetString(363, "ptmsgs_portalinfrastructure") + CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLEncodedString(((IObjEditorModelRO) m_model).GetParentFolderPath());
		myCell.AddInnerHTMLElement(new HTMLBr());
		// Row 2 - end
		
		return result;
	}
}

