package com.plumtree.portaluiinfrastructure.editor.commonpages.keywords;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This is the implementation of the Expandable List  framework for the
 * Keywords on an object.  Add will not be allowed at this time.
 *
 * @author michaeld
 */
public class KeywordsModel extends ExpListModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.keywords.KeywordsModel");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "Keywords";

	/** Max number of columns */
	public static final int KEYWORDSMODEL_COL_MAX = 3;

	/**
	 * First column: an index to keep the list sorted.
	 */
	public static final int KEYWORDSMODEL_COL_INDEX = 0;

	/** Second column: name. */
	public static final int KEYWORDSMODEL_COL_KEYWORD = 1;

	/** Fourth column: language. */
	public static final int KEYWORDSMODEL_COL_URL = 2;
	
	private int m_nClassID;
	private int m_nObjectID;

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		// Currently we do not allow rows to be added on repost for keywords
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)  with a column
	 * mapping and an array of sort. The growable array will always be sorted
	 * by the 1st  column ascending.
	 *
	 * @param _saData
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper)
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
		{
			KEYWORDSMODEL_COL_INDEX, KEYWORDSMODEL_COL_KEYWORD,
			KEYWORDSMODEL_COL_URL
		};

		// MJD- Sort array
		// The growable array will be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = KEYWORDSMODEL_COL_KEYWORD;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		SearchKeywordHelper kwHelper = new SearchKeywordHelper(m_asOwner);
		IXPList listKeywords = kwHelper.getPortalObjectKeywords(m_nClassID, m_nObjectID);
		
		Object[][] arrAllData = null;
		if (null != listKeywords && !listKeywords.IsEmpty())
		{		
			//MJD- Create the data array
			arrAllData = new Object[KEYWORDSMODEL_COL_MAX][listKeywords.GetSize()];
	
			//MJD- Add the keywords
			IXPEnumerator keywords = listKeywords.GetEnumerator();
			
			int i = 0;
			while(keywords.MoveNext())
			{
				String keyword	 = (String) keywords.GetCurrent();
				
				arrAllData[KEYWORDSMODEL_COL_INDEX][i]		= new Integer(i);
				arrAllData[KEYWORDSMODEL_COL_KEYWORD][i]	= keyword;

				keyword = XPHttpUtility.UrlEncode(keyword, LinkConstants.UTF_8_ENCODING);
				
				arrAllData[KEYWORDSMODEL_COL_URL][i]		= m_asOwner.GetCurrentNormalizedBaseURL() + IPTOpenerConstants.QS_KEYWORD + "=" + keyword;
				
				i++;
			}
		}
		
		//MJD- We set up the data, initialize the list.
		_saData.Initialize(arrColumns, arrAllData, arrSort, false);
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param objToEdit is the IPTObject to be edited
	 */
	public void InitializeKeywords(IPTObject objToEdit, int _nListKey)
	{
		m_nClassID = objToEdit.GetClassID();
		m_nObjectID = objToEdit.GetObjectID();
		
		Object[][] arrExpListColInfo = new Object[2][EXPLIST_COLUMN_INVALID];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]     = new Integer(KEYWORDSMODEL_COL_KEYWORD);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(507, "ptmsgs_portalinfrastructure");
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "20%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		arrExpListColInfo[1][EXPLIST_COLUMN_ID]     = new Integer(KEYWORDSMODEL_COL_URL);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(508, "ptmsgs_portalinfrastructure");
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "80%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		//MJD- Record the object we're editing
		//m_objEditing = objToEdit;
		
		super.InitializeExpandableList(m_asOwner.GetString(509, "ptmsgs_portalinfrastructure"),
			arrExpListColInfo, PTImageType.ACTION_ADD, "", _nListKey);
		super.DisableAddButton();
		super.DisableCheckBoxes();
		super.SetEmptyListMessages(m_asOwner.GetString(510, "ptmsgs_portalinfrastructure"),
			m_asOwner.GetString(511, "ptmsgs_portalinfrastructure"));
	}

	/**
	 * Saves the data when a repost occurs. Editors using this framework need
	 * to call that method from  the savePage method of the main Model.
	 *
	 * @param _htFormData
	 *
	 * @return int Status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		int intStatus = super.SaveSection(_htFormData);

		//MJD- Let the superclass do it's thing
		return intStatus;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#SaveRow(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper, int, com.plumtree.openfoundation.util.XPHashtable)
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex, XPHashtable _htFormData)
	{
		//MJD- Nothing to do to save a row- it's handled in SaveSection
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new KeywordsModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

}
