package com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This is the implementation of the Expandable List  framework for the
 * Growable Array. The Growable Array is a list of input texts.  On add, a new
 * input text populated with the default value  will be added at the bottom of
 * the list.
 *
 * @author MichaelS
 */
public class LocNamesModel extends ExpListModel implements ILocNamesModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.LocNamesModel");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "LocNames";

	/** MES- Constants for client side validation */
	public static final int CLIENT_VALIDATION_MAX_NAME = 255;
	public static final int CLIENT_VALIDATION_MAX_DESCRIPTION = 255;
		
	/**
	 * First column: an index to keep the list sorted.
	 */
	public static final int LOCNAMEMODEL_COL_INDEX = 0;

	/** Second column: name. */
	public static final int LOCNAMEMODEL_COL_NAME = 1;

	/** Third column: description. */
	public static final int LOCNAMEMODEL_COL_DESCRIPTION = 2;

	/** Fourth column: language. */
	public static final int LOCNAMEMODEL_COL_LANG = 3;
	
	/** Fifth column: language name. */
	public static final int LOCNAMEMODEL_COL_LANGNAME = 4;

	/** Number total of columns */
	public static final int LOCNAMEMODEL_COL_MAX = 5;

	/**MES- Constants we use to get data out of x_config.xml */
	private static final String MAND_OBJ_LANG_VAR_SECTION = "International";
	private static final String MAND_OBJ_LANG_VAR_NAME = "MandatoryObjectLanguage";

	/** Icon to display on each row, just before the input text. */
	public PTImageType m_imgRowIcon;

	/** MES- Does the portal have a mandatory language?  See comments below. */
	public boolean m_bHasMandatoryLang = false;

	/** MES- Does the object support localization at all? */
	public boolean m_bSupportsLocalization = false;
	
	/** RWW - Allow someone to set a different max length
	 * for name. For example, AdminFolders need to have a
	 * max lenght of 63 instead of the default 255 for 
	 * community naming purposes.
	 */
	public int m_iClientValidationMaxNameOverride;
	
	/** RWW - Sse the max name override value if this
	 * is true, use the default value if this is false.
	 */
	public boolean m_bUseClientValidationMaxNameOverride;

	/** MES- This is a sort of "temp" variable used when a popup edits a
	 * name and description.  It's populated by the RepostControl, and read
	 * by LocNamesPopupView and this class */
	public int m_iRowToEdit;

	/** The object we are editing */
	private IPTLocalizable m_objEditing;
	
	/** The language the user is currently in*/
	private String m_sUserLang = null;
	
	/** Label for Name Field */
	private String m_strNameLabel = "";
	
	/** Boolean: Do not display or set Descriptions */
	private boolean m_bNoDescriptions = false;
	
	/** Pop Up Display Page Name */
	private String m_strPopUpDisplayPageName = LocNamesPopUpDP.STR_MVC_CLASS_NAME;

	/**  
	 * RWW - Returns whether we should use use the
	 * override or default value for name field.
	 */
	public boolean IsUsingMaxNameOverride()
	{
		return m_bUseClientValidationMaxNameOverride;
	}
	
	/**
	 * RWW - Returns the override value for the max length
	 * for the name field (for client validation).
	 * 
	 * @return Max length for name field.
	 */
	public int GetMaxNameOverride()
	{
		return m_iClientValidationMaxNameOverride;
	}
	
	/**
	 * Adds one row at the bottom of the list and  sets the following values:
	 * First column: m_nNextIndex Second column: m_sDefaultValue
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		//MES- Get the data that was posted to us
		String sNewName = ((String[]) _htFormData.GetElement(GetUniqueString(LocNamesView.HTML_INPUT_NEW_NAME)))[0];
		String sNewDescription = ((String[]) _htFormData.GetElement(GetUniqueString(LocNamesView.HTML_INPUT_NEW_DESCRIPTION)))[0];
		String sNewLang = ((String[]) _htFormData.GetElement(GetUniqueString(LocNamesView.HTML_INPUT_NEW_LANG)))[0];
		String sNewLangName = m_asOwner.GetResourceManager().GetDisplayLocaleFromLocaleID(sNewLang, m_sUserLang);
		
		//MES- Are we adding a new row, or editing an existing row?
		//	m_iRowToEdit was set by LocNamesRepostControl, and is the
		//	row number or LocNamesView.EDIT_ROW_NEWROW
		if (LocNamesView.EDIT_ROW_NEWROW != m_iRowToEdit)
		{
			//MES- Editing an existing row
			m_saData.SetItem(m_iRowToEdit, LOCNAMEMODEL_COL_NAME, sNewName);
			m_saData.SetItem(m_iRowToEdit, LOCNAMEMODEL_COL_DESCRIPTION, sNewDescription);
			m_saData.SetItem(m_iRowToEdit, LOCNAMEMODEL_COL_LANG, sNewLang);
			m_saData.SetItem(m_iRowToEdit, LOCNAMEMODEL_COL_LANGNAME, sNewLangName);				
		}
		else
		{
			//MES- Adding a new row
			int iRows = m_saData.GetCount();
			Object[] oRow = new Object[LOCNAMEMODEL_COL_MAX];
			oRow[LOCNAMEMODEL_COL_INDEX]		   = new Integer(iRows);
			oRow[LOCNAMEMODEL_COL_NAME]			   = sNewName;
			oRow[LOCNAMEMODEL_COL_DESCRIPTION]     = sNewDescription;
			oRow[LOCNAMEMODEL_COL_LANG]			   = sNewLang;
			oRow[LOCNAMEMODEL_COL_LANGNAME]		   = sNewLangName;

			//MES- Add the row
			m_saData.AddRow(oRow);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LocNamesModel();
	}

	/**
	 * MES- Finish is called by the ObjEditorModel when the object is being
	 * stored.  We should store the data from the model to the IPTObject here.
	 */
	public void Finish()
	{
		//MES- Add the localized names and descriptions, if we're supporting that
		if (m_objEditing.GetIsLocalized() && m_bSupportsLocalization)
		{
			//MES- The localized strings arein m_saData.  We need to 
			//	put it into the object.
			int iRows = m_saData.GetCount();
			Object[][] arrNames = new Object[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_MAX_NUM_COLUMNS][iRows];
			Object[][] arrDescriptions = new Object[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_MAX_NUM_COLUMNS][iRows];

			//MES- Run through the items, adding them to the arrays
			for (int iRow = 0; iRow < iRows; ++iRow)
			{
				String sName = (String) m_saData.GetItem(iRow, LOCNAMEMODEL_COL_NAME);
				String sDescription = (String) m_saData.GetItem(iRow, LOCNAMEMODEL_COL_DESCRIPTION);
				String sLang = (String) m_saData.GetItem(iRow, LOCNAMEMODEL_COL_LANG);

				arrNames[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_LANG][iRow]			  = sLang;
				arrNames[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_STRING][iRow]			  = sName;
				arrDescriptions[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_LANG][iRow]		  = sLang;
				arrDescriptions[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_STRING][iRow]     = sDescription;
			}

			//MES- Set the localized names and descriptions
			m_objEditing.SetLocalizedNames(arrNames);
			m_objEditing.SetLocalizedDescriptions(arrDescriptions);
		}
	}

	/**
	 * @return Name label
	 */
	public String GetNameLabel()
	{
		if ( null == m_strNameLabel || "".equals(m_strNameLabel) )
		{
			return m_asOwner.GetString(63, ResourceConstants.PORTALINFRASTRUCTURE);
		}
		return m_strNameLabel;
	}
	
	/**
	 * Call this method if the default name label is not appropriate.
	 *
	 * @param sNameLabel 
	 */
	public void SetNameLabel(String strNameLabel)
	{
		m_strNameLabel = strNameLabel;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetNoDescriptions()
	 */
	public boolean IsNoDescriptions()
	{
		return m_bNoDescriptions;
	}
	
	/**
	 * If this method is not called, then it will default to using descriptions unless the Object does not support it.
	 *
	 * @param bNoDescriptions 
	 */
	public void SetIsNoDescriptions(boolean bNoDescriptions)
	{
		m_bNoDescriptions = bNoDescriptions;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetPopUpDisplayPageName()
	 */
	public String GetPopUpDisplayPageName()
	{
		return m_strPopUpDisplayPageName;
	}
	
	/**
	 * Call this method if you want the popup display page to be something other than LocNamesPopUpDP.STR_MVC_CLASS_NAME
	 *
	 * @param sPopUpDisplayPageName 
	 */
	public void SetPopUpDisplayPageName(String strPopUpDisplayPageName)
	{
		m_strPopUpDisplayPageName = strPopUpDisplayPageName;
	}

	/**
	 * MES- GetIsLocalized is used by controls to find out if the object
	 * is localized.
	 *
	 * @return a boolean indicating if the object is localized
	 */
	public boolean GetIsLocalized()
	{
		return m_objEditing.GetIsLocalized();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * MES- GetPrimaryDesc is used by controls to find out the primary
	 * description for the object we're editing
	 *
	 * @return the primary name of the object
	 */
	public String GetPrimaryDesc()
	{
		return m_objEditing.GetDescription();
	}

	/**
	 * MES- GetPrimaryLang is used by controls to find out the primary
	 * language for the object we're editing
	 *
	 * @return the identifier of the primary language
	 */
	public String GetPrimaryLang()
	{
		return m_objEditing.GetPrimaryLang();
	}

	/**
	 * MES- GetPrimaryName is used by controls to find out the primary
	 * name for the object we're editing
	 *
	 * @return the primary name of the object
	 */
	public String GetPrimaryName()
	{
		return m_objEditing.GetName();
	}

	/**
	 * Does the portal have a mandatory language?
	 *
	 * @return 
	 */
	public boolean HasMandatoryLang()
	{
		return m_bHasMandatoryLang;
	}

	/**
	 * Does the object support localization at all?
	 *
	 * @return 
	 */
	public boolean SupportsLocalization()
	{
		return m_bSupportsLocalization;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetRowToEdit()
	{
		return m_iRowToEdit;
	}

	/**
	 * Returns the icon to display on each row before the  input text. If the
	 * value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon()
	{
		return m_imgRowIcon;
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param objToEdit is the IPTObject to be edited
	 */
	public void InitializeNameDescEditor(IPTLocalizable objToEdit, int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[2][EXPLIST_COLUMN_INVALID];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]     = new Integer(LOCNAMEMODEL_COL_NAME);

		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(49, ResourceConstants.PORTALINFRASTRUCTURE);
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "80%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.TRUE;

		arrExpListColInfo[1][EXPLIST_COLUMN_ID]     = new Integer(LOCNAMEMODEL_COL_LANGNAME);

		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(48, ResourceConstants.PORTALINFRASTRUCTURE);
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "20%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.TRUE;

		//MES- Record the object we're editing
		m_objEditing = objToEdit;

		//MES- Get info from x_config.xml about whether we support "mandatory" primary langs
		//	Some customers may wish to enforce that ALL objects MUST have a
		//	particular primary language (e.g. Ford may decide that 80% of their
		//	workforce is English speaking, and all objects should have an English name.)
		//	To do this, they'd put the locale they want to be mandatory into the
		//	MandatoryObjectLanguage key in x_config.xml.  We should respect that item if
		//	it's there by not allowing the client to choose primary language 
		String sMandatoryLang = ((PTConfigVarPack) m_asOwner.GetApplication().GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsString(MAND_OBJ_LANG_VAR_SECTION, MAND_OBJ_LANG_VAR_NAME, "value");

		if (null == sMandatoryLang)
		{
			sMandatoryLang = "";
		}

		//MES- Make sure that if the object gets stored, the primary lang will
		//	be the mandatory lang.
		m_bHasMandatoryLang = false;

		if ( !("").equals(sMandatoryLang) )
		{
			m_objEditing.SetPrimaryLang(sMandatoryLang);
			m_bHasMandatoryLang = true;
		}

		//MES- Find out if the object supports localization at all
		m_bSupportsLocalization = m_objEditing.GetSupportsLocalization();

		super.InitializeExpandableList(m_asOwner.GetString(50, ResourceConstants.PORTALINFRASTRUCTURE), arrExpListColInfo, PTImageType.ACTION_ADD, m_asOwner.GetString(47, ResourceConstants.PORTALINFRASTRUCTURE), _nListKey /*MES- List Key*/);
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)  with a column
	 * mapping and an array of sort. The growable array will always be sorted
	 * by the 1st  column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
		{
			LOCNAMEMODEL_COL_INDEX, LOCNAMEMODEL_COL_NAME,
			LOCNAMEMODEL_COL_DESCRIPTION, LOCNAMEMODEL_COL_LANG, LOCNAMEMODEL_COL_LANGNAME
		};

		// JF- Sort array
		// The growable array will be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = LOCNAMEMODEL_COL_INDEX;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		//MES- Only initialize if we actually SUPPORT localization
		if (m_bSupportsLocalization)
		{
			//MES- Convert the data from the form in the object into the form in the
			//	list.  The list contains Name, Description, Language, and Default (the
			//	Default flag indicates if that row is the primary name, desc, and lang.)
			Object[][] arrLocalizedNames = (Object[][]) m_objEditing.GetLocalizedNames();
			Object[][] arrLocalizedDescriptions = (Object[][]) m_objEditing.GetLocalizedDescriptions();

			//MES- Put the arrays into hash tables- we need to correlate the name and the description
			//	for a given language, and hashtables are a convenient way to do that
			XPHashtable hashLangToName = new XPHashtable();
			XPHashtable hashLangToDescription = new XPHashtable();
			AddLocalizedArraysToMap(arrLocalizedNames, hashLangToName, hashLangToDescription);
			AddLocalizedArraysToMap(arrLocalizedDescriptions, hashLangToDescription, hashLangToName);

			//MES- Create the data array
			Object[][] arrAllData = new Object[LOCNAMEMODEL_COL_MAX][hashLangToName.GetSize()];

			//MES- Add the localized strings
			String sName;
			String sDescription;
			String sLang;
			IXPEnumerator enumLangs = hashLangToName.GetKeys();
			enumLangs.MoveNext();

			m_sUserLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();
			
			for (int iRowIndex = 0; iRowIndex < hashLangToName.GetSize();
					++iRowIndex)
			{
				sLang			 = (String) enumLangs.GetCurrent();
				sName			 = (String) hashLangToName.GetElement(sLang);
				sDescription     = (String) hashLangToDescription.GetElement(sLang);

				arrAllData[LOCNAMEMODEL_COL_INDEX][iRowIndex]		    = new Integer(iRowIndex + 1);
				arrAllData[LOCNAMEMODEL_COL_NAME][iRowIndex]		    = sName;
				arrAllData[LOCNAMEMODEL_COL_DESCRIPTION][iRowIndex]     = sDescription;
				arrAllData[LOCNAMEMODEL_COL_LANG][iRowIndex]		    = sLang;
				// DCA - storing localized language name so that we can sort by it
				arrAllData[LOCNAMEMODEL_COL_LANGNAME][iRowIndex]		= m_asOwner.GetResourceManager().GetDisplayLocaleFromLocaleID(sLang, m_sUserLang);
				
				enumLangs.MoveNext();
			}

			//MES- We set up the data, initialize the list.
			_saData.Initialize(arrColumns, arrAllData, arrSort, false);
		}
		else
		{
			//MES- We don't support localization.  Set up the array with
			//	NO rows, so that it's at least initialized correctly.
			Object[][] arrEmptyData = new Object[LOCNAMEMODEL_COL_MAX][0];
			_saData.Initialize(arrColumns, arrEmptyData, arrSort, false);
		}
	}

	/**
	 * Saves the data when a repost occurs. Editors using this framework need
	 * to call that method from  the savePage method of the main Model.
	 *
	 * @param _htFormData
	 *
	 * @return int Status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		int intStatus = super.SaveSection(_htFormData);

		try
		{
			//MES- Store the primary name, primary desc, primary lang,
			//	and IsLocalized info to the object.  Normally, 
			//	in the MVC model we'd just store this to member variables
			//	and store it to the object in our Finish method.  We can't
			//	do that, because other pages need to know the "new" name
			//	of the object before Finish has been called, and they 
			//	don't know how to get to this model.  It's a flaw in the
			//	architecture that we work around by editing the actual
			//	object- the object itself becomes the data sharing mechanism.
			String sPrimaryName = ((String[]) _htFormData.GetElement(GetUniqueString(LocNamesPrimaryNameView.HTMLINPUT_NAME)))[0];
			m_objEditing.SetName(sPrimaryName);

			//MES- Only handle description if this object type supports setting the desc
			if (!IsNoDescriptions())
			{
				String sPrimaryDescription = ((String[]) _htFormData.GetElement(GetUniqueString(LocNamesPrimaryNameView.HTMLINPUT_DESCRIPTION)))[0];
				m_objEditing.SetDescription(sPrimaryDescription);
			}

			//MES- Store the primary language.  Sometimes we post and store every time
			//	the primary language changes, but sometimes we don't (we do when it could
			//	affect the choices for localized languages, but if we're not showing
			//	localized languages, then changing the language doesn't affect the display,
			//	so we don't have to post.)
			//	NOTE: If there's a MANDATORY language, then the Primary Lang input won't be 
			//	displayed, and therefore won't be posted to us.  In this case, we should NOT
			//	try to read the form value, as it doesn't exist...
			if (!m_bHasMandatoryLang)
			{
				SetPrimaryLang(((String[]) _htFormData.GetElement(GetUniqueString(LocNamesPrimaryNameView.PRIMARY_LANG_DROPDOWN)))[0]);
			}
		}
		catch (Exception e)
		{
			//Something is not allowed
			intStatus = RepostControl.PAGE_STATUS_INVALID;

			if ((e instanceof PTException) && (((PTException) e).GetErrorCode() == -2147024809))
			{
				// This code means invalid arg, which can mean incorrect length, invalid characters,
				// or all spaces.
				PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "LocNamesModel::SaveSection", e, false, UIErrorLevel.SERIOUS,
					XPResourceManager.FormatMessage(m_asOwner.GetString(415, ResourceConstants.PORTALINFRASTRUCTURE), PT_SERVERCONSTANTS.PT_MAX_FOLDERNAMELENGTH));
			}
			else
			{
				PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "LocNamesModel::SaveSection", e, false, UIErrorLevel.SERIOUS,
					m_asOwner.GetString(416, ResourceConstants.PORTALINFRASTRUCTURE));
			}
		}

		//MES- Let the superclass do it's thing
		return intStatus;
	}

	/**
	 * MES- SetIsLocalized is used by controls to set the IsLocalized flag on
	 *     the object we're editing.  See comments in SaveSection
	 *
	 * @param bIsLocalized indicates if the object supports localization
	 *
	 * @return void
	 */
	public void SetIsLocalized(boolean bIsLocalized)
	{
		m_objEditing.SetIsLocalized(bIsLocalized);
	}

	/**
	 * MES- SetPrimaryLang is used by controls to set the primary language on
	 *     the object we're editing.  See comments in SaveSection
	 *
	 * @param sPrimaryLang is the identifier of the new primary language
	 *
	 * @return void
	 */
	public void SetPrimaryLang(String sPrimaryLang)
	{
		//MES- Store the new primary language into the model
		m_objEditing.SetPrimaryLang(sPrimaryLang);

		//MES- And delete any localized string that's in that language
		RemoveLang(sPrimaryLang);
	}

	/**
	 * 
	 *
	 * @param nRowToEdit 
	 */
	public void SetRowToEdit(int nRowToEdit)
	{
		m_iRowToEdit = nRowToEdit;
	}

	/**
	 * Sets the icon to display on each row before the  input text. By default,
	 * no icon is displayed.
	 *
	 * @param _imgRowIcon
	 */
	public void SetRowIcon(PTImageType _imgRowIcon)
	{
		m_imgRowIcon = _imgRowIcon;
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 *
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex, XPHashtable _htFormData)
	{
		//MES- Nothing to do to save a row- it's handled in SaveSection
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * MES- AddLocalizedArraysToMap is a helper function called by InitializeSortedArray.
	 * It is used to correlate entries in the Object.GetLocalizedNames and
	 * Object.GetLocalizedDescriptions calls.  One of the arrays is taken in, and it's
	 * put into BOTH HashMaps.  The actual value is put into the "primary" hashmap, and
	 * a blank placeholder is placed into the secondary hashmap.  This way, the hashmaps
	 * are always in sync.
	 *
	 * @param arrLocalizedStrings is the array of strings to add
	 * @param hashPrimary is the table to put the strings into (or update in place)
	 * @param hashSecondary is the table to put the placeholders into
	 */
	private void AddLocalizedArraysToMap(Object[][] arrLocalizedStrings, XPHashtable hashPrimary, XPHashtable hashSecondary)
	{
		//MES- Do we have any strings to add?
		if (null != arrLocalizedStrings)
		{	
			//MES- Run through them
			for (int iStringIndex = 0;
					iStringIndex < arrLocalizedStrings[0].length;
					++iStringIndex)
			{
				String sLang = (String) arrLocalizedStrings[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_LANG][iStringIndex];
				String sLocalizedString = (String) arrLocalizedStrings[PT_LOCALIZED_STRINGS_INDICES.PT_LSINDEX_STRING][iStringIndex];

				//MES- Just put it into the primary map, we know what the value's supposed to be
				hashPrimary.PutElement(sLang, sLocalizedString);

				//MES- Only put a placeholder into the secondary map if there isn't
				//	already an entry- we wouldn't want to overwrite the "real" value.
				if (!hashSecondary.ContainsKey(sLang))
				{
					hashSecondary.PutElement(sLang, "");
				}
			}
		}
	}

	/**
	 * MES- RemoveLang is used to remove an entry from the m_saData array.
	 * It removes the first row that's associated with the language passed
	 * in.  This is used when the user switches the primary language of the
	 * object- no localized language should match the primary language, so
	 * any localization matching the new primary language should be deleted.
	 *
	 * @param sLangToRemove is the language to remove
	 */
	private void RemoveLang(String sLangToRemove)
	{
		//MES- Run through the array, looking for an entry with that lang.
		//	As there should be at most one, we can quit as soon as we find one!
		int iNumRows = m_saData.GetCount();

		for (int iIndex = 0; iIndex < iNumRows; ++iIndex)
		{
			String sRowLang = (String) m_saData.GetItem(iIndex, LOCNAMEMODEL_COL_LANG);

			if (0 == XPStringUtility.CompareIgnoreCase(sRowLang, sLangToRemove))
			{
				m_saData.RemoveRow(iIndex);

				return;
			}
		}
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetObjectID()
	 */
	public int GetObjectID() 
	{
		IPTServerContext pSC = null;
		try
		{
			pSC = (IPTServerContext)m_objEditing;
		}
		catch (Exception e)
		{
			// if the object does not support IPTServerContext, return 0 -jas
			return 0;
		}
		
		return pSC.GetObjectID();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetObjectUUID()
	 */
	public String GetObjectUUID() {
		IPTMigratable pM = null;
		try
		{
			pM = (IPTMigratable)m_objEditing;
		}
		catch (Exception e)
		{
			// if the object does not support IPTMigratable, return null -jas
			return null;
		}
		
		return pM.GetObjectUUID();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetClassID()
	 */
	public int GetClassID()
	{
		IPTObject pObj = null;
		try
		{
			pObj = (IPTObject)m_objEditing;
		}
		catch (Exception e)
		{
			// if the object does not support IPTObject, return 0 -jas
			return 0;
		}
		
		return pObj.GetClassID();
	}
}