package com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List  framework for the
 * Growable Array. Is constains the HTML to display the Growable Array.  It
 * gets the data to display from GrowableListModel.
 *
 * @author MichaelS
 */
public class LocNamesPrimaryNameView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.LocNamesPrimaryNameView");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "LocNamesPrimaryName";

	/** LOCNAME_CHK_SUPPORTS_LOC is the name of the clientside checkbox control
	 * that is used to indicate if this object should support localization */
	public static final String LOCNAME_CHK_SUPPORTS_LOC = "in_cb_SupportsLoc";

	/** MES- PRIMARY_LANG_DROPDOWN is the name of the control that users use to
	 * select the primary language for the object */
	public static final String PRIMARY_LANG_DROPDOWN = "in_se_PrimarLang";

	/** MES- The validate function is known to the Display Page */
	public static final String VALIDATION_FUNC_NAME = "ValidateNamesAndDesc";

	/** MES- This function is only called from code in this file- it responds to changing the IsLocalized checkbox */
	public static final String SWITCH_LOCALIZED_STATE_FUNC_NAME = "SwitchLocalizedState";

	/** MES- The names of various HTML elements, such as inputs */
	public static final String HTMLINPUT_NAME = "in_tx_Name";

	
	public static final String HTMLINPUT_DESCRIPTION = "in_ta_Description";

	/** MES- Other constants for drawing UI */
	public static final int STANDARD_INPUT_BOX_WIDTH = 50;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LocNamesPrimaryNameView();
	}

	/**
	 * This method returns the HTMLElement that encompasses the output of the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		ILocNamesModelRO model = (ILocNamesModelRO) m_model;
		HTMLSpan mySpan;

		try
		{
			//MES- Figure out the prompt for the "Name" field.
			//	This has a special case for User objects.  Since User
			//	objects have so many different kinds of names (auth name,
			//	login name, etc.), the label should be more specific.
			//	NOTE:  Since there's only one special case, we'll just
			//	handle it here.  If there were lots of special cases,
			//	we'd probably want the caller to tell us what label to use
			String sNameLabel = model.GetNameLabel();

			// RWW - Figure out the max length for the "Name" field 
			// for client side validation.  Normally, this is set to
			// a default value of 255, but for Admin Folders for  
			// example, we use a limit of 63 (community reasons).
			int iClientValidationMaxName;
			if (model.IsUsingMaxNameOverride())
				iClientValidationMaxName = model.GetMaxNameOverride();
			else
				iClientValidationMaxName = LocNamesModel.CLIENT_VALIDATION_MAX_NAME;
			
			result.AddInnerHTMLString("\n<!-- Begin: Display LocNamesPrimaryNameView -->\n");

			HTMLTable myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);

			//MES- First row, the name
			HTMLTableRow myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			HTMLTableCell myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.LEFT);
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(sNameLabel);
			myCell.AddInnerHTMLElement(mySpan);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.LEFT);

			HTMLInput nameInput = new HTMLInput(HTMLInputTypes.TEXT, ((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_NAME), "");
			myCell.AddInnerHTMLElement(nameInput);
			nameInput.SetValue(model.GetPrimaryName());
			nameInput.SetMaxLength(iClientValidationMaxName);
			nameInput.SetSize(STANDARD_INPUT_BOX_WIDTH);
			nameInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

			//MES- Second row, the description
			//	ONLY show the description if the user is allowed to
			//	set the description!
			// JHQ: IsDescriptionDisabled() on IDescriptionModelRO.
			if (!model.IsNoDescriptions())
			{
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.SetVAlign(CommonHTMLStrings.TOP);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
				
				mySpan.AddInnerHTMLString(m_asOwner.GetString(64, "ptmsgs_portalinfrastructure"));
				myCell.AddInnerHTMLElement(mySpan);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);

				HTMLTextArea myTextArea = new HTMLTextArea(XPConvert.ToString(STANDARD_INPUT_BOX_WIDTH), "3");
				myCell.AddInnerHTMLElement(myTextArea);
				myTextArea.AddInnerHTMLString(model.GetPrimaryDesc());
				myTextArea.SetName(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_DESCRIPTION));
				myTextArea.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			}

			// Third row, the object ID -jas
			int iClassID = model.GetClassID();
			if (0 != iClassID)
			{
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.SetVAlign(CommonHTMLStrings.TOP);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(527, "ptmsgs_portalinfrastructure"));
				myCell.AddInnerHTMLElement(mySpan);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.AddInnerHTMLString(XPConvert.ToString(iClassID));
			}

			// Fourth row, the object ID -jas
			int iObjectID = model.GetObjectID();
			if (0 != iObjectID)
			{
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.SetVAlign(CommonHTMLStrings.TOP);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(498, "ptmsgs_portalinfrastructure"));
				myCell.AddInnerHTMLElement(mySpan);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.AddInnerHTMLString(XPConvert.ToString(iObjectID));
			}

			// Fifth row, the UUID -jas
			String strUUID = model.GetObjectUUID();
			if (null != strUUID)
			{
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
	
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.SetVAlign(CommonHTMLStrings.TOP);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
	
				mySpan.AddInnerHTMLString(m_asOwner.GetString(499, "ptmsgs_portalinfrastructure"));
				myCell.AddInnerHTMLElement(mySpan);
	
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.AddInnerHTMLString(strUUID);
			}
			
			//MES- Sixth row, Primary Lang dropdown
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.LEFT);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);


			mySpan.AddInnerHTMLString(m_asOwner.GetString(65, "ptmsgs_portalinfrastructure"));
			myCell.AddInnerHTMLElement(mySpan);

			//MES- Get the current language
			String sLang = XPConvert.ToString( PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,  m_asOwner) );

			//MES- Does the portal have a mandatory primary language?
			//	See the comments in LocNamesModel.java.	
			if (model.HasMandatoryLang())
			{
				//MES- Show the mandatory language	
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				myCell.AddInnerHTMLString(m_asOwner.GetResourceManager().GetDisplayLocaleFromLocaleID(model.GetPrimaryLang(), sLang));
			}
			else
			{
				//MES- Show the dropdown of languages	
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

				HTMLSelect seLangDropdown = LocNamesView.GetLangChoicesControl(sLang, ((IExpListModelRO) m_model).GetUniqueString(PRIMARY_LANG_DROPDOWN), model.GetPrimaryLang(), m_asOwner.GetResourceManager());
				myCell.AddInnerHTMLElement(seLangDropdown);

				//MES- If changing the primary language would change the rest
				//	of the UI, we should post on language change, but if it would NOT,
				//	then we should not post, so that the user doesn't have to 
				//	wait for a server round trip.  If we're localized, then
				//	we're showing a list of localized langs, and we may have to
				//	delete a duplicate from that list, so in that case we should
				//	post.
				if (model.SupportsLocalization() && model.GetIsLocalized())
				{
					seLangDropdown.SetOnChange("postToSelf(" + ((IExpListModelRO) m_model).GetUniqueInt(LocNamesRepostControl.POSTTOSELF_ACTION_CHANGE_PRIMARYLANG) + ");");	// mj: removed 'Javascript:' from function name
				}
			}

			//MES- Seventh row, the "Supports Localization" checkbox or string.
			//	NOTE: Do NOT show the checkbox for objects that don't support
			//	localization!
			if (model.SupportsLocalization())
			{
				myRow = new HTMLTableRow();
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				myTable.AddInnerHTMLElement(myRow);
				
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.LEFT);
				myCell.SetVAlign(CommonHTMLStrings.TOP);
				
				HTMLTable myInnerTable = new HTMLTable();
				myCell.AddInnerHTMLElement(myInnerTable);
				HTMLTableRow myInnerTableRow = new HTMLTableRow();
				myInnerTableRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				myInnerTable.AddInnerHTMLElement(myInnerTableRow);
				
				HTMLTableCell myInnerTableCell = new HTMLTableCell();
				myInnerTableRow.AddInnerHTMLElement(myInnerTableCell);
				myInnerTableCell.SetAlign(CommonHTMLStrings.LEFT);
				myInnerTableCell.SetVAlign(CommonHTMLStrings.MIDDLE);
				myInnerTableCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				HTMLInput inpSupportsLocalization = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE, ((IExpListModelRO) m_model).GetUniqueString(LOCNAME_CHK_SUPPORTS_LOC), "", m_asOwner.GetString(68, "ptmsgs_portalinfrastructure"));
				myInnerTableCell.AddInnerHTMLElement(inpSupportsLocalization);
				inpSupportsLocalization.SetChecked(model.GetIsLocalized());
				inpSupportsLocalization.SetOnClick(((IExpListModelRO) m_model).GetUniqueString(SWITCH_LOCALIZED_STATE_FUNC_NAME) + "();");	// mj: removed 'Javascript:' from function name
				
				myInnerTableCell = new HTMLTableCell();
				myInnerTableRow.AddInnerHTMLElement(myInnerTableCell);
				myInnerTableCell.SetAlign(CommonHTMLStrings.LEFT);
				myInnerTableCell.SetVAlign(CommonHTMLStrings.MIDDLE);
				myInnerTableCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				myInnerTableCell.AddInnerHTMLString(m_asOwner.GetString(67, "ptmsgs_portalinfrastructure"));

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
			}

			result.AddInnerHTMLString("\n<!-- End: Display LocNamesPrimaryNameView -->\n");
		}
		catch (Exception e)
		{
			log.Error(e, "LocNamesPrimaryNameView::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(62, "ptmsgs_portalinfrastructure"), e);
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on
	 * the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		try
		{
			XPStringBuilder sb = new XPStringBuilder(200);

			//MES- See note above about PostToSelf.            
			sb.Append("function ").Append(VALIDATION_FUNC_NAME).Append("()\n");
			sb.Append("{\n");

			//MES- Validate the name.  It must not be blank.
			sb.Append("		sName = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_NAME)).Append(".value;\n");

			//MES- Trim the name
			sb.Append("		sTrimmedName = sName.replace(/^\\s+/g, '').replace(/\\s+$/g, '');\n");
			sb.Append("		if (sTrimmedName.length <= 0)\n");
			sb.Append("		{\n");


			sb.Append("			alert(\"").Append(m_asOwner.GetString(69, "ptmsgs_portalinfrastructure")).Append("\");\n");
			sb.Append("			return false;\n");
			sb.Append("		}\n");

			//MES- If we changed the name, store the modified name
			sb.Append("		if (sTrimmedName != sName)\n");
			sb.Append("		{\n");
			sb.Append("			document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_NAME)).Append(".value = sTrimmedName;\n");
			sb.Append("		}\n");

			//MES- Validate the description- it can be blank but cannot be over 255 characters.
			//	NOTE: Don't validate it if we're not DISPLAYING the description!
			// JHQ: IsDescriptionDisabled() on IDescriptionModelRO.
			if (!((ILocNamesModelRO)m_model).IsNoDescriptions())
			{
				sb.Append("		sDesc = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_DESCRIPTION)).Append(".value;\n");
				sb.Append("		if (sDesc.length > ").Append(LocNamesModel.CLIENT_VALIDATION_MAX_DESCRIPTION).Append(")\n");
				sb.Append("		{\n");


				sb.Append("			alert(\"").Append(XPResourceManager.FormatMessage(m_asOwner.GetString(70, "ptmsgs_portalinfrastructure"), new Integer(LocNamesModel.CLIENT_VALIDATION_MAX_DESCRIPTION + 1))).Append("\");\n");
				sb.Append("			return false;\n");
				sb.Append("		}\n");
			}

			sb.Append("		return true;\n");
			sb.Append("}\n");

			//MES- Create a function that will respond to clicks of the Is Localized checkbox
			//	NOTE: We only want to "post to self" if we're NOT ALREADY in the middle of 
			//	a "post to self".  Record if we're in the middle of a post, and don't allow
			//	a redundant post.  This is for bug 15468.
			sb.Append("bAlreadyPostedLocChange = false;\n");
			sb.Append("function ").Append(((IExpListModelRO) m_model).GetUniqueString(SWITCH_LOCALIZED_STATE_FUNC_NAME)).Append("()\n");
			sb.Append("{\n");
			sb.Append("	if (!bAlreadyPostedLocChange)\n");
			sb.Append("	{\n");
			sb.Append("		bAlreadyPostedLocChange = true;\n");
			sb.Append("		postToSelf(").Append(((IExpListModelRO) m_model).GetUniqueInt(LocNamesRepostControl.POSTTOSELF_ACTION_CHANGE_ISLOCALIZED)).Append(");\n");
			sb.Append("		return true;");
			sb.Append("	}\n");
			sb.Append("	return false;");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, "LocNamesPrimaryNameView::DisplayJavascript An error occured when trying to display the JavaScript.");
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

