package com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * MES- LocNamesRepostControl is the repost control for the Localized Names and Descriptions
 * page.  It controls what happens when the form posts to itself.
 *
 * @version 1.0
 * @author MichaelS
 */
public class LocNamesRepostControl extends ExpListControl
{
	/** MES- The name of this object */
	public static final String STR_MVC_CLASS_NAME = "LocNamesRepost";

	/** MES- Custom post actions that we post to ourself- we don't want to conflict
	 * with a superclass! */
	public static final int POSTTOSELF_ACTION_NAMEDESC_POPUP     = 60;

	
	public static final int POSTTOSELF_ACTION_CHANGE_ISLOCALIZED = 61;

	
	public static final int POSTTOSELF_ACTION_CHANGE_PRIMARYLANG = 62;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LocNamesRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call  the associated method for each
	 * action.
	 *
	 * @param _nAction is the action to take
	 * @param _htFormData is a hashtable that stores the posted form data and querystring
	 * arguments
	 */
	public void PerformRepostAction(int _nAction, XPHashtable _htFormData)
	{
		ExpListModel myExpListModel = (ExpListModel) m_model;
		
		//MES- Is this an action we know about?
		if (_nAction == myExpListModel.GetUniqueInt(POSTTOSELF_ACTION_NAMEDESC_POPUP))
		{
			//MES- This is our "own" action, we know how to deal with it
			PerformNameDescPopupAction(_htFormData);
		}
		else if (_nAction == myExpListModel.GetUniqueInt(POSTTOSELF_ACTION_CHANGE_ISLOCALIZED))
		{
			//MES- The user changed the IsLocalized checkbox, reset the member data
			//	and reshow the form
			PerformIsLocalizedChangeAction(_htFormData);
		}
		else if (_nAction == myExpListModel.GetUniqueInt(POSTTOSELF_ACTION_CHANGE_PRIMARYLANG))
		{
			//MES- The user changed the IsLocalized checkbox, reset the member data
			//	and reshow the form
			PerformChangePrimaryLangAction(_htFormData);
		}
		else
		{
			//MES- We don't know what this is, pass it to our parent
			super.PerformRepostAction(_nAction, _htFormData);
		}
	}

	/**
	 * MES- PerformChangePrimaryLangAction reacts to the user changing the
	 * Primary Language dropdown by updating model variables
	 *
	 * @param _htFormData is a hashtable that stores the form post data and querystring
	 */
	private void PerformChangePrimaryLangAction(XPHashtable _htFormData)
	{
		((ILocNamesModel) m_model).SetPrimaryLang(((String[]) _htFormData.GetElement(
				((ExpListModel) m_model).GetUniqueString(LocNamesPrimaryNameView.PRIMARY_LANG_DROPDOWN)))[0]);
	}

	/**
	 * MES- PerformIsLocalizedChangeAction reacts to the user changing the
	 * "Is Localized" checkbox by updating model variables
	 *
	 * @param _htFormData is a hashtable that stores the form post data and querystring
	 */
	private void PerformIsLocalizedChangeAction(XPHashtable _htFormData)
	{
		((ILocNamesModel) m_model).SetIsLocalized(_htFormData.ContainsKey(
			((ExpListModel) m_model).GetUniqueString(LocNamesPrimaryNameView.LOCNAME_CHK_SUPPORTS_LOC)));
	}

	/**
	 * MES- PerformNameDescPopupAction handles the case where a popup is being displayed
	 *
	 * @param _htFormData is a hashtable that stores the form post data and querystring
	 */
	private void PerformNameDescPopupAction(XPHashtable _htFormData)
	{
		//MES- Get the row number of the item we're editing and store it in the Model, where
		//	the Form can get to it.  The Model will also use this info later, when storing
		//	the data from the popup.
		((ILocNamesModel) m_model).SetRowToEdit(XPConvert.ToInteger(((String[]) _htFormData.GetElement(
			((ExpListModel) m_model).GetUniqueString(LocNamesView.POPUP_CONTROL_ARG_ROWTOEDIT)))[0]));
	}
}

