package com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List  framework for the
 * Growable Array. Is constains the HTML to display the Growable Array.  It
 * gets the data to display from GrowableListModel.
 *
 * @author MichaelS
 */
public class LocNamesView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.LocNamesView");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "LocNames";

	/** MES- Hidden elements for posting from the Name and Description popup */
	public static final String HTML_INPUT_NEW_NAME		  = "in_hi_NewName";

	
	public static final String HTML_INPUT_NEW_DESCRIPTION = "in_hi_NewDesc";

	
	public static final String HTML_INPUT_NEW_LANG = "in_hi_NewLang";

	/**
	 * MES- EDIT_ROW_NEWROW indicates that the Name and Description editor
	 * should make a NEW item
	 */
	public static final int EDIT_ROW_NEWROW = -1;

	/** MES- POPUP_CONTROL_ARG_ROWTOEDIT is a querystring argument we pass to the popup so
	 * that it knows what row it's editing */
	public static final String POPUP_CONTROL_ARG_ROWTOEDIT = "ndrow";

	/** MES- We cache the list of supported langs so that we don't have to keep getting it over
	 * and over */
	private String[] m_saSupportedLangs = null;

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on
	 * the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		// The URL to open as the pop-up
		ASURL myPopUp = new ASURL(m_asOwner);
		myPopUp.SetLinkGetCachedSpace(m_asOwner);
		myPopUp.SetDisplayPage(((ILocNamesModelRO)m_model).GetPopUpDisplayPageName());

		//MES- We want to pass the data to our repost control so that it can be stored
		myPopUp.SetControl(((EditorAS)m_asOwner).GetRepostControlName());

		//MES- Set the repost action to our special "popup" action for this URL
		myPopUp.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF,
			((IExpListModelRO) m_model).GetUniqueInt(LocNamesRepostControl.POSTTOSELF_ACTION_NAMEDESC_POPUP));

		XPStringBuilder sb;

		try
		{
			// Open Pop Up function
			sb = new XPStringBuilder(200);
			sb.Append("function OpenNameDescPopUp(intRowToEdit)\n");
			sb.Append("{\n");

			//MES- We have to build an URL that contains the querystring argument (which contains the
			//	row number we're editing.)
			sb.Append("  openURL = '").Append(myPopUp.GetURLAsString())
			.Append("&").Append(((ExpListModel) m_model).GetUniqueString(POPUP_CONTROL_ARG_ROWTOEDIT)).Append("=' + intRowToEdit;\n");
			sb.Append(
				"  window.open(openURL, '_blank3', 'location=no,menubar=no,height=250,width=400');\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, "LocNamesView::DisplayJavascript An error occured when trying to display the JavaScript.");
		}

		return myScript;
	}

	/**
	 * Returns the HTML for the row _nRowIndex. Each row contains just an icon
	 * and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 *
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		//MES- Get the data for the row
		String sName	    = (String) _saData.GetItem(_nRowIndex,
				LocNamesModel.LOCNAMEMODEL_COL_NAME);
		String sDescription = (String) _saData.GetItem(_nRowIndex,
				LocNamesModel.LOCNAMEMODEL_COL_DESCRIPTION);
		String sLangName	= (String) _saData.GetItem(_nRowIndex,
				LocNamesModel.LOCNAMEMODEL_COL_LANGNAME);

		HTMLElementCollection myRow = new HTMLElementCollection();

		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		//MES- The anchor to edit an existing name/description
		// mj: replaced the following line with a blank constructur and SetOnClick()
		// HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL); //"OpenNameDescPopUp(" + XPConvert.ToString(_nRowIndex) + ");");
		HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick(ConstructStaticHelpers.BLANK_URL); //"OpenNameDescPopUp(" + XPConvert.ToString(_nRowIndex) + ");");
		myAnchor.SetOnClick("OpenNameDescPopUp(" + XPConvert.ToString(_nRowIndex) +
			"); return false;");
		myAnchor.AddInnerHTMLEncodedString(sName);

		//MES- Add the name and description, separated by a linebreak
		myCell.AddInnerHTMLElement(myAnchor);
		if ( !((ILocNamesModelRO)m_model).IsNoDescriptions() )
		{
			myCell.AddInnerHTMLElement(new HTMLBr());
			myCell.AddInnerHTMLEncodedString(sDescription);
		}
		myCell.SetNoWrap(false);
		myRow.AddInnerHTMLElement(myCell);

		//MES- Next column is language	
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLEncodedString(sLangName);
		myRow.AddInnerHTMLElement(myCell);

		return myRow;
	}
	
	
	//MES- An internal helper class that wraps up data about a language choice.
	//	Used by GetLangChoicesControl.
	static class LangInfo
	{
		public LangInfo(String sLangIDArg, String sLangNameArg)
		{
			sLangID = sLangIDArg;
			sLangName = sLangNameArg;
			bIsCurrentChoice = false;
		}
		String sLangID;	//MES- The ID of the lang, e.g. "en"
		String sLangName;	//MES- The localized name of the language, e.g. "English"
		boolean bIsCurrentChoice;	//MES- Is this lang the choice to be selected in the UI?
	}
	
	//MES- An internal helper class used by GetLangChoicesControl to sort
	//	LangInfos.
	static class LangInfoComparer implements IXPComparer
	{
		//MES- The compare function should compare the lang names (which
		//	are localized)
		public int Compare(Object obj1, Object obj2)
		{
			LangInfo infoCompare1 = (LangInfo)obj1;
			LangInfo infoCompare2 = (LangInfo)obj2;
			return infoCompare1.sLangName.compareTo(infoCompare2.sLangName);
		}
		
		//MES- Unfortunately, IXPComparer derives from Comparator, which means that we
		//	also have to implement "compare", though the logic is the same.
		public int compare(Object obj1, Object obj2)
		{
			return Compare(obj1, obj2);
		}
	}

	//MES- TODO: Should this be moved to some centralized location?  Other classes
	//	might need this too?
	public static HTMLSelect GetLangChoicesControl(String sUserLang,
		String sControlName, String sCurrentChoice, XPResourceManager rm,
		XPHashtable htDisallowedLangs)

	{
		//MES- Get the list of known languages from the Resource Manager
		String[] asKnownLangs = rm.GetSupportedLanguages();

		//MES- Standardize the arguments
		if (null != sCurrentChoice)
		{
			sCurrentChoice = XPStringUtility.ToLowerCase(sCurrentChoice);
		}
		
		//MES- Map the langs to the name for that lang
		XPArrayList lstLangs = new XPArrayList();
		//MES- Do we need to explicitly add the current choice?
		//	We'd have to do this if the current choice doesn't
		//	appear in the list for some reason.
		boolean bNeedToAddCurrentChoice = true;
		if (null == sCurrentChoice)
			bNeedToAddCurrentChoice = false;
			
		for (int iLangIndex = 0; iLangIndex < asKnownLangs.length; ++iLangIndex)
		{
			//MES- Is it an excluded lang?
			String sLang = XPStringUtility.ToLowerCase(asKnownLangs[iLangIndex]);

			if (!htDisallowedLangs.Contains(sLang))
			{
				//MES- It's not excluded, add it to the list to show
				LangInfo infoLang = new LangInfo(sLang, rm.GetDisplayLocaleFromLocaleID(sLang, sUserLang));
				lstLangs.Add(infoLang);
				
				//MES- Is it the current choice?
				if (bNeedToAddCurrentChoice && null != sCurrentChoice)
				{
					if (0 == sCurrentChoice.compareTo(sLang))
					{
						bNeedToAddCurrentChoice = false;
						infoLang.bIsCurrentChoice = true;
					}
				}
			}
		}
		
		//MES- Add the current choice, if we need to (i.e. if the current choice was not 
		//	in the lstLangs array)
		if (bNeedToAddCurrentChoice)
		{
			LangInfo infoLang = new LangInfo(sCurrentChoice, rm.GetDisplayLocaleFromLocaleID(sCurrentChoice, sUserLang));
			infoLang.bIsCurrentChoice = true;
			lstLangs.Add(infoLang);
		}
		
		//MES- Sort the list
		XPCollections.Sort(lstLangs, new LangInfoComparer());
		

		//MES- Create a select control
		HTMLSelect selLangs = new HTMLSelect(sControlName, "");
		selLangs.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);

		//MES- Add each string to the dropdown
		for (int iLangIndex = 0; iLangIndex < lstLangs.GetSize(); ++iLangIndex)
		{
			LangInfo infoLang = (LangInfo)lstLangs.GetElement(iLangIndex);
			//MES- Add to the dropdown
			HTMLOption optLang = new HTMLOption(infoLang.sLangID);
			selLangs.AddInnerHTMLElement(optLang);
			optLang.AddInnerHTMLString(infoLang.sLangName);

			//MES- Is it the default one?
			if (infoLang.bIsCurrentChoice)
			{
				//MES- Set it to selected
				optLang.SetSelected(true);
			}
		}

		return selLangs;
	}

	/**
	 * 
	 *
	 * @param sUserLang 
	 * @param sControlName 
	 * @param sCurrentChoice 
	 * @param rm 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	public static HTMLSelect GetLangChoicesControl(String sUserLang,
		String sControlName, String sCurrentChoice, XPResourceManager rm)

	{
		XPHashtable emptyTable = new XPHashtable();

		return GetLangChoicesControl(sUserLang, sControlName, sCurrentChoice,
			rm, emptyTable);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LocNamesView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * MES- GetHTMLForAddAction returns the HTML for the "Add" button
	 *
	 * @return HTMLTableCell containing the appropriate HTML
	 *
	 * @throws Exception on error
	 */
	protected HTMLTableCell GetHTMLForAddAction()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();

		if (ShouldShowAddButton())
		{
			myCell.SetHeight("25");
			myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
			myCell.SetNoWrap(true);
			myCell.AddInnerHTMLString(SPACE);

			// Add icon
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
					true, this.m_asOwner);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImage.SetAlt("");
			myImage.SetBorder(CommonHTMLStrings.ZERO);
			myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

			//MES- Add a JavaScript anchor that opens the popup
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.SetOnClick("OpenNameDescPopUp(" +
					XPConvert.ToString(EDIT_ROW_NEWROW) + ");");
			myAnchor.AddInnerHTMLElement(myImage);
			myImage = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_LOCALE_SETTINGS,
					true, this.m_asOwner).GetHTMLElement();
			myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			myAnchor.AddInnerHTMLElement(myImage);

			mySpan = new HTMLSpan();
			myAnchor.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

			// Add label
			mySpan.AddInnerHTMLString(m_asOwner.GetString(422, "ptmsgs_portalinfrastructure"));
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);
			myCell.AddInnerHTMLElement(myAnchor);
			myCell.AddInnerHTMLString(SPACE);
		}

		//MES- Add hidden form elements for the Name and Description popup to fill in
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE,
			((IExpListModelRO) m_model).GetUniqueString(HTML_INPUT_NEW_NAME), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE,
			((IExpListModelRO) m_model).GetUniqueString(HTML_INPUT_NEW_DESCRIPTION), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE,
			((IExpListModelRO) m_model).GetUniqueString(HTML_INPUT_NEW_LANG), "");
		myCell.AddInnerHTMLElement(myInput);

		return myCell;
	}

	/**
	 * Helper method to get the HTML for the icon. (Each row has an icon before
	 * the input text.)
	 *
	 * @param _imgRowIcon is the image to display
	 *
	 * @return HTMLImg
	 *
	 * @throws Exception
	 */
	protected HTMLImg GetHTMLForIcon(PTImageType _imgRowIcon)

	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		myConstruct     = UIConstructFactory.GetConstruct(_imgRowIcon, true,
				this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetWidth("16");
		myImage.SetHeight("16");
		myImage.SetBorder(CommonHTMLStrings.ZERO);
		myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

		return myImage;
	}

	/**
	 * MES- CacheLangInfo sets m_saSupportedLangs if needed, or is a no-op
	 * if m_saSupportedLangs already contains the array of supported langs.
	 *
	 * @return none
	 *
	 */
	private void CacheLangInfo()
	{
		//MES- Cache the list of supported langs, if we haven't already
		if (null == m_saSupportedLangs)
		{
			XPResourceManager rm = m_asOwner.GetResourceManager();
			m_saSupportedLangs = rm.GetSupportedLanguages();
		}
	}

	/**
	 * MES- ShouldShowAddButton is an internal helper function that decides if the "add"
	 * button should be shown.  We suppress the "add" button if the localizations
	 * already include a localization into every known language- there are no langs
	 * left to localize to!
	 *
	 * @return boolean indicating if Add should be shown
	 *
	 */
	private boolean ShouldShowAddButton()
	{
		//MES- Make sure we know what the supported langs are
		CacheLangInfo();

		//MES- If there are more supported languages than entries, then we know we're OK.
		//	NOTE: The primary lang is NOT in the data, so we have to add one to the data!
		IPTGrowableSortedArrayWrapperRO data = ((IExpListModelRO) m_model).GetReadOnlyItems();
		int iDataRows						 = data.GetCount();

		if ((iDataRows + 1) < m_saSupportedLangs.length)
		{
			return true;
		}

		//MES- We might be out of langs, run through the used langs, seeing if there's a supported
		//	lang that's not in the list.
		//MES- Put the used langs into a map for fast and easy lookup
		XPHashtable mapUsedLangs = new XPHashtable();
		String sPrimaryLang		 = ((ILocNamesModelRO) m_model).GetPrimaryLang();
		mapUsedLangs.PutElement(sPrimaryLang, sPrimaryLang);

		for (int iDataIndex = 0; iDataIndex < iDataRows; ++iDataIndex)
		{
			String sDataLang = (String) data.GetItem(iDataIndex,
					LocNamesModel.LOCNAMEMODEL_COL_LANG);

			//MES- Use lower case to be case insensitive
			sDataLang = XPStringUtility.ToLowerCase(sDataLang);
			mapUsedLangs.PutElement(sDataLang, sDataLang);
		}

		//MES- Lookup each supported language in the map of used languages- is any supported
		//	language not used?
		for (int iSupportedLangIndex = 0;
				iSupportedLangIndex < m_saSupportedLangs.length;
				++iSupportedLangIndex)
		{
			String sSupportedLang = m_saSupportedLangs[iSupportedLangIndex];

			//MES- Use lower case to be case insensitive
			sSupportedLang = XPStringUtility.ToLowerCase(sSupportedLang);

			//MES- If this language isn't used, we're done!
			if (!mapUsedLangs.Contains(sSupportedLang))
			{
				return true;
			}
		}

		return false;
	}
	
   	/**
   	 * Returns the HTML for the View.
   	 *
   	 * @return HTMLElement
   	 */
   	public HTMLElement Display()
   	{
 		HTMLElementCollection resultWrapper = new HTMLElementCollection();
 		
 		HTMLSpan result = new HTMLSpan();
 		result.SetID("LOC_NAME_WRAPPER_ID");
 		resultWrapper.AddInnerHTMLElement(result);
 		
 		result.AddInnerHTMLElement(super.Display());

 		return result;
   	}   	

}

