package com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.uiinfrastructure.activityspace.*;


/**
 * Helper class that contains the items in a single migration history entry.
 *
 * @version $Revision$
 * @author ArvindS
 */
public class MigrationHistoryItem
{
	private String m_strMigrationComment;
	private String m_strMigrationSourcePortalUUID;
	private XPDateTime m_xpdtMigrationDate;
	private AActivitySpace m_asOwner;
	
	/**
	 * Creates a new MigrationHistoryItem object.
	 *
	 * @param _xpdtMigrationDate - Date retrieved from the server for this history item.
	 * @param _strMigrationComment - Migration comment retrieved from the server for this history item.
	 * @param _strMigrationSourcePortalUUID - Portal UUID retrieved from the server for this history item.
	 */
	public MigrationHistoryItem(XPDateTime _xpdtMigrationDate,
		String _strMigrationComment, String _strMigrationSourcePortalUUID,
		AActivitySpace _asOwner)
	{
		m_xpdtMigrationDate				   = _xpdtMigrationDate;
		m_strMigrationComment			   = _strMigrationComment;
		m_strMigrationSourcePortalUUID     = _strMigrationSourcePortalUUID;
		m_asOwner						   = _asOwner;
	}

	/**
	 * Retrieves the migration comment portion of this history item.
	 *
	 * @return The migration comment.
	 */
	public String GetMigrationComment()
	{
		return m_strMigrationComment;
	}

	/**
	 * Retrieves the migration status date for this history item.
	 *
	 * @return The migration status date.
	 */
	public String GetMigrationDate()
	{
		XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(
			XPDateFormat.SHORT, 
			XPDateFormat.SHORT,
			PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
			PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner));
			
		return xpDateTimeFormat.Format(m_xpdtMigrationDate);
	}

	/**
	 * Retrieves the source portal uuid for this history item.
	 *
	 * @return The source portal uuid.
	 */
	public String GetMigrationSourcePortalUUID()
	{
		return m_strMigrationSourcePortalUUID;
	}
}

