package com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * Model for the migration history of a single PTObject.
 *
 * @author ArvindS
 */
public class MigrationHistoryPluginModel extends EditorHelperModel
	implements IMigrationHistoryModel, IMigrationHistoryModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.MigrationHistoryPluginModel");

	
	public static final String STR_MVC_CLASS_NAME = "MigrationHistoryPlugin";
	private XPArrayList m_arrList = null;
	private int m_nCurrentMigrationStatus;
	private boolean m_bApprovedForMigration;
	
	public MigrationHistoryPluginModel()
	{
		super();
		m_arrList = new XPArrayList();
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationHistoryPluginModel();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCurrentMigrationStatus()
	{
		return m_nCurrentMigrationStatus;
	}

	/**
	 * 
	 *
	 * @param _nIndex 
	 *
	 * @return 
	 */
	public MigrationHistoryItem GetHistoryItem(int _nIndex)
	{
		return (MigrationHistoryItem) m_arrList.GetElement(_nIndex);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumHistoryItems()
	{
		return m_arrList.GetSize();
	}

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean InitializeHistory(int nClassID, int nObjectID)
	{
		try
		{
			IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
			
			IPTMigrationManager ptMM = (IPTMigrationManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
					false);

			m_nCurrentMigrationStatus = ptMM.QueryMigrationStatus(nClassID,
					nObjectID);

			IPTQueryResult ptQRHistory = ptMM.QueryMigrationHistory(nClassID,
					nObjectID);

			int nCount = ptQRHistory.RowCount();

			for (int i = 0; i < nCount; i++)
			{
				String strMigrationComment		    = ptQRHistory.ItemAsString(i,
						PT_PROPIDS.PT_PROPID_MIGRATION_COMMENT);
				XPDateTime xpdtMigration		    = ptQRHistory.ItemAsXPDateTime(i,
						PT_PROPIDS.PT_PROPID_MIGRATION_DATE);
				String strMigrationSourcePortalUUID = ptQRHistory.ItemAsString(i,
						PT_PROPIDS.PT_PROPID_MIGRATION_SOURCEPORTALUUID);

				MigrationHistoryItem mhi = new MigrationHistoryItem(xpdtMigration,
						strMigrationComment, strMigrationSourcePortalUUID, m_asOwner);
				m_arrList.Add(mhi);
			}

			return true;
		}
		catch (Exception e)
		{
			
				log.Error(e, "MigrationHistoryPluginModel: Unable to initialize history.");
			

			return false;
		}
	}

	/**
	 * Retrieves the flag indicating whether or not we are being
	 * hosted by another activity space, or our own.
	 */
	public boolean IsStandalone()
	{
		return false;
	}

	/**
	 * Retrieves the flag indicating whether or not to display
	 * the approval checkbox (currently only for full sysadmins)
	 */
	public boolean ShouldDisplayApproval()
	{		
		if (PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED == m_nCurrentMigrationStatus)
		{
			return false;
		}
		
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		// Return true if the current user is a system administrator
		return PlumtreeHelpers.CheckCurrentUserIsAdmin(ptSession);
	}
	
	/**
	 * Helper method to Store the migration status on the object.
	 *
	 */	
	public void StoreMigrationStatus(int nClassID, int nObjectID)
	{	
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		if (PlumtreeHelpers.CheckCurrentUserIsAdmin(ptSession))
		{
			if (((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).IsMigrationCheckboxChecked())
			{
				try
				{
					// open the migration manager
					IPTMigrationManager ptMM = (IPTMigrationManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
							false);

					// simulate approval process:
					// first set the request
					ptMM.BulkSetMigrationStatus(nClassID,
						new int[] { nObjectID }, PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED, "");
						
					
					// then set the migration status to approved for the object
					ptMM.BulkSetMigrationStatus(nClassID,
						new int[] { nObjectID }, PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED, "");
				}
				catch (Exception e)
				{
					
						log.Error("MigrationHistoryPluginModel::SaveMigrationStatus Unable to save the migration status." +
							" The following exception happened: " + e);
					
				}
			}
		}
	}
	
	/**
	 * Sets the flag indicating this object has been approved for migration
	 */
	public void SetApprovedForMigration(boolean bApproved)
	{
		m_bApprovedForMigration = bApproved;
	}
	
	/**
	 * Retrieves the flag indicating whether the checkbox has
	 * been checked in this editor session.
	 */
	public boolean IsMigrationCheckboxChecked()
	{
		return m_bApprovedForMigration;
	}
	
	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		if (_htFormData.ContainsKey(MigrationHistoryView.HTMLCHECKBOX_MIGRATION))
		{
			m_bApprovedForMigration = true;
		}
		else
		{
			m_bApprovedForMigration = false;
		}
		
		return EditorRepostControl.PAGE_STATUS_VALID;
	}
}

