package com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;


import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;

/**
 * This interface contains all of the methods for accessing object property
 * information in the model.
 *
 * @author josephc
 */
public interface IObjPropModelRO extends IExpListPropModelRO
{
	/**
	 * Checks to see if the object supports EOD
	 *
	 * @return Returns true if object supports EOD.  Otherwise returns false.
	 */
	public boolean CheckObjectSupportsEOD();

	/**
	 * Checks to see if the property is an HREF
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if HREF. Otherwise returns false.
	 */
	public boolean CheckRowIsHREF(int _nRowIndex);

	/**
	 * Checks to see if the property is mandatory
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if mandatory. Otherwise returns false.
	 */
	public boolean CheckRowIsMandatory(int _nRowIndex);

	/**
	 * Checks to see if the property is multivalued
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if multivalued. Otherwise returns false.
	 */
	public boolean CheckRowIsMultiValued(int _nRowIndex);

	/**
	 * Checks to see if the property is read-only
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if read-only. Otherwise returns false.
	 */
	public boolean CheckRowIsReadOnly(int _nRowIndex);

	/**
	 * Checks to see if the property is visible
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if visible. Otherwise returns false.
	 */
	public boolean CheckRowIsVisible(int _nRowIndex);
	
	/**
	 * Returns true if the display page is mandatory because it contains
	 * mandatory properties.
	 *
	 * @return True if page contains mandatory properties that user must enter values for.
	 */
	public boolean CheckDisplayPageIsMandatory();

	/**
	 * Return pick list values for the property
	 *
	 * @param _nPropertyID Property ID
	 *
	 * @return Pick list values
	 */
	public Object[][] GetPickListValues(int _nPropertyID);

	/**
	 * Returns the value of the requested PROPID from the EOD query result.
	 *
	 * @param _nRowIndex Row index
	 * @param nPropID PT_PROPID
	 *
	 * @return Value of requested PROPID
	 */
	public Object GetRowPropertyInfo(int _nRowIndex, int nPropID);

	/**
	 * Returns the reference value name
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Reference value name
	 */
	public String GetRowRefValueName(int _nRowIndex);

	/**
	 * Returns string representation of property value
	 *
	 * @param oValue Property value as Object
	 * @param nPropertyType Property type
	 *
	 * @return Property value as string
	 */
	public String GetStringFromObjectValue(Object oValue, int nPropertyType);

	/**
	 * Returns any previously selected reference
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Value of property
	 */
	public String GetSelectedReference(int _nRowIndex);

	/**
	 * Returns true if current user has access to global object property map.
	 * In order to access this editor, the user must be a member of the administrators
	 * group and must have the right to access the Plumtree utilities.
	 *
	 * @return True if user has access. False otherwise.
	 */
	public boolean HasAccessToGlobalObjectPropMapEditor();
	
	/**
	 * If a property has a pick tree or pick list, check that the pick values
	 * can be successfully retrieved.
	 * 
	 * @param _nRowIndex Row index
	 * 
	 * @return True if pick values can be successfully retrieved.
	 */
	public boolean CheckPickValuesAreValid(int _nRowIndex);
}

