package com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;

// Framework Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Display page for browse view of object properties
 *
 * @author josephc
 */
public class ObjPropBrowseDP extends AFormDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.ObjPropBrowseDP");

	/** Class name for ObjPropBrowseDP */
	public static final String STR_MVC_CLASS_NAME = "ObjPropBrowse";

	/** HTML button for closing editor / going back (508) */
	public static final String HTMLBUTTON_EDITOR_CLOSE = "in_bu_Close";

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()
	 */
	public String GetFormTitle()
	{
		String strObjectName = ((ObjPropEditorModel) m_asOwner.GetModel(ObjPropEditorModel.STR_MVC_CLASS_NAME)).GetObjectName();
		return XPResourceManager.FormatMessage(m_asOwner.GetString(279, "ptmsgs_portalinfrastructure"), XPHttpUtility.HtmlEncode(strObjectName));
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the object properties page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException 
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection myResult = new HTMLElementCollection();

		myResult.AddInnerHTMLElement(GetHeader());
		myResult.AddInnerHTMLElement(m_asOwner.GetView(ObjPropBrowseView.STR_MVC_CLASS_NAME).Display());

		return myResult;
	}
	
	public HTMLTable GetHeader()
	{
		HTMLTable mainTable = null;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLH1 headerH1;
		
		try
		{
			mainTable = new HTMLTable();
			mainTable.SetBorder("0");
			mainTable.SetWidth("100%");
			mainTable.SetCellPadding("5");
			mainTable.SetCellSpacing("0");
	
			// BEGIN Banner and Edit and Close buttons
			myRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			headerH1 = new HTMLH1();
			myCell.AddInnerHTMLElement(headerH1);
			myCell.SetHeight("30");
			
			// Title
			String strObjectName = ((ObjPropEditorModel) m_asOwner.GetModel(ObjPropEditorModel.STR_MVC_CLASS_NAME)).GetObjectName();
			
			headerH1.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(86, "ptmsgs_portalinfrastructure"), XPHttpUtility.HtmlEncode(strObjectName)));
			headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);

			// buttons
			myCell = new HTMLTableCell();
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetWidth("300");
			myCell.SetColSpan("2");
			myRow.AddInnerHTMLElement(myCell);
	
			if (GetOwner().GetAccessStyle() == AccessStyles.STANDARD)
			{
				// Close button
				myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_EDITOR_CLOSE, "");
				myCell.AddInnerHTMLElement(myInput);
		
				// TODO: Create a "close" button in portaluiinfrastructure
				myInput.SetValue(m_asOwner.GetString(118, "ptmsgs_portalbrowsingmsgs"));
				myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
				myInput.SetOnClick("self.close(); return false;");
			}
			else
			{
				// Finish button (in 508 mode it's not a popup, 
				// so we just want to go back to previous page.
				String strFinish = m_asOwner.GetString(147, ResourceConstants.INFRASTRUCTURE); // "Finish"
				myInput = new HTMLInput(HTMLInputTypes.SUBMIT,
						RepostControl.HTMLSUBMIT_508_POSTTOSELF +
						RepostControl.POSTTOSELF_ACTION_CANCEL, "");
				myCell.AddInnerHTMLElement(myInput);

				myInput.SetValue(strFinish); // "Finish"
				myInput.SetAlt(strFinish); // "Finish"
				myInput.SetAccessKey(m_asOwner.GetString(26, "ptmsgs_portal508quickkeymsgs"));
				myInput.SetTitle(m_asOwner.GetString(28, "ptmsgs_portal508quickkeymsgs"));
				myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			}			
		}
		catch (Exception e)
		{
			
				log.Error(e, "The following error occured when trying to display the HTML: " +
					e.getMessage());
			
		}
		
		return mainTable;
	}
	
	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		if (GetOwner().GetAccessStyle() == AccessStyles.STANDARD)
		{
			HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
	
			myScripts.AddInnerHTMLElement(m_asOwner.GetView(
					ObjPropBrowseView.STR_MVC_CLASS_NAME).DisplayJavascript());
	
			return myScripts;
		}
		else
		{
			return null;
		}
	}
	
}

