package com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;

import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List for object properties
 *
 * @author josephc
 */
public class ObjPropBrowseView extends ExpListPropBrowseView
{
	/** Class name for the ObjPropBrowseView */
	public static final String STR_MVC_CLASS_NAME = "ObjPropBrowse";

	/** Height of rows in list */
	protected String m_strRowHeight = "20";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjPropBrowseView();
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex Row index
	 *
	 * @return HTML for row
	 *
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Get cell containing class name
		result.AddInnerHTMLElement(GetHTMLForName(_nRowIndex));

		// Get cell containing property value
		result.AddInnerHTMLElement(GetHTMLForPropertyValue(_nRowIndex));

		// Get cell containing row action (add, remove, or nothing)
		HTMLTableCell cellAction = GetHTMLForRowAction(_nRowIndex);

		if (null != cellAction)
		{
			result.AddInnerHTMLElement(cellAction);
		}

		return result;
	}

	/**
	 * Returns null because rows are read-only in browse-mode.
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Table cell for action
	 *
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForRowAction(int _nRowIndex)
	{
		return null;
	}

	/**
	 * Returns table cell for property value
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Table cell for property value
	 *
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForPropertyValue(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		myCell.SetWidth("80%");
		myCell.SetHeight(m_strRowHeight);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		Object oValue = iOPModel.GetRowValue(_nRowIndex);
		int nPropertyType = iOPModel.GetRowType(_nRowIndex);
		String strValue = iOPModel.GetStringFromObjectValue(oValue, nPropertyType);

		if (null != oValue)
		{
			if (iOPModel.CheckRowIsHREF(_nRowIndex))
			{
				HTMLAnchor myAnchor = new HTMLAnchor(strValue);
				myCell.AddInnerHTMLElement(myAnchor);
				myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strValue));
			}
			else
			{
				myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strValue));
			}
		}

		return myCell;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Helper method to determine whether or not row is visible.  This method
	 * is used by Display().  This method overrides the default behavior of
	 * the ExpListView, where all rows are visible.
	 *
	 * @param _nRowIndex
	 *
	 * @return True if row should be displayed, otherwise false.
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#CheckRowIsVisible(int)
	 */
	protected boolean CheckRowIsVisible(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		// Display the row if the property is visible and the row has not been deleted.
		if ((iOPModel.CheckRowIsVisible(_nRowIndex)) && (ObjPropModel.ROW_STATUS_DELETED != iOPModel.GetRowStatus(_nRowIndex)))
		{
			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Returns HTML for name of property. If the row is a new property then
	 * display name.  If the row is another value in a multi-valued property,
	 * then don't display name.  Distinguish mandatory properties from
	 * optional properties.
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return HTML table cell for name
	 *
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForName(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetWidth("20%");
		myCell.SetHeight(m_strRowHeight);
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

		// Get current row's name and propertyID
		String strName = iOPModel.GetRowName(_nRowIndex);

		// If we have a new property, then display name
		if (CheckRowIsFirstForProperty(_nRowIndex))
		{
			HTMLSpan spanSubTitle = new HTMLSpan();
			myCell.AddInnerHTMLElement(spanSubTitle);
			spanSubTitle.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			spanSubTitle.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strName));
		}

		return myCell;
	}
}

