package com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.server.treeiterator.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List for object properties
 *
 * @author josephc
 */
public class ObjPropEditView extends ExpListPropEditView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.ObjPropEditView");

	/** Class name for the ObjPropEditView */
	public static final String STR_MVC_CLASS_NAME = "ObjPropEdit";

	/** Prefix for picklist input */
	public static final String HTMLINPUT_SELECT_PICKLIST_PREFIX = "in_se_PickList";

	/** TagID for picklist */
	public static final String HTMLINPUT_SELECT_PICKLIST_TAGID = "PickListTagID";

	/** HTML Object name: clear value (set to true to clear the property value) */
	public static final String HTMLHIDDEN_CLEARVALUE   = "in_hi_clearvalue";

	/** JavaScript function to open pick tree. */
	private static final String JAVASCRIPT_PICKTREE_OPEN = "pickTreeOpen";

	/** JavaScript function to get pick tree value. */
	private static final String JAVASCRIPT_PICKTREE_GETVALUE = "pickTreeGetValue";

	/** JavaScript function to open reference tree. */
	private static final String JAVASCRIPT_REFTREE_OPEN = "referenceTreeOpen";

	/** JavaScript function to get reference tree value. */
	private static final String JAVASCRIPT_REFTREE_GETVALUE = "referenceTreeGetValue";

	/** JavaScript function to add or remove a property value. */
	private static final String JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE = "addRemovePropertyValue";

	/** JavaScript function to clear a property value. */
	private static final String JAVASCRIPT_CLEAR_PROPERTY_VALUE = "clearPropertyValue";

	/** JavaScript function to open Global Object Properties Editor. */
	private static final String JAVASCRIPT_OBJ_PROP_EDITOR_OPEN = "objPropEditorOpen";

	/** Height of rows in list */
	protected String m_strRowHeight = "30";


	/**
	 * Helper method to determine whether or not row is visible.  This method
	 * is used by Display().  This method overrides the default behavior of
	 * the ExpListView, where all rows are visible.
	 *
	 * @param _nRowIndex
	 *
	 * @return True if row should be displayed, otherwise false.
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#CheckRowIsVisible(int)
	 */
	protected boolean CheckRowIsVisible(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		// Display the row if the property is visible and the row has not been deleted.
		if ((iOPModel.CheckRowIsVisible(_nRowIndex)) &&
			(ObjPropModel.ROW_STATUS_DELETED != iOPModel.GetRowStatus(_nRowIndex)))
		{
			// Special case for name and description properties. They shouldn't show up in the edit view.
			if (ObjPropModel.PROP_OBJECTID_NAME == iOPModel.GetRowPropertyID(_nRowIndex) ||
				ObjPropModel.PROP_OBJECTID_DESCRIPTION == iOPModel.GetRowPropertyID(_nRowIndex))
			{
				return false;
			}
			else
			{
				return true;
			}
		}
		else
		{
			return false;
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjPropEditView();
	}

	/**
	 * Returns the HTML for the View.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		// Override this method so that we can add a hidden form input for use in
		// clearing property values.

		HTMLElement result = super.Display();

		// Hidden input for the clear property value functionality
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
			((IObjPropModelRO) m_model).GetUniqueString(HTMLHIDDEN_CLEARVALUE), "");
		myInput.SetValue(XPConvert.ToString(false));

		result.AddInnerHTMLElement(myInput);

		return result;
	}

	/**
	 * JavaScript for opening tree selectors and retrieving values on return
	 * from tree.
	 *
	 * @return JavaScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLScript result = super.DisplayJavascript();
		XPStringBuilder sb;

		try
		{
			// The URL to open a pick tree
			ASURL asURLPickTree = GetPickTreeURL();

			// JavaScript fucntion to open pick tree
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_OPEN)).Append("(varPropertyID, varRowIndex)\n");
			sb.Append("{\n");
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
			sb.Append("  window.open('").Append(asURLPickTree.GetURLAsString());
			sb.Append("&").Append(ServerStartTreeControl.INIT_DATA).Append("=' + varPropertyID");
			sb.Append(", 'PickTreeWindow', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// JavaScript function to get pick tree value on return
			sb = new XPStringBuilder(100);
			sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_GETVALUE)).Append("()\n");
			sb.Append("{\n");
			sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MODIFYROW)).Append(");\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// The URL to open a reference tree
			ASURL asURLRefTree = GetRefTreeURL();

			// JavaScript function to open reference tree
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_OPEN)).Append("(varClassID, varRowIndex, varTreeSelectMode, varSelectedRef)\n");
			sb.Append("{\n");
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
			sb.Append("  window.open('").Append(asURLRefTree.GetURLAsString());
			sb.Append("&").Append(StartTreeControl.CLASS_IDS_TO_DISPLAY).Append("=' + varClassID");
			sb.Append(" + '&").Append(StartTreeControl.SELECT_MODE).Append("=' + varTreeSelectMode");
			sb.Append(" + '&").Append(StartTreeControl.SELECTED_ITEMS).Append("=' + varSelectedRef");
			sb.Append(", 'ReferenceTreeWindow', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// JavaScript function to open Global Object Properties Map
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_OBJ_PROP_EDITOR_OPEN)).Append("()\n");
			sb.Append("{\n");
			sb.Append("  window.open('").Append(GetASURLToObjPropMap(null).GetURLAsString());
			sb.Append("', 'ObjPropWindow', 'location=no,menubar=no,resizable=yes,scrollbars=yes');\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// JavaScript function to get reference object on return from reference tree
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_GETVALUE)).Append("()\n");
			sb.Append("{\n");
			sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MODIFYROW)).Append(");\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// JavaScript to add or remove property values
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE)).Append("(varAction, varRowIndex)\n");
			sb.Append("{\n");
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
			sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append("varAction").Append(");\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// JavaScript to clear property values
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_CLEAR_PROPERTY_VALUE)).Append("(varRowIndex)\n");
			sb.Append("{\n");
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_CLEARVALUE)).Append(".value = true;\n");
			// Since we are using the base ExpListControl, we just use the MODIFY_ROW action to clear
			// a value.  Our model has special code in the ModifyRow method to handle this case.
			sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MODIFYROW)).Append(");\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element.");
		}

		return result;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex Row index
	 *
	 * @return HTML for row
	 *
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Get cell containing class name
		result.AddInnerHTMLElement(GetHTMLForName(_nRowIndex));
		
		// Get cell containing property value
		result.AddInnerHTMLElement(GetHTMLForPropertyValue(_nRowIndex));
		
		// Get cell containing row action (add, remove, or nothing)
		HTMLTableCell cellAction = GetHTMLForRowAction(_nRowIndex);
				
		if (null != cellAction)
		{
			result.AddInnerHTMLElement(cellAction);
		}
		
		return result;
	}


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Displays HTML below action bar. If the table contained any mandatory
	 * properties, then we want to display "*RequiredText".
	 *
	 * @return HTML below action bar
	 *
	 * @throws Exception
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLBelowMainTable()
	 */
	protected HTMLTable GetHTMLBelowMainTable()
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
		
		if (iOPModel.CheckDisplayPageIsMandatory())
		{
			HTMLTable myTable;
			HTMLTableRow myRow;
			HTMLTableCell myCell;
			HTMLSpan mySpan;

			myTable = new HTMLTable();
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding(CommonHTMLStrings.FIVE);

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("150");
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetColSpan(CommonHTMLStrings.THREE);
			myCell.SetNoWrap(true);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
			mySpan.AddInnerHTMLString("*");
			mySpan.AddInnerHTMLString(m_asOwner.GetString(267, "ptmsgs_portalinfrastructure"));

			return myTable;
		}
		else
		{
			return null;
		}
	}



	/**
	 * Returns HTML for pick list
	 *
	 * @param _nRowIndex Row index
	 * @param _strValue Property value as string
	 *
	 * @return HTML for pick list
	 *
	 * @throws HTMLException
	 */
	protected HTMLElementCollection GetHTMLForPickList(int _nRowIndex, String _strValue)
	{
		HTMLElementCollection myCollection = new HTMLElementCollection();
		
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		if (iOPModel.CheckPickValuesAreValid(_nRowIndex))
		{
			HTMLSelect mySelect = new HTMLSelect(iOPModel.GetUniqueString(HTMLINPUT_SELECT_PICKLIST_PREFIX) + _nRowIndex, iOPModel.GetUniqueString(HTMLINPUT_SELECT_PICKLIST_TAGID) + _nRowIndex);
			myCollection.AddInnerHTMLElement(mySelect);
	
			// Add the first option, which is empty value
			HTMLOption optionEmpty = new HTMLOption("");
			mySelect.AddInnerHTMLElement(optionEmpty);
			mySelect.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
	
			// Open the property ObjectManager in order to open property.
			Object[][] arPickListValues = iOPModel.GetPickListValues(iOPModel.GetRowPropertyID(_nRowIndex));
	
			boolean bValueInList = false;
			
			// Add drop down
			if (null != arPickListValues)
			{
				for (int nOption = 0; nOption < arPickListValues[0].length;
						nOption++)
				{
					String strPickListVal = (String) arPickListValues[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME][nOption];
									
					String strEncodedString = XPHttpUtility.HtmlEncode(strPickListVal);
					HTMLOption optionPickListVal = new HTMLOption(strEncodedString);
					optionPickListVal.AddInnerHTMLString(strEncodedString);
	
					mySelect.AddInnerHTMLElement(optionPickListVal);
					
					if (strPickListVal.equals(_strValue))
					{
						bValueInList = true;
					}
				}
			}
	
			if (null != _strValue && 0 < _strValue.length())
			{
				// If the option doesn't exist as a valid pick list value, then display alert message.		
				if (!bValueInList)
				{
					// Display alert message indicating that value is no longer valid
					HTMLSpan mySpan = new HTMLSpan();
					myCollection.AddInnerHTMLElement(mySpan);
					mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
					mySpan.AddInnerHTMLEncodedString(XPResourceManager.FormatMessage(m_asOwner.GetString(469, "ptmsgs_portalinfrastructure"), _strValue));
				}
				else
				{
					// Set the selected value
					mySelect.SetValue(XPHttpUtility.HtmlEncode(_strValue));
				}
			}
		}
		else
		{
			myCollection.AddInnerHTMLEncodedString(_strValue);
			myCollection.AddInnerHTMLString(" ");
			
			HTMLSpan mySpan = new HTMLSpan();
			myCollection.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
			mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(471, "ptmsgs_portalinfrastructure"));
		}
		return myCollection;
	}

	/**
	 * Returns HTML for pick tree
	 *
	 * @param _nRowIndex Row index
	 * @param _strValue Property value as string
	 *
	 * @return HTML for pick tree
	 *
	 * @throws Exception
	 */
	protected HTMLElement GetHTMLForPickTree(int _nRowIndex, String _strValue)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLAnchor myAnchor;
		HTMLImg myImage;
		PTConstruct myConstruct;
		XPStringBuilder sbJavascriptOpenPickTree;
		HTMLElementCollection result = new HTMLElementCollection();

		result.AddInnerHTMLEncodedString(_strValue);

		if (iOPModel.CheckPickValuesAreValid(_nRowIndex))
		{
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			result.AddInnerHTMLElement(myAnchor);
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT, true, this.m_asOwner);
			myImage = (HTMLImg) myConstruct.GetHTMLElement();
			myAnchor.AddInnerHTMLElement(myImage);
	
			myImage.SetAlt(m_asOwner.GetString(89, "ptmsgs_portalinfrastructure"));
			myImage.SetWidth("25");
			myImage.SetHeight("25");
			myImage.SetBorder(CommonHTMLStrings.ZERO);
			myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
	
			sbJavascriptOpenPickTree = new XPStringBuilder(100);
			sbJavascriptOpenPickTree.Append(iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_OPEN)).Append("(");
			sbJavascriptOpenPickTree.Append(iOPModel.GetRowPropertyID(_nRowIndex)); // Append property ID
			sbJavascriptOpenPickTree.Append(", ");
			sbJavascriptOpenPickTree.Append(_nRowIndex); // Append current row to modify
			sbJavascriptOpenPickTree.Append("); return false;");
			myAnchor.SetOnClick(sbJavascriptOpenPickTree.ToString());
		}
		else
		{
			result.AddInnerHTMLString(" ");
			
			HTMLSpan mySpan = new HTMLSpan();
			result.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
			
			mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(472, "ptmsgs_portalinfrastructure"));
		}

		return result;
	}

	/**
	 * Returns HTML for reference tree
	 *
	 * @param _nRowIndex Row index
	 * @param _strValue Reference value as string
	 *
	 * @return HTML for pick tree
	 *
	 * @throws Exception
	 */
	protected HTMLElement GetHTMLForReferenceTree(int _nRowIndex, String _strValue)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLAnchor myAnchor;
		HTMLImg myImage;
		PTConstruct myConstruct;
		XPStringBuilder sbOpenRefTree;
		HTMLElementCollection result = new HTMLElementCollection();

		// Reference value
		String strRefObjectName = iOPModel.GetRowRefValueName(_nRowIndex);

		if (null != strRefObjectName)
		{
			result.AddInnerHTMLEncodedString(iOPModel.GetRowRefValueName(_nRowIndex));
			result.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}

		// Edit link
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		result.AddInnerHTMLElement(myAnchor);
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT, true, this.m_asOwner);
		myImage = (HTMLImg) myConstruct.GetHTMLElement();
		myAnchor.AddInnerHTMLElement(myImage);

		myImage.SetAlt(m_asOwner.GetString(266, "ptmsgs_portalinfrastructure")); // Reference Tree
		myImage.SetWidth("25");
		myImage.SetHeight("25");
		myImage.SetBorder(CommonHTMLStrings.ZERO);
		myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

		// Get reference class ID
		int nReferenceClassID = XPConvert.ToInteger(iOPModel.GetRowPropertyInfo(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_REFCLASS));

		sbOpenRefTree = new XPStringBuilder(100);
		sbOpenRefTree.Append(iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_OPEN)).Append("(");
		sbOpenRefTree.Append(nReferenceClassID); // Append ref class ID
		sbOpenRefTree.Append(", ");
		sbOpenRefTree.Append(_nRowIndex); // Append current row to modify
		sbOpenRefTree.Append(", ");

		if ((PT_CLASSIDS.PT_ADMIN_FOLDER_ID == nReferenceClassID) || (PT_CLASSIDS.PT_CATALOGFOLDER_ID == nReferenceClassID))
		{
			sbOpenRefTree.Append(TreeConstants.N_COMPOSITESELECT);
		}
		else
		{
			sbOpenRefTree.Append(TreeConstants.N_LEAFSELECT);
		}

		sbOpenRefTree.Append(", '");
		sbOpenRefTree.Append(iOPModel.GetSelectedReference(_nRowIndex));
		sbOpenRefTree.Append("'); return false;");
		myAnchor.SetOnClick(sbOpenRefTree.ToString());

		// Only add the clear link if there is a value to clear
		if (null != strRefObjectName)
		{
			// Clear link
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			result.AddInnerHTMLElement(myAnchor);
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_REMOVE, true, this.m_asOwner);
			myImage = (HTMLImg) myConstruct.GetHTMLElement();
			myAnchor.AddInnerHTMLElement(myImage);
	
			myImage.SetAlt(m_asOwner.GetString(545, "ptmsgs_portalinfrastructure")); // Clear Value
			myImage.SetWidth("25");
			myImage.SetHeight("25");
			myImage.SetBorder(CommonHTMLStrings.ZERO);
			myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

			XPStringBuilder sbClearValue = new XPStringBuilder(100);
			sbClearValue.Append(iOPModel.GetUniqueString(JAVASCRIPT_CLEAR_PROPERTY_VALUE)).Append("(");
			sbClearValue.Append(_nRowIndex); // Append current row to modify
			sbClearValue.Append("); return false;");

			myAnchor.SetOnClick(sbClearValue.ToString());
		}

		return result;
	}

	/**
	 * Checks to see if the row can be removed.
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if row can be removed. Otherwise returns false.
	 *
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.IObjPropModelRO#CheckRowIsRemovable(int,
	 *      boolean)
	 */
	protected boolean CheckRowIsRemovable(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		// If read-only, cannot remove row
		if (iOPModel.CheckRowIsReadOnly(_nRowIndex))
		{
			return false;
		}

		// If first row for property, then cannot remove row
		if (CheckRowIsFirstForProperty(_nRowIndex))
		{
			return false;
		}

		return true;
	}

	/**
	 * Returns anchor for add button
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Anchor for add button
	 *
	 * @throws Exception
	 */
	protected HTMLAnchor GetAddAnchor(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLAnchor myAnchor;

		myAnchor     = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD, true, m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");

		myAnchor.AddInnerHTMLElement(myImage);
		myAnchor.AddInnerHTMLString(m_asOwner.GetString(366, "ptmsgs_portalinfrastructure"));

		XPStringBuilder sb = new XPStringBuilder(100);

		sb.Append(iOPModel.GetUniqueString(JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE));
		sb.Append("('");
		sb.Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD));
		sb.Append("', '");
		sb.Append(_nRowIndex);
		sb.Append("'); return false;");

		myAnchor.SetOnClick(sb.ToString());

		return myAnchor;
	}

	/**
	 * Returns anchor for delete button
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Anchor for delete button
	 *
	 * @throws Exception
	 */
	protected HTMLAnchor GetDeleteAnchor(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLAnchor myAnchor;

		myAnchor     = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

		// Delete icon
		myConstruct     = UIConstructFactory.GetConstruct(iOPModel.GetDeleteIcon(), true, this.m_asOwner);
		myImage = (HTMLImg) myConstruct.GetHTMLElement();
		myAnchor.AddInnerHTMLElement(myImage);
		myImage.SetAlt(iOPModel.GetDeleteIconAlt());
		myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

		XPStringBuilder sb = new XPStringBuilder(100);

		sb.Append(iOPModel.GetUniqueString(JAVASCRIPT_ADD_REMOVE_PROPERTY_VALUE));
		sb.Append("('");
		sb.Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE));
		sb.Append("', '");
		sb.Append(_nRowIndex);
		sb.Append("'); return false;");

		myAnchor.SetOnClick(sb.ToString());

		return myAnchor;
	}

	/**
	 * Returns HTML for name of property. If the row is a new property then
	 * display name.  If the row is another value in a multi-valued property,
	 * then don't display name.  Distinguish mandatory properties from
	 * optional properties.
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return HTML table cell for name
	 *
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForName(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetWidth("20%");
		myCell.SetHeight(m_strRowHeight);
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

		// Get current row's name and propertyID
		String strName = iOPModel.GetRowName(_nRowIndex);

		// If we have a new property, then display name
		if (CheckRowIsFirstForProperty(_nRowIndex) || (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD))
		{
			HTMLSpan spanSubTitle = new HTMLSpan();
			myCell.AddInnerHTMLElement(spanSubTitle);
			spanSubTitle.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			spanSubTitle.AddInnerHTMLEncodedString(strName);

			if (iOPModel.CheckRowIsMandatory(_nRowIndex) && !iOPModel.CheckRowIsReadOnly(_nRowIndex))
			{
				HTMLSpan mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.ALERT_REQUIRED_TEXT);
				mySpan.AddInnerHTMLString("*");
			}
		}

		return myCell;
	}	

	/**
	 * Returns table cell for property value
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Table cell for property value
	 *
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForPropertyValue(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		myCell.SetWidth("80%");
		myCell.SetHeight(m_strRowHeight);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		Object oValue = iOPModel.GetRowValue(_nRowIndex);
		int nPropertyType = iOPModel.GetRowType(_nRowIndex);
		String strValue = iOPModel.GetStringFromObjectValue(oValue, nPropertyType);

		// If the property is read-only, then just display the value.  Else display display the input text box for the value.
		if (iOPModel.CheckRowIsReadOnly(_nRowIndex))
		{
			if (null != oValue)
			{
				if (iOPModel.CheckRowIsHREF(_nRowIndex))
				{
					HTMLAnchor myAnchor = new HTMLAnchor(strValue);
					myCell.AddInnerHTMLElement(myAnchor);
					myAnchor.AddInnerHTMLEncodedString(strValue);
				}
				else
				{
					if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == nPropertyType)
					{
						strValue = iOPModel.GetRowRefValueName(_nRowIndex);
					}

					myCell.AddInnerHTMLEncodedString(strValue);
				}
			}
		}
		else
		{
			// Determine what kind of form element to display
			int nPickType = XPConvert.ToInteger(iOPModel.GetRowPropertyInfo(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_PICKTYPE));

			switch (nPickType)
			{
			case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST:
			case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:

				// Get drop down menu for picklist
				myCell.AddInnerHTMLElement(GetHTMLForPickList(_nRowIndex, strValue));

				break;

			case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:

				// Get picktree link
				myCell.AddInnerHTMLElement(GetHTMLForPickTree(_nRowIndex, strValue));

				break;

			default:
				myCell.AddInnerHTMLElement(GetHTMLElementForRow(_nRowIndex, oValue));
				break;
			}
		}

		return myCell;
	}

	/**
	 * Returns table cell for adding a value or deleting a value.
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Table cell for action
	 *
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForRowAction(int _nRowIndex)
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLTableCell myCell;
		HTMLAnchor myAnchor;

		myCell = new HTMLTableCell();
		myCell.SetHeight(m_strRowHeight);
		myCell.SetWidth("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);

		// Get cell containing add or remove button
		if (!iOPModel.CheckRowIsReadOnly(_nRowIndex))
		{
			if (CheckRowIsFirstForProperty(_nRowIndex) && iOPModel.CheckRowIsMultiValued(_nRowIndex))
			{
				myAnchor = GetAddAnchor(_nRowIndex);
				myCell.AddInnerHTMLElement(myAnchor);
			}
			else if (CheckRowIsRemovable(_nRowIndex))
			{
				myAnchor = GetDeleteAnchor(_nRowIndex);
				myCell.AddInnerHTMLElement(myAnchor);
			}
		}

		return myCell;
	}

	/**
	 * Return ASURL for pick tree
	 *
	 * @return ASURL for pick tree
	 */
	private ASURL GetPickTreeURL()
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		// The URL to open a pick tree as a subspace.  We want to use the same pick tree each time.
		ASURL asURLPickTree = new ASURL(m_asOwner);

		asURLPickTree.SetLinkCreateNewSpace(ServerTreeAS.STR_MVC_CLASS_NAME, m_asOwner);

		asURLPickTree.SetSubSpaceKey(iOPModel.GetUniqueString(ObjPropModel.SUBSPACE_KEY_PICKTREE));
		asURLPickTree.SetControl(ServerStartTreeControl.STR_MVC_CLASS_NAME);
		asURLPickTree.AddControlArgument(ServerStartTreeControl.INTERFACE_TYPE, XPConvert.ToString(ServerTreeModel.m_nPROP_PICK_TREE));
		asURLPickTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
		asURLPickTree.AddControlArgument(AStartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		asURLPickTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		asURLPickTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
		asURLPickTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL, iOPModel.GetUniqueString(JAVASCRIPT_PICKTREE_GETVALUE));
		asURLPickTree.AddControlArgument(AStartTreeControl.TITLE, m_asOwner.GetString(91, "ptmsgs_portalinfrastructure"));
		asURLPickTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(90, "ptmsgs_portalinfrastructure"));
		asURLPickTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));

		return asURLPickTree;
	}

	/**
	 * Return ASURL for reference tree
	 *
	 * @return ASURL for reference tree
	 */
	private ASURL GetRefTreeURL()
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		// The URL to open a new tree to select reference objects
		ASURL asURLRefTree = new ASURL(m_asOwner);

		asURLRefTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		asURLRefTree.SetSubSpaceKey(iOPModel.GetUniqueString(ObjPropModel.SUBSPACE_KEY_REFTREE));
		asURLRefTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		asURLRefTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
		asURLRefTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
		asURLRefTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		asURLRefTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
		asURLRefTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, iOPModel.GetUniqueString(JAVASCRIPT_REFTREE_GETVALUE));
		asURLRefTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(92, "ptmsgs_portalinfrastructure"));
		asURLRefTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(93, "ptmsgs_portalinfrastructure"));
		asURLRefTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, XPConvert.ToString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT));

		return asURLRefTree;
	}

	/**
	 * Return the ASURL object going to the global object properties map.
	 *
	 * @param _sSubSpaceKey Key for the sub Editor.
	 *
	 * If we are going to a new sub Editor, the key can be null and
	 * we will just pass in the default key. If we are going back to an
	 * existing sub Editor, it should be the sub Editor key.
	 *
	 * @return ASURL
	 */
	private ASURL GetASURLToObjPropMap(String _sSubSpaceKey)
	{
		if (null == _sSubSpaceKey)
		{
			_sSubSpaceKey = "ObjPropMapEditor";
		}

		ASURL myURL = ((EditorAS) m_asOwner).GoToSubEditor("ObjPropMapEditor", _sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_MISC, null, null);

		return myURL;
	}

	/**
	 * Returns the HTML for the editing mappings
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForEditMappings()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLImg myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD, true, this.m_asOwner);
		myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
		myAddIcon.SetAlt("");
		myAddIcon.SetAlign("absmiddle");

		// Object icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_PROPERTY, true, this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString(JAVASCRIPT_OBJ_PROP_EDITOR_OPEN) + "(); return false;");
		myAnchor.AddInnerHTMLString(SPACE);
		myAnchor.AddInnerHTMLElement(myAddIcon);
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(m_asOwner.GetString(155, "ptmsgs_portalinfrastructure"));
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);

		return myCell;
	}

	/**
	 * We don't have an action bar in our edit mode, but we will display a button to link to the
	 * global object properties map below where the action bar would have been.
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLBelowActionBar()
	{
		IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;

		HTMLTable myTable = null;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		if (iOPModel.HasAccessToGlobalObjectPropMapEditor())
		{
			myTable = new HTMLTable();
			myTable.SetBorder("0");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("0");

			// 1st Row begin (there is only one row)
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);

			// Add icon cell
			myRow.AddInnerHTMLElement(GetHTMLForEditMappings());

			// Last Empty Cell
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetHeight("25");
			myCell.AddInnerHTMLString(SPACE);
		}

		return myTable;
	}
}

