package com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * Editor model for browsing object properties.
 *
 * @author josephc
 */
public class ObjPropEditorModel extends ObjEditorModel implements IObjEditorModelRO
{
	/** Class name for ObjPropEditorModel */
	public static final String STR_MVC_CLASS_NAME = "ObjPropEditorModel";

	/**
	 * That method is called by the EditorStartControl. It retrieves the existing IPTObject
	 * in edit mode.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 *
	 * @throws XPException
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		// Set class ID and object ID with values from QS.
		SetMemberVariablesFromQS(_htFormData);

		if (!CheckEditorAccess(_htFormData))
		{
			return false;
		}

		// Initialize m_ptObject
		InitPTObject(_htFormData);

		StartObjectProp();

		// Perform Editor specific tasks
		DoTaskOnStartEditor(_htFormData);

		return true;
	}

	/**
	 * Helper method to check the current user rights to this Object Editor.
	 *
	 * @param _htFormData Form data
	 * @return boolean
	 */
	protected boolean CheckEditorAccess(XPHashtable _htFormData)
	{
		// JIC- In edit mode, we need to check the object ACL.
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == m_nEditorType)
		{
			boolean bObjectIsAccessible = false;

			// JIC- We check read-only access.
			switch (m_nClassID)
			{
			case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
			case PT_CLASSIDS.PT_CATALOGCARD_ID:
				bObjectIsAccessible = m_Session.GetCatalog().IsCatalogObjectAccessible(m_nClassID, m_nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);

				break;

			case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
				bObjectIsAccessible = m_Session.GetAdminCatalog().IsAdminFolderAccessible(m_nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);

				break;

			default:
				bObjectIsAccessible = m_Session.GetAdminCatalog().GetObjectManager(m_nClassID).IsObjectAccessible(m_nObjectID, m_Session.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);

				break;
			}

			if (bObjectIsAccessible)
			{
				// JIC- The user has access but only in read-only mode.
				m_bIsEditorReadOnly = true;

				return true;
			}
		}

		return false;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjPropEditorModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

