package com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;

// Framework Imports
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Displays the Views for the common security page.
 * 
 * @author Julie Fournier
 */
public class ObjectSecurityDP extends EditorDP 
{
	/** Activity Space class name */
	public static final String STR_MVC_CLASS_NAME = "ObjectSecurity";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() 
	{
		// JF- We get the String from the Model so Editors can customize it.
		String sPageTitle;
		sPageTitle =
			((IObjectSecurityModelRO) m_asOwner
				.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB))
				.GetLeftNavString();

		return (sPageTitle);
	}

	/**
	 * Implement this method to add HTML below the sub header.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(270, "ptmsgs_portalinfrastructure"),
			this.m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() 
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		if (((IObjectSecurityModelRO) m_asOwner
			.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB))
			.GetShowHeaderAndLeftNav()) 
		{
			// Insert super class HTML
			result.AddInnerHTMLElement(super.PageDisplay());

			HTMLElementCollection views = new HTMLElementCollection();

			//JF- Add the Security Section.
			views.AddInnerHTMLElement(
				((EditorView) m_asOwner
					.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB))
					.Display());

			views.AddInnerHTMLElement(EditorView.GetSpacerTable());

			// JF- Add the Priority drop-down Section.
			views.AddInnerHTMLElement(
				((EditorView) m_asOwner
					.GetView(
						ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN))
					.Display());

			result.AddInnerHTMLElement(CreateLeftNavBar(views));
		} else {
			result.AddInnerHTMLElement(
				((EditorView) m_asOwner
					.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB))
					.Display());
			result.AddInnerHTMLElement(EditorView.GetSpacerTable());
			result.AddInnerHTMLElement(
				((EditorView) m_asOwner
					.GetView(
						ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN))
					.Display());
		}

		return result;
	}

	/**
	 * Returns JavaScript for all the Views displayed by this DP.
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection scripts = super.DisplayJavaScriptFromChild();

		scripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)
				.DisplayJavascript());

		return scripts;
	}
}

