package com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;

// Server Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List
 * framework for the Select PTObject list.
 * Is constains the HTML to display the object Array.
 * It gets the data to display from SelectPTObjectModel.
 *
 * @author Julie Fournier
 */
public class ObjectSecurityView extends SelectPTObjectView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.ObjectSecurityView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "ObjectSecurity";

	/**
	 * HTML Object name: Access Level drop-down */
	public static final String HTMLSELECT_ACCESS_LEVEL = "in_se_AccessLevel";

	/**
	 * HTML Object name: Mandatory drop-down */
	public static final String HTMLSELECT_MANDATORY = "in_se_Mandatory";

	/**
	 * HTML Object name: Community membership drop-down */
	public static final String HTMLSELECT_COMMMEMBERSHIP = "in_se_Mandatory";

	/**
	 * HTML Object names */
	public static final String HTMLINPUT_GROUPTREEASID = "in_hi_GroupTreeSpaceID";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjectSecurityView();
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		// The URL to open a new tree
		ASURL myROTree = new ASURL(m_asOwner);

		myROTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);

		myROTree.SetSubSpaceKey(((ISelectPTObjectModelRO) m_model).GetUniqueString(
				ObjectSecurityModel.SUBSPACE_KEY_GROUPTREE));
		myROTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		myROTree.AddControlArgument(AStartTreeControl.SELECT_MODE,
			TreeConstants.N_NOSELECT);
		myROTree.AddControlArgument(AStartTreeControl.CLASS_IDS_TO_DISPLAY,
			PT_CLASSIDS.PT_USER_ID + "," + PT_CLASSIDS.PT_USERGROUP_ID);
		myROTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE,
			TreeConstants.N_SERVERSUBMIT);
		myROTree.AddControlArgument(StartTreeControl.ROOT_ID, 1); // This argument is ignored
		myROTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myROTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(285, "ptmsgs_portalinfrastructure"));
		myROTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
			m_asOwner.GetString(284, "ptmsgs_portalinfrastructure"));

		// The URL to open a new tree for everyone
		ASURL myROEveryoneTree = new ASURL(m_asOwner);

		myROEveryoneTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);

		myROEveryoneTree.SetSubSpaceKey(((ISelectPTObjectModelRO) m_model).GetUniqueString(
				ObjectSecurityModel.SUBSPACE_KEY_EVERYONETREE));
		myROEveryoneTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		myROEveryoneTree.AddControlArgument(StartTreeControl.ROOT_ID,
			XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
		myROEveryoneTree.AddControlArgument(AStartTreeControl.SELECT_MODE,
			TreeConstants.N_NOSELECT);
		myROEveryoneTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE,
			TreeConstants.N_SERVERSUBMIT);
		myROEveryoneTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myROEveryoneTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				HTMLINPUT_GROUPTREEASID) + PT_INTRINSICS.PT_USERGROUP_EVERYONE);
		myROEveryoneTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			"" + PT_CLASSIDS.PT_USERGROUP_ID + "," + PT_CLASSIDS.PT_USER_ID);
		myROEveryoneTree.AddControlArgument(StartTreeControl.TITLE,
			m_asOwner.GetString(283, "ptmsgs_portalinfrastructure"));
		myROEveryoneTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
			m_asOwner.GetString(282, "ptmsgs_portalinfrastructure"));

		// The url to open a previously opened server tree
		// This needs to have the SpaceID added to it.
		ASURL myOldTree = new ASURL(m_asOwner);
		myOldTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		myOldTree.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
		myOldTree.IsSubSpace();

		String strSelectedItems = ((ISelectPTObjectModelRO) m_model).GetSelectedItems();

		if (strSelectedItems.length() < 100)
		{
			myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				strSelectedItems);
		} else
		{
			// This list can be quite long for users, so we need to pass
			// it by reference.
			myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				strSelectedItems, m_asOwner);	
		}

		XPStringBuilder sb;

		try
		{
			// Open Read-only Group Tree function
			sb = new XPStringBuilder(200);
			sb.Append("function " +
				((ISelectPTObjectModelRO) m_model).GetUniqueString(
					"ReadOnlyTree") + "(varGroupID,myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('").Append(myROTree.GetURLAsString())
			.Append("&").Append(AStartTreeControl.DISPLAYED_ITEMS)
			.Append("=" + PT_CLASSIDS.PT_USERGROUP_ID + ",' + varGroupID + '").Append("&")
			.Append(AStartTreeControl.PARENT_FORM_SPACE_ID).Append("=")
			.Append(((ISelectPTObjectModelRO) m_model).GetUniqueString(
					HTMLINPUT_GROUPTREEASID)).Append("' + varGroupID").Append(", '_blank3' + varGroupID,'")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(myOldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_blank3' + varGroupID,'")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			// Open Read-only Everyone Tree function
			sb = new XPStringBuilder(200);
			sb.Append("function " +
				((ISelectPTObjectModelRO) m_model).GetUniqueString(
					"EveryoneReadOnlyTree") + "(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('")
			.Append(myROEveryoneTree.GetURLAsString()).Append("', '_blank4','")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(myOldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_blank4','")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "ObjectSecurityView::DisplayJavascript The following error occured when trying to display the JavaScript.");
			
		}

		return myScript;
	}

	/**
	 * Return the HTML to display more info about the mandatory column when it's enabled.
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLBelowActionBar()
	{
		HTMLTable myTable = null;

		if (ObjectSecurityModel.MANDCOL_NONE != ((IObjectSecurityModelRO) m_model).GetSupportMandatoryColumn())
		{
			myTable = new HTMLTable();

			HTMLTableRow myRow;
			HTMLTableCell myCell;

			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);

			myCell.AddInnerHTMLString(m_asOwner.GetString(430,
					"ptmsgs_portalinfrastructure"));
		}

		return myTable;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));

		int nMandType = ((IObjectSecurityModelRO) m_model).GetSupportMandatoryColumn();

		if (ObjectSecurityModel.MANDCOL_REGULAR == nMandType)
		{
			result.AddInnerHTMLElement(GetHTMLForMandatoryCell(_saData,
					_nRowIndex));
		}
		else if (ObjectSecurityModel.MANDCOL_COMMUNITY == nMandType)
		{
			result.AddInnerHTMLElement(GetHTMLForCommMembershipCell(_saData,
					_nRowIndex));
		}

		int nRowAccessLevelIDToSelect = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
				ObjectSecurityModel.EXPLIST_COL_ACCESSLEVEL_ID));
		boolean bRowAccessFlag			  = XPConvert.ToBoolean(_saData.GetItem(_nRowIndex,
				ObjectSecurityModel.EXPLIST_COL_ROWACCESS));

		// JF- Below we are building a unique name for the select input.
		// First we use the GetUniqueString method to make sure there are
		// no conflicts if we have 2 security lists on the same page.
		// Then we append the row index.
		String sInputSelectName = ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLSELECT_ACCESS_LEVEL) +
			_nRowIndex;

		result.AddInnerHTMLElement(GetHTMLForAccessLevelCell(sInputSelectName,
				nRowAccessLevelIDToSelect, bRowAccessFlag, _nRowIndex));

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the Access Level drop-down cell.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForAccessLevelCell(
		String _sInputSelectName, int _nRowAccessLevelIDToSelect,
		boolean _bRowAccessFlag, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLSelect mySelect;
		HTMLOption myOption;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.SetAlign(CommonHTMLStrings.CENTER);

		boolean bIsListReadOnly = ((IObjectSecurityModelRO) m_model).GetIsListReadOnly();
		boolean bIsEveryoneGroup = ((IObjectSecurityModelRO) m_model).IsEveryoneGroup(_nRowIndex);

		// JF- This is a read/write row, we display the drop-down for each row
		// JF- The Everyone Group is a special case, we always want to be able to modify the access level
		if (((ObjectSecurityModel.PT_ACCESS_LIST_ENTRY_READWRITE == _bRowAccessFlag) || (bIsEveryoneGroup)) &&
				!bIsListReadOnly)
		{
			mySelect = new HTMLSelect(_sInputSelectName, "select1");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			int[] arrAccessLevels = ((IObjectSecurityModelRO) m_model).GetAccessLevels();
			int nAccessLevelID;

			// JF- For each access level we display an option in the select.
			for (int i = 0; i < arrAccessLevels.length; i++)
			{
				nAccessLevelID     = arrAccessLevels[i];
				myOption		   = new HTMLOption(XPConvert.ToString(nAccessLevelID));
				myOption.AddInnerHTMLString(((IObjectSecurityModelRO) m_model).GetAccessLevelString(
						nAccessLevelID));

				if (nAccessLevelID == _nRowAccessLevelIDToSelect)
				{
					myOption.SetSelected(true);
				}

				mySelect.AddInnerHTMLElement(myOption);
			}
		}

		// JF- This is a read-only row, the user cannot change the access level. We only display text.
		else
		{
			myCell.AddInnerHTMLString(((IObjectSecurityModelRO) m_model).GetAccessLevelString(
					_nRowAccessLevelIDToSelect));
		}

		return myCell;
	}

	/**
	 * We re-implement this method because some rows are
	 * read only and the user doesn't have the rights to
	 * delete them so we don't display the checkbox.
	 *
	 * @param _nRowIndex
	 * @return HTMLTableCell
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)

	{
		IPTGrowableSortedArrayWrapperRO saData = ((ObjectSecurityModel) m_model).GetItems();
		boolean bRowAccessFlag					   = XPConvert.ToBoolean(saData.GetItem(_nRowIndex,
				ObjectSecurityModel.EXPLIST_COL_ROWACCESS));

		// JF- This is a read/write row, we just call the super method to display the checkbox
		if ((ObjectSecurityModel.PT_ACCESS_LIST_ENTRY_READWRITE == bRowAccessFlag))
		{
			return super.GetHTMLForCheckBox(_nRowIndex);
		}

		// JF- This is a read-only row, we don't want to display the checkbox
		// We return an empty cell instead.
		else
		{
			HTMLTableCell myCell = new HTMLTableCell();
			myCell.SetWidth("20");
			myCell.SetHeight("30");
			myCell.SetAlign("center");
			myCell.SetVAlign("middle");
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myCell.AddInnerHTMLString(SPACE);

			return myCell;
		}
	}

	/**
	 * Returns the HTML for the Mandatory drop-down cell.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForCommMembershipCell(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLSelect mySelect;
		HTMLOption myOption;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
				ObjectSecurityModel.EXPLIST_COL_CLASSID));

		// JF- The mandatory drop-down is only available for groups
		if (PT_CLASSIDS.PT_USERGROUP_ID == nClassID)
		{
			// JF- Build the input name with the list key to avoid conflicts if we have more than one security tab on the same page.
			String sInputSelectName = ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLSELECT_COMMMEMBERSHIP) +
				_nRowIndex;

			// JF- Get the mandatory value for this column
			int nMandatory = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					ObjectSecurityModel.EXPLIST_COL_MANDATORY));
			int nGroupID   = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					ObjectSecurityModel.EXPLIST_COL_OBJECTID));

			// JF- Get the read-only flag for the page
			boolean bIsListReadOnly = ((IObjectSecurityModelRO) m_model).GetIsListReadOnly();

			if (((IObjectSecurityModelRO) m_model).HasEditAccessToGroup(
					nGroupID) && !bIsListReadOnly)
			{
				mySelect = new HTMLSelect(sInputSelectName, "select2");
				mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
				myCell.AddInnerHTMLElement(mySelect);

				// Option 1 - Not mandatory member
				myOption = new HTMLOption("" +
						PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE +
						"");

				myOption.AddInnerHTMLString(m_asOwner.GetString(114,
						"ptmsgs_portalinfrastructure"));

				if (PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE == nMandatory)
				{
					myOption.SetSelected(true);
				}

				mySelect.AddInnerHTMLElement(myOption);

				// Option 2 - Mandatory member
				myOption = new HTMLOption("" +
						PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_MANDATORY +
						"");

				myOption.AddInnerHTMLString(m_asOwner.GetString(115,
						"ptmsgs_portalinfrastructure"));

				if (PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_MANDATORY == nMandatory)
				{
					myOption.SetSelected(true);
				}

				mySelect.AddInnerHTMLElement(myOption);

				// Option 3 - Mandatory member with tab
				myOption = new HTMLOption("" +
						PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_TAB +
						"");

				myOption.AddInnerHTMLString(m_asOwner.GetString(116,
						"ptmsgs_portalinfrastructure"));

				if (PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_TAB == nMandatory)
				{
					myOption.SetSelected(true);
				}

				mySelect.AddInnerHTMLElement(myOption);
			}

			// JF- This is a read-only row, the user cannot change the page. We only display text.
			else
			{
				switch (nMandatory)
				{
				case PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE:

					myCell.AddInnerHTMLString(m_asOwner.GetString(114,
							"ptmsgs_portalinfrastructure") + CommonHTMLStrings.SPACE);

					break;

				case PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_MANDATORY:

					myCell.AddInnerHTMLString(m_asOwner.GetString(115,
							"ptmsgs_portalinfrastructure") + CommonHTMLStrings.SPACE);

					break;

				case PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_TAB:

					myCell.AddInnerHTMLString(m_asOwner.GetString(116,
							"ptmsgs_portalinfrastructure") + CommonHTMLStrings.SPACE);

					break;
				}
			}
		}

		return myCell;
	}

	/**
	 * Returns the HTML for the Mandatory drop-down cell.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForMandatoryCell(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLSelect mySelect;
		HTMLOption myOption;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
				ObjectSecurityModel.EXPLIST_COL_CLASSID));

		// JF- The mandatory drop-down is only available for groups
		if (PT_CLASSIDS.PT_USERGROUP_ID == nClassID)
		{
			// JF- Build the input name with the list key to avoid conflicts if we have more than one security tab on the same page.
			String sInputSelectName = ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLSELECT_MANDATORY) +
				_nRowIndex;

			// JF- Get the mandatory value for this column
			int nMandatory = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					ObjectSecurityModel.EXPLIST_COL_MANDATORY));
			int nGroupID   = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					ObjectSecurityModel.EXPLIST_COL_OBJECTID));

			// JF- Get the read-only flag for the page
			boolean bIsListReadOnly = ((IObjectSecurityModelRO) m_model).GetIsListReadOnly();

			// JF- The current user needs to have edit access on the group to be able to change the mandatory drop-down
			if (((IObjectSecurityModelRO) m_model).HasEditAccessToGroup(
						nGroupID) && !bIsListReadOnly)
			{
				mySelect = new HTMLSelect(sInputSelectName, "select2");
				mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
				myCell.AddInnerHTMLElement(mySelect);

				// Option 1 - Not Mandatory
				myOption = new HTMLOption("" +
						ObjectSecurityModel.MANDATORY_FALSE + "");

				myOption.AddInnerHTMLString(m_asOwner.GetString(113,
						"ptmsgs_portalinfrastructure"));

				if (ObjectSecurityModel.MANDATORY_FALSE == nMandatory)
				{
					myOption.SetSelected(true);
				}

				mySelect.AddInnerHTMLElement(myOption);

				// Option 2 - Mandatory
				myOption = new HTMLOption("" +
						ObjectSecurityModel.MANDATORY_TRUE + "");

				myOption.AddInnerHTMLString(m_asOwner.GetString(112,
						"ptmsgs_portalinfrastructure"));

				if (ObjectSecurityModel.MANDATORY_TRUE == nMandatory)
				{
					myOption.SetSelected(true);
				}

				mySelect.AddInnerHTMLElement(myOption);
			}

			// JF- This is read-only, we only display text.
			else
			{
				if (ObjectSecurityModel.MANDATORY_TRUE == nMandatory)
				{
					myCell.AddInnerHTMLString(m_asOwner.GetString(112,
							"ptmsgs_portalinfrastructure"));
				}
				else
				{
					myCell.AddInnerHTMLString(m_asOwner.GetString(113,
							"ptmsgs_portalinfrastructure"));
				}
			}
		}

		return myCell;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForNameColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLAnchor myAnchor;
		HTMLInput myInput;

		myCell = new HTMLTableCell();
		myCell.SetWidth("100%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// RWW: need to rearrange order here.  first get the
		// class id and names so that we can look up icon by
		// the class id

		// get the object name and class id
		String sPTObjectName = (String) _saData.GetItem(_nRowIndex,
				SelectPTObjectModel.EXPLIST_COL_STRING);
		int nClassID		 = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
				SelectPTObjectModel.EXPLIST_COL_CLASSID));

		// RWW: get the icon depending on the class id
		PTImageType imgRowIcon = ((ISelectPTObjectModelRO) m_model).GetRowIconByClassID(nClassID);

		if (null != imgRowIcon)
		{
			myCell.AddInnerHTMLElement(GetIcon(imgRowIcon));
		}

		PTConstruct myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
		HTMLImg spacerImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		spacerImage.SetAlt("---");
		spacerImage.SetWidth(CommonHTMLStrings.FIVE);
		spacerImage.SetBorder("0");
		myCell.AddInnerHTMLElement(spacerImage);

		int nObjectID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
			SelectPTObjectModel.EXPLIST_COL_OBJECTID));
							
		if ((PT_CLASSIDS.PT_USERGROUP_ID == nClassID)
			&& ((IObjectSecurityModelRO) m_model).DisplayGroupMembersTree(nObjectID))
		{
			// JF- We are displaying the link to the groups in groups tree
			String sGroupTreeSpaceID = (String) _saData.GetItem(_nRowIndex,
					ObjectSecurityModel.EXPLIST_COL_GROUPTREEASID);

			if (PT_INTRINSICS.PT_USERGROUP_EVERYONE == nObjectID)
			{
				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(((ISelectPTObjectModelRO) m_model).GetUniqueString(
						"EveryoneReadOnlyTree") + "(document." +
					AFormDP.HTMLFORM_NAME + "." +
					((ISelectPTObjectModelRO) m_model).GetUniqueString(
						HTMLINPUT_GROUPTREEASID) + nObjectID +
					"); return false;");
				myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
						sPTObjectName));
			}
			else
			{
				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(((ISelectPTObjectModelRO) m_model).GetUniqueString(
						"ReadOnlyTree") + "('" + nObjectID + "'," +
					"document." + AFormDP.HTMLFORM_NAME + "." +
					((ISelectPTObjectModelRO) m_model).GetUniqueString(
						HTMLINPUT_GROUPTREEASID) + nObjectID +
					"); return false;");
				myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
						sPTObjectName));
			}

			myCell.AddInnerHTMLElement(myAnchor);

			// hidden input with the read-only group tree space ID
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					((ISelectPTObjectModelRO) m_model).GetUniqueString(
						HTMLINPUT_GROUPTREEASID) + nObjectID, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(sGroupTreeSpaceID);
		}
		else
		{
			// JF- We are just displaying the object name
			myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sPTObjectName));
		}

		return myCell;
	}
}

