package com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;

// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Section for the Priority drop-down below the Security tab
 * for Portlets and Communities.
 *
 * @author Julie Fournier
 */
public class PriorityDropDownView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.PriorityDropDownView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "PriorityDropDown";

	/**
	 * Priority drop down select name */
	public static final String HTMLSELECT_PRIORITY = "in_se_Priority";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PriorityDropDownView();
	}

	/**
	 * Returns HTML for Drop-down menu.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLSelect mySelect;
		HTMLOption myOption;
		HTMLSpan mySpan;

		try
		{
			if (((IPriorityDropDownModelRO) m_model).GetSupportMandatoryColumn())
			{
				int nMandatoryPriority = ((IPriorityDropDownModelRO) m_model).GetMandatoryPriority();

				HTMLTable myTable = new HTMLTable();
				result.AddInnerHTMLElement(myTable);
				myTable.SetWidth("100%");
				myTable.SetBorder("0");
				myTable.SetCellPadding("5");
				myTable.SetCellSpacing("0");

				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetAlign(CommonHTMLStrings.RIGHT);

				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				mySpan.AddInnerHTMLString(((IPriorityDropDownModelRO) m_model).GetStringForUI());
				mySpan.AddInnerHTMLString(SPACE);

				mySelect = new HTMLSelect(HTMLSELECT_PRIORITY, "select1");
				myCell.AddInnerHTMLElement(mySelect);
				mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

				// option 1 - Very High
				myOption     = new HTMLOption("" +
						PT_MANDATORYORDERING.PT_MANDATORYORDER_VERYHIGH + "");
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(119,
						"ptmsgs_portalinfrastructure"));
				mySelect.AddInnerHTMLElement(myOption);

				if (PT_MANDATORYORDERING.PT_MANDATORYORDER_VERYHIGH == nMandatoryPriority)
				{
					myOption.SetSelected(true);
				}

				// option 2 - High
				myOption     = new HTMLOption("" +
						PT_MANDATORYORDERING.PT_MANDATORYORDER_HIGH + "");
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(120,
						"ptmsgs_portalinfrastructure"));
				mySelect.AddInnerHTMLElement(myOption);

				if (PT_MANDATORYORDERING.PT_MANDATORYORDER_HIGH == nMandatoryPriority)
				{
					myOption.SetSelected(true);
				}

				// option 3 - Medium
				myOption     = new HTMLOption("" +
						PT_MANDATORYORDERING.PT_MANDATORYORDER_MEDIUM + "");
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(121,
						"ptmsgs_portalinfrastructure"));
				mySelect.AddInnerHTMLElement(myOption);

				if (PT_MANDATORYORDERING.PT_MANDATORYORDER_MEDIUM == nMandatoryPriority)
				{
					myOption.SetSelected(true);
				}

				// option 4 - Low
				myOption     = new HTMLOption("" +
						PT_MANDATORYORDERING.PT_MANDATORYORDER_LOW + "");
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(122,
						"ptmsgs_portalinfrastructure"));
				mySelect.AddInnerHTMLElement(myOption);

				if (PT_MANDATORYORDERING.PT_MANDATORYORDER_LOW == nMandatoryPriority)
				{
					myOption.SetSelected(true);
				}

				// option 5 - Very Low
				myOption     = new HTMLOption("" +
						PT_MANDATORYORDERING.PT_MANDATORYORDER_VERYLOW + "");
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(123,
						"ptmsgs_portalinfrastructure"));
				mySelect.AddInnerHTMLElement(myOption);

				if (PT_MANDATORYORDERING.PT_MANDATORYORDER_VERYLOW == nMandatoryPriority)
				{
					myOption.SetSelected(true);
				}
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "PriorityDropDownView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(124,
					"ptmsgs_portalinfrastructure"), e);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

