package com.plumtree.portaluiinfrastructure.editor.saveobject;

// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the name and description.
 *
 * @author Julie Fournier
 */
public class SaveObjectCantChangeFolderView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectCantChangeFolderView");

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectCantChangeFolder";

	/**
	 * Associated read-only Model.
	 */
	private ISaveObjectModelRO m_model;

	/**
	 * Parent AS.
	 */
	private SaveObjectAS m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SaveObjectCantChangeFolderView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLB myBold;

		try
		{
			// Content table
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("10");

			// Row 1 - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

			myCell.AddInnerHTMLString(m_asOwner.GetString(125,
					"ptmsgs_portalinfrastructure"));

			// Row 1 - end
			// Row 2 - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
			myBold = new HTMLB();
			myCell.AddInnerHTMLElement(myBold);
			myBold.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
					((ISaveObjectModelRO) m_model).GetFolderName()));

			// Row 2 - end
		}
		catch (HTMLException e)
		{
			
				log.Error(e, "SaveObjectCantChangeFolderView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(126,
					"ptmsgs_portalinfrastructure"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (ISaveObjectModelRO) model;
		m_asOwner     = (SaveObjectAS) parent;
	}
}

