package com.plumtree.portaluiinfrastructure.editor.saveobject;

// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This DP is used to close the save pop-up and refresh the Editor.
 *
 * @author Julie Fournier
 */
public class SaveObjectClosePopUpDP implements IDisplayPage
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectClosePopUpDP");

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectClosePopUp";

	/**
	 * Parent AS.
	 */
	protected AActivitySpace m_asOwner;

	/**
	 * Construct the HTMLPage for Display.
	 *
	 * @param IWebData The HTMLPage for display to the browser should be set on this
	 *             object.  This object should not be stored anywhere.
	 */
	public void Display(IWebData webData)
	{
		HTMLPage myPage = new HTMLPage();

		// Set the HTMLPage as the data to be sent to the browser.
		webData.SetData(myPage);

		HTMLHead myHead = new HTMLHead();
		myPage.SetHead(myHead);

		HTMLBody myBody = new HTMLBody();
		myPage.SetBody(myBody);

		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		// JF- Create the ASURL going to the Dependencies page.
		ASURL nextPage = new ASURL(m_asOwner);
		nextPage.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
		nextPage.SetDisplayPage(ObjDependenciesDP.STR_MVC_CLASS_NAME);

		try
		{
			sb = new XPStringBuilder(200);

			// JF- redirect the main window
			sb.Append("  parent.parent.window.opener.postToSelf('" +
				ObjEditorRepostControl.POSTTOSELF_ACTION_APPLY_CHANGES +
				"'); \n");
			sb.Append("  parent.parent.window.close(); \n");
			
			myScript.AddInnerHTMLString(sb.ToString());
			myHead.AddInnerHTMLElement(myScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "SaveObjectClosePopUpDP::Display The following error occured" +
					" when trying to generate the JavaScript to close the pop up: " +
					he.getMessage());
			

			throw new XPException(m_asOwner.GetString(146,
					"ptmsgs_portalinfrastructure"), he);
		}
	}

	/**
	 * Return the name of the MVC object.
	 *
	 * @return the name of the object.
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Return the parent Activity Space.
	 *
	 * @return AActivitySpace
	 */
	public AActivitySpace GetOwner()
	{
		return m_asOwner;
	}

	/**
	 * Initialize the Display Page.
	 *
	 * @param AActivitySpace the parent AActivitySpace of this IDisplayPage.
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
	}
}

