package com.plumtree.portaluiinfrastructure.editor.saveobject;

// Server imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * Display Page for the save pop-up main frame.
 *
 * @author Julie Fournier
 */
public class SaveObjectFoldersFrameDP extends FrameSetDP
{
	/** Frameset object name */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectPopUpFrameFolders";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.dialogheader.FrameSetDialog#GetFrameSetTitle()
	 */
	public String GetFrameSetTitle()
	{
		// JF- This is a frame inside another frame, no need to set the title here.
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameScrollTop()
	 */
	public boolean GetFrameScrollTop()
	{
		return true;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameScrollBody()
	 */
	public boolean GetFrameScrollBody()
	{
		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameSetAttributes()
	 */
	public String GetFrameSetAttributes()
	{
		ISaveObjectModelRO myModel = (ISaveObjectModelRO) m_asOwner.GetModel(SaveObjectModel.STR_MVC_CLASS_NAME);
		
		if (0 == myModel.GetRecentlyUsedFolders().length)
		{
			return "100%,0px";
		}
		else
		{
			return "80%,70px";
		}
	}

	/**
	 * Returns the URL for the body frame.
	 *
	 * @return ASURL
	 */
	public ASURL GetFrameURLBody()
	{
		ASURL myBodyFrame = new ASURL(m_asOwner);

		myBodyFrame.SetLinkGetCachedSpace(m_asOwner);
		myBodyFrame.SetDisplayPage(SaveObjectRecentFoldersDP.STR_MVC_CLASS_NAME);

		return myBodyFrame;
	}

	/**
	 * Returns the URL to go to the Top Frame.
	 *
	 * @return ASURL
	 */
	public ASURL GetFrameURLTop()
	{
		ASURL myTopFrame		   = new ASURL(m_asOwner);
		ISaveObjectModelRO myModel = (ISaveObjectModelRO) m_asOwner.GetModel(SaveObjectModel.STR_MVC_CLASS_NAME);
		int nFolderID			   = myModel.GetAdminFolderID();

		// JF- Get the cached folder tree.
		if (m_asOwner.GetSubSpaceExists(
					SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY))
		{
			myTopFrame.SetLinkGetCachedSpace(m_asOwner.GetSubSpace(
					SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY));
			myTopFrame.SetDisplayPage(TreeDP.STR_MVC_CLASS_NAME);

			if (!myModel.IsAdminFolderInRecentFolders(nFolderID))
			{
				myTopFrame.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
				myTopFrame.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
					PT_CLASSIDS.PT_ADMIN_FOLDER_ID + "," + nFolderID);
			}
		}

		// JF- This is the first time, create a new one.
		else
		{
			myTopFrame.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
			myTopFrame.SetSubSpaceKey(SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY);
			myTopFrame.SetDisplayPage(TreeDP.STR_MVC_CLASS_NAME);
			myTopFrame.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
			myTopFrame.AddControlArgument(StartTreeControl.ROOT_ID,
				XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
			myTopFrame.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
			myTopFrame.AddControlArgument(StartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
			myTopFrame.AddControlArgument(StartTreeControl.SELECT_MODE,
				XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
			myTopFrame.AddControlArgument(StartTreeControl.ONCLICK_CALL,
				"parent." + BODY_FRAME + ".UnSelectFromRecentFolders");
			myTopFrame.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
				
			m_asOwner.GetString(133, "ptmsgs_portalinfrastructure"));

			if (!myModel.IsAdminFolderInRecentFolders(nFolderID))
			{
				myTopFrame.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
					PT_CLASSIDS.PT_ADMIN_FOLDER_ID + "," + nFolderID);
			}
		}

		return myTopFrame;
	}
}

