package com.plumtree.portaluiinfrastructure.editor.saveobject;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.common.*;

/**
 * This is the main Display Page for the save object pop-up window.
 * It defines the 3 frames: top one with the tabs, body one with
 * the tree or the security and the bottom one with the name and description.
 * By default the body frame will display the folder tree.
 *
 * @author Julie Fournier
 */
public class SaveObjectMainFrameDP extends FrameSetDP
{
	/** Frameset object name */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectPopUpFrameMain";

	/** in pixels */
	public static final int DEFAULT_BOTTOM_SIZE = 145;

	/** The size of the bottom frame for various languages. (NOTE: arrays can't really be final since their data can be changed.) */
	public static final Object[][] BOTTOM_SIZES = { { "ja", 	"zh", 	"ko" },
													{ "160", 	"155", 	"150" } };

	/** the indices for the bottom frame size array. */
	public static final int BOTTOM_SIZES_LANG = 0;
	public static final int BOTTOM_SIZES_SIZE = 1;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameScrollBody()
	 */
	public boolean GetFrameScrollBody()
	{
		return true;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameScrollBottom()
	 */
	public boolean GetFrameScrollBottom()
	{
		return false;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameSetAttributes()
	 */
	public String GetFrameSetAttributes()
	{
		String strLang = m_asOwner.GetLanguage();

		int nBottomSize = DEFAULT_BOTTOM_SIZE;

		for (int i = 0; i < BOTTOM_SIZES[BOTTOM_SIZES_LANG].length; i++)
		{
			if (0 == XPStringUtility.CompareIgnoreCase(strLang, (String) BOTTOM_SIZES[BOTTOM_SIZES_LANG][i]))
			{
				nBottomSize = XPConvert.ToInteger(BOTTOM_SIZES[BOTTOM_SIZES_SIZE][i]);
			}
		}

		return "60px,80%," + nBottomSize + "px";
	}

	/**
	 * @see com.plumtree.uiinfrastructure.common.FrameSetDP#GetFrameSetTitle()
	 */
	public String GetFrameSetTitle()
	{
		ISaveObjectModelRO myModel = (ISaveObjectModelRO) m_asOwner.GetModel(SaveObjectModel.STR_MVC_CLASS_NAME);

		return myModel.GetTitle();
	}

	/**
	 * Returns the URL to open the body frame.
	 *
	 * @return ASURL
	 */
	public ASURL GetFrameURLBody()
	{
		// Display the folder tree
		ASURL myBodyFrame = new ASURL(m_asOwner);

		ISaveObjectModelRO myModel = (ISaveObjectModelRO) m_asOwner.GetModel(SaveObjectModel.STR_MVC_CLASS_NAME);
		int nCurrentTab			   = myModel.GetCurrentTab();

		if (SaveObjectModel.SAVEOBJECT_TAB_FOLDERTREE == nCurrentTab)
		{
			if (myModel.ForceSaveInFolder())
			{
				myBodyFrame.SetLinkGetCachedSpace(m_asOwner);
				myBodyFrame.SetDisplayPage(SaveObjectCantChangeFolderDP.STR_MVC_CLASS_NAME);
			}
			else
			{
				myBodyFrame.SetLinkGetCachedSpace(m_asOwner);
				myBodyFrame.SetDisplayPage(SaveObjectFoldersFrameDP.STR_MVC_CLASS_NAME);
			}
		}
		else if (SaveObjectModel.SAVEOBJECT_TAB_SECURITY == nCurrentTab)
		{
			// JF- We go to the security page.
			myBodyFrame.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
			myBodyFrame.SetDisplayPage(ObjectSecurityDP.STR_MVC_CLASS_NAME);
		}

		return myBodyFrame;
	}

	/**
	 * Returns the URL to go to the Bottom Frame (name and description).
	 *
	 * @return ASURL
	 */
	public ASURL GetFrameURLBottom()
	{
		ASURL result = new ASURL(m_asOwner);
		result.SetLinkGetCachedSpace(m_asOwner);
		result.SetDisplayPage(SaveObjectBottomFrameDP.STR_MVC_CLASS_NAME);

		return result;
	}

	/**
	 * Returns the URL to go to the Top Frame (tabs).
	 *
	 * @return ASURL
	 */
	public ASURL GetFrameURLTop()
	{
		ASURL result = new ASURL(m_asOwner);
		result.SetLinkGetCachedSpace(m_asOwner);
		result.SetDisplayPage(SaveObjectTopFrameDP.STR_MVC_CLASS_NAME);

		return result;
	}
}

