package com.plumtree.portaluiinfrastructure.editor.saveobject;

// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the name and description.
 *
 * @author Julie Fournier
 */
public class SaveObjectNameDescView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectNameDescView");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectPopUpNameDesc";

	/** HTML Object name: input text for the object name */
	public static final String HTMLINPUT_NAME = "in_tx_Name";

	/** HTML Object name: input text for the object description */
	public static final String HTMLINPUT_DESCRIPTION = "in_tx_Description";

	/** HTML Object name: checkbox to approve migration */
	public static final String HTMLCHECKBOX_MIGRATION = "in_cb_Migration";

	/** HTML Object name: save button */
	public static final String HTMLBUTTON_SAVE = "in_bu_Save";

	/** HTML Object name: cancel button */
	public static final String HTMLBUTTON_CANCEL = "in_bu_Cancel";
	
	public static final String STR_JS_FUNC_NAME_SAVE = "Save";

	/** Associated read-only Model. */
	private ISaveObjectModelRO m_model;

	/** Parent AS. */
	private SaveObjectAS m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SaveObjectNameDescView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		try
		{
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetHeight("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");
			myTable.SetStyleClass(PTStyleClass.DIALOGUE_BG);

			// 1st Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.DIALOGUE_FORM_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(139,
					"ptmsgs_portalinfrastructure"));

			myCell.AddInnerHTMLElement(new HTMLBr());
			myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_NAME, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetValue(m_model.GetObjectName());
			myInput.SetMaxLength(LocNamesModel.CLIENT_VALIDATION_MAX_NAME);
			myInput.SetSize(50);
			myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
			// 1st Row end
			
			if (!m_model.IsDescriptionDisabled())
			{
				// 2nd Row begin
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
	
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("100%");
				myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
	
				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.DIALOGUE_FORM_TEXT);
	
				mySpan.AddInnerHTMLString(m_asOwner.GetString(140,
						"ptmsgs_portalinfrastructure"));
	
				myCell.AddInnerHTMLElement(new HTMLBr());
				myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_DESCRIPTION,
						"");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
				myInput.SetValue(m_model.GetObjectDescription());
				myInput.SetMaxLength(LocNamesModel.CLIENT_VALIDATION_MAX_DESCRIPTION);
				myInput.SetSize(60);
				myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
				// 2nd Row end
			}
			
			if (m_model.IsSysAdmin())
			{
				// 3rd Row begin
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("100%");
				myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.DIALOGUE_FORM_TEXT);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(141,
						"ptmsgs_portalinfrastructure"));

				myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
						HTMLCHECKBOX_MIGRATION, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
				myInput.SetChecked(m_model.IsMigrationApproved());
				myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
				// 3rd Row end
			}

			// 4th Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetVAlign("bottom");
			myCell.SetNoWrap(true);
			myCell.SetHeight("20");

			// Save button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_SAVE, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(142,
					"ptmsgs_portalinfrastructure"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick("Save(); return false;");

			// Cancel button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(143,
					"ptmsgs_portalinfrastructure"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick("parent.window.close(); return false;");

			// 4th Row end
			
			// JF- There is a conflict between the wondow.focus that we have in AFormDP and this one
			// For now we are just commenting out this one (see bug 19618)
			//HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			//myScript.AddInnerHTMLString("doOnLoad();\n");

			//result.AddInnerHTMLElement(myScript);
		}
		catch (HTMLException e)
		{
			
				log.Error(e, "SaveObjectNameDescView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(145,
					"ptmsgs_portalinfrastructure"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = PlumtreeHelpers.GetExecuteViaEnterJScript(STR_JS_FUNC_NAME_SAVE);
		XPStringBuilder sb;

		try
		{
			sb = new XPStringBuilder(500);
			sb.Append("function " + STR_JS_FUNC_NAME_SAVE + "()\n");
			sb.Append("{\n");
			sb.Append("  \n");
			
			if (m_model.IsCurrentObjectCommunity())
			{
				sb.Append("  var strName = document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_NAME + ".value;\n");
				sb.Append("  \n");
				sb.Append("  if ((-1 != strName.lastIndexOf(\"\\\\\")) ||");
				sb.Append(" (-1 != strName.lastIndexOf(\"\\t\")) ||");
				sb.Append(" (-1 != strName.lastIndexOf(\"\\n\")))\n"); 
				sb.Append("  {\n ");
				sb.Append("    alert('" + m_asOwner.GetString(755, ResourceConstants.PORTALCOMMONMSGS) + "');\n");
				sb.Append("    return false;\n");
				sb.Append("  }\n ");
			}
			sb.Append("  \n");
			sb.Append("   if (ValidateTree()) \n");
			sb.Append("   {\n");

			// JF- We also need to pass in the DP name, usually the AS does it for us but in this case we have 
			// a frame and the AS thinks we are on SaveObjectMainFrameDP
			sb.Append("     document." + AFormDP.HTMLFORM_NAME + "." +
				ASConstants.PAGE_INPUT + ".value = '" +
				SaveObjectBottomFrameDP.STR_MVC_CLASS_NAME + "' ;\n");
			sb.Append("     postToSelf(" +
				SaveObjectRepostControl.POSTTOSELF_ACTION_SAVENAME_AND_DESCRIPTION +
				");");
			sb.Append("   }\n");
			sb.Append("}\n");

			sb.Append("function ValidateTree()\n");
			sb.Append("{\n");
			sb.Append("  if (null != parent." +
				SaveObjectMainFrameDP.BODY_FRAME + "." +
				SaveObjectFoldersFrameDP.TOP_FRAME + 
				" && null != parent." +
				SaveObjectMainFrameDP.BODY_FRAME + "." +
				SaveObjectFoldersFrameDP.TOP_FRAME + ".document." +
				AFormDP.HTMLFORM_NAME + "." + TreeView.HTMLBUTTON_RADIO +
				")\n");
			sb.Append("  {\n");

			sb.Append("    varFolderTree = parent." +
				SaveObjectMainFrameDP.BODY_FRAME + "." +
				SaveObjectFoldersFrameDP.TOP_FRAME + ".document." +
				AFormDP.HTMLFORM_NAME + "." + TreeView.HTMLBUTTON_RADIO +
				";\n");

			//sb.Append("    varFolderID = parent." + SaveObjectMainFrameDP.BODY_FRAME + "." 
			//			+ SaveObjectFoldersFrameDP.BODY_FRAME + ".document." 
			//			+ AFormDP.HTMLFORM_NAME + "." + SaveObjectRecentFoldersView.HTMLHIDDEN_SELECTED_FOLDER + ";\n");
			sb.Append("    varRecentFolders = parent." +
				SaveObjectMainFrameDP.BODY_FRAME + "." +
				SaveObjectFoldersFrameDP.BODY_FRAME + ".document." +
				AFormDP.HTMLFORM_NAME + "." +
				SaveObjectRecentFoldersView.HTMLINPUT_RECENT_FOLDERS + ";\n");

			sb.Append("    if (varFolderTree)\n");
			sb.Append("    { \n");
			sb.Append("      if (varFolderTree.length)\n");
			sb.Append("      { \n");
			sb.Append(
				"        for ( var i = 0; i < varFolderTree.length; i++ ) \n");
			sb.Append("        {\n");
			sb.Append("          if ( varFolderTree[i].checked == true ) \n");
			sb.Append("          {\n");

			//sb.Append("             varFolderID.value =  varFolderTree.value ;\n");
			sb.Append("             return true;\n");
			sb.Append("          }\n");
			sb.Append("        }\n");
			sb.Append("      } \n");
			sb.Append("      else if (varFolderTree.checked == true) \n");
			sb.Append("      {\n");

			//sb.Append("        varFolderID.value =  varFolderTree.value ;\n");
			sb.Append("        return true;\n");
			sb.Append("      }\n");
			sb.Append("    }\n");

			sb.Append("    if (varRecentFolders)\n");
			sb.Append("    { \n");
			sb.Append("      if (varRecentFolders.length)\n");
			sb.Append("      { \n");
			sb.Append(
				"        for ( var i = 0; i < varRecentFolders.length; i++ ) \n");
			sb.Append("        {\n");
			sb.Append("          if ( varRecentFolders[i].checked == true ) \n");
			sb.Append("          {\n");

			//sb.Append("             varFolderID.value =  varRecentFolders.value ;\n");
			sb.Append("             return true;\n");
			sb.Append("          }\n");
			sb.Append("        }\n");
			sb.Append("      } \n");
			sb.Append("      else if (varRecentFolders.checked == true) \n");
			sb.Append("      {\n");

			//sb.Append("        varFolderID.value =  varRecentFolders.value ;\n");
			sb.Append("        return true;\n");
			sb.Append("      }\n");
			sb.Append("    }\n");

			sb.Append("  } \n");
			sb.Append("  else \n");
			sb.Append("  { \n");
			sb.Append("    return true; \n");
			sb.Append("  } \n");

			sb.Append("  alert('" +
				m_asOwner.GetString(144, "ptmsgs_portalinfrastructure") +
				"');\n");
			sb.Append("  return false;\n");
			sb.Append("}\n");

			if (m_model.GetRepostBodyFromBottomFrame())
			{
				if ((SaveObjectModel.SAVEOBJECT_TAB_FOLDERTREE == m_model.GetCurrentTab()) &&
						(!m_model.ForceSaveInFolder()))
				{
					sb.Append(" varForm = parent." +
						SaveObjectMainFrameDP.BODY_FRAME + "." +
						SaveObjectFoldersFrameDP.BODY_FRAME + ".document." +
						AFormDP.HTMLFORM_NAME + "; \n");

					sb.Append(" varForm." + ASConstants.PAGE_INPUT +
						".value = '" +
						SaveObjectRecentFoldersDP.STR_MVC_CLASS_NAME + "' ;\n");

					sb.Append(" varForm." + RepostControl.HTMLINPUT_POSTTOSELF +
						".value =  '" +
						SaveObjectRepostControl.POSTTOSELF_ACTION_REPOST_TREE_AND_SAVE +
						"';\n");
				}
				else
				{
					sb.Append(" varForm = parent." +
						SaveObjectMainFrameDP.BODY_FRAME + ".document." +
						AFormDP.HTMLFORM_NAME + "; \n");

					sb.Append(" varForm." + RepostControl.HTMLINPUT_POSTTOSELF +
						".value =  '" +
						SaveObjectRepostControl.POSTTOSELF_ACTION_SAVEOBJECT +
						"';\n");
				}

				sb.Append(" varForm." + ASConstants.SPACENAME_INPUT +
					".value = '" + SaveObjectAS.STR_MVC_CLASS_NAME + "' ;\n");
				sb.Append(" varForm." + ASConstants.CONTROL_INPUT +
					".value = '" + SaveObjectRepostControl.STR_MVC_CLASS_NAME +
					"' ;\n");
				sb.Append(" varForm." + ASConstants.SPACEID_INPUT +
					".value = '" + m_asOwner.GetSpaceID() + "' ;\n");

				sb.Append(" varForm.submit();\n");
			}
			
			sb.Append("function doOnLoad()\n");
			sb.Append("{\n");
			sb.Append("var form = document.");
			sb.Append(AFormDP.HTMLFORM_NAME);
			sb.Append(";\n");
			sb.Append("form.");
			sb.Append(HTMLINPUT_NAME);
			sb.Append(".focus();\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error("SaveObjectNameDescView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (ISaveObjectModelRO) model;
		m_asOwner     = (SaveObjectAS) parent;
	}
}

