package com.plumtree.portaluiinfrastructure.editor.saveobject;

// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the most recently used folders.
 *
 * @author Julie Fournier
 */
public class SaveObjectRecentFoldersView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectRecentFoldersView");

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectRecentFolders";

	/** HTML Object name: radio buttons for the recently used folders. */
	public static final String HTMLINPUT_RECENT_FOLDERS = "in_ra_Folders";

	/**
	 * Associated read-only Model.
	 */
	private ISaveObjectModelRO m_model;

	/**
	 * Parent AS.
	 */
	private SaveObjectAS m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SaveObjectRecentFoldersView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		//HTMLInput myInput;
		try
		{
			Object[][] arrFolders = m_model.GetRecentlyUsedFolders();
			int nFolderID		  = m_model.GetAdminFolderID();

			if (0 < arrFolders.length)
			{
				myTable = new HTMLTable();
				result.AddInnerHTMLElement(myTable);
				myTable.SetWidth("100%");
				myTable.SetHeight("100%");
				myTable.SetBorder("0");
				myTable.SetCellPadding("3");
				myTable.SetCellSpacing("0");

				// 1st Row begin
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("100%");
				myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
				myCell.SetColSpan("2");

				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.DIALOGUE_SUBHEAD);
				mySpan.AddInnerHTMLString(m_asOwner.GetString(287, "ptmsgs_portalinfrastructure"));

				// 1st Row end
				// 2nd Row begin
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);
				myRow.AddInnerHTMLElement(GetCellForFolder(
						XPConvert.ToInteger(arrFolders[0][0]), (String) arrFolders[0][1],
						nFolderID));
				
				if (2 < arrFolders.length)
				{
					myRow.AddInnerHTMLElement(GetCellForFolder(
						XPConvert.ToInteger(arrFolders[2][0]), (String) arrFolders[2][1],
						nFolderID));
				}
				else
				{
					//AGC- changed null to 
					myRow.AddInnerHTMLElement(GetCellForFolder(-1, null, nFolderID));
				}

				// 2nd Row end
				// 3rd Row begin
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);
				
				if (1 < arrFolders.length)
				{
					myRow.AddInnerHTMLElement(GetCellForFolder(
						XPConvert.ToInteger(arrFolders[1][0]), (String) arrFolders[1][1],
						nFolderID));
				}
				else
				{
					myRow.AddInnerHTMLElement(GetCellForFolder(-1, null, nFolderID));
				}
				
				if (3 < arrFolders.length)
				{
					myRow.AddInnerHTMLElement(GetCellForFolder(
						XPConvert.ToInteger(arrFolders[3][0]), (String) arrFolders[3][1],
						nFolderID));
				}
				else
				{
					myRow.AddInnerHTMLElement(GetCellForFolder(-1, null, nFolderID));
				}

				// 3rd Row end
			}

			//myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_SELECTED_FOLDER, "");
			//result.AddInnerHTMLElement(myInput);
			//myInput.SetValue("-1");
		}
		catch (HTMLException e)
		{
			
				log.Error(e, "SaveObjectRecentFoldersView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(286, "ptmsgs_portalinfrastructure"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		try
		{
			sb = new XPStringBuilder(800);
			sb.Append("function UnSelectFromTree()\n");
			sb.Append("{\n");
			sb.Append("  varSelectedFolder = parent." +
				SaveObjectFoldersFrameDP.TOP_FRAME + ".document." +
				AFormDP.HTMLFORM_NAME + "." + TreeView.HTMLBUTTON_RADIO +
				";\n");
			sb.Append("  if (varSelectedFolder)\n");
			sb.Append("  { \n");
			sb.Append("    if (varSelectedFolder.length)\n");
			sb.Append("    { \n");
			sb.Append(
				"      for ( var i = 0; i < varSelectedFolder.length; i++ ) \n");
			sb.Append("      {\n");
			sb.Append("        if ( varSelectedFolder[i].checked) \n");
			sb.Append("        {\n");
			sb.Append("           varSelectedFolder[i].checked = false;\n");
			sb.Append("           break; \n");
			sb.Append("        }\n");
			sb.Append("      }\n");
			sb.Append("    } \n");
			sb.Append("    else if (varSelectedFolder.checked) \n");
			sb.Append("    {\n");
			sb.Append("      varSelectedFolder[i].checked = false;\n");
			sb.Append("    }\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			sb.Append("function UnSelectFromRecentFolders(clickedInput)\n");
			sb.Append("{\n");
			sb.Append("  varSelectedFolder = parent." +
				SaveObjectFoldersFrameDP.BODY_FRAME + ".document." +
				AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_RECENT_FOLDERS + ";\n");
			sb.Append("  if (varSelectedFolder)\n");
			sb.Append("  { \n");
			sb.Append("    if (varSelectedFolder.length)\n");
			sb.Append("    { \n");
			sb.Append("      for ( var i = 0; i < varSelectedFolder.length; i++ ) \n");
			sb.Append("      {\n");
			sb.Append("        if ( varSelectedFolder[i].checked) \n");
			sb.Append("        {\n");
			sb.Append("           varSelectedFolder[i].checked = false;\n");
			sb.Append("           break; \n");
			sb.Append("        }\n");
			sb.Append("      }\n");
			sb.Append("    } \n");
			sb.Append("    else if (varSelectedFolder.checked) \n");
			sb.Append("    {\n");
			sb.Append("      varSelectedFolder.checked = false;\n");
			sb.Append("    }\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			if (m_model.GetRepostTreeRecentFoldersFrame())
			{
				// JF- We just reposted this frame to change the selected tab.
				// Now we are going to repost the body tab and update the content of it, 
				// according to the new selected tab.
				sb.Append(" varForm = parent." +
					SaveObjectMainFrameDP.TOP_FRAME + ".document." +
					AFormDP.HTMLFORM_NAME + "; \n");

				sb.Append(" varForm." + ASConstants.SPACENAME_INPUT +
					".value = '" + SaveObjectAS.STR_MVC_CLASS_NAME + "' ;\n");
				sb.Append(" varForm." + ASConstants.CONTROL_INPUT +
					".value = '" + SaveObjectRepostControl.STR_MVC_CLASS_NAME +
					"' ;\n");
				sb.Append(" varForm." + ASConstants.SPACEID_INPUT +
					".value = '" + m_asOwner.GetSpaceID() + "' ;\n");
				sb.Append(" varForm." + RepostControl.HTMLINPUT_POSTTOSELF +
					".value =  '" +
					SaveObjectRepostControl.POSTTOSELF_ACTION_GOTO_SECURITYTAB +
					"';\n");
				sb.Append(" varForm.submit();\n");
			}

			if (m_model.GetRepostTreeAndSave())
			{
				// JF- We just reposted this frame to change the selected tab.
				// Now we are going to repost the body tab and update the content of it, 
				// according to the new selected tab.
				sb.Append(" varForm = parent." +
					SaveObjectMainFrameDP.TOP_FRAME + ".document." +
					AFormDP.HTMLFORM_NAME + "; \n");

				sb.Append(" varForm." + ASConstants.SPACENAME_INPUT +
					".value = '" + SaveObjectAS.STR_MVC_CLASS_NAME + "' ;\n");
				sb.Append(" varForm." + ASConstants.CONTROL_INPUT +
					".value = '" + SaveObjectRepostControl.STR_MVC_CLASS_NAME +
					"' ;\n");
				sb.Append(" varForm." + ASConstants.SPACEID_INPUT +
					".value = '" + m_asOwner.GetSpaceID() + "' ;\n");
				sb.Append(" varForm." + RepostControl.HTMLINPUT_POSTTOSELF +
					".value =  '" +
					SaveObjectRepostControl.POSTTOSELF_ACTION_SAVEOBJECT +
					"';\n");
				sb.Append(" varForm.submit();\n");
			}

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "SaveObjectRecentFoldersView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/** HTML Object name: hidden inpu for the selected folder ID */

	//public static final String HTMLHIDDEN_SELECTED_FOLDER = "in_hi_FolderID";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (ISaveObjectModelRO) model;
		m_asOwner     = (SaveObjectAS) parent;
	}

	/**
	 * Helper method to return the HTML for Table cell with the folder information.
	 *
	 * @param _ID Folder ID
	 * @param _sName Folder Name
	 *
	 * @return HTMLTableCell
	 */
	private HTMLTableCell GetCellForFolder(int _ID, String _sName,
		int nFolderIDToSelect)

	{
		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myCell.SetHeight("10");

		if ((-1 < _ID) && (null != _sName))
		{
			HTMLInput myInput;
			PTConstruct myConstruct;
			HTMLImg myImage;

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLINPUT_RECENT_FOLDERS, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(XPConvert.ToString(_ID));
			myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
			myInput.SetOnClick("UnSelectFromTree();");	// mj: removed 'JavaScript:' from function name

			if (nFolderIDToSelect == _ID)
			{
				myInput.SetChecked(true);
			}

			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER,
					true, m_asOwner);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImage.SetAlt("");
			myImage.SetAlign("absmiddle");
			myCell.AddInnerHTMLElement(myImage);

			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			myCell.AddInnerHTMLEncodedString(_sName);
		}

		return myCell;
	}
	
	//AGC- Added to fix jump problems.
	/**
	 * Returns the value of objValue or nDefault if objValue is null or
	 * the conversion fails.
	 */
	public static int ObjectToInt(Object objValue, int nDefault)
	{
		if (null == objValue)
		{
			return nDefault;
		}

		int nValue = nDefault;

		try
		{
			nValue = XPConvert.ToInteger(objValue);
		}
		catch (Exception e)
		{
			
				log.Debug(e, "WSModelHelper::ObjectToInt: Error - Returning Default value e: " +
					e.getMessage());
			

			nValue = nDefault;
		}

		return nValue;
	}
	
}

