package com.plumtree.portaluiinfrastructure.editor.saveobject;

// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This DP is used to redirect to the dependencies page.
 * Because we are going from a page with 3 frames to a page with
 * no frame, it has to be done by a JavaScript.
 * The body frame will redirect to this DP and this DP is just a
 * JavaScript that will do the real redirection to the dependencies page.
 *
 * @author Julie Fournier
 */
public class SaveObjectRedirectDP implements IDisplayPage
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.editor.saveobject.SaveObjectRedirectDP");

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectRedirect";

	/**
	 * Parent AS.
	 */
	protected AActivitySpace m_asOwner;

	/**
	 * Construct the HTMLPage for Display.
	 *
	 * @param IWebData The HTMLPage for display to the browser should be set on this
	 *             object.  This object should not be stored anywhere.
	 */
	public void Display(IWebData webData)
	{
		HTMLPage myPage = new HTMLPage();

		// Set the HTMLPage as the data to be sent to the browser.
		webData.SetData(myPage);

		HTMLHead myHead = new HTMLHead();
		myPage.SetHead(myHead);

		HTMLBody myBody = new HTMLBody();
		myPage.SetBody(myBody);

		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		// JF- Create the ASURL going to the Dependencies page.
		ASURL nextPage = new ASURL(m_asOwner);
		nextPage.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
		nextPage.SetDisplayPage(ObjDependenciesDP.STR_MVC_CLASS_NAME);

		try
		{
			sb = new XPStringBuilder(200);

			// JF- Add the ASURL to the JavaScript.
			sb.Append("parent.parent.location = '" + nextPage.GetURLAsString() +
				"';\n");
			myScript.AddInnerHTMLString(sb.ToString());
			myHead.AddInnerHTMLElement(myScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "SaveObjectRedirectDP::Display The following error occured" +
					" when trying to generate the JavaScript to redirect to the dependencies page: " +
					he.getMessage());
			

			throw new XPException(m_asOwner.GetString(146,
					"ptmsgs_portalinfrastructure"), he);
		}
	}

	/**
	 * Return the name of the MVC object.
	 *
	 * @return the name of the object.
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Return the parent Activity Space.
	 *
	 * @return AActivitySpace
	 */
	public AActivitySpace GetOwner()
	{
		return m_asOwner;
	}

	/**
	 * Initialize the Display Page.
	 *
	 * @param AActivitySpace the parent AActivitySpace of this IDisplayPage.
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
	}
}

