package com.plumtree.portaluiinfrastructure.editor.saveobject;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author Julie Fournier
 */
public class SaveObjectRepostControl extends RepostControl
	implements IHTTPControl
{
	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectPopUpRepost";

	/**
	 * Repost Action: To save the object.
	 */
	public final static int POSTTOSELF_ACTION_SAVEOBJECT = 400;

	/**
	 * Repost Action: To redirect the body frame to the security page.
	 */
	public final static int POSTTOSELF_ACTION_GOTO_SECURITYTAB = 401;

	/**
	 * Repost Action: To redirect the body frame to the folder tree.
	 */
	public final static int POSTTOSELF_ACTION_GOTO_FOLDERTREETAB = 402;

	/**
	 * Repost Action: Simple repost to sasve the name and description frame.
	 */
	public final static int POSTTOSELF_ACTION_SAVENAME_AND_DESCRIPTION = 403;

	/**
	 * Repost Action: To change tab.
	 */
	public final static int POSTTOSELF_ACTION_CHANGETAB = 404;

	/**
	 * Repost Action: Repost tree frame
	 */
	public final static int POSTTOSELF_ACTION_REPOST_TREE = 405;

	/**
	 * Repost Action: Repost tree frame and save object
	 */
	public final static int POSTTOSELF_ACTION_REPOST_TREE_AND_SAVE = 406;

	/** Web Data Object (needs to be nulled out after execution to prevent leaks) */
	private IWebData m_WebData;

	/** HTTP Request (needs to be nulled out after execution to prevent leaks) */
	private IXPRequest m_xpRequest;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SaveObjectRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits this Control with the HTTP Request and the Web Data object.
	 *
	 * @param _xpRequest
	 * @param _webdata
	 */
	public void SetHTTPItems(IXPRequest _xpRequest, IWebData _webdata)
	{
		m_xpRequest     = _xpRequest;
		m_WebData	    = _webdata;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		Redirect result;

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_SAVEOBJECT:

			if (!((SaveObjectModel) m_model).ForceSaveInFolder())
			{
				((SaveObjectModel) m_model).AddAdminFolderIDToCookie(m_xpRequest,
					m_WebData);
			}

			try
			{
				m_model.Finish();
	
				// JF- We are done with the Editor, we call finish on the parent AS, 
				// which will take care of storing the Object.
				EditorAS parentSpace	   = (EditorAS) m_asOwner.GetParentSpace();
				ObjEditorModel parentModel = (ObjEditorModel) parentSpace.GetModel(parentSpace.m_strModelName);

				// The parent space is not initialized, which means it can't be used normally in
				// the INewEditObjectActions PEI when that is triggered.  So we initialize it here.
				parentSpace.SetCurrentHTTPRequestResponseObjects(m_asOwner.GetCurrentHTTPRequest(), m_asOwner.GetCurrentHTTPResponse());
				parentSpace.SetCurrentRequestURL(m_asOwner.GetCurrentRequestURL());

				parentModel.Finish();
	
				// JF- Then we redirect to the dependencies page.
				// We are in the bottom frame and we want to redirect the entire window. 
				// We redirect to a DP that will take care of redirecting the frame.
				result = new Redirect();
				result.SetLinkGetCachedSpace(m_asOwner);
				result.SetDisplayPage(SaveObjectRedirectDP.STR_MVC_CLASS_NAME);
				SetRedirect(result);

				break;
			}
			catch (Exception e)
			{
				IXPEnumerator arrErrors = UIErrorHandler.GetErrors(m_asOwner.GetSubSession(), m_asOwner.GetApplication(), m_asOwner, true, true);
					
				if (!arrErrors.MoveNext())
				{
					UIError myError = new UIError(UIErrorLevel.SERIOUS,
						UIErrorScope.CURRENT_USER, null, 
						m_asOwner.GetString(445, "ptmsgs_portalinfrastructure"), null);
					UIErrorHandler.RaiseError(myError,
						m_asOwner.GetSubSession(), m_asOwner.GetApplication());
				}
				
				result = new Redirect();
				result.SetLinkGetCachedSpace(m_asOwner);
				result.SetDisplayPage(SaveObjectClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(result);
				
				return;
			}

		case POSTTOSELF_ACTION_SAVENAME_AND_DESCRIPTION:

			// JF- We saved the name and description, but we also want to save the body frame.
			// With the flag below, when the name and description Section is displayed, it will 
			// have a JS to repost the body Section.
			((SaveObjectModel) m_model).SetRepostBodyFromBottomFrame(true);

			break;

		case POSTTOSELF_ACTION_CHANGETAB:

			if (!((SaveObjectModel) m_model).HideSecurityTab())
			{
				// JF- We saved the new tab ID, but we also want to save the body frame and redirect it 
				// according to the new tab ID.
				// With the flag below, when the tab Section is displayed, it will 
				// have a JS to repost the body Section.
				((SaveObjectModel) m_model).SetRepostBodyFromTopFrame(true);
			}

			break;

		case POSTTOSELF_ACTION_GOTO_SECURITYTAB:

			if (!((SaveObjectModel) m_model).HideSecurityTab())
			{
				// JF- We redirect to the Security page. We get it from our parent Space.
				result = new Redirect();

				if (((SaveObjectModel) m_model).ForceSaveInFolder())
				{
					result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
					result.SetDisplayPage(ObjectSecurityDP.STR_MVC_CLASS_NAME);
				}
				else
				{
					result.SetLinkGetCachedSpace(m_asOwner);
					result.SetDisplayPage(SaveObjectGoToSecurityTabDP.STR_MVC_CLASS_NAME);
				}

				SetRedirect(result);
			}

			break;

		case POSTTOSELF_ACTION_GOTO_FOLDERTREETAB:

			if (!((SaveObjectModel) m_model).HideSecurityTab())
			{
				result = new Redirect();

				if (((SaveObjectModel) m_model).ForceSaveInFolder())
				{
					result.SetLinkGetCachedSpace(m_asOwner);
					result.SetDisplayPage(SaveObjectCantChangeFolderDP.STR_MVC_CLASS_NAME);
				}
				else
				{
					// JF- We redirect to the folder tree. (It's a sub space.)
					//result.SetSpaceGetCached(m_asOwner.GetSubSpace(SaveObjectModel.SAVEOBJECT_FOLDERTREE_SUBSPACEKEY));
					result.SetLinkGetCachedSpace(m_asOwner);
					result.SetDisplayPage(SaveObjectFoldersFrameDP.STR_MVC_CLASS_NAME);
				}

				SetRedirect(result);
			}

			break;

		case POSTTOSELF_ACTION_REPOST_TREE:
			((SaveObjectModel) m_model).SetRepostTreeRecentFoldersFrame(true);

			break;

		case POSTTOSELF_ACTION_REPOST_TREE_AND_SAVE:
			((SaveObjectModel) m_model).SetRepostTreeAndSave(true);

			break;
		}

		// null out these so we don't leak them.
		m_xpRequest = null;
		m_WebData = null;
	}
}

