package com.plumtree.portaluiinfrastructure.editor.saveobject;

// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This control is used to initalize the save object pop-up.
 * It has to be called the first time the pop-up is displayed.
 *
 * @author Julie Fournier
 */
public class SaveObjectStartControl implements IControl, IHTTPControl
{
	/** Object Name for AS */
	public static final String STR_MVC_CLASS_NAME = "SaveObjectPopUpStart";

	/** Associated Activity Space */
	protected SaveObjectAS m_asOwner;

	/** Associated Model */
	protected SaveObjectModel m_model;

	/** HTTP Request (needs to be nulled out after execution to prevent leaks) */
	private IXPRequest m_xpRequest;

	/**
	 * Intializes the Model.
	 *
	 * @return Redirect
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		m_model.InitializeSaveObjectPopUp(m_xpRequest);

		// null out request so we don't leak it.
		m_xpRequest = null;

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SaveObjectStartControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the class with the associated model and activity space.
	 *
	 * @param model
	 * @param space
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_model		  = (SaveObjectModel) model;
		m_asOwner     = (SaveObjectAS) space;
	}

	/**
	 * Inits this Control with the HTTP Request.
	 * (Will be used to retrieve most recently used folders.)
	 *
	 * @param _xpRequest
	 * @param _webdata
	 */
	public void SetHTTPItems(IXPRequest _xpRequest, IWebData _webdata)
	{
		m_xpRequest = _xpRequest;
	}
}

