package com.plumtree.portaluiinfrastructure.error;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * @author Ben Geislinger
 *
 * This helper class is used to determine whether or not to display admin
 * errors.  The UIErrorHandler should be initialized by the AppStartUp code
 * to use this helper class.
 */
public class PTErrorHandler implements IAdminUIErrorHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.error.PTErrorHandler");

	/**
	 * Call this method to obtain a boolean value indicating whether or not
	 *     the current user should see errors intended for administrators.
	 * <br><br>
	 * @param ptSession IPTSession
	 * @return boolean value
	 */
	public boolean GetDisplayAdminErrors(Object session)
	{
		log.Debug("GetDisplayAdminErrors()");

		// This can happen on a failed login attempt.
		if (session == null)
		{
			return false;
		}

		IPTSessionInfo info = ((IPTSession) session).GetSessionInfo();

		boolean bUserIsAdmin = false;

		try
		{
			bUserIsAdmin = PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) session);
		}
		catch (Exception ex)
		{
			log.Error(ex, "Error while checking if user is in the Administrators group.");
		}

		log.Debug("GetDisplayAdminErrors() - bUserIsAdmin: " + XPConvert.ToString(bUserIsAdmin));
		log.Debug("userid: " + info.GetCurrentUserID());

		return bUserIsAdmin;
	}

	/**
	 * Call this method to obtain a boolean value indicating whether or not
	 *     the current user should see errors intended for administrators.
	 * <br><br>
	 * @param AActivitySpace
	 * @return boolean value
	 */
	public boolean GetDisplayAdminErrors(AActivitySpace space)
	{
		
			log.Debug("GetDisplayAdminErrors()");
		

		return UIErrorHandler.GetDisplayAdminErrors(space.GetUserSession());
	}
}

