package com.plumtree.portaluiinfrastructure.expandablelist.inherit;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class CommunitiesListView extends SelectPTObjectView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.expandablelist.inherit.CommunityListView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "InheritList";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunitiesListView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
		result.AddInnerHTMLElement(GetHTMLForInheritsColumn(_saData, _nRowIndex));

		return result;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForInheritsColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// RWW: Retrieve object name and class id.
		boolean bInheritsCommTemp = (1 == XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
			InheritListModel.EXPLIST_COL_INHERITS))) ? true : false;

		if (bInheritsCommTemp)
		{
			myCell.AddInnerHTMLString(m_asOwner.GetString(3048, ResourceConstants.PORTALADMINMSGS));
		}
		else
		{
			myCell.AddInnerHTMLString(m_asOwner.GetString(3049, ResourceConstants.PORTALADMINMSGS));
		}

		myCell.AddInnerHTMLString(SPACE);

		return myCell;
	}
	
}
