package com.plumtree.portaluiinfrastructure.expandablelist.inherit;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;

/**
 * @author michaeld
 */
public class InheritListModel extends SelectPTObjectModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.expandablelist.inherit.InheritListModel");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "InheritList";

	public static final int EXPLIST_COL_MAX = 5;
	
	public static final int EXPLIST_COL_INHERITS = 4;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new InheritListModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Initializes the read only inherit list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _nDisplayClassID Class ID of the Objects displayed on the list.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeInheritList(String _sSectionTitle, int _nDisplayClassID, int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[2][5];
		// Name column
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_STRING);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(3046, ResourceConstants.PORTALADMINMSGS);
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.TRUE;
		// Inherits Template Column
		arrExpListColInfo[1][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_INHERITS);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(3047, ResourceConstants.PORTALADMINMSGS);
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "20";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		super.InitializeReadOnlyExpandableList(
			_sSectionTitle,
			arrExpListColInfo,
			_nListKey);
			
		super.InitializeListClassIDs(new int[] { _nDisplayClassID });
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
				EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING, EXPLIST_COL_INHERITS
			};

		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_STRING;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, false,
			EXPLIST_DEFAULT_INITIAL_SIZE);
	}

	/**
	 * Uses the passed in parameters to query which objects use the passed in template
	 * and which inherit it then adds those as the default objects.
	 *
	 * @param _Session
	 * @param _nDisplayClassID
	 * @param _nTemplateObjectID
	 * @param _nTemplateColumnPropID
	 * @param _nInheritTemplateColumnPropID
	 */
	public void SetDefaultObjects(IPTSession _Session, int _nDisplayClassID, int _nTemplateObjectID,
		int _nTemplateColumnPropID, int _nInheritTemplateColumnPropID)
	{
		int[][] aOrderBy = new int[1][2];
		aOrderBy[0][0] = PT_PROPIDS.PT_PROPID_NAME;
		aOrderBy[0][1] = PT_ORDERBY_SETTINGS.PT_ORDERBY_ASCENDING;
			
		Object[][] aQueryFilter = new Object[3][1];
		aQueryFilter[0][0]     = new Integer(_nTemplateColumnPropID);
		aQueryFilter[1][0]     = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
		aQueryFilter[2][0]     = new Integer(_nTemplateObjectID);

		IPTQueryResult ptqrObjects = _Session.GetObjectManagers(_nDisplayClassID)
			.Query(
				PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_DESCRIPTION | 
					_nTemplateColumnPropID | _nInheritTemplateColumnPropID,
				-1,
				aOrderBy,
				0,
				-1,
				aQueryFilter);
	
		Object[][] arrObjects = SetupInheritedObjects(ptqrObjects, _nDisplayClassID, _nInheritTemplateColumnPropID);
	
		super.SetDefaultObjects(arrObjects);
	}

	/**
	 * Takes a query result of objects and sets up the member variables from
	 * it.
	 *
	 * @param IPTQueryResult ptqrObjects
	 * @param _nDisplayClassID
	 * @param _nInheritTemplateColumnPropID
	 * @return Object[][]
	 */
	private Object[][] SetupInheritedObjects(IPTQueryResult ptqrObjects, int _nDisplayClassID, int _nInheritTemplateColumnPropID)
	{
		int nObjectCount;

		if (null == ptqrObjects)
		{
			nObjectCount = 0;
		}
		else
		{
			nObjectCount = ptqrObjects.RowCount();
		}

		Object[][] arrReturn = new Object[nObjectCount][EXPLIST_COL_MAX];

		for (int i = 0; i < nObjectCount; i++)
		{
			arrReturn[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX]		= new Integer(this.m_nNextIndex);
			this.m_nNextIndex++;
			arrReturn[i][EXPLIST_COL_CLASSID]				   = new Integer(_nDisplayClassID);
			arrReturn[i][EXPLIST_COL_OBJECTID]				   = ptqrObjects.ItemAsObject(i,
					PT_PROPIDS.PT_PROPID_OBJECTID);
			arrReturn[i][EXPLIST_COL_STRING]				   = (String) ptqrObjects.ItemAsObject(i,
					PT_PROPIDS.PT_PROPID_NAME);
			arrReturn[i][EXPLIST_COL_INHERITS]				   = ptqrObjects.ItemAsObject(i,
					_nInheritTemplateColumnPropID);
		}

		return arrReturn;
	}
}
