package com.plumtree.portaluiinfrastructure.expandablelist.properties;

import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Browse view for expandable list of properties. 
 *
 * @author josephc
 */
public abstract class ExpListPropBrowseView extends ExpListView
{
	/** Used to set the style of the row */
	protected PTStyleClass m_rowStyleClass;

	/**
	 * Compares the property ID of the row to the previous row's property ID to
	 * determine whether or not the row is a new property or not.
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return True if new property, False otherwise.
	 */
	protected boolean CheckRowIsFirstForProperty(int _nRowIndex)
	{
		IExpListPropModelRO iOPModel = (IExpListPropModelRO) m_model;

		if (-1 == m_nLastVisibleRow)
		{
			return true;
		}
		else
		{
			int nPropertyID = iOPModel.GetRowPropertyID(_nRowIndex);
	
			// Get last visible row's name and propertyID
			int nLastPropertyID = iOPModel.GetRowPropertyID(m_nLastVisibleRow);
	
			// If the current propertyID not equal to the previous propertyID
			// then we know that the row contains a new property.
			return nPropertyID != nLastPropertyID;
		}
	}

	/**
	 * Helper method to set the style of a row.  This method is used by
	 * Display(). Overrides the ExpListView::SetExpListRowStyle().
	 *
	 * @param _myRow
	 * @param _nRowIndex
	 *
	 * @throws HTMLException
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#SetExpListRowStyle(HTMLTableRow,
	 *      int)
	 */
	protected void SetRowStyle(HTMLTableRow _myRow, int _nRowIndex)
	{
		// If we're on the first row, then reset the style
		if (0 == _nRowIndex)
		{
			m_rowStyleClass = PTStyleClass.LIST_ITEM_ONE_BG;
		}

		// If the row is the first for the property
		if (CheckRowIsFirstForProperty(_nRowIndex))
		{
			// Toggle style index if we have a new property
			if (PTStyleClass.LIST_ITEM_ONE_BG == m_rowStyleClass)
			{
				m_rowStyleClass = PTStyleClass.LIST_ITEM_TWO_BG;
			}
			else
			{
				m_rowStyleClass = PTStyleClass.LIST_ITEM_ONE_BG;
			}
		}

		_myRow.SetStyleClass(m_rowStyleClass);
	}
}

