package com.plumtree.portaluiinfrastructure.expandablelist.properties;

import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;

/**
 * Read-only interface for expandable list of properties model.
 *
 * @author josephc
 */
public interface IExpListPropModelRO extends IExpListModelRO
{
	/**
	 * Returns the name of the property in the indicated row
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Name of property
	 */
	public String GetRowName(int _nRowIndex);

	/**
	 * Returns the property ID of the property in the indicated row
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Property ID
	 */
	public int GetRowPropertyID(int _nRowIndex);

	/**
	 * Returns the status of the row (added, deleted, edited, modified)
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Row status
	 */
	public int GetRowStatus(int _nRowIndex);

	/**
	 * Returns the value type of the property
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Value type of property
	 */
	public int GetRowType(int _nRowIndex);

	/**
	 * Returns the value of the property
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return Value of property
	 */
	public Object GetRowValue(int _nRowIndex);

	/**
	 * Returns the datetime-picker control manager.
	 *
	 * @return The datetime-picker control manager.
	 */
	public JSDateTimePickerMgr GetDateTimePickerControlManager();

	/**
	 * Returns the unique date/time picker string ID for the row.
	 *
	 * @param _nRowIndex
	 * @return
	 */
	public String GetUniqueDateTimePickerKey(int _nRowIndex);
}

