package com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.selectptobjectsbytype;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * This model sorts the expandable list of pt objects first by class id
 * and then by name.
 * 
 * @author DonH
 */
public class SelectPTObjectsByTypeModel extends SelectPTObjectModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.selectptobjectsbytype.SelectPTObjectsByTypeModel");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SelectPTObjectsByType";

	/**
	 * Returns the column ID of the primary sorted column.
	 * (the array can be sorted by multiple columns)
	 *
	 * @return int
	 */
	public int GetMainColumnSort()
	{
		int[][] arrSort = m_saData.GetSort();

		// JF- For sorting objects by type, row 0 is sorted by class ID but in the UI it will 
		// look like it's sorted by name or privilege because there is no column for class ID.
		// This is why we return the value of row 1 below.
		return arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID];
	}

	/**
	 * Returns the sort direction of the primary sorted column.
	 *
	 * @return int
	 */
	public int GetMainColumnSortDirection()
	{
		int[][] arrSort = m_saData.GetSort();

		// JF- For sorting objects by type, row 0 is sorted by class ID but in the UI it will 
		// look like it's sorted by name or privilege because there is no column ofr class ID.
		// This is why we return the value of row 1 below.
		return arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION];
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Sort array
		// For sorting objects by type the list is always sorted by class id
		// descending as a primary sort (e.g. we always want to see all the groups
		// together and then all the users).
		int[][] arrSort = new int[2][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_CLASSID;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;

		// JF- Then by default the user will first see the list sorted by object name.
		arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_STRING;
		arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null bellow)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(GetArrayOfColumns(), null, arrSort, true,
			EXPLIST_DEFAULT_INITIAL_SIZE);
	}

	/**
	 * Helper method to get the sort.
	 *
	 * This method should be overridden if the colums are different.
	 * 
	 * @return int[]
	 */
	protected int[] GetArrayOfColumns()
	{
		// JF- Column mapping
		int[] arrColumns;

		arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
				EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING
			};

		return arrColumns;
	}

	/**
	 * Reverses the sort of all the sorted columns.
	 *
	 */
	public void ReverseCurrentSort()
	{
		int[][] arrSort = m_saData.GetSort();

		// JF- Get the current sort.
		// JF- We need to reverse the 2 columns: class ID and the other one (name or privilege)
		for (int i = 0; i < arrSort.length; i++)
		{
			int nCurrentDirection = arrSort[i][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION];

			// JF- The new direction is the oposite of the previous direction.
			if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == nCurrentDirection)
			{
				arrSort[i][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
			}
			else
			{
				arrSort[i][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
			}
		}

		m_saData.Sort(arrSort);
	}

	/**
	 * Gets the column ID back from the form data and resort
	 * the array by that column ID, ascending.
	 *
	 * @param _htFormData
	 */
	public void SortByColumn(XPHashtable _htFormData)
	{
		String sDataKey = GetUniqueString(ExpListView.HTMLHIDDEN_COLUMNID);

		// JF- First we need to get back the column ID from the form data.
		if (_htFormData.ContainsKey(sDataKey))
		{
			String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && (0 != aDataValue.length))
			{
				try
				{
					int nColumnID = XPConvert.ToInteger(aDataValue[0]);

					// JF- We create a new sort array
					int[][] arrSort = new int[2][2];

					// JF- The security page is always sorted by class ID first (group first and then users)
					arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_CLASSID;
					arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;

					// JF- Then by the other propID that we got from the form: name or privilege
					arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = nColumnID;
					arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

					// JF- Finally we resort the array
					m_saData.Sort(arrSort);
				}
				catch (Exception e)
				{
					log.Error(e, STR_MVC_CLASS_NAME + "::SortByColumn An exception occured" +
						" when trying to resort the array by column with ID: " +
						aDataValue[0]);
				}
			}
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SelectPTObjectsByTypeModel();
	}
}