package com.plumtree.portaluiinfrastructure.expandablelist.template;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.template.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author michaeld
 */
public class TemplateListModel extends ExpListModel implements ITemplateListModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
			"com.plumtree.portaluiinfrastructure.expandablelist.template.TemplateListModel");

	/** Object Name */
	public final static String STR_MVC_CLASS_NAME = "TemplateList";

	/** Template Growable Array Template ID Column */
	public final static int EXPLIST_COL_TEMPLATE_ID = 0;

	/** Template Growable Array Template Name Column */
	public final static int EXPLIST_COL_TEMPLATE_NAME = 1;
	
	/** Template Growable Array Inherit Template Column */
	public final static int EXPLIST_COL_INHERIT_TEMPLATE = 2;
	
	/** Template Growable Array Column Count */
	public final static int EXPLIST_COL_COUNT = 3;

	/**
	 * Key name used by the Activity Space to store the select template tree. */
	public static final String SUBSPACE_NAME_SELECTTEMPLATETREE = "SelectTemplateTree";
	
	/** Key name used by the Activity Spce to store the community template editor. */
	public static final String SUBSPACE_NAME_COMMTEMP = "EditCommTemp";

	/** IPTSession */
	protected IPTSession m_Session;
	
	/** Class ID of the template */
	private int m_nTemplateClassID;
	
	/** Label for the add button */
	private String m_strAddLabel;

	/** Space IDs */
	private XPHashtable m_htFormData;
	
	/**
	 * Set the label of the add button. This must be called before InitializeTemplateList is called.
	 * @param label for the add button 
	 */
	public void SetAddLabel(String _strAddLabel)
	{
		m_strAddLabel = _strAddLabel;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		if (m_asOwner.GetSubSpaceExists(SUBSPACE_NAME_SELECTTEMPLATETREE))
		{
			TemplateTreeAS asTree = (TemplateTreeAS) m_asOwner.GetSubSpace(SUBSPACE_NAME_SELECTTEMPLATETREE);

			ITreeModelRO myTree    = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList mySelected = myTree.GetSelectedItems();
			
			// Get the old template id
			int nOldTemplateID = 0;
			boolean bOldInheritTemplate = true;
			if (0 < m_saData.GetCount())
			{
				nOldTemplateID = XPConvert.ToInteger(m_saData.GetItem(0, EXPLIST_COL_TEMPLATE_ID));
				bOldInheritTemplate = XPConvert.ToBoolean(m_saData.GetItem(0, EXPLIST_COL_INHERIT_TEMPLATE));
			}

			// Set template id
			int nTemplateID = ((TreeLeafNode) mySelected.GetElement(0)).m_nObjectID;
			
			IInheritTemplateModelRO inheritModel = (IInheritTemplateModelRO) asTree.GetModel(TemplateTreeAS.PLUGIN_INHERIT_TEMPLATE);
			boolean bInheritTemplate = inheritModel.IsTemplateInherited();

			// if either the template changed or the inherit template changed
			if ( nOldTemplateID != nTemplateID || bOldInheritTemplate != bInheritTemplate )
			{
				String strTemplateName = "";
				IPTObject ptTemplate = null;
				
				// if new template is not the same as the old one
				if ( nOldTemplateID != nTemplateID )
				{
					try
					{
						// Get template object
						ptTemplate = (IPTObject) m_Session.GetObjectManagers(m_nTemplateClassID)
							.Open(nTemplateID, false);

						// Get the template name
						strTemplateName = ptTemplate.GetLocalizedName();
					}
					catch ( Exception e )
					{
						UIError myError = new UIError(UIErrorLevel.SERIOUS,
							UIErrorScope.CURRENT_USER, e, 
							m_asOwner.GetString(525, ResourceConstants.PORTALINFRASTRUCTURE), 
							m_asOwner.GetString(526, ResourceConstants.PORTALINFRASTRUCTURE));
	
						UIErrorHandler.RaiseError(myError,
							m_asOwner.GetSubSession(), m_asOwner.GetApplication());
	
						
						log.Error("TemplateListModel.AddRowsOnRepost: Selecting template with class id " + m_nTemplateClassID + " and object id " +
							nTemplateID + " was not successful.");
						
					}
				}
				else
				{
					strTemplateName = XPConvert.ToString(m_saData.GetItem(0, EXPLIST_COL_TEMPLATE_NAME));
				}
				
				if ( !("").equals(strTemplateName) )
				{
					// put data in sorted array
					m_saData.ClearArray();
					Object[] commTempRow = new Object[EXPLIST_COL_COUNT];
					commTempRow[EXPLIST_COL_TEMPLATE_ID] = new Integer(nTemplateID);
					commTempRow[EXPLIST_COL_TEMPLATE_NAME] = strTemplateName;
					commTempRow[EXPLIST_COL_INHERIT_TEMPLATE] = new Boolean(bInheritTemplate);
					m_saData.AddRow(commTempRow);
				}
			}
		}
	}

	public void InitializeTemplateList(IPTSession _Session, int _nTemplateClassID, int _nTemplateID, boolean _bInheritTemplate,
		String _strSectionTitle, PTImageType _imgType, int _nListKey)
	{
		m_Session = _Session;
		m_nTemplateClassID = _nTemplateClassID;
		String  strTemplateName = "";
		
		if ( 0 != _nTemplateID )
		{
			try
			{
				strTemplateName = ((IPTObject)m_Session.GetObjectManagers(m_nTemplateClassID).Open(_nTemplateID, false)).GetLocalizedName();
			}
			catch (Exception ex)
			{
				// TODO-MJD: Could not open the template to get its name. Set name equal to "You do not have permission to see this template."
				strTemplateName = "";
			}
		}
		
		Object[][] arrExpListColInfo = new Object[1][5];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]     		= new Integer(EXPLIST_COL_TEMPLATE_NAME);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(524, ResourceConstants.PORTALINFRASTRUCTURE);
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		super.InitializeExpandableList(_strSectionTitle, arrExpListColInfo, _imgType, m_strAddLabel, _nListKey);
		
		super.DisableCheckBoxes();
		
		if ( 0 != _nTemplateID )
		{
			Object[] commTempRow = new Object[EXPLIST_COL_COUNT];
			commTempRow[EXPLIST_COL_TEMPLATE_ID] = new Integer(_nTemplateID);
			commTempRow[EXPLIST_COL_TEMPLATE_NAME] = strTemplateName;
			commTempRow[EXPLIST_COL_INHERIT_TEMPLATE] = new Boolean(_bInheritTemplate);
			
			m_saData.AddRow(commTempRow);
		}

		// Setup hash map with names and values of form inputs
		// Currently this can only be used by the pages list view, 
		// but it could easily be extended for use by other views.
		m_htFormData = new XPHashtable();
		m_htFormData.PutElement(TemplateListView.HTMLINPUT_TEMPLATETREEASID, "");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper)
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_COL_TEMPLATE_ID, EXPLIST_COL_TEMPLATE_NAME, EXPLIST_COL_INHERIT_TEMPLATE
			};

		// JF- Sort array
		// The growable array will always be sorted by the String column (the one displayed).
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_TEMPLATE_NAME;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null bellow)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, false, 1);
	}

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		int nReturn = super.SaveSection(_htFormData);

		String strKey;
		String[] data;
		IXPEnumerator xpKeys = m_htFormData.GetKeys();
		XPHashtable tempFormData = new XPHashtable(); 

		// Put values of inputs on main page into the form data object.
		// These inputs include the space ids for selecting a community
		// template, adding a new page, and one for each edit page. Also
		// the current edit page index is kept in here.
		while (xpKeys.MoveNext())
		{
			strKey = (String) xpKeys.GetCurrent();

			if (_htFormData.ContainsKey(strKey))
			{
				data = (String[]) _htFormData.GetElement(strKey);

				if ((null != data) && (0 != data.length))
				{
					tempFormData.PutElement(strKey, data[0]);

					// Put value from _htFormData in m_htFormData 
				}
			}
		}
		
		// Now copy it back to the core page model 
		IXPEnumerator xpKeys2 = tempFormData.GetKeys();
		String data2;
		while (xpKeys2.MoveNext())
		{
			strKey = (String) xpKeys2.GetCurrent();

			if (_htFormData.ContainsKey(strKey))
			{
				data2 = (String) tempFormData.GetElement(strKey);

				if ((null != data2) && (0 != data2.length()))
				{
					m_htFormData.PutElement(strKey, data2);

					// Put value from _htFormData in m_htFormData 
				}
			}
		}

		return nReturn;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#SaveRow(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper, int, com.plumtree.openfoundation.util.XPHashtable)
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex, XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TemplateListModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.expandablelist.template.ITemplateListModelRO#GetInputValue(java.lang.String)
	 */
	public String GetInputValue(String name)
	{
		String value = (String) m_htFormData.GetElement(name);

		if (value == null)
		{
			return "";
		}

		return value;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.expandablelist.template.ITemplateListModelRO#GetTemplateClassID()
	 */
	public int GetTemplateClassID()
	{
		return m_nTemplateClassID;
	}
}
