package com.plumtree.portaluiinfrastructure.failover;

import com.plumtree.openfoundation.util.*;

import com.plumtree.openkernel.sharedcache.*;

/**
 * This class stores info about a cookie.
 * 
 * @author ErickS, JosephC 
 */
public class CookieInfo
{
	private static String STR_NAME = "NAME";
	private static String STR_VALUE = "VALUE";
	private static String STR_DOMAIN = "DOMAIN";
	private static String STR_PATH = "PATH";
	private static String STR_SECURE = "SECURE";
	private static String STR_EXPIRE = "EXPIRE";
	private String m_strName;
	private String m_strValue;
	private String m_strDomain;
	private String m_strPath;
	private boolean m_bSecure;
	private XPDateTime m_dtExpire;

	/**
	 * Creates a new CookieInfo object.
	 *
	 * @param strName DOCUMENT_ME
	 * @param strVal DOCUMENT_ME
	 * @param strDomain DOCUMENT_ME
	 * @param strPath DOCUMENT_ME
	 * @param bSecure DOCUMENT_ME
	 * @param dtExpire DOCUMENT_ME
	 */
	public CookieInfo(String strName, String strVal, String strDomain, String strPath, boolean bSecure, XPDateTime dtExpire)
	{
		m_strName	    = strName;
		m_strValue	    = strVal;
		m_strDomain     = strDomain;
		m_strPath	    = strPath;
		m_bSecure	    = bSecure;
		m_dtExpire	    = dtExpire;
	}

	/**
	 * Creates a new CookieInfo object.
	 *
	 * @param cacheNode DOCUMENT_ME
	 */
	public CookieInfo(IOKSharedCacheNode cacheNode)
	{
		m_strName	    = (String) cacheNode.GetElement(STR_NAME);
		m_strValue	    = (String) cacheNode.GetElement(STR_VALUE);
		m_strDomain     = (String) cacheNode.GetElement(STR_DOMAIN);
		m_strPath	    = (String) cacheNode.GetElement(STR_PATH);

		int iSecure = XPConvert.ToInteger(cacheNode.GetElement(STR_SECURE));

		if (1 == iSecure)
		{
			m_bSecure   = true;
		}
		else
		{
			m_bSecure = false;
		}

		m_dtExpire = (XPDateTime) cacheNode.GetElement(STR_EXPIRE);
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public String GetName()
	{
		return m_strName;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public String GetValue()
	{
		return m_strValue;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public String GetDomain()
	{
		return m_strDomain;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public String GetPath()
	{
		return m_strPath;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public boolean GetSecure()
	{
		return m_bSecure;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public XPDateTime GetDateExpire()
	{
		return m_dtExpire;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public IOKSharedCacheNode GetCacheNode()
	{
		IOKSharedCacheNode spBag = ReplicationCache.GetSharedCache().CreateNode();
		spBag.PutElement(STR_NAME, m_strName);
		spBag.PutElement(STR_VALUE, m_strValue);
		spBag.PutElement(STR_DOMAIN, m_strDomain);
		spBag.PutElement(STR_PATH, m_strPath);

		if (m_bSecure)
		{
			spBag.PutElement(STR_SECURE, new Integer(1));
		}
		else
		{
			spBag.PutElement(STR_SECURE, new Integer(0));
		}

		if (null != m_dtExpire)
		{
			spBag.PutElement(STR_EXPIRE, m_dtExpire);
		}

		return spBag;
	}
}
