package com.plumtree.portaluiinfrastructure.failover;

import com.plumtree.openfoundation.util.*;

import com.plumtree.openkernel.config.*;
import com.plumtree.openkernel.factory.*;
import com.plumtree.openkernel.http.*;
import com.plumtree.openkernel.sharedcache.*;

import com.plumtree.openlog.*;

import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;

import com.plumtree.xpshared.config.*;

/**
 * This class handles the ReplicationCache
 *
 * @author ErickS, JosephC
 */
public class ReplicationCache
{
	private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE), "com.plumtree.portaluiinfrastructure.failover.ReplicationCache");

	/**
	 * DOCUMENT ME!
	 */
	public static int CLEANUP_MINUTES = 30;

	/**
	 * DOCUMENT ME!
	 */
	public static final String DATE_EXPIRED = "DATE_EXPIRED";

	/**
	 * DOCUMENT ME!
	 */
	public static final String COOKIES = "COOKIES";

	/**
	 * DOCUMENT ME!
	 */
	public static final String SESSION_PREFS = "SESSION_PREFS";

	/** whether or not the replication cache has already been initialized. */
	private static boolean m_initialized = false;
	private static boolean m_enabled = false;
	private static IOKSharedCache m_sharedCache;
	private static XPDateTime m_lastCleanupDate;

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public static IOKSharedCache GetSharedCache()
	{
		return m_sharedCache;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public static IOKSharedCacheNode GetCookies(String replicationToken)
	{
		String[] key = new String[] { replicationToken, ReplicationCache.COOKIES };

		return (IOKSharedCacheNode) ReplicationCache.GetSharedCache().GetElement(key);
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 * @param segment DOCUMENT_ME
	 * @param cookie DOCUMENT_ME
	 */
	public static void SetCookie(String replicationToken, String segment, IOKHttpCookie cookie)
	{
		CookieInfo cookieInfo = new CookieInfo(cookie.Name(), cookie.Value(), cookie.Domain(), cookie.Path(), cookie.Secure(), cookie.DateExpire());

		String[] cookieKey = new String[]
		{
			replicationToken, ReplicationCache.COOKIES, segment
		};

		synchronized (ReplicationCache.GetSharedCache())
		{
			ReplicationCache.GetSharedCache().PutElement(cookieKey, cookieInfo.GetCacheNode());
		}
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public static IOKSharedCacheNode GetSessionPrefs(String replicationToken)
	{
		String[] key = new String[]
		{
			replicationToken, ReplicationCache.SESSION_PREFS
		};

		return (IOKSharedCacheNode) ReplicationCache.GetSharedCache().GetElement(key);
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 * @param sessionPref DOCUMENT_ME
	 * @param prefValue DOCUMENT_ME
	 */
	public static void SetSessionPref(String replicationToken, String sessionPref, String prefValue)
	{
		String[] key = new String[]
		{
			replicationToken, ReplicationCache.SESSION_PREFS, sessionPref
		};

		synchronized (ReplicationCache.GetSharedCache())
		{
			ReplicationCache.GetSharedCache().PutElement(key, prefValue);
		}
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 * @param sessionPref DOCUMENT_ME
	 */
	public static void RemoveSessionPref(String replicationToken, String sessionPref)
	{
		String[] key = new String[]
		{
			replicationToken, ReplicationCache.SESSION_PREFS, sessionPref
		};

		ReplicationCache.GetSharedCache().RemoveElement(key);
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public static XPDateTime GetLastModified(String replicationToken)
	{
		String[] key = new String[]
		{
			replicationToken, ReplicationCache.DATE_EXPIRED
		};

		return (XPDateTime) ReplicationCache.GetSharedCache().GetElement(key);
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 * @param lastModified DOCUMENT_ME
	 */
	public static void SetLastModified(String replicationToken, XPDateTime lastModified)
	{
		String[] dateKey = new String[]
		{
			replicationToken, ReplicationCache.DATE_EXPIRED
		};

		synchronized (m_sharedCache)
		{
			ReplicationCache.GetSharedCache().PutElement(dateKey, lastModified);
		}
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param replicationToken DOCUMENT_ME
	 */
	public static void Remove(String replicationToken)
	{
		synchronized (m_sharedCache)
		{
			m_sharedCache.RemoveElement(replicationToken);
		}
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param vpConfig DOCUMENT_ME
	 */
	public static void StaticInit(PTConfigVarPack vpConfig)
	{
		if (m_initialized)
		{
			log.Error("ReplicationCache StaticInit attempted twice.  Ignoring second attempt.");

			return;
		}

		m_initialized		  = true;
		m_lastCleanupDate     = new XPDateTime();

		try
		{
			String sReplicationCacheName;

			if (null != vpConfig)
			{
				sReplicationCacheName = vpConfig.GetConfigValueAsString("Failover", "ClusterName", "value");
			}
			else
			{
				sReplicationCacheName = "MyTestRC";
        	}

			String configpath = ConfigPathResolver.GetOpenConfigPath();
			IOKContext myConfigContext = OKConfigFactory.createInstance(configpath, "portal");

			IOKSharedCachingService factory = OKSharedCacheFactory.getInstance(myConfigContext);
			m_sharedCache = factory.CreateCache(sReplicationCacheName);

			log.Info("Finished initializing ReplicationCache");
		}
		catch (Exception e)
		{
			log.Error(e, "Unable to init replication cache");
		}
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param enabled DOCUMENT_ME
	 */
	public synchronized static void SetEnabled(boolean enabled)
	{
		m_enabled = enabled;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public synchronized static boolean GetEnabled()
	{
		return m_enabled;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param dt DOCUMENT_ME
	 * @param expireMinutes DOCUMENT_ME
	 *
	 * @return DOCUMENT_ME
	 */
	public static boolean IsExpired(XPDateTime dt, int expireMinutes)
	{
		long elapsedTime = XPSystem.GetCurrentTimeMilliSec() - dt.GetTimeInMilliSeconds();
		long expireMilliseconds = expireMinutes * 60 /*seconds in a minute*/ * 1000 /*milliseconds in a second*/;

		return (expireMilliseconds <= elapsedTime);
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param numMinutes DOCUMENT_ME
	 */
	public synchronized static void SetCleanUpMinutes(int numMinutes)
	{
		CLEANUP_MINUTES = numMinutes;
	}

	/**
	 * DOCUMENT_ME
	 */
	public synchronized static void CleanupIfExpired()
	{
		// check if it's been more than CLEANUP_MINUTES when we last checked.
		// if so, trigger a cleanup thread.
		if (IsExpired(m_lastCleanupDate, CLEANUP_MINUTES))
		{
			// spawn a cleanup thread
			log.Info("ReplicationCache needs purging.  Spawning cleanup thread.");
			m_lastCleanupDate = new XPDateTime(); // set it to the current time

			XPThread cleanupThread = new XPThread(new CleanupCache(m_sharedCache));
			cleanupThread.SetBackground(true);
			cleanupThread.Start();
		}
	}
}
