package com.plumtree.portaluiinfrastructure.failover;

import com.plumtree.openfoundation.util.*;

import com.plumtree.openkernel.http.*;

import com.plumtree.openlog.*;

import com.plumtree.portaluiinfrastructure.statichelpers.*;

import com.plumtree.server.*;

/**
 * This class handles the ReplicationCacheEntry.
 *
 * @author ErickS, JosephC
 */
public class ReplicationCacheEntry implements IOKSessionStateNotification, IPTSessionPrefChangeNotification
{
	private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE), "com.plumtree.portaluiinfrastructure.failover.ReplicationCacheEntry");
	private String m_replicationToken;

	/**
	 * Creates a new ReplicationCacheEntry object.
	 *
	 * @param replicationToken DOCUMENT_ME
	 */
	public ReplicationCacheEntry(String replicationToken)
	{
		m_replicationToken = replicationToken;
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param segment DOCUMENT_ME
	 * @param cookie DOCUMENT_ME
	 */
	public void OnSetCookie(String segment, IOKHttpCookie cookie)
	{
		log.Info("Adding cookie to the replication cache.");

		ReplicationCache.SetCookie(m_replicationToken, segment, cookie);

		log.Info("Cookie name: " + cookie.Name() + ", value: " + cookie.Value() + " added to the replication cache.");
		ReplicationCache.SetLastModified(m_replicationToken, new XPDateTime());

		ReplicationCache.CleanupIfExpired();
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param host DOCUMENT_ME
	 * @param address DOCUMENT_ME
	 */
	public void OnPreferedHostChange(String host, OKIPAddress address)
	{
		//TODO: ES - take this whole method out once IOKSessionStateNotification
		// interface has been changed in OpenKernel.

		/*
		   byte[] bt_address = address.GetAddress();
		   m_htPreferredHosts.PutElement(strHost, bt_address);
		   ReplicationCache.UpdateLastModified(m_replicationToken);
		 */
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param sessionPref DOCUMENT_ME
	 * @param prefValue DOCUMENT_ME
	 */
	public void OnSessionPrefAdd(String sessionPref, String prefValue)
	{
		log.Info("Adding session pref to replication cache.");

		ReplicationCache.SetSessionPref(m_replicationToken, sessionPref, prefValue);

		log.Info("Session pref key: " + sessionPref + ", value: " + prefValue + " added to replication cache.");

		ReplicationCache.SetLastModified(m_replicationToken, new XPDateTime());

		ReplicationCache.CleanupIfExpired();
	}

	/**
	 * DOCUMENT_ME
	 *
	 * @param sessionPref DOCUMENT_ME
	 */
	public void OnSessionPrefRemove(String sessionPref)
	{
		log.Info("Removing session pref from replication cache.");

		ReplicationCache.RemoveSessionPref(m_replicationToken, sessionPref);

		log.Info("Session pref key: " + sessionPref + " removed from replication cache.");

		ReplicationCache.CleanupIfExpired();
	}
}
