package com.plumtree.portaluiinfrastructure.filter;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.pagecontrols.datepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.jsutil.*;

/**
 * @author CraigS, based on MikeS code
 */
public class FilterForm
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.filter.FilterForm");

	public static final String IS_FILTER_FORM 			   = "in_hi_isfilterform";
	
	
	public static final String TOP_OPERATOR				   = "in_ra_topoperator";

	
	public static final String IGNORE_BLANK_STATEMENTS     = "in_hi_ignoreblanks";

	
	public static final String IGNORE_BLANK_STATEMENTS_VAL = "ignore";

	
	public static final String ACTIVE_CLAUSE	    = "in_hi_activeclause";

	
	public static final String ACTION			    = "in_hi_groupaction";

	
	public static final String ACTION_ADD_GRP	    = "ADD";

	
	public static final String ACTION_REMOVE_GRP    = "REMOVE";

	
	public static final String ACTION_ADD_STMT	    = "ADDSTMT";

	
	public static final String ACTION_REMOVE_STMT   = "REMOVESTMT";

	
	public static final String ACTION_REMOVE_CHECKED_STMTS   = "REMOVECHECKEDSTMTS";

	
	public static final String TOTAL_GROUPS		    = "in_hi_totalgroups";

	
	public static final String FULL_TEXT		    = "in_tx_fulltext";

	
	public static final String DEPTH_PREFIX		    = "in_hi_depth_";

	
	public static final String MAX_STMTS		    = "in_hi_maxrows_";

	
	public static final String GROUP_OPERATOR	    = "in_ra_groupoperator_";

	
	public static final String OPERATOR_AND		    = "and";

	
	public static final String OPERATOR_OR		    = "or";

	
	public static final String REVEALED			    = "in_hi_revealed_";

	
	public static final String PROPERTY_SELECTED    = "in_se_PropSelect";

	
	public static final String PROPERTY_HIDDEN	    = "in_hi_PropSelect";

	
	public static final String INTRINSIC_HIDDEN	    = "in_hi_Intrinsic";

	
	public static final String INTRINSIC_OP_HIDDEN	    = "in_hi_IntrinsicOp";

	
	public static final String INTRINSIC_VAL_HIDDEN	    = "in_hi_IntrinsicVal";

	
	public static final String OPERATOR_NUMERIC     = "in_se_OpNumber";

	
	public static final String OPERATOR_DATE	    = "in_se_OpDate";

	
	public static final String OPERATOR_TEXT	    = "in_se_OpText";
	
	
	public static final String OPERATOR_MEMBER_OF	= "in_se_OpMemberOf";

	
	public static final String COMPARISON_VALUE     = "in_tx_compareval";

	
	public static final String COMPARISON_VALUE_IF_DATE  = "in_tx_comparedate";
	
	
	public static final String COMPARISON_VALUE_MEMBER_OF = "in_hi_comparememberof";

	
	public static final String REMOVE_STMT_CHECKBOX = "in_cb_removestmt";

	public static IPTFilter BuildFilterFromForm(AActivitySpace asOwner,
                                              XPHashtable form)
	{
		return BuildFilterFromForm(asOwner, form, /* prefix= */ "", /* oldFilter= */ null);
	}

	public static IPTFilter BuildFilterFromForm(AActivitySpace asOwner,
                                              XPHashtable form,
                                              String prefix)
	{
		return BuildFilterFromForm(asOwner, form, prefix, /* oldFilter= */ null);
	}

	public static IPTFilter BuildFilterFromForm(AActivitySpace asOwner,
                                              XPHashtable form,
                                              IPTFilter oldFilter)
	{
		return BuildFilterFromForm(asOwner, form, /* prefix= */ "", oldFilter);
	}

	/**
	 * 
	 *
	 * @param form 
	 * @param prefix 
	 *
	 * @return 
	 */
	private static IPTFilter BuildFilterFromForm(AActivitySpace asOwner,
                                               XPHashtable form,
                                               String prefix,
                                               IPTFilter oldFilter)
	{
		
		    log.Debug("In BuildFilterFromForm prefix is: " + prefix);

		// we lookup this item right away because if it is not in
		// the form, it means we must have arrived here from some
		// page other than the filter construction page
		    
		// aj: There are two cases to check here:
		//     a) there is a search query - if so we are good
		//     b) the IS_FILTER_FORM hidden var exists - if so we are good
		//     The later condition was introduced for filter forms that don't have searches
		//     but simply property filters.  In this case, the search query will be empty
		//     and the filter form component won't work.
		String strIsFilterForm = GetFormStr(IS_FILTER_FORM + prefix, form);
		String strToplevelOperator = GetFormStr(TOP_OPERATOR + prefix, form);
		if (strToplevelOperator.equals("") && strIsFilterForm.equals(""))
		{
			return null;
		}


		// Check the "ignore blank statements" flag.  This is used by the 508
		// advanced search interface, where the user can't simply delete any
		// blank statements before submitting the search.
		boolean ignoreBlanks   = false;
		String ignoreBlanksVal = GetFormStr(IGNORE_BLANK_STATEMENTS + prefix,
				form);

		if ((null != ignoreBlanksVal) &&
				(ignoreBlanksVal.equals(IGNORE_BLANK_STATEMENTS_VAL)))
		{
			ignoreBlanks = true;
		}

		IXPDictionary clausehash = new XPHashtable();

		int AddGroupTo		    = 0;
		int RemoveGroup		    = 0;
		int addStatementTo	    = 0;
		int removeStatementFrom = 0;

		int GroupFocus = GetFormInt(ACTIVE_CLAUSE + prefix, form);

		// set the add or remove flags
		String strGroupAction = GetFormStr(ACTION + prefix, form);

		if (strGroupAction.equalsIgnoreCase(ACTION_ADD_GRP))
		{
			AddGroupTo = GroupFocus;
		}
		else if (strGroupAction.equalsIgnoreCase(ACTION_REMOVE_GRP))
		{
			RemoveGroup = GroupFocus;
		}
		else if (strGroupAction.equalsIgnoreCase(ACTION_ADD_STMT))
		{
			addStatementTo = GroupFocus;
		}
		else if (strGroupAction.equalsIgnoreCase(ACTION_REMOVE_STMT))
		{
			removeStatementFrom = GroupFocus;
		}

		// now determine how many groups are in the form...
		int GroupCount = GetFormInt(TOTAL_GROUPS + prefix, form);

		// start building a new filter, start with the toplevel items, search string and operator
		IPTFilter filter = oldFilter;

	    if (null == filter) 
	    {
			filter = PortalObjectsFactory.CreateSearchFilter();
		}
		
		filter.ClearPropertyFilter();

	    String searchString = GetFormStr(FULL_TEXT + prefix, form);
	
	    log.Debug("In BuildFilterFromForm searchString is: " + searchString);
	
	    filter.SetSearchString(searchString);
	
		int nOperator = PT_BOOLOPS.PT_BOOLOP_OR;

		if (strToplevelOperator.equalsIgnoreCase(OPERATOR_AND))
		{
			nOperator = PT_BOOLOPS.PT_BOOLOP_AND;
		}

		filter.SetOperator(nOperator);
		
		int depthmarker = 0;

		for (int i = 1; i <= GroupCount; i++)
		{
			String strID = XPConvert.ToString(i);
			int depth    = GetFormInt(DEPTH_PREFIX + prefix + strID, form);

			// if the request parameters identify a clause deletion
			// we apply the request recursively to subclauses....
			if (((depth > 0) && (RemoveGroup == i)) || (depthmarker > 0))
			{
				if (RemoveGroup == i)
				{
					depthmarker = depth;

					continue;
				}

				if (depth > depthmarker)
				{
					continue;
				}
				else
				{
					depthmarker = 0;
				}
			}

			// get this clause and seed it with the correct info
			IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);

			int clauseOperator		 = -1;
			String strclauseOperator = GetFormStr(GROUP_OPERATOR  + prefix + strID, form);

			if ((null == strclauseOperator) || (0 == strclauseOperator.length()))
			{
				// If not set at all, assume the same as the top operator;
				// this is needed for 508 advanced search (in which there is only one operator
				// for the whole query) to work
		        strclauseOperator = strToplevelOperator;
			}

			// um... still no clause operator.  check for a hidden one
			if ((null == strclauseOperator) || (0 == strclauseOperator.length()))
			{
				strclauseOperator = GetFormStr("in_hi_groupoperator_"  + prefix +	strID, form);
			}
			
			if (strclauseOperator.equalsIgnoreCase(OPERATOR_AND))
			{
				clauseOperator = PT_BOOLOPS.PT_BOOLOP_AND;
			}
			else if (strclauseOperator.equalsIgnoreCase(OPERATOR_OR))
			{
				clauseOperator = PT_BOOLOPS.PT_BOOLOP_OR;
			}

			if (-1 == clauseOperator)
			{
				throw new XPException("Invalid clause operator: " +
					strclauseOperator);
			}

			clause.SetOperator(clauseOperator);

			// how many statements are in this clause?
			int statementcount = GetFormInt(REVEALED  + prefix + strID, form);

			// if removing a single statement from this clause, decrement
			// the statement count so we skip the last statement
			if ((removeStatementFrom == i) && (statementcount > 0))
			{
				statementcount--;
			}

			int actualStatementCount = 0;

			for (int j = 1; j <= statementcount; j++)
			{
			    String strTag = "_" + strID + "_" + XPConvert.ToString(j);

				// check whether removal of this statement has been requested
				// (this is an alternative to removing the last statement in
				//  a clause, handled by the groupaction mechanism above)
			    if (strGroupAction.equalsIgnoreCase(ACTION_REMOVE_CHECKED_STMTS)) {
				  String strRemove = GetFormStr(REMOVE_STMT_CHECKBOX  + prefix + strTag, form);

				  if ((null != strRemove) && (strRemove.length() > 0)) {
				       // skip this statement
				       continue;
				  }
			    }
			    IPTPropertyFilterStatement statement = null;
				// Check this statement for an intrinsic.
			    String strItems = GetFormStr(INTRINSIC_HIDDEN  + prefix+ strTag, form);
			    if (! strItems.equals(""))
			    {
				    statement = (IPTPropertyFilterStatement) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
				    int operand = XPConvert.ToInteger(strItems);
				    statement.SetOperand(operand);

				    strItems = GetFormStr(INTRINSIC_OP_HIDDEN  + prefix+ strTag, form);
				    int operation = XPConvert.ToInteger(strItems);
				    statement.SetOperator(operation);

				    strItems = GetFormStr(INTRINSIC_VAL_HIDDEN  + prefix+ strTag, form);
				    statement.SetValue(strItems);

				    
					log.Debug("In BuildFilterFromForm adding statement (x,y,z) = (" + operand + ", " + operation + ", " + strItems + ")");
				    
			    }
			    else
			    {

					// because the type will always be a single character (one digit)
					// we are going to parse this string with this knowledge
					strItems = GetFormStr(PROPERTY_SELECTED  + prefix+
							strTag, form);
	
					if (strItems.equals(""))
					{
						strItems = GetFormStr(PROPERTY_HIDDEN  + prefix+ strTag,
								form);
					}
	
					int separator = strItems.indexOf("|", 0);
					int nPropID   = XPConvert.ToInteger(strItems.substring(0, separator));
					int type	  = XPConvert.ToInteger(strItems.substring(separator + 1));
	
					statement = (IPTPropertyFilterStatement) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
					statement.SetOperand(nPropID);
					String strElementType = mapPropertyTypeToElement(type);
	
					int nOp = GetFormInt(strElementType  + prefix+ strTag, form);
	
					// if the operator wasn't specified
					if (0 == nOp)
					{
						// assume a default operator for each type
						if (type == PT_PROPERTY_TYPES.PT_PROPTYPE_STRING)
						{
							nOp = PT_FILTEROPS.PT_FILTEROP_CONTAINS;
						}
						else if(type == PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP)
						{
							nOp = PT_FILTEROPS.PT_FILTEROP_EQ;
						} else
						{
							nOp = PT_FILTEROPS.PT_FILTEROP_GT;
						}
					}
	
					statement.SetOperator(nOp);
	
					String stmtValue = null;
	
					// Have to initialize to something non-null for jumpability
					XPDateTime stmtDateValue = new XPDateTime();
					boolean gotDate = false;
	
					if (type == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE)
					{
						// First, check if COMPARISON_VALUE_IF_DATE is present,
						// which will be the case if this form was generated by
						// EncodeFilterAsControlArgs() below.
						stmtValue = GetFormStr(COMPARISON_VALUE_IF_DATE  + prefix+ strTag, form);
	
						if ((null != stmtValue) && (stmtValue.length() > 0)) 
						{
							// If it was there, it contains msecs since 1970
							long msecs = 0;
							boolean gotMsecs = false;
							try {
								msecs = XPConvert.ToLong(stmtValue);
								gotMsecs = true;
							} catch (Exception e) {
								gotMsecs = false;
							}
	
							if (gotMsecs) 
							{
								gotDate = true;
								stmtDateValue = new XPDateTime(msecs);
							}
	
						} 
						else 
						{
						    // check for relative time
							boolean isRelative = (
									(nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_LT) ||
								    (nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_GT) ||
								    (nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_LTE) ||
								    (nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE));
							
							stmtValue = GetFormStr("in_tx_relativeval"  + prefix+ strTag, form);	
						    
							if (isRelative && ((null != stmtValue) && (stmtValue.length() > 0))) 
							{
							    /* 1) relativeval  == the numerical value from from
							     * 2) relativeunit == the unit measure (i.e. days, weeks) 
							     *                     as a negative
							     * 
							     * calculate the miliseconds 
							     * (i.e. relativeval * (how many ms in unit))
							     */
							    int units = XPConvert.ToInteger(GetFormStr("in_se_relativeunit"  + prefix+ strTag, form));
							    try
							    {
							        long longOrig = XPConvert.ToLong(stmtValue);

							        long max = QueryCondition.MAX_VALUE_DAY;
							        switch(-units)
							        {
							        	case QueryCondition.MS_PER_MIN:
							        		max = QueryCondition.MAX_VALUE_MIN;
							        		break;
							        	case QueryCondition.MS_PER_HOUR:
							        		max = QueryCondition.MAX_VALUE_HOUR;
							        		break;
							        	case QueryCondition.MS_PER_DAY:
							        		max = QueryCondition.MAX_VALUE_DAY;
							        		break;
							        	case QueryCondition.MS_PER_WEEK:
							        		max = QueryCondition.MAX_VALUE_WEEK;
							        		break;
							        	default:
							        		break;
							        }

								    if (max >= longOrig)
								    {
									    long val =  longOrig * units;
								        stmtValue = XPConvert.ToString(val);
								    }
							    }
							    catch (XPFormatException e)
							    {
							        /* if we can not convert to int, then just keep the original value */
							    }
							    
							    gotDate=false;
							}
							else
							{
								// If COMPARISON_VALUE_IF_DATE not present, see if there
								// was a datepicker on a real web page
								// where someone entered a date.
	
								// First, we need the user's locale and timezone
								String locale =
									(String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE, asOwner);
								String timezone = 
									(String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE, asOwner);
								XPLocale xpLocale = null;
								XPTimeZone xpTimeZone = null;
	
								if (null != locale) {
									xpLocale = new XPLocale(locale);
								} else {
									xpLocale = XPLocale.GetDefault();
								}
	
								if (null != timezone) {
									xpTimeZone = XPTimeZone.GetTimeZone(timezone);
								} else {
									xpTimeZone = XPTimeZone.GetCurrentTimeZone();
								}
	
								// Now, look for a standard mode datepicker
								log.Debug("looking for standard mode dp " + xpLocale.GetDisplayLanguage());  
							    XPDateTime xpDT = ADatePickerComponent.GetDateTime(/* requestParameters= */ form,
														   /* instanceID= */ prefix + strTag,
														   /* locale= */ xpLocale, 
														   /* timezone= */ xpTimeZone,
														   /* doValidation= */ false,
														   /* accessStyle= */ AccessStyles.STANDARD);
                                
								if (null == xpDT) {
                                    log.Debug("looking for 508 mode dp " + xpLocale.GetDisplayLanguage());
									// If that didn't work, try 508-mode datepicker
									xpDT = ADatePickerComponent.GetDateTime(/* requestParameters= */ form,
															   /* instanceID= */ prefix + strTag,
															   /* locale= */ xpLocale,
															   /* timezone= */ xpTimeZone,
															   /* doValidation= */ false,
															   /* accessStyle= */ AccessStyles.SECTION_508);
								}
                                
								if (null == xpDT) {
                                    log.Debug("looking for relative dt " + xpLocale.GetDisplayLanguage());
									// Still nothing?  Well, maybe this is a relative time operator..
									if ((nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_LT) ||
									    (nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_GT) ||
									    (nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_LTE) ||
									    (nOp == PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE)) {

										// If so, EncodeFilterAsControlArgs() might have encoded the relative time as a String.. we can just use this as-is
										String relativeTime = GetFormStr(COMPARISON_VALUE  + prefix+ strTag, form);
										// if we got anything
										if ((null != relativeTime) && (relativeTime.length() > 0)) {
											// aha, use it
											gotDate = false;
											stmtValue = relativeTime;
										}
									}
								}

								// If we got a date, use it
								if (null != xpDT) {
									gotDate = true;
									stmtDateValue = xpDT;
								}
							}
						}
					}  // end if date type
					else if(type == PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP)
					{						
						// if memberof type, look for the COMPARISON_VALUE_MEMBER_OF
						stmtValue = GetFormStr(COMPARISON_VALUE_MEMBER_OF  + prefix+ strTag, form);
					} else
					{
						// if not date type, just look for COMPARISON_VALUE
						stmtValue = GetFormStr(COMPARISON_VALUE  + prefix+ strTag, form);
					}
	
					// If got no value and it's okay to ignore blank lines
					if (ignoreBlanks &&
							(((null == stmtValue) || (stmtValue.length() == 0)) && (! gotDate)))
					{
						// skip this statement
						continue;
					}
	
					// If got a date value
					if (gotDate) 
					{
						// store our XPDateTime version in the filter
						statement.SetValue(stmtDateValue);
					} else {
						// store our String version in the filter
						statement.SetValue(stmtValue);
					}
				}

				// Add statement to clause
			    clause.AddItem(statement, actualStatementCount);
			    actualStatementCount++;
			}

			// add a statement to this clause, if requested and if we're not at the
			// max number of statements
			if (addStatementTo == i)
			{
				// check the max number of statements for this clause
				int maxStatements = GetFormInt(MAX_STMTS  + prefix+ strID, form);

				// if there is no max or if we haven't reached the max
				if ((maxStatements == 0) || (statementcount < maxStatements))
				{
					// create a statement with default parameters and add it
					IPTPropertyFilterStatement statement = (IPTPropertyFilterStatement) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
					statement.SetOperand( /* property NAME */
						1);
					statement.SetOperator(PT_FILTEROPS.PT_FILTEROP_CONTAINS);
					statement.SetValue("");

					clause.AddItem(statement, statementcount);
				}
			}

			// this will be recorded as the current parent clause at this depth
			clausehash.PutElement(XPConvert.ToString(depth), clause);

			if (-1 == (depth - 1))
			{
				filter.SetPropertyFilter(clause);
			}
			else
			{
				IPTPropertyFilterClauses parentclause = (IPTPropertyFilterClauses) clausehash.GetElement(XPConvert.ToString(depth -
							1));
				parentclause.AddItem(clause, parentclause.GetCount());
			}

			// and finally add a group if requested
			if (AddGroupTo == i)
			{
				IPTPropertyFilterClauses NewClause = (IPTPropertyFilterClauses) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);
				clause.AddItem(NewClause, clause.GetCount());
			}
		}

		return filter;
	}

	/**
	 *  This method does the inverse of BuildFilterFromForm.
	 *  It returns true if the filter is valid (may be used for a search,
	 *  e.g. has no empty comparison values), false otherwise.
	 */
	public static boolean EncodeFilterAsControlArgs(IPTSession session,
		AActivitySpace owner, IPTFilter filter, IXPDictionary hash)
	{
		return EncodeFilterAsControlArgs(session, owner, filter, hash, "");
	}

	/**
	 *  This method does the inverse of BuildFilterFromForm.
	 *  It returns true if the filter is valid (may be used for a search,
	 *  e.g. has no empty comparison values), false otherwise.
	 */
	public static boolean EncodeFilterAsControlArgs(IPTSession session,
		AActivitySpace owner, IPTFilter filter, IXPDictionary hash,
		String prefix)
	{
		boolean filterValid = true;

		// Set the top-level operator
		int nOperator = filter.GetOperator();

		if (PT_BOOLOPS.PT_BOOLOP_AND == nOperator)
		{
			hash.PutElement(TOP_OPERATOR + prefix, new String[] { OPERATOR_AND });
		}
		else
		{
			hash.PutElement(TOP_OPERATOR + prefix, new String[] { OPERATOR_OR });
		}

		// Set the full-text string
		String searchString = filter.GetSearchString();
		hash.PutElement(FULL_TEXT + prefix, new String[] { searchString });

		// Create an iterator over the filter
		FilterIterator iter = new FilterIterator(session, filter, owner);

		// We'll need to know types of properties
		IASQueryResult propertyInfo = iter.GetPropertiesVisibleToCurrentUser();

		int clauseCount = 0;
		int stmtCount   = 0;

		// Iterate over clauses
		while (iter.GetNextClausePosition())
		{
			clauseCount++;

			String clauseTag = XPConvert.ToString(clauseCount);

			// Set clause depth
			int depth = iter.GetCurrentClauseDepth();
			hash.PutElement(DEPTH_PREFIX  + prefix+ clauseTag,
				new String[] { XPConvert.ToString(depth) });

			// Set clause operator
			boolean cOperator = iter.GetCurrentClauseOperator(); // TRUE <-> AND

			if (cOperator)
			{
				hash.PutElement(GROUP_OPERATOR  + prefix+ clauseTag,
					new String[] { OPERATOR_AND });
				
				hash.PutElement("in_hi_groupoperator_"  + prefix+ clauseTag,
						new String[] { OPERATOR_AND });				
			}
			else
			{
				hash.PutElement(GROUP_OPERATOR  + prefix+ clauseTag,
					new String[] { OPERATOR_OR });
				
				hash.PutElement("in_hi_groupoperator_"  + prefix+ clauseTag,
						new String[] { OPERATOR_OR });
			}

			// Now, statements within this clause
			stmtCount = 0;

			IPTPropertyFilterStatement stmt = iter.GetNextStatement();

			while (null != stmt)
			{
				stmtCount++;

				String stmtTag = "_" + clauseTag + "_" +
					XPConvert.ToString(stmtCount);

				// Get all statement info
				int stmtProp   = stmt.GetOperand(); // PLUMTREE_ID
				int stmtOp     = stmt.GetOperator(); // PT_FILTEROPS

				// The property type needs to be encoded after the property ID.
				// To find the type, we need to loop over propertyInfo looking for this property id..
				int propType = -1;

				for (int j = 0; j < propertyInfo.GetCount(); j++)
				{
					if (XPConvert.ToInteger(propertyInfo.GetFields(j, PT_PROPIDS.PT_PROPID_OBJECTID)) == stmtProp)
					{
						// found it
						try
						{
							propType = XPConvert.ToInteger(propertyInfo.GetFields(j,
									PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
						}
						catch (Exception e)
						{
							throw XPException.GetInstance(e);
						}

						break;
					}
				}

				// if not found must be an integer prop without info.
				if (-1 == propType)
				{
				    hash.PutElement(INTRINSIC_HIDDEN  + prefix+ stmtTag,
					    new String[]
					    {
						    XPConvert.ToString(stmtProp) 
					    });
				    hash.PutElement(INTRINSIC_OP_HIDDEN  + prefix+ stmtTag,
					    new String[] { XPConvert.ToString(stmtOp) });

          			String stmtVal = stmt.GetValueAsString();

         			if (((null == stmtVal) || (0 == stmtVal.length())) &&
              				OperatorRequiresValue(stmtOp)) {
            			filterValid = false;
          			}

					hash.PutElement(INTRINSIC_VAL_HIDDEN  + prefix+ stmtTag,
					    new String[] { stmtVal});

				}
				else 
				{ 

					String operatorElement = mapPropertyTypeToElement(propType);
	
					// Add property
					hash.PutElement(PROPERTY_SELECTED  + prefix+ stmtTag,
						new String[]
						{
							XPConvert.ToString(stmtProp) + "|" +
							XPConvert.ToString(propType)
						});
	
					// Add operator
					hash.PutElement(operatorElement  + prefix+ stmtTag,
						new String[] { XPConvert.ToString(stmtOp) });
	
					// Add value
					if ((propType == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE) &&
					    ((PT_FILTEROPS.PT_FILTEROP_RELATIVE_LT != stmtOp) &&
					     (PT_FILTEROPS.PT_FILTEROP_RELATIVE_GT != stmtOp) &&
					     (PT_FILTEROPS.PT_FILTEROP_RELATIVE_LTE != stmtOp) &&
					     (PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE != stmtOp)))
					{
						// Must initialize to something non-null
						XPDateTime stmtDateVal = new XPDateTime();
	
						try {
							stmtDateVal = stmt.GetValueAsXPDateTime();
						} catch (Exception e) {
							filterValid = false;
						}
	
						hash.PutElement(COMPARISON_VALUE_IF_DATE  + prefix+ stmtTag,
	                    			      new String[] { XPConvert.ToString(stmtDateVal.GetTimeInMilliSeconds()) } );
					}
					else if(propType == PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP)
					{
						String stmtVal = stmt.GetValueAsString();
						
						if (((null == stmtVal) || (0 == stmtVal.length())) &&
								OperatorRequiresValue(stmtOp)) 
						{
							filterValid = false;
						}
	
						hash.PutElement(COMPARISON_VALUE_MEMBER_OF  + prefix+ stmtTag,
							new String[] { stmtVal });
					} else
					{
						String stmtVal = stmt.GetValueAsString();
	
						if (((null == stmtVal) || (0 == stmtVal.length())) &&
								OperatorRequiresValue(stmtOp)) 
						{
							filterValid = false;
						}
	
						hash.PutElement(COMPARISON_VALUE  + prefix+ stmtTag,
							new String[] { stmtVal });
					}
				}

				// Move to next statement
				stmt = iter.GetNextStatement();
			}
			 // end loop over statements in one clause

			// Add number of statements in clause
			hash.PutElement(REVEALED  + prefix+ clauseTag,
				new String[] { XPConvert.ToString(stmtCount) });
		}
		 // end loop over clauses

		// finally, set the number of clauses
		hash.PutElement(TOTAL_GROUPS + prefix,
			new String[] { XPConvert.ToString(clauseCount) });

		// One last check: if there is no search string and no property constraints,
		// the filter is invalid
		if (((null == searchString) || (0 == searchString.length())) &&
				((0 == clauseCount) ||
				((1 == clauseCount) && (0 == stmtCount))))
		{
			filterValid = false;
		}

		return filterValid;
	}

	/**
	 * 
	 *
	 * @param operator 
	 *
	 * @return 
	 */
	public static boolean OperatorRequiresValue(int iOperator)
	{
		// "is empty" is actually "contains no value"
		return (iOperator != PT_FILTEROPS.PT_FILTEROP_ISEMPTY);
	}

	/**
	 * 
	 *
	 * @param strKey 
	 * @param form 
	 *
	 * @return 
	 */
	private static int GetFormInt(String strKey, IXPDictionary form)
	{
		String[] data;
		int n = 0;

		data = (String[]) form.GetElement(strKey);

		if ((null != data) && !(0 == data.length))
		{
			try
			{
				n = XPConvert.ToInteger((String) data[0]);
			}
			catch (Exception e)
			{
				throw XPException.GetInstance(e);
			}
		}

		return n;
	}

	/**
	 * 
	 *
	 * @param strKey 
	 * @param form 
	 *
	 * @return 
	 */
	private static String GetFormStr(String strKey, IXPDictionary form)
	{
		String[] data;
		String strValue = "";

		data = (String[]) form.GetElement(strKey);

		if ((null != data) && !(0 == data.length))
		{
			strValue = data[0];
		}

		return strValue;
	}

	/**
	 * 
	 *
	 * @param propType 
	 *
	 * @return 
	 */
	private static String mapPropertyTypeToElement(int propType)
	{
		switch (propType)
		{
		case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
		case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
			return OPERATOR_NUMERIC;

		case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
			return OPERATOR_DATE;

		case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
		case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
			return OPERATOR_TEXT;
		
		case PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP:
			return OPERATOR_MEMBER_OF;

		default:
			return OPERATOR_NUMERIC; // hmmm...why?
		}
	}

	public static JSDateTimePickerMgr MakeTempDateTimePickerMgr(AActivitySpace asOwner)
	{
		// Get the user's locale and timezone
		String locale =
			(String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE, asOwner);
		String timezone = 
			(String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE, asOwner);
		XPLocale xpLocale = null;
		XPTimeZone xpTimeZone = null;
		
		if (null != locale) {
			xpLocale = new XPLocale(locale);
		} else {
			xpLocale = XPLocale.GetDefault();
		}
		
		if (null != timezone) {
			xpTimeZone = XPTimeZone.GetTimeZone(timezone);
		} else {
			xpTimeZone = XPTimeZone.GetCurrentTimeZone();
		}
		
		String  strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(asOwner.GetIsSecuredSpace());
		PageMgr pageMgr = new PageMgr(asOwner.GetAccessStyle(), xpLocale, xpTimeZone, strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(asOwner));
		JSRegistry jsRegistry = JSRegistry.GetRegistry(strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(asOwner));
		
		// Finally, initialize the datetime picker manager
		return  new JSDateTimePickerMgr(jsRegistry, new JSDatePickerVersionMgr(), pageMgr);
	}

}

