package com.plumtree.portaluiinfrastructure.filter;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * @author CraigS, based on MikeS code
 */
public class FlattenedFilter
{
	private Object[][] m_FilterItems = null;
	private int m_MaxFilterItems;

	/**
	 * Creates a new FlattenedFilter object.
	 *
	 * @param filter 
	 */
	public FlattenedFilter(IPTFilter filter)
	{
		m_FilterItems = new Object[50][2];		
		LoadFromFilter(filter);
	}

	/**
	 * 
	 *
	 * @param position 
	 *
	 * @return 
	 */
	public IPTPropertyFilterItem GetItem(int position)
	{
		return (IPTPropertyFilterItem) m_FilterItems[position][0];
	}

	/**
	 * 
	 *
	 * @param position 
	 *
	 * @return 
	 */
	public int GetItemDepth(int position)
	{
		return XPConvert.ToInteger(m_FilterItems[position][1]);
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumItems()
	{
		return m_MaxFilterItems;
	}

	/**
	 * 
	 *
	 * @param filter 
	 */
	private void LoadFromFilter(IPTFilter filter)
	{
		m_MaxFilterItems = 0;

		IPTPropertyFilterItem fi = filter.GetPropertyFilter();
		
		/* if this is a top level statment, then create a clause wrapper so that
		 * the ui can handle it.
		 */
		if (null != fi)
		{
			if (PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT == fi.GetType())
			{
				int op = filter.GetOperator();
				IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);
				clause.AddItem(fi, -1);
				clause.SetOperator(op);
				filter.ClearPropertyFilter();
				filter.SetPropertyFilter(clause);
				fi = filter.GetPropertyFilter();
			}

		}
		RecursiveLoadItems(fi, 0);
	}

	/**
	 * 
	 *
	 * @param fi 
	 * @param level 
	 */
	private void RecursiveLoadItems(IPTPropertyFilterItem fi, int level)
	{
		if (null == fi)
		{
			return;
		}

		m_FilterItems[m_MaxFilterItems][0]     = fi;
		m_FilterItems[m_MaxFilterItems][1]     = new Integer(level);
		m_MaxFilterItems++;

		// If this item is a clause
		if (PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT != fi.GetType())
		{
			IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) fi;
			XPArrayList clauseList		    = new XPArrayList();

			// we're only interested in statements first
			for (int i = 0; i < clause.GetCount(); i++)
			{
				IPTPropertyFilterItem nextItem = clause.GetItem(i);

				if (PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT == nextItem.GetType())
				{
					m_FilterItems[m_MaxFilterItems][0]     = nextItem;
					m_FilterItems[m_MaxFilterItems][1]     = new Integer(level);
					m_MaxFilterItems++;
				}
				else
				{
					clauseList.Add(nextItem);
				}
			}

			level++;

			for (int j = 0; j < clauseList.GetSize(); j++)
			{
				RecursiveLoadItems((IPTPropertyFilterItem) clauseList.GetElement(
						j), level);
			}
		}
	}
}

