package com.plumtree.portaluiinfrastructure.filter;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.pagecontrols.datepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author sample, modified substantially by CraigS
 *
 *  This class generates html necessary to construct a single
 *  query condition against the array of properties passed in
 */
public class QueryCondition
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.filter.QueryCondition");

	private AActivitySpace m_asOwner;
	private int _stmtPropertyID;
	private int _typeOfSelectedProperty;
	private int _stmtOperator;
	private String _stringValue;
	private boolean _bRelativeValue;
	private XPDateTime _dtValue;
	private boolean _dtValueInitialized;

	private XPArrayList _propertyKeys;
	private XPArrayList _propertyValues;
	private boolean _visible;
	
	// aj: bug 42237, need different operators if this is a dgroup...
	private boolean _bIsDynamicGroupView;

	// aj: bug 45002, need an IPTSession to resolve group object ids to names
	private IPTSession _session;
	private XPHashtable _htGroupNameCache;
	
  	private PTStyleClass _styleClass;
  	private boolean _padCheckBox = false;
  	private PageMgr m_ptPageMgr;

  	private String _formname;
  	private String _divID;

	// aj: JavaScript function names for "Group Chooser" (Member Of type props)
  	public static final String JAVASCRIPT_OPEN_GROUP_CHOOSER = "OpenGroupChooser";
  	public static final String JAVASCRIPT_GROUP_CHOOSER_GETVALUE = "GetValueFromGroupChooser";
  	public static final String HTMLHIDDEN_ROWINDEX = "in_hi_groupChooser_rowIndex";
  	public static final String HTMLHIDDEN_ROWINDEX_ID = "groupChooser_rowIndex";
  	public static final String SUBSPACE_KEY_GROUP_CHOOSER = "GroupChooserSubSpace";

  	/* relative unit constants */
  	public final static int MS_PER_MIN 		= 60000;
  	public final static int MS_PER_HOUR		= 3600000;
  	public final static int MS_PER_DAY 		= 86400000;
    public final static int MS_PER_WEEK		= 604800000;
    public final static long MAX_VALUE_MIN 	= Long.MAX_VALUE/MS_PER_MIN;
    public final static long MAX_VALUE_HOUR	= Long.MAX_VALUE/MS_PER_HOUR;
    public final static long MAX_VALUE_DAY 	= Long.MAX_VALUE/MS_PER_DAY;
    public final static long MAX_VALUE_WEEK = Long.MAX_VALUE/MS_PER_WEEK;
    
    /* relative data array indices */
    public final static int IDX_RELATIVEDATA_UNITS 	= 0;
    public final static int IDX_RELATIVEDATA_VALUE 	= 1;
    public final static int IDX_RELATIVEDATA_MAX 	= 2;
    
    /* property info array indices */
    public final static int IDX_PROPINFO_ID 	= 0;
    public final static int IDX_PROPINFO_NAME	= 1;
    public final static int IDX_PROPINFO_TYPE 	= 2;

	/**
	 * Creates a new QueryCondition object.
	 *
	 * @param owner owning activity space
	 */
	public QueryCondition(AActivitySpace owner)
	{
		m_asOwner = owner;
		_visible = false;
		_bIsDynamicGroupView = false;

		_propertyKeys = new XPArrayList();
		_propertyValues = new XPArrayList();

		_styleClass = null;

		_formname = "mainform";
		_divID = "dpDiv";
		
		// aj: set the session to null
		_session = null;
		_htGroupNameCache = new XPHashtable(10);
	}
	
	/**
	 * Creates a new QueryCondition object with a reference to the current
	 * user's session.  This constructor is necessary to allow for group
	 * id to name resolution.
	 *
	 * @param owner owning activity space
	 * @param session the current user's session
	 */
	public QueryCondition(AActivitySpace owner, IPTSession session)
	{
		m_asOwner = owner;
		_visible = false;
		_bIsDynamicGroupView = false;

		_propertyKeys = new XPArrayList();
		_propertyValues = new XPArrayList();

		_styleClass = null;

		_formname = "mainform";
		_divID = "dpDiv";
		
		_session = session;
		_htGroupNameCache = new XPHashtable(10);
	}

	/**
	 *  Set the form name.
	 *  @param form name
	 */
	public void SetFormName(String formname)
	{
		_formname = formname;
	}

	/**
	 *  Set the dp div id.
	 *  @param div id
	 */
	public void SetDivID(String divID)
	{
	    _divID = divID;
	}

	/**
	 *  Set a background style class for this row.
	 *  @param styleClass desired style class
	 */
	public void SetStyleClass(PTStyleClass styleClass)
	{
		_styleClass = styleClass;
	}

	public void PadCheckBox(boolean val)
	{
		_padCheckBox = val;
	}

	/**
	 *  Make this QueryCondition visible or invisible
	 *  the next time the page is rendered
	 *  @param visible true for visible, false for invisible
	 */
	public void SetVisible(boolean visible) {
		_visible = visible;
	}
	
	/**
	 * Is this QueryCondition part of a dynamic group view?  If
	 * so, we should use the proper operators for that UI.
	 * 
	 * @param dynGroupView true for dgroup view, false for search & friends
	 */
	public void SetIsDynamicGroupView(boolean dynGroupView)
	{
		_bIsDynamicGroupView = dynGroupView;
	}

	/**
	 * Sets this condition to be selected to the indicated property ID, operator, and String value.
	 *
	 * @param propID property ID to select
	 * @param operator operator to select, must be valid for given property ID
	 * @param strValue value to select
	 */
	public void SetSelections(int propID, int iOperator, String strValue)
	{
		_stmtPropertyID = propID;
		_stmtOperator = iOperator;

		UpdateTypeForSelectedProperty();

		if (null!=strValue)
		{
		    _stringValue = strValue.trim();
		} 
		
		// Have to initialize this to something non-null for jumpability.
		_dtValue = new XPDateTime();
		_dtValueInitialized = false;
		
		/* if we are setting a string value and this prop is of type date, then treat it as relative */ 
		_bRelativeValue = (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == _typeOfSelectedProperty);
	}

	/**
	 * Sets this condition to be selected to the indicated property ID, operator, and date/time value.
	 *
	 * @param propID property ID to select
	 * @param operator operator to select, must be valid for given property ID
	 * @param ptdtValue value to select
	 */
	public void SetSelections(int propID, int iOperator, XPDateTime dtValue)
	{
		_stmtPropertyID = propID;
		_stmtOperator = iOperator;

		UpdateTypeForSelectedProperty();

		if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE != _typeOfSelectedProperty)
		{

				log.Error("Incorrect date value passed to QueryCondition.SetSelections.. expected STRING for this property type.");

		}

		_dtValue = dtValue;
		_dtValueInitialized = true;
		_stringValue = null; //jhq- when using date values, we don't use stringvalue, so it should be null'ed out. mgs -when the copy of this selection was made in the 2nd pass, the date value was being cleared out
		_bRelativeValue = false;
	}

	/**
	 * Creates a deep copy of this QueryCondition.
	 *
	 * @return the duplicate.
	 */
	public QueryCondition MakeDuplicate()
	{
		QueryCondition acopy = new QueryCondition(m_asOwner, _session);

		// Copy the property info
		IXPEnumerator keys   = _propertyKeys.GetEnumerator();
		IXPEnumerator values = _propertyValues.GetEnumerator();
		int[] vals		 = null;

		while (keys.MoveNext())
		{
			values.MoveNext();
			vals = (int[]) values.GetCurrent();
			acopy.AddProperty(XPConvert.ToString(keys.GetCurrent()), vals[0], vals[1]);
		}

		// If something has been selected
		if (_stmtPropertyID != 0)
		{
			// Copy the selections as well
			if (_dtValueInitialized) 
			{
				acopy.SetSelections(_stmtPropertyID, _stmtOperator, _dtValue);
			}
			else 
			{  //only do this if not an initalized date -mgs
				acopy.SetSelections(_stmtPropertyID, _stmtOperator, _stringValue);
			}
		}

		// Set same visible/invisible status
		acopy.SetVisible(_visible);
		
		// Set the is dynamic group view bool
		acopy.SetIsDynamicGroupView(_bIsDynamicGroupView);

		// Set same style class
		if (null != _styleClass) {
			acopy.SetStyleClass(_styleClass);
		}

		// set same form name
		if (null != _formname)
		{
		    acopy.SetFormName(_formname);
		}

		// set div tag id
		if (null != _divID)
		{
		    acopy.SetDivID(_divID);
		}

		return acopy;
	}

	/**
	 *
	 *
	 * @param strTag
	 * @param strStatementID
	 * @param showError
	 *
	 * @return
	 */
	public HTMLElement GetTableRow(String strTag, String strStatementID,
                                 boolean showError, boolean showRemovalCheckbox,
                                 JSDateTimePickerMgr jsDateTimePickerMgr, PageMgr _ptPageMgr, boolean jitDatePicker)
	{
		//Checking if pathways is enabled
	    IPathwaysRestAPIService pathwaysHelper = PathwaysRestAPIService.GetInstance(m_asOwner);

	    //If Pathways is enabled, we must alter the operators for each property to only list the CONTAINS operator as
	    // currently this is the only operator pathways search supports.
	    if ( pathwaysHelper.IsPathwaysEnabled() )
	    {
	    	return GetPathwaysTableRow("", strTag, strStatementID, showError, showRemovalCheckbox,
	    			jsDateTimePickerMgr, _ptPageMgr, jitDatePicker);
	    }
	    else{
	    	return GetTableRow("", strTag, strStatementID, showError, showRemovalCheckbox,
	    			jsDateTimePickerMgr, _ptPageMgr, jitDatePicker);
	    }
	}

	/**
	 *
	 *
	 * @param strTag
	 * @param strStatementID
	 * @param showError
	 *
	 * @return
	 */
	public HTMLElement GetTableRow(String strPrefix, String strTag, String strStatementID,
                                 boolean showError, boolean showRemovalCheckbox,
                                 JSDateTimePickerMgr jsDateTimePickerMgr, PageMgr _ptPageMgr, boolean jitDatePicker)
	{
		m_ptPageMgr = _ptPageMgr;
		HTMLTableRow row = new HTMLTableRow();
		String strID     = strPrefix+"_" + strTag + "_" + strStatementID;

		try
		{
		    String sCurValue = _stringValue;
		    
			/* get relative data */
		    Object[] arRelativeData = GetRelativeData(_stringValue);
		    if (_bRelativeValue)
		    {
				sCurValue = XPConvert.ToString(arRelativeData[IDX_RELATIVEDATA_VALUE]);
		    }
		    
      		if (null != _styleClass) {
        		row.SetStyleClass(_styleClass);
     		} else {
        		row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      		}

            // removal checkbox..
            if (showRemovalCheckbox) {
	              HTMLTableCell cbCell = new HTMLTableCell();
	              row.AddInnerHTMLElement(cbCell);

	              HTMLInput removalCB = new HTMLInput(HTMLInputTypes.CHECKBOX,
	                      FilterForm.REMOVE_STMT_CHECKBOX + strID, "");
	              removalCB.SetValue("x");  // can be anything greater than 0 length
	              if(_padCheckBox)
	              {

	              cbCell.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;");
	              cbCell.AddInnerHTMLElement(removalCB);
	              cbCell.AddInnerHTMLString("&nbsp;");
				  }
				  else
				  {
				  	cbCell.SetWidth("20");
					cbCell.AddInnerHTMLElement(removalCB);
				  }
            }

			// let's build the select control...
			HTMLTableCell propCell = new HTMLTableCell();
			propCell.SetWidth("200");
			//propCell.SetAlign("absLeft");

			HTMLSelect myPropSelect = new HTMLSelect("in_se_PropSelect" +
					strID, "");
			myPropSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myPropSelect.SetID(strPrefix+strTag + "_PropSelect_" + strStatementID);
			myPropSelect.SetOnChange("AdjustOperator"+strPrefix+"('" + strPrefix+strTag +
				"', '" + strStatementID +
				"', this.options[this.selectedIndex].value);");

			IXPEnumerator keys   = _propertyKeys.GetEnumerator();
			IXPEnumerator values = _propertyValues.GetEnumerator();

			int[] vals		 = null;
			int selectedType = 0;

			while (keys.MoveNext())
			{
				values.MoveNext();
				vals = (int[]) values.GetCurrent();

				HTMLOption myOption = new HTMLOption(XPConvert.ToString(vals[0]) + "|" +
						XPConvert.ToString(vals[1]));

				if (vals[0] == _stmtPropertyID)
				{
					myOption.SetSelected(true);
					selectedType = vals[1];
				}

				myOption.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
						(String) keys.GetCurrent()));
				myPropSelect.AddInnerHTMLElement(myOption);
			}

			HTMLDiv tableCellDiv = new HTMLDiv();
			tableCellDiv.SetID(strTag + "_divPropRow_" + strStatementID);

			if (!_visible)
			{
				tableCellDiv.SetStyle("display: none;");
			}

			tableCellDiv.AddInnerHTMLElement(myPropSelect);
			propCell.AddInnerHTMLElement(tableCellDiv);
			row.AddInnerHTMLElement(propCell);

			// now we should construct the conditional operator elements
			// reviewing this you might be inclined to say that there is
			// enough repetition here to warrant a generic function for
			// generating the comparison drop downs.  unfortunately these
			// operator drop downs will probably never change so its more
			// trouble than its worth
			// first Text property operators...
			// this cell will contain all of the possible operator drop downs...
			HTMLTableCell propCellOperator = new HTMLTableCell();
			propCellOperator.SetWidth("150");
			//propCellOperator.SetAlign("absLeft");

			String strDisp  = ""; //"position:absolute;left:450;";
			HTMLDiv Textdiv = new HTMLDiv();

			Textdiv.SetID(strPrefix+strTag + "_divText_" + strStatementID);

			if (((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_STRING) ||
					(selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_REF)) && _visible)
			{
				Textdiv.SetStyle(strDisp);
			}
			else
			{
				Textdiv.SetStyle("display: none;");
			}
			
			HTMLSelect TextOpSelect = new HTMLSelect("in_se_OpText" + strID,
			        "in_se_OpText" + strID);
			TextOpSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			TextOpSelect.SetID(strPrefix+strTag + "_TextOpSelect_" + strStatementID);
			TextOpSelect.SetOnChange(
			        "ToggleStatementInput"+strPrefix+"(this.selectedIndex, '" + strPrefix+strTag + "', '" +
				strStatementID + "');");
		    
			HTMLOption Option1 = new HTMLOption(XPConvert.ToString(
					PT_FILTEROPS.PT_FILTEROP_CONTAINS));
		
			Option1.AddInnerHTMLString(m_asOwner.GetString(33,
			"ptmsgs_portalinfrastructure"));
		
			if (PT_FILTEROPS.PT_FILTEROP_CONTAINS == _stmtOperator)
			{
				Option1.SetSelected(true);
			}
		
			TextOpSelect.AddInnerHTMLElement(Option1);

			HTMLOption Option2 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_ISEMPTY));

			Option2.AddInnerHTMLString(m_asOwner.GetString(34,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_ISEMPTY == _stmtOperator)
			{
				Option2.SetSelected(true);
			}

			TextOpSelect.AddInnerHTMLElement(Option2);

			Textdiv.AddInnerHTMLElement(TextOpSelect);
			propCellOperator.AddInnerHTMLElement(Textdiv);

			// second, Date property operators...
			HTMLDiv Datediv = new HTMLDiv();

			Datediv.SetID(strPrefix+strTag + "_divDate_" + strStatementID);

			if ((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE) && _visible)
			{
				Datediv.SetStyle(strDisp);
			}
			else
			{
				Datediv.SetStyle("display: none;");
			}
			HTMLSelect DateOpSelect = new HTMLSelect("in_se_OpDate" + strID, "");
			DateOpSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			DateOpSelect.SetID(strPrefix+strTag + "_DateOpSelect_" + strStatementID);
			DateOpSelect.SetOnChange("ToggleDateInput"+strPrefix+"(this.selectedIndex, '" + strPrefix+strTag + "', '" +
				strStatementID + "');");


			HTMLOption Option3 = new HTMLOption(XPConvert.ToString(PT_FILTEROPS.PT_FILTEROP_GT));

			Option3.AddInnerHTMLString(m_asOwner.GetString(35,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_GT == _stmtOperator)
			{
				Option3.SetSelected(true);
			}

			DateOpSelect.AddInnerHTMLElement(Option3);

			HTMLOption Option4 = new HTMLOption(XPConvert.ToString(PT_FILTEROPS.PT_FILTEROP_LT));

			Option4.AddInnerHTMLString(m_asOwner.GetString(36,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_LT == _stmtOperator)
			{
				Option4.SetSelected(true);
			}

			DateOpSelect.AddInnerHTMLElement(Option4);

			HTMLOption Option5 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_EQ));

			Option5.AddInnerHTMLString(m_asOwner.GetString(37,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_EQ == _stmtOperator)
			{
				Option5.SetSelected(true);
			}

			DateOpSelect.AddInnerHTMLElement(Option5);

			HTMLOption Option6 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_NE));

			Option6.AddInnerHTMLString(m_asOwner.GetString(38,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_NE == _stmtOperator)
			{
				Option6.SetSelected(true);
			}

			DateOpSelect.AddInnerHTMLElement(Option6);


			// aj: bug 42237, dynamic groups don't support relative date/time
			if(!_bIsDynamicGroupView)
			{
				HTMLOption Option15 = new HTMLOption(XPConvert.ToString(
				        PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE));
	
				Option15.AddInnerHTMLString(m_asOwner.GetString(534,"ptmsgs_portalinfrastructure"));
	
				if (PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE == _stmtOperator)
				{
					Option15.SetSelected(true);
				}
	
				DateOpSelect.AddInnerHTMLElement(Option15);
			}

			Datediv.AddInnerHTMLElement(DateOpSelect);
			propCellOperator.AddInnerHTMLElement(Datediv);

			// third, the numeric operators
			HTMLDiv Numberdiv = new HTMLDiv();

			Numberdiv.SetID(strPrefix+strTag + "_divNumber_" + strStatementID);

			if (((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_LONG) ||
					(selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE)) && _visible)
			{
				Numberdiv.SetStyle(strDisp);
			}
			else
			{
				Numberdiv.SetStyle("display: none;");
			}

			HTMLSelect NumberOpSelect = new HTMLSelect("in_se_OpNumber" +
					strID, "");
			NumberOpSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			HTMLOption Option7 = new HTMLOption(XPConvert.ToString(PT_FILTEROPS.PT_FILTEROP_GT));

			Option7.AddInnerHTMLString(m_asOwner.GetString(39,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_GT == _stmtOperator)
			{
				Option7.SetSelected(true);
			}

			NumberOpSelect.AddInnerHTMLElement(Option7);

			HTMLOption Option8 = new HTMLOption(XPConvert.ToString(PT_FILTEROPS.PT_FILTEROP_LT));

			Option8.AddInnerHTMLString(m_asOwner.GetString(40,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_LT == _stmtOperator)
			{
				Option8.SetSelected(true);
			}

			NumberOpSelect.AddInnerHTMLElement(Option8);

			HTMLOption Option9 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_EQ));

			Option9.AddInnerHTMLString(m_asOwner.GetString(37,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_EQ == _stmtOperator)
			{
				Option9.SetSelected(true);
			}

			NumberOpSelect.AddInnerHTMLElement(Option9);

			HTMLOption Option10 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_NE));

			Option10.AddInnerHTMLString(m_asOwner.GetString(38,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_NE == _stmtOperator)
			{
				Option10.SetSelected(true);
			}

			NumberOpSelect.AddInnerHTMLElement(Option10);

			HTMLOption Option11 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_GTE));

			Option11.AddInnerHTMLString(m_asOwner.GetString(41,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_GTE == _stmtOperator)
			{
				Option11.SetSelected(true);
			}

			NumberOpSelect.AddInnerHTMLElement(Option11);

			HTMLOption Option12 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_LTE));

			Option12.AddInnerHTMLString(m_asOwner.GetString(42,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_LTE == _stmtOperator)
			{
				Option12.SetSelected(true);
			}

			NumberOpSelect.AddInnerHTMLElement(Option12);

			Numberdiv.AddInnerHTMLElement(NumberOpSelect);
			propCellOperator.AddInnerHTMLElement(Numberdiv);

			// aj: finally the membership operators
			HTMLDiv Memberdiv = new HTMLDiv();

			Memberdiv.SetID(strPrefix+strTag + "_divMember_" + strStatementID);

			if ((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP) && _visible)
			{
				Memberdiv.SetStyle(strDisp);
			}
			else
			{
				Memberdiv.SetStyle("display: none;");
			}

			HTMLSelect MemberOpSelect = new HTMLSelect("in_se_OpMemberOf" + strID,
					"in_se_OpMemberOf" + strID);
			MemberOpSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			HTMLOption Option13 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_EQ));

			Option13.AddInnerHTMLString(m_asOwner.GetString(501,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_EQ == _stmtOperator)
			{
				Option13.SetSelected(true);
			}

			MemberOpSelect.AddInnerHTMLElement(Option13);

			HTMLOption Option14 = new HTMLOption(XPConvert.ToString(
						PT_FILTEROPS.PT_FILTEROP_NE));

			Option14.AddInnerHTMLString(m_asOwner.GetString(502,
					"ptmsgs_portalinfrastructure"));

			if (PT_FILTEROPS.PT_FILTEROP_NE == _stmtOperator)
			{
				Option14.SetSelected(true);
			}

			MemberOpSelect.AddInnerHTMLElement(Option14);
		    
			Memberdiv.AddInnerHTMLElement(MemberOpSelect);
			propCellOperator.AddInnerHTMLElement(Memberdiv);

			row.AddInnerHTMLElement(propCellOperator);


			// and now the input element
			HTMLTableCell inputCell = new HTMLTableCell();
			inputCell.SetWidth("100%");
			//inputCell.SetAlign("absLeft");
			inputCell.SetNoWrap(true);

			HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT_TYPE,
			        "in_tx_compareval" + strID, "");
			input.SetStyleClass(PTStyleClass.FORM_TEXTBOX_TEXT);
			input.SetSize("40");
			if (null != sCurValue) {
				input.SetValue(sCurValue);
			}

			HTMLDiv CompareDiv = new HTMLDiv();
			CompareDiv.SetID(strPrefix+strTag + "_divCompareval_" + strStatementID);

			if ((!_visible) ||
					(PT_FILTEROPS.PT_FILTEROP_ISEMPTY == _stmtOperator))
			{
				CompareDiv.SetStyle("display: none;");
			}

			HTMLElement compareDivGuts = input;


			HTMLDiv CompareMemberDiv = new HTMLDiv();
			CompareMemberDiv.SetID(strPrefix+strTag + "_divCompareMember_" + strStatementID);

			if (!_visible)
			{
				CompareMemberDiv.SetStyle("display: none;");
			}

			// aj: we have three parts of the group chooser, first is the text/group name
			HTMLDiv groupNameDiv = new HTMLDiv();
			groupNameDiv.SetID(strPrefix+strTag + "_divGroupName_" + strStatementID);
			groupNameDiv.SetStyle("listText");
			String sGroupName = LookupGroupName(sCurValue);
			
			// aj: second is an anchor/icon to edit the group
			HTMLAnchor editGroupAnchor = GetGroupChooserOpenAnchor(strTag, strStatementID, sCurValue);
			groupNameDiv.AddInnerHTMLElement(editGroupAnchor);
			groupNameDiv.AddInnerHTMLString(sGroupName);

			// aj: third is a hidden value with the group id
			HTMLInput inputGroup = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE,
			        FilterForm.COMPARISON_VALUE_MEMBER_OF + strID, "");
			if (null != sCurValue) {
				inputGroup.SetValue(sCurValue);
			}


			HTMLElement compareMemberDivGuts = new HTMLDiv();
			compareMemberDivGuts.AddInnerHTMLElement(groupNameDiv);
			compareMemberDivGuts.AddInnerHTMLElement(inputGroup);

			
			// contains everything relative 
			HTMLDiv RelativeDiv = new HTMLDiv();
			RelativeDiv.SetID(strPrefix+strTag + "_divRelative_" + strStatementID);
			HTMLElement relativeDivGuts = new HTMLDiv();

			// relative time input box 
			input = new HTMLInput(HTMLInputTypes.TEXT_TYPE, "in_tx_relativeval" + strID, "");
			input.SetStyleClass(PTStyleClass.FORM_TEXTBOX_TEXT);
			input.SetSize("10");
			if (null != sCurValue)
			{
				input.SetValue(sCurValue);
			}
			relativeDivGuts.AddInnerHTMLElement(input);

			// relative time value dropdown 
			int nRelativeUnits = XPConvert.ToInteger(arRelativeData[IDX_RELATIVEDATA_UNITS]);
			HTMLSelect RelativeUnitSelect = new HTMLSelect("in_se_relativeunit" + strID,"in_se_relativeunit" + strID);
			RelativeUnitSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			// minutely option 
			HTMLOption RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_MIN));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(703,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_MIN==nRelativeUnits)
			{
			    RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			// hourly option 
			RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_HOUR));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(704,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_HOUR==nRelativeUnits)
			{
			    RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			// days option 
			RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_DAY));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(705,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_DAY==nRelativeUnits)
			{
			    RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			// weeks option 
			RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_WEEK));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(706,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_WEEK==nRelativeUnits)
			{
			    RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			relativeDivGuts.AddInnerHTMLElement(RelativeUnitSelect);


			HTMLDiv DateChooserDiv = new HTMLDiv();
			DateChooserDiv.SetID(strPrefix+strTag + "_divDateChooser_" + strStatementID);

			// Try to get the date/time picker for the current row
			Object objDateTimePicker = jsDateTimePickerMgr.GetComponent(strPrefix+strID);

			// If a date/time picker hasn't been created for this row
			if (null == objDateTimePicker)
			{

				// Create and register a new picker now.

				// We need a date/time to initialize it.  If _dtValue has been set,
				// use this, otherwise use the current time.

				XPDateTime xpDT = null;

				if (! _dtValueInitialized) {
					// initialize with current date/time
					xpDT = new XPDateTime();
				} else {
					// initialize with selected date/time
					xpDT = _dtValue;
				}

				// OK to actually create and register the picker now
				ADatePickerComponent jsDateTimePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DateTimePicker");
				jsDateTimePicker.Init(_formname,xpDT,
																			m_ptPageMgr,
																			strID);
				jsDateTimePickerMgr.RegisterComponent(jsDateTimePicker);

			}

			// Date/time picker for this row now exists.. get its HTML and display it

			HTMLElement dateChooserDivGuts = jsDateTimePickerMgr.GetComponentHTML(strID);
			if(((selectedType != PT_PROPERTY_TYPES.PT_PROPTYPE_DATE) || ! _visible) && jitDatePicker)
			{
				dateChooserDivGuts = FunctionalizeDateChooser(dateChooserDivGuts, strID, strPrefix+strTag + "_divDateChooser_" + strStatementID,jsDateTimePickerMgr, jitDatePicker);
			}
			
			HTMLSpan errorSpan = null;

			if (showError && _visible)
			{
				String errorString = ValidateSelections();

				if ((null != errorString) && (errorString.length() > 0))
				{
					errorSpan = new HTMLSpan();
					errorSpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
					errorSpan.AddInnerHTMLString(errorString);
				}
			}

			if ((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE) && _visible)
			{
				CompareDiv.SetStyle("display: none;");
				CompareMemberDiv.SetStyle("display: none;");

				if ((PT_FILTEROPS.PT_FILTEROP_RELATIVE_GT  == _stmtOperator) ||
			        (PT_FILTEROPS.PT_FILTEROP_RELATIVE_LT  == _stmtOperator) ||
			        (PT_FILTEROPS.PT_FILTEROP_RELATIVE_GTE == _stmtOperator) ||
			        (PT_FILTEROPS.PT_FILTEROP_RELATIVE_LTE == _stmtOperator))
			    {
					DateChooserDiv.SetStyle("display: none;");
					RelativeDiv.SetStyle(strDisp);
			    }
				else
				{
					DateChooserDiv.SetStyle(strDisp);
					RelativeDiv.SetStyle("display: none;");
				}

				if (null != errorSpan)
				{
					HTMLTable miniTable  = new HTMLTable();
					HTMLTableRow miniRow = new HTMLTableRow();
					miniTable.AddInnerHTMLElement(miniRow);

					HTMLTableCell miniCell = new HTMLTableCell();
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(dateChooserDivGuts);
					miniCell.AddInnerHTMLElement(relativeDivGuts);
					miniCell.SetNoWrap(true);

					miniCell = new HTMLTableCell();
					miniCell.SetNoWrap(true);
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(errorSpan);

					dateChooserDivGuts = miniTable;
				}
			}
			else if (((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP) && _visible))
			{
				DateChooserDiv.SetStyle("display: none;");
				CompareDiv.SetStyle("display: none;");
				CompareMemberDiv.SetStyle(strDisp);
				RelativeDiv.SetStyle("display: none;");

				if (null != errorSpan)
				{
					HTMLTable miniTable  = new HTMLTable();
					HTMLTableRow miniRow = new HTMLTableRow();
					miniTable.AddInnerHTMLElement(miniRow);

					HTMLTableCell miniCell = new HTMLTableCell();
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(compareMemberDivGuts);

					miniCell = new HTMLTableCell();
					miniCell.SetNoWrap(true);
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(errorSpan);

					compareMemberDivGuts = miniTable;
				}
			} else
			{
				DateChooserDiv.SetStyle("display: none;");
				CompareMemberDiv.SetStyle("display: none;");
				RelativeDiv.SetStyle("display: none;");

				if (null != errorSpan)
				{
					HTMLTable miniTable  = new HTMLTable();
					HTMLTableRow miniRow = new HTMLTableRow();
					miniTable.AddInnerHTMLElement(miniRow);

					HTMLTableCell miniCell = new HTMLTableCell();
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(compareDivGuts);

					miniCell = new HTMLTableCell();
					miniCell.SetNoWrap(true);
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(errorSpan);

					compareDivGuts = miniTable;
				}
			}
			
			CompareDiv.AddInnerHTMLElement(compareDivGuts);
			CompareMemberDiv.AddInnerHTMLElement(compareMemberDivGuts);
			DateChooserDiv.AddInnerHTMLElement(dateChooserDivGuts);
			RelativeDiv.AddInnerHTMLElement(relativeDivGuts);

			inputCell.AddInnerHTMLElement(CompareDiv);
			inputCell.AddInnerHTMLElement(CompareMemberDiv);
			inputCell.AddInnerHTMLElement(DateChooserDiv);
			inputCell.AddInnerHTMLElement(RelativeDiv);
			row.AddInnerHTMLElement(inputCell);
			
		}
		catch (Exception e)
		{

				log.Error(e, "QueryCondition::getDivTableRow: An error occured when trying to display the HTML.");


			throw new XPException(m_asOwner.GetString(32,
					"ptmsgs_portalinfrastructure"), e);
		}

		return row;
	}

	/**
	 * Checks that the current selections are valid and returns
	 * a localized error string if they are not
	 * @return localized error or empty string
	 */
	public String ValidateSelections()
	{
		String strWarning = "";

		// Handle the date case first as a special case
		if ((PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == _typeOfSelectedProperty) && !_bRelativeValue)
		{
			if ((!_dtValueInitialized) && (null == _stringValue))
			{
				// Value is required
				return m_asOwner.GetString(43, "ptmsgs_portalinfrastructure");
			}

			// Valid date
			return strWarning;
		}

		// For any other type, a string value must be set IF the operator is
		// anything other than "contains no value"
		if (FilterForm.OperatorRequiresValue(_stmtOperator)
			&& ((null == _stringValue) || (0 == _stringValue.length())))
		{
			return m_asOwner.GetString(43, "ptmsgs_portalinfrastructure");
		}

	    // For numeric types, make sure the string can be converted to the correct type
		/* or this is a relative date value which should be treated as a number even though the type is date */
		if ((PT_PROPERTY_TYPES.PT_PROPTYPE_LONG == _typeOfSelectedProperty) || _bRelativeValue)
	    {
			long value = 0;
	      	String trimmedString = _stringValue.trim();

			try
			{
				value = XPConvert.ToLong(trimmedString);
			}
			catch (Exception e)
			{
				log.Error(e, "Query condition unable to validate selection.");
			}

			// if it looks like we converted it to "0", but the string was anything but "0"
			if ((0 == value) && (!trimmedString.equals("0")))
			{
				strWarning = m_asOwner.GetString(44, "ptmsgs_portalinfrastructure");
			}

			// Another check.. I'm not sure if this is necessary but let's avoid taking it out..
			else if (!trimmedString.equals(XPConvert.ToString(value)))
			{
				strWarning = m_asOwner.GetString(44, "ptmsgs_portalinfrastructure");
			}
			
			// relative check - the value must be a multiple of days or weeks. if not, the value must
			// have been invalid.
			if (_bRelativeValue)
			{
			    Object[] arRelativeData = GetRelativeData(trimmedString);
			    
			    long max = XPConvert.ToLong(arRelativeData[IDX_RELATIVEDATA_MAX]);
				if (value > max)
				{
				    strWarning = "Comparison value cannot be larger than " + max;
				}
			}
	    }

	    /* seperated the double check from the long check... different types */
		else if (PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE == _typeOfSelectedProperty)
		{
			double value = 0.0;
			String trimmedString;

			if (_stringValue.equals("0"))
				trimmedString = "0.0";
			else
				trimmedString = _stringValue.trim();

			try
			{
				value = XPConvert.ToDouble(trimmedString);
			}
			catch (Exception e)
			{

					log.Error(e, "Query condition unable to validate selection.");

			}

			// if it looks like we converted it to "0", but the string was anything but "0"
			if ((0.0 == value) && (!trimmedString.equals("0.0")))
			{
				strWarning = m_asOwner.GetString(533, "ptmsgs_portalinfrastructure");
			}
			// this check is not needed, and it's in accurate because when a string representing
			// a double is larger than 10^7, the number is represented in computerized scientific
			// notation, so 11111000.0 is converted to 1.1111E7, and converting that back to 
			// a string will give us the following condition "11111000".equals("1.1111E7")==false
			// see bug #46530
//			// Another check.. I'm not sure if this is necessary but let's avoid taking it out..
//			else if (!trimmedString.equals(XPConvert.ToString(value)))
//			{
//				strWarning = m_asOwner.GetString(533, "ptmsgs_portalinfrastructure");
//			}
		}

		return strWarning;
	}

	/**
	 * Tell this QueryCondition about another property that could be selected.
	 *
	 * @param propName Name of property (localized)
	 * @param propID   ID of property
	 * @param propType Type of property (PT_PROPERTY_TYPES)
	 */
	public void AddProperty(String propName, int propID, int propType)
	{
		int[] arIDandType = new int[2];
		arIDandType[0]     = propID;
		arIDandType[1]     = propType;

		_propertyKeys.Add(propName);
		_propertyValues.Add(arIDandType);
	}


	/**
	 *  Helper method to lookup a property type given its ID
	 */
	public int GetTypeExpectedForProperty(int propID)
	{
		IXPEnumerator keys   = _propertyKeys.GetEnumerator();
		IXPEnumerator values = _propertyValues.GetEnumerator();
		int[] vals		 = null;

		while (keys.MoveNext())
		{
			values.MoveNext();
			vals = (int[]) values.GetCurrent();

			if (vals[0] == propID)
			{
				return vals[1];
			}
		}

		return 0;
	}

	public int GetStatementProperty()
	{
	    return _stmtPropertyID;
	}

	/**
	 *  Helper method to lookup a property given its ID
	 */
	public boolean ContainsProperty(int propID)
	{
		IXPEnumerator keys   = _propertyKeys.GetEnumerator();
		IXPEnumerator values = _propertyValues.GetEnumerator();
		int[] vals		 = null;

		while (keys.MoveNext())
		{
			values.MoveNext();
			vals = (int[]) values.GetCurrent();

			if (vals[0] == propID)
			{
				return true;
			}
		}

		return false;
	}

	/**
	 * The property IDs, Names, & Types that are in this condition.
	 *
	 * @return array of property info
	 */
	public Object[][] GetPropInfo()
	{
	    if (0==_propertyKeys.GetSize())
	    {
	        Object[][] zeroIDs = new Object[0][0];
	        return zeroIDs;
	    }

		IXPEnumerator keys   = _propertyKeys.GetEnumerator();
		IXPEnumerator values = _propertyValues.GetEnumerator();
		int[] vals		 = null;

		Object[][] arPropInfo = new Object[_propertyKeys.GetSize()][3];
		for (int i=0; keys.MoveNext(); i++)
		{
			values.MoveNext();
			vals = (int[]) values.GetCurrent();

			arPropInfo[i][IDX_PROPINFO_ID] 		= new Integer(vals[0]);
			arPropInfo[i][IDX_PROPINFO_NAME]	= keys.GetCurrent();
			arPropInfo[i][IDX_PROPINFO_TYPE]	= new Integer(vals[1]);
		}

		return arPropInfo;
	}

	/**
	 *  Helper method to lookup a property type given its ID
	 */
	private void UpdateTypeForSelectedProperty()
	{
		_typeOfSelectedProperty = GetTypeExpectedForProperty(_stmtPropertyID);
	}

	private HTMLElement FunctionalizeDateChooser(HTMLElement chooserScriptCollection, String strID, String dateDivId,
  									JSDateTimePickerMgr jsDateTimePickerMgr, boolean jitDatePicker)
	{
		XPStringBuilder sb = new XPStringBuilder();
		HTMLScript script  = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
				// TODO: Several of the constants below are private in JSDatePicker. Have them made public or
				// fold this code in there.
	  	sb.Append("var varName_" + strID + " = null;\n");
	  	sb.Append("function fxn" + dateDivId + "() {\n");
	  	sb.Append("    if( varName_"+ strID + " == null) {\n");
		sb.Append("        varName_" + strID + " = new PTDatepicker(");
		sb.Append( "\""+_divID+"\"," ); //DIV name TODO: This is private on the datepicker
		sb.Append( "\"" + "varName_" + strID + "\"," ); // var name - this needs to be unique TODO: This is private on the datepicker
		sb.Append( "\"" + _formname + "\"," ); //form name
		sb.Append( "\"" + "in_tx_DPInput_" + strID + "\"," ); //name for the input text box TODO: This is private on the datepicker
		sb.Append( "\"" + "in_bu_DPButton_" + strID + "\"," ); //name for the button TODO: This is private on the datepicker
		XPDateTime current = new XPDateTime();
		XPDateFormat formatter = XPDateFormat.GetDateInstance(XPDateFormat.MEDIUM);
		String date = formatter.Format(current);
		sb.Append( "\"" + date + "\"," ); //Default value
		sb.Append( "\"MMM d, yyyy\","); //Date format
		sb.Append( GetFirstDayOfWeek() + "," );

		String isurl = ConfigHelper.GetImageServerBaseURL(m_asOwner);

		String version = jsDateTimePickerMgr.GetVersionIDAsString();

		sb.Append( "\"" + isurl + "common/private/js/" + JSDateTimePickerMgr.STR_JS_COMPONENT_NAME + "/" + version + "/images/" + "\");\n" );
		sb.Append("         var dateDiv = document.getElementById(\"" + dateDivId + "\");\n");
	  	sb.Append("    		var text1 = varName_" + strID + ".writeControl(true);\n");
	  	sb.Append("         dateDiv.innerHTML = text1 + dateDiv.innerHTML;\n");
	  	sb.Append("     }\n");
	  	sb.Append("}\n");
	  	script.AddInnerHTMLString(sb.toString());
	  	IXPEnumerator list = chooserScriptCollection.GetInnerHTMLElements(false);
	  	HTMLElementCollection retval = new HTMLElementCollection();
	  	retval.AddInnerHTMLElement(script);
	  	while(list.MoveNext())
	  	{
	  		HTMLElement e = (HTMLElement)list.GetCurrent();
	  		if(! (e instanceof HTMLScript))
	  			retval.AddInnerHTMLElement(e);
		}
		return retval;
	}

	/**
	 * Returns anchor for add button
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Anchor for add button
	 *
	 * @throws Exception
	 */
	protected HTMLAnchor GetGroupChooserOpenAnchor(String _sGroupIndex, String _sRowIndex, String sCurValue)
	{
		HTMLAnchor myAnchor;
		HTMLImg myImage;
		PTConstruct myConstruct;
		XPStringBuilder sbOpenGroupChooser;

		// aj: create an anchor with the pencil image
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT, true, this.m_asOwner);
		myImage = (HTMLImg) myConstruct.GetHTMLElement();
		myAnchor.AddInnerHTMLElement(myImage);

		// aj: set alt text and image params
		myImage.SetAlt(m_asOwner.GetString(503, "ptmsgs_portalinfrastructure"));
		myImage.SetWidth("25");
		myImage.SetHeight("25");
		myImage.SetBorder(CommonHTMLStrings.ZERO);
		myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

		// aj: create the jscript link to the group chooser...
		sbOpenGroupChooser = new XPStringBuilder(100);
		sbOpenGroupChooser.Append(JAVASCRIPT_OPEN_GROUP_CHOOSER).Append("(");
		sbOpenGroupChooser.Append(PT_CLASSIDS.PT_USERGROUP_ID); // Append user group class ID
		sbOpenGroupChooser.Append(", '");
		sbOpenGroupChooser.Append(_sGroupIndex); // Append current group to modify
		sbOpenGroupChooser.Append("|");
		sbOpenGroupChooser.Append(_sRowIndex); // Append current row to modify
		sbOpenGroupChooser.Append("', ");
		sbOpenGroupChooser.Append(TreeConstants.N_LEAFSELECT);	// Append Leaf Select MODE
		sbOpenGroupChooser.Append(", ");
		sbOpenGroupChooser.Append((sCurValue != null && sCurValue.length() > 0)?("'"+sCurValue+"'"):("0"));// current value...
		sbOpenGroupChooser.Append("); return false;");
		myAnchor.SetOnClick(sbOpenGroupChooser.ToString());

		return myAnchor;
	}

	private String LookupGroupName(String sGroupID)
	{
		// aj: default is "None"
		String sResult = m_asOwner.GetString(148, ResourceConstants.PORTALINFRASTRUCTURE);
		
		if(sGroupID == null || sGroupID.equals(""))
		{
			return sResult;
		}

		// aj: try/catch the name resolution...
		try{
			sGroupID = XPStringUtility.Trim(sGroupID);
			int nGroupID = XPConvert.ToInteger(sGroupID);
			
			// aj: the session could be null depending on how
			//     the QueryCondition was initialized.  if it 
			//     is not available, we'll just use the group id
			if(_session != null)
			{
				// aj: check cache first
				if(_htGroupNameCache.ContainsKey(sGroupID))
				{
					sResult = XPConvert.ToString(_htGroupNameCache.GetElement(sGroupID));
				} else {
					Object[][] queryFilterObjID = 
						PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID,
							PT_FILTEROPS.PT_FILTEROP_EQ, new Integer(nGroupID));	

					IPTQueryResult pQueryResult = 
						_session.GetUserGroups().Query(PT_PROPIDS.PT_PROPID_NAME |
							PT_PROPIDS.PT_PROPID_OBJECTID, -1,
							PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1,
							queryFilterObjID);
					
					// aj: check that we got a match
					if(pQueryResult.RowCount() > 0)
					{
						// aj: grab first result, can't have dupes...
						sResult = pQueryResult.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
						
						// aj: add to cache
						_htGroupNameCache.PutElement(sGroupID, sResult);
					} else {
						// aj: invalid group id, use default of "None"
					}
				}
			} else {
				sResult = sGroupID;
			}
		} catch (Exception e)
		{
			// aj: ignore...
		}

		// aj: finally return the group id
		return sResult;
	}
	
	private static boolean IsLong(String _value)
	{
	    try
	    {
	        XPConvert.ToLong(_value);
	    }
	    catch (XPFormatException e)
	    {
	        return false;
	    }
	    
	    return true;
	}
	
	private static Object[] GetRelativeData(String _value)
	{
		Object[] arRelativeData = new Object[3];

		if (null!=_value && IsLong(_value))
	    {
		    /* convert to long */
		    long longValue = XPConvert.ToLong(_value);
		    
			/* calc the factor value and the unit value */
			long absValue = (longValue > 0) ? longValue : -longValue;
	
			if (0==absValue)
			{
			    arRelativeData[IDX_RELATIVEDATA_UNITS] = new Integer(-MS_PER_DAY);
			    arRelativeData[IDX_RELATIVEDATA_VALUE] = "0";
			    arRelativeData[IDX_RELATIVEDATA_MAX]   = new Long(MAX_VALUE_DAY);
			}
			else if (0 == (absValue % MS_PER_WEEK))
			{
			    arRelativeData[IDX_RELATIVEDATA_UNITS] = new Integer(-MS_PER_WEEK);
			    arRelativeData[IDX_RELATIVEDATA_VALUE] = XPConvert.ToString( (absValue / MS_PER_WEEK) );
			    arRelativeData[IDX_RELATIVEDATA_MAX]   = new Long(MAX_VALUE_WEEK);
			}
			else if (0 == (absValue % MS_PER_DAY))
			{
			    arRelativeData[IDX_RELATIVEDATA_UNITS] = new Integer(-MS_PER_DAY);
			    arRelativeData[IDX_RELATIVEDATA_VALUE] = XPConvert.ToString( (absValue / MS_PER_DAY) );
			    arRelativeData[IDX_RELATIVEDATA_MAX]   = new Long(MAX_VALUE_DAY);
			}
			else if (0 == (absValue % MS_PER_HOUR))
			{
			    arRelativeData[IDX_RELATIVEDATA_UNITS] = new Integer(-MS_PER_HOUR);
			    arRelativeData[IDX_RELATIVEDATA_VALUE] = XPConvert.ToString( (absValue / MS_PER_HOUR) );
			    arRelativeData[IDX_RELATIVEDATA_MAX]   = new Long(MAX_VALUE_HOUR);
			}
			else if (0 == (absValue % MS_PER_MIN))
			{
			    arRelativeData[IDX_RELATIVEDATA_UNITS] = new Integer(-MS_PER_MIN);
			    arRelativeData[IDX_RELATIVEDATA_VALUE] = XPConvert.ToString( (absValue / MS_PER_MIN) );
			    arRelativeData[IDX_RELATIVEDATA_MAX]   = new Long(MAX_VALUE_MIN);
			}
			else
			{
			    arRelativeData[IDX_RELATIVEDATA_UNITS] = new Integer(-MS_PER_DAY);
			    arRelativeData[IDX_RELATIVEDATA_VALUE] = _value;
			    arRelativeData[IDX_RELATIVEDATA_MAX]   = new Long(MAX_VALUE_DAY);
			}
	    }
		else
		{
		    arRelativeData[IDX_RELATIVEDATA_UNITS] = new Integer(-MS_PER_DAY);
		    arRelativeData[IDX_RELATIVEDATA_VALUE] = _value;
		    arRelativeData[IDX_RELATIVEDATA_MAX]   = new Long(MAX_VALUE_DAY);
	    }
		
		return arRelativeData;
	}
	
	/**
	 * Return the first day of the week int which is locale-specific.
	 * 
	 * @return int representing first day of week.
	 */
	private int GetFirstDayOfWeek()
	{
		XPCalendar xpCalendar = XPCalendar.GetInstance(
				m_ptPageMgr.GetTimeZone(),
				m_ptPageMgr.GetLocale());
		return  xpCalendar.GetFirstDayOfWeek();
	}
	
	/**
	 * This method lists the CONTAINS operator for each property object type in the search criteria filter for
	 * a pathways enabled advanced search
	 * @param strPrefix
	 * @param strTag
	 * @param strStatementID
	 * @param showError
	 * @param showRemovalCheckbox
	 * @param jsDateTimePickerMgr
	 * @param _ptPageMgr
	 * @param jitDatePicker
	 * @return
	 */
	//TODO fix
	public HTMLElement GetPathwaysTableRow(String strPrefix, String strTag, String strStatementID,
			boolean showError, boolean showRemovalCheckbox,
			JSDateTimePickerMgr jsDateTimePickerMgr, PageMgr _ptPageMgr, boolean jitDatePicker)
	{
		m_ptPageMgr = _ptPageMgr;
		HTMLTableRow row = new HTMLTableRow();
		String strID     = strPrefix+"_" + strTag + "_" + strStatementID;

		try
		{
			String sCurValue = _stringValue;

			/* get relative data */
			Object[] arRelativeData = GetRelativeData(_stringValue);
			if (_bRelativeValue)
			{
				sCurValue = XPConvert.ToString(arRelativeData[IDX_RELATIVEDATA_VALUE]);
			}

			if (null != _styleClass) {
				row.SetStyleClass(_styleClass);
			} else {
				row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			}

			// removal checkbox..
			if (showRemovalCheckbox) {
				HTMLTableCell cbCell = new HTMLTableCell();
				row.AddInnerHTMLElement(cbCell);

				HTMLInput removalCB = new HTMLInput(HTMLInputTypes.CHECKBOX,
						FilterForm.REMOVE_STMT_CHECKBOX + strID, "");
				removalCB.SetValue("x");  // can be anything greater than 0 length
				if(_padCheckBox)
				{

					cbCell.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;");
					cbCell.AddInnerHTMLElement(removalCB);
					cbCell.AddInnerHTMLString("&nbsp;");
				}
				else
				{
					cbCell.SetWidth("20");
					cbCell.AddInnerHTMLElement(removalCB);
				}
			}

			// let's build the select control...
			HTMLTableCell propCell = new HTMLTableCell();
			propCell.SetWidth("200");
			//propCell.SetAlign("absLeft");

			HTMLSelect myPropSelect = new HTMLSelect("in_se_PropSelect" +
					strID, "");
			myPropSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myPropSelect.SetID(strPrefix+strTag + "_PropSelect_" + strStatementID);
			myPropSelect.SetOnChange("AdjustOperator"+strPrefix+"('" + strPrefix+strTag +
					"', '" + strStatementID +
			"', this.options[this.selectedIndex].value);");

			IXPEnumerator keys   = _propertyKeys.GetEnumerator();
			IXPEnumerator values = _propertyValues.GetEnumerator();

			int[] vals		 = null;
			int selectedType = 0;

			while (keys.MoveNext())
			{
				values.MoveNext();
				vals = (int[]) values.GetCurrent();

				HTMLOption myOption = new HTMLOption(XPConvert.ToString(vals[0]) + "|" +
						XPConvert.ToString(vals[1]));

				if (vals[0] == _stmtPropertyID)
				{
					myOption.SetSelected(true);
					selectedType = vals[1];
				}

				myOption.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
						(String) keys.GetCurrent()));
				myPropSelect.AddInnerHTMLElement(myOption);
			}

			HTMLDiv tableCellDiv = new HTMLDiv();
			tableCellDiv.SetID(strTag + "_divPropRow_" + strStatementID);

			if (!_visible)
			{
				tableCellDiv.SetStyle("display: none;");
			}

			tableCellDiv.AddInnerHTMLElement(myPropSelect);
			propCell.AddInnerHTMLElement(tableCellDiv);
			row.AddInnerHTMLElement(propCell);

			
			// now we should construct the conditional operator elements
			// reviewing this you might be inclined to say that there is
			// enough repetition here to warrant a generic function for
			// generating the comparison drop downs.  unfortunately these
			// operator drop downs will probably never change so its more
			// trouble than its worth
			// first Text property operators...
			// this cell will contain all of the possible operator drop downs...
			HTMLTableCell propCellOperator = new HTMLTableCell();
			propCellOperator.SetWidth("150");
			//propCellOperator.SetAlign("absLeft");	
			
			// Bug fix 9373312 - NLS: WORD WRAP ISN OT GOOD FOR ASIAN LOCALE IN ADVANCE SEARCH LAYOUT
			// adding alignment and width to the operand in search criteria filter for each property type
			String strDisp = "text-align:center; width:60"; // "position:absolute;left:450;";
			String strDispNone = "text-align:center; width:60; display:none";
			HTMLDiv Textdiv = new HTMLDiv();

			Textdiv.SetID(strPrefix+strTag + "_divText_" + strStatementID);

			if (((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_STRING) ||
					(selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_REF)) && _visible)
			{
				Textdiv.SetStyle(strDisp);
			}
			else
			{
				Textdiv.SetStyle(strDispNone);
			}

			//below is the section that populates the filter in the search criteria with the correct operators
			// based on the object type of the property.  In order to integrate Pathways search, I will have to limit
			// the selection of operators to CONTAINS only for all object types.  

			//Text operators, we are creating CONTAINS
			
			HTMLGenericElement TextOpSelect = new HTMLGenericElement(m_asOwner.GetString(33,
			"ptmsgs_portalinfrastructure"));
			TextOpSelect.SetID(strPrefix+strTag + "_TextOpSelect_" + strStatementID);

			Textdiv.AddInnerHTMLElement(TextOpSelect);

			propCellOperator.AddInnerHTMLElement(Textdiv);

			// second, Date property operators, equivalent of CONTAINS for text objects = IS for date
			HTMLDiv Datediv = new HTMLDiv();

			Datediv.SetID(strPrefix+strTag + "_divDate_" + strStatementID);

			if ((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE) && _visible)
			{
				Datediv.SetStyle(strDisp);
			}
			else
			{
				Datediv.SetStyle(strDispNone);
			}
			
			HTMLGenericElement DateOpSelect = new HTMLGenericElement(m_asOwner.GetString(37,
			"ptmsgs_portalinfrastructure"));

			DateOpSelect.SetID(strPrefix+strTag + "_DateOpSelect_" + strStatementID);
			Datediv.AddInnerHTMLElement(DateOpSelect);
			propCellOperator.AddInnerHTMLElement(Datediv);

			// third, the numeric operators, limiting to IS operator
			HTMLDiv Numberdiv = new HTMLDiv();

			Numberdiv.SetID(strPrefix+strTag + "_divNumber_" + strStatementID);

			if (((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_LONG) ||
					(selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE)) && _visible)
			{
				Numberdiv.SetStyle(strDisp);
			}
			else
			{
				Numberdiv.SetStyle(strDispNone);
			}

			HTMLGenericElement NumberOpSelect = new HTMLGenericElement(m_asOwner.GetString(37,
			"ptmsgs_portalinfrastructure"));

			Numberdiv.AddInnerHTMLElement(NumberOpSelect);
			propCellOperator.AddInnerHTMLElement(Numberdiv);

			// TODO the membership, input, and relative operators below have been edited to only show one operator, 
			// the default one... however, I have been unable to create a property in the search criteria that would
			//display the relationship operator of greater than, less than, member of values so cannot further test
			//that the below operators will be used in the search criteria.  
			//It may be that the date operator invoked the greater than, less than operators which has already been edited
			//to only show the IS operator in that case, so the below code may not be needed, however, I'm leaving it in
			//in case there are other parts in the code that will need it.
			
			// aj: finally the membership operators
			HTMLDiv Memberdiv = new HTMLDiv();

			Memberdiv.SetID(strPrefix+strTag + "_divMember_" + strStatementID);

			if ((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP) && _visible)
			{
				Memberdiv.SetStyle(strDisp);
			}
			else
			{
				Memberdiv.SetStyle(strDispNone);
			}

			HTMLGenericElement MemberOpSelect = new HTMLGenericElement(m_asOwner.GetString(501,
			"ptmsgs_portalinfrastructure"));

			Memberdiv.AddInnerHTMLElement(MemberOpSelect);

			propCellOperator.AddInnerHTMLElement(Memberdiv);

			row.AddInnerHTMLElement(propCellOperator);


			// and now the input element
			HTMLTableCell inputCell = new HTMLTableCell();
			inputCell.SetWidth("100%");
			//inputCell.SetAlign("absLeft");
			inputCell.SetNoWrap(true);

			HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT_TYPE,
					"in_tx_compareval" + strID, "");
			input.SetSize("40");
			if (null != sCurValue) {
				input.SetValue(sCurValue);
			}

			HTMLDiv CompareDiv = new HTMLDiv();
			CompareDiv.SetID(strPrefix+strTag + "_divCompareval_" + strStatementID);

			if ((!_visible) ||
					(PT_FILTEROPS.PT_FILTEROP_ISEMPTY == _stmtOperator))
			{
				CompareDiv.SetStyle(strDispNone);
			}

			HTMLElement compareDivGuts = input;


			HTMLDiv CompareMemberDiv = new HTMLDiv();
			CompareMemberDiv.SetID(strPrefix+strTag + "_divCompareMember_" + strStatementID);

			if (!_visible)
			{
				CompareMemberDiv.SetStyle(strDispNone);
			}

			// aj: we have three parts of the group chooser, first is the text/group name
			HTMLDiv groupNameDiv = new HTMLDiv();
			groupNameDiv.SetID(strPrefix+strTag + "_divGroupName_" + strStatementID);
			groupNameDiv.SetStyle("listText");
			String sGroupName = LookupGroupName(sCurValue);

			// aj: second is an anchor/icon to edit the group
			HTMLAnchor editGroupAnchor = GetGroupChooserOpenAnchor(strTag, strStatementID, sCurValue);
			groupNameDiv.AddInnerHTMLElement(editGroupAnchor);
			groupNameDiv.AddInnerHTMLString(sGroupName);

			// aj: third is a hidden value with the group id
			HTMLInput inputGroup = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE,
					FilterForm.COMPARISON_VALUE_MEMBER_OF + strID, "");
			if (null != sCurValue) {
				inputGroup.SetValue(sCurValue);
			}


			HTMLElement compareMemberDivGuts = new HTMLDiv();
			compareMemberDivGuts.AddInnerHTMLElement(groupNameDiv);
			compareMemberDivGuts.AddInnerHTMLElement(inputGroup);


			// contains everything relative 
			HTMLDiv RelativeDiv = new HTMLDiv();
			RelativeDiv.SetID(strPrefix+strTag + "_divRelative_" + strStatementID);
			HTMLElement relativeDivGuts = new HTMLDiv();

			// relative time input box 
			input = new HTMLInput(HTMLInputTypes.TEXT_TYPE, "in_tx_relativeval" + strID, "");
			input.SetSize("10");
			if (null != sCurValue)
			{
				input.SetValue(sCurValue);
			}
			relativeDivGuts.AddInnerHTMLElement(input);

			// relative time value dropdown 
			int nRelativeUnits = XPConvert.ToInteger(arRelativeData[IDX_RELATIVEDATA_UNITS]);
			HTMLSelect RelativeUnitSelect = new HTMLSelect("in_se_relativeunit" + strID,"in_se_relativeunit" + strID);

			// minutely option 
			HTMLOption RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_MIN));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(703,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_MIN==nRelativeUnits)
			{
				RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			// hourly option 
			RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_HOUR));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(704,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_HOUR==nRelativeUnits)
			{
				RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			// days option 
			RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_DAY));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(705,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_DAY==nRelativeUnits)
			{
				RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			// weeks option 
			RelativeUnitOps = new HTMLOption(XPConvert.ToString(-MS_PER_WEEK));
			RelativeUnitOps.AddInnerHTMLString(m_asOwner.GetString(706,"ptmsgs_portalcommonmsgs"));
			if (-MS_PER_WEEK==nRelativeUnits)
			{
				RelativeUnitOps.SetSelected(true);
			}
			RelativeUnitSelect.AddInnerHTMLElement(RelativeUnitOps);

			relativeDivGuts.AddInnerHTMLElement(RelativeUnitSelect);


			HTMLDiv DateChooserDiv = new HTMLDiv();
			DateChooserDiv.SetID(strPrefix+strTag + "_divDateChooser_" + strStatementID);

			// Try to get the date/time picker for the current row
			Object objDateTimePicker = jsDateTimePickerMgr.GetComponent(strPrefix+strID);

			// If a date/time picker hasn't been created for this row
			if (null == objDateTimePicker)
			{

				// Create and register a new picker now.

				// We need a date/time to initialize it.  If _dtValue has been set,
				// use this, otherwise use the current time.

				XPDateTime xpDT = null;

				if (! _dtValueInitialized) {
					// initialize with current date/time
					xpDT = new XPDateTime();
				} else {
					// initialize with selected date/time
					xpDT = _dtValue;
				}

				// OK to actually create and register the picker now
				ADatePickerComponent jsDateTimePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DateTimePicker");
				jsDateTimePicker.Init(_formname,xpDT,
						m_ptPageMgr,
						strID);
				jsDateTimePickerMgr.RegisterComponent(jsDateTimePicker);

			}

			// Date/time picker for this row now exists.. get its HTML and display it

			HTMLElement dateChooserDivGuts = jsDateTimePickerMgr.GetComponentHTML(strID);
			if(((selectedType != PT_PROPERTY_TYPES.PT_PROPTYPE_DATE) || ! _visible) && jitDatePicker)
			{
				dateChooserDivGuts = FunctionalizeDateChooser(dateChooserDivGuts, strID, strPrefix+strTag + "_divDateChooser_" + strStatementID,jsDateTimePickerMgr, jitDatePicker);
			}

			HTMLSpan errorSpan = null;

			if (showError && _visible)
			{
				String errorString = ValidateSelections();

				if ((null != errorString) && (errorString.length() > 0))
				{
					errorSpan = new HTMLSpan();
					errorSpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
					errorSpan.AddInnerHTMLString(errorString);
				}
			}

			if ((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE) && _visible)
			{
				CompareDiv.SetStyle(strDispNone);
				CompareMemberDiv.SetStyle(strDispNone);
				DateChooserDiv.SetStyle(strDisp);
				RelativeDiv.SetStyle(strDispNone);

				if (null != errorSpan)
				{
					HTMLTable miniTable  = new HTMLTable();
					HTMLTableRow miniRow = new HTMLTableRow();
					miniTable.AddInnerHTMLElement(miniRow);

					HTMLTableCell miniCell = new HTMLTableCell();
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(dateChooserDivGuts);
					miniCell.AddInnerHTMLElement(relativeDivGuts);
					miniCell.SetNoWrap(true);

					miniCell = new HTMLTableCell();
					miniCell.SetNoWrap(true);
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(errorSpan);

					dateChooserDivGuts = miniTable;
				}
			}
			else if (((selectedType == PT_PROPERTY_TYPES.PT_PROPTYPE_MEMBERSHIP) && _visible))
			{
				DateChooserDiv.SetStyle(strDispNone);
				CompareDiv.SetStyle(strDispNone);
				CompareMemberDiv.SetStyle(strDisp);
				RelativeDiv.SetStyle(strDispNone);

				if (null != errorSpan)
				{
					HTMLTable miniTable  = new HTMLTable();
					HTMLTableRow miniRow = new HTMLTableRow();
					miniTable.AddInnerHTMLElement(miniRow);

					HTMLTableCell miniCell = new HTMLTableCell();
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(compareMemberDivGuts);

					miniCell = new HTMLTableCell();
					miniCell.SetNoWrap(true);
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(errorSpan);

					compareMemberDivGuts = miniTable;
				}
			} else
			{
				DateChooserDiv.SetStyle(strDispNone);
				CompareMemberDiv.SetStyle(strDispNone);
				RelativeDiv.SetStyle(strDispNone);

				if (null != errorSpan)
				{
					HTMLTable miniTable  = new HTMLTable();
					HTMLTableRow miniRow = new HTMLTableRow();
					miniTable.AddInnerHTMLElement(miniRow);

					HTMLTableCell miniCell = new HTMLTableCell();
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(compareDivGuts);

					miniCell = new HTMLTableCell();
					miniCell.SetNoWrap(true);
					miniRow.AddInnerHTMLElement(miniCell);
					miniCell.AddInnerHTMLElement(errorSpan);

					compareDivGuts = miniTable;
				}
			}

			CompareDiv.AddInnerHTMLElement(compareDivGuts);
			CompareMemberDiv.AddInnerHTMLElement(compareMemberDivGuts);
			DateChooserDiv.AddInnerHTMLElement(dateChooserDivGuts);
			RelativeDiv.AddInnerHTMLElement(relativeDivGuts);

			inputCell.AddInnerHTMLElement(CompareDiv);
			inputCell.AddInnerHTMLElement(CompareMemberDiv);
			inputCell.AddInnerHTMLElement(DateChooserDiv);
			inputCell.AddInnerHTMLElement(RelativeDiv);
			row.AddInnerHTMLElement(inputCell);

		}
		catch (Exception e)
		{

			log.Error(e, "QueryCondition::getDivTableRow: An error occured when trying to display the HTML.");


			throw new XPException(m_asOwner.GetString(32,
			"ptmsgs_portalinfrastructure"), e);
		}

		return row;
	}
}