package com.plumtree.portaluiinfrastructure.friendlyurl;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;

/**
 * This class handles API requests for REST APIs.
 */
public class APIFriendlyURLParser extends FriendlyURLParser
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.friendlyurl.APIFriendlyURLParser");

	/**
	 * The version key for the first version of the api.
	 */
	public static final String API_VERSION_1 = "v1";

	/**
	 * The key used to specify the KD Rest API.
	 */
	public static final String API_TYPE_KD = "kd";

	/**
	 * The key used to specify the User Rest API.
	 */
	public static final String API_TYPE_USER = "user";
	
	public static final String API_TYPE_DOJODATASTORE_KDFOLDER = "docfolders";
	
	public static final String API_TYPE_DOJODATASTORE_KDDOCUMENTS = "docs";

	protected String m_strChildID;

	public APIFriendlyURLParser(String strKeyword, String strClassId, XPStringTokenizer stURLTokens) 
	{
		// This will set the object name to be the version key (i.e. v1)
		super(strKeyword, strClassId, stURLTokens);

		if (!API_VERSION_1.equals(m_strObjectName))
		{
			log.Warn("APIFriendlyURLParser:Init The API version is not available.  Found [" +
				m_strObjectName + "], but was expecting " + API_VERSION_1 + ".");
		}

		try {
			// make sure to try to decode everything since it was part of the URL

			// The API area (i.e. kd)
			m_strChildName = URLDecode(stURLTokens.GetNextToken());

			// The ID of the object where the API should be executed.  Can be either a
			// string or an int, so we let the API control handle parsing it.
			if ( stURLTokens.HasMoreTokens() ) {
				m_strChildID = URLDecode(stURLTokens.GetNextToken());
			}
		} catch (Exception e)
		{
			log.Warn(e, "APIFriendlyURLParser:Init The API area or object ID was not available in the URL.");
		}		
	}

	public String GetChildIDString()
	{
		return m_strChildID;
	}
}