package com.plumtree.portaluiinfrastructure.friendlyurl;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Generic Friendly URL parser capable of parsing the name of the object.
 * 
 * @author duang
 */
public class FriendlyURLParser implements IFriendlyURLParser 
{ 
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
			"com.plumtree.portaluiinfrastructure.friendlyurl.FriendlyURLParser");
	
	// DCA - keyword parsed from URL.
	protected String m_strKeyword;
	
	// DCA - class Id mapped to the keyword from URL.
	protected String m_strClassId;
	
	// DCA - name of object parsed from URL.
	protected String m_strObjectName;
	
	// DCA - object Id either parsed from URL or retrieved using the name of object.
	protected int m_nObjectId;

	// DCA - Additional name specifier, used for example for community page name. Optional and not used by most class types.
	protected String m_strChildName;
	
	// DCA - Additional id specifier, used for example for Urls to community page id. Optional and not used by most class types.
	protected int m_nChildId;
	
	/**
	 * DCA - this is only here in case child classes doesn't want to call the constructor below
	 */
	protected FriendlyURLParser() {}
	
	public FriendlyURLParser(String strKeyword, String strClassId, XPStringTokenizer stURLTokens) 
	{
		m_strKeyword = strKeyword;
		m_strClassId = strClassId;
		
		try {
			m_strObjectName = stURLTokens.GetNextToken();
			// DCA - make sure to try to decode since it was part of the URL
			m_strObjectName = URLDecode(m_strObjectName);
		} catch (Exception e) {
			log.Warn(e, "FriendlyURLParser:Init The object name was not available in the URL.");
		}
		
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.friendlyurl.IFriendlyURLParser#GetChildId()
	 */
	public int GetChildId() {
		return m_nChildId;
	}
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.friendlyurl.IFriendlyURLParser#GetClassId()
	 */
	public String GetClassId() {
		return m_strClassId;
	}
	
	public void SetClassId(String strClassId) {
		m_strClassId = strClassId;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.friendlyurl.IFriendlyURLParser#GetObjectId()
	 */
	public int GetObjectId() {
		return m_nObjectId;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.friendlyurl.IFriendlyURLParser#GetChildName(boolean)
	 */
	public String GetChildName(boolean bDeNormalize) {
		if (bDeNormalize && null != m_strChildName) {
			return FriendlyURL.DeNormalizeObjectName(m_strChildName);
		} else {
			return m_strChildName;
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.friendlyurl.IFriendlyURLParser#GetKeyword()
	 */
	public String GetKeyword() {
		return m_strKeyword;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.friendlyurl.IFriendlyURLParser#GetObjectName(boolean)
	 */
	public String GetObjectName(boolean bDeNormalize) {
		if (bDeNormalize && null != m_strObjectName) {
			return FriendlyURL.DeNormalizeObjectName(m_strObjectName);
		} else {
			return m_strObjectName;
		}
	}
	
	protected String URLDecode(String strEncodedString) {
		String strDecodedString = null;
		// DCA - weblogic doesn't seem to encode URL's automatically so this string might not be encoded
		try {
			log.Debug(getClass().getName() + ":URLDecode Decoding: " + strEncodedString + ".");
			strDecodedString = XPHttpUtility.UrlDecode(strEncodedString, LinkConstants.UTF_8_ENCODING);
		} catch (XPUnsupportedEncodingException e) {
			// DCA - object name must've not been encoded. Log exception and move on.
			log.Debug(e, getClass().getName() + ":URLDecode The string: " + strEncodedString + " could not be decoded.");
			strDecodedString = strEncodedString;
		}
		
		return strDecodedString;
	}
}