package com.plumtree.portaluiinfrastructure.friendlyurl;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.interpreter.*;
import com.plumtree.uiinfrastructure.interpreter.filter.*;
import com.plumtree.uiinfrastructure.interpreter.filter.utils.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * A filter to handle friendly gateway url request.
 * 
 * @author RobertZ
 */
public class GatewayFriendlyURLFilter extends BaseInterpreterFilter
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent("UI_Infrastructure"),
		"com.plumtree.portaluiinfrastructure.friendlyurl.GatewayFriendlyURLFilter");
		
	/**
	 * This method detects if the incoming request is a gateway request.
	 * If it is, it will take over the processing of the request, and return
	 * a boolean true to indicate that Interpreter shall not process the
	 * request further. 
	 * 
	 * NOTE: No exceptions should bubble up from this method. Let the gateway handler take care of any errors.
	 */
	public boolean PreFilter(RequestData requestData)
	{
		IXPRequest request = requestData.m_xpRequest;

		String strURL = request.GetRequestURL();
		String queryString = request.GetQueryString();
		queryString = (null == queryString) ? "" : "?"+queryString;
		
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		IFriendlyURLManager ptFriendlyURLMgr = (IFriendlyURLManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
		String keyword = ptFriendlyURLMgr.LookupFriendlyURLKeyFromClassId(FriendlyURLConstants.FRIENDLY_GATEWAY_URL);
		if ( keyword == null || "".equals(keyword) ) {
			log.Debug("No keyword defined for friendly gateway url in FriendlyURLs.xml. Friendly Gateway URLs disabled");
			return false;
		}
		
		// Use the gateway handle request if this is a gateway url
		if ( GatewayHelpers.IsFriendlyGatewayURL(strURL, keyword) )
		{		
			// convert the friendly gateway url to a regular gatewayurl
			String convertedUrl = GatewayHelpers.ConvertToRegularGatewayURL(strURL, keyword) + queryString ;
			requestData.SetRequestURL(  convertedUrl );
			requestData.SetRequestFullURL( convertedUrl );
			log.Debug("Calling HandleGatewayRequest(...) for URL [" + request.GetRequestURL() + "] from friendly Gateway URL ["+strURL+"]");

			// If we need to login from the gateway, we let the
			// interpreter handle that.			
			return GatewayHandlers.HandleGatewayRequest(requestData);
		}

		/*
		 * ================================================================================================
		 * END OF SPECIAL PROCESSING FOR THE GATEWAY REQUESTS
		 * ================================================================================================
		 */

		return false;
	}
	
}