package com.plumtree.portaluiinfrastructure.friendlyurl;

/**
 * This class is responsible for parsing friendly URLs and populating the different
 * variables (ie name of object, id of object, ...)
 * 
 * @author duang
 */
public interface IFriendlyURLParser {

	/**
	 * Returns the child Id if one was parsed from the URL, 0 otherwise.
	 * @return
	 */
	public int GetChildId();

	/**
	 * Returns the class Id mapped to the keyword parsed from the URL.
	 * @return
	 */
	public String GetClassId();
	
	/**
	 * Sets the class Id mapped to the keyword parsed from the URL.
	 * @return
	 */
	public void SetClassId(String strClassId);

	/**
	 * Returns the object Id if one was parsed from the URL, 0 otherwise.
	 * @return
	 */
	public int GetObjectId();

	/**
	 * Returns the child name if one was parsed from the URL, null otherwise.
	 * @param bDeNormalize		Indicates whether the name should be denormalized before being returned
	 * @return
	 */
	public String GetChildName(boolean bDeNormalize);

	/**
	 * Returns the keyword if one was parsed from the URL, null otherwise.
	 * @return
	 */
	public String GetKeyword();

	/**
	 * Returns the object name if one was parsed from the URL, null otherwise.
	 * @param bDeNormalize		Indicates whether the name should be denormalized before being returned
	 * @return
	 */
	public String GetObjectName(boolean bDeNormalize);

}