package com.plumtree.portaluiinfrastructure.friendlyurl;

import com.plumtree.openfoundation.util.*;

/**
 * A manager class in charge of retrieving the correct friendly URL parser
 * given a URL path.
 * 
 * @author duang
 */
public interface IFriendlyURLParserManager {

	/**
	 * Stores the map of keywords to class Ids.
	 * 
	 * @param htKeyToClassIdLookup		Map of keywords to class ids taken from FriendlyURLS.xml
	 */
	public void SetKeyToClassIdLookupTable(XPHashtable htKeyToClassIdLookup);
	
	/**
	 * Returns an IFriendlyURLParser based on the URL path given.
	 * 
	 * @param stURLTokens		URL path
	 * @return	
	 */
	public IFriendlyURLParser GetParser(XPStringTokenizer stURLTokens);
	
	/**
	 * Looks up the friendly url keyword for the specified type.
	 * 
	 * @param typeId Class id or type id
	 * @return The friendly url keyword or null if typeid was not defined
	 */
	public String FindKeywordForType(String typeId);
}