package com.plumtree.portaluiinfrastructure.friendlyurl;

import com.plumtree.openfoundation.util.*;

/**
 * Friendly URL parser specific to user URLs. Checks the URL for user ID.
 * 
 * @author matt
 */
public class UserFriendlyURLParser extends FriendlyURLParser {

	public UserFriendlyURLParser(String strKeyword, String strClassId, XPStringTokenizer stURLTokens) {
		m_strKeyword = strKeyword;
		m_strClassId = strClassId;

		// Use default page by default
		m_nChildId = 0;

		// /username/userid
		// /username
		// both pagename and pageid are optional, and pagename can be used alone
		// /username/userid/pagename/pageid
		// /username/pagename/pageid
		// /username/userid/pagename
		// /username/pagename
		if (stURLTokens.HasMoreTokens()) {
			// this has to be the user name
			String strUserName = stURLTokens.GetNextToken();
			m_strObjectName = URLDecode(strUserName);
		}
		if (stURLTokens.HasMoreTokens()) {
			// this could be either the user id or the page name.
			String strTemp = stURLTokens.GetNextToken();
			boolean bNumeric = true;
			for (int i=0; i<strTemp.length(); i++) {
				if (!XPCharacterUtility.IsASCIIDecimalDigit(strTemp.charAt(i))) {
					// non-numeric value; must be page name
					bNumeric = false;
					break;
				}
			}

			if (bNumeric)
			{
				// this should be the user id
				// NOTE: If you have user/pagename where the pagename is all digits,
				// this will mistakenly think that the pagename is the user ID of the
				// user.  Since we only generate name/id/name/id urls, getting a URL
				// like this would require a user to manually edit it.  Therefore,
				// we don't think this is a big problem and we will just leave it, since
				// fixing it would be difficult.
				m_nObjectId = XPConvert.ToInteger(strTemp);
				parsePage(null, stURLTokens);
			} else
			{
				parsePage(strTemp, stURLTokens);
			}
		}
	}

	/**
	 * This helper method parses the page information, if present.
	 * 
	 * @param strToken This is used if the first page token has already
	 * been retrieved from the tokenizer
	 * @param stURLTokens
	 */
	private void parsePage(String strToken, XPStringTokenizer stURLTokens)
	{
		if ((strToken == null) && (stURLTokens.HasMoreTokens()))
		{
			strToken = stURLTokens.GetNextToken(); 
		}

		// This has to be the page name.
		m_strChildName = strToken;

		// Don't use the default page if we have one specified -
		// force page lookup if the ID isn't present.
		m_nChildId = -1;

		if (stURLTokens.HasMoreTokens()) {
			// this has to be the page id
			String strTemp = stURLTokens.GetNextToken();
			for (int i=0; i<strTemp.length(); i++) {
				if (!XPCharacterUtility.IsASCIIDecimalDigit(strTemp.charAt(i))) {
					// abort; non-numeric value
					// Note: can't use break here, because that just takes you
					// out of the for loop, not the method.
					return;
				}
			}

			m_nChildId = XPConvert.ToInteger(strTemp);
		}
	}
}