package com.plumtree.portaluiinfrastructure.helpers;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;

public class AppDataObjectFactory implements IAppDataObjectFactory 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.helpers.AppDataObjectFactory");

	//the singleton instance
	private static IAppDataObjectFactory m_FactoryInstance;

	// This stores whether or not the factory is in test mode.
	private static boolean m_bIsProduction = false;

	// Private constructor to ensure controlled access to the singleton.
	private AppDataObjectFactory() {}

	/**
	 * @return The singleton config helper.
	 */
	public static IAppDataObjectFactory GetInstance()
    {
		if (m_FactoryInstance == null)
		{
			m_bIsProduction = true;
			m_FactoryInstance = new AppDataObjectFactory();
		}
		return m_FactoryInstance;
	}

    /**
     * Unit tests should use this method to overwrite/teardown existing helper singleton.
     * DO NOT USE for production code. 
     */
	public static void SetTestInstance(IAppDataObjectFactory testHelper)
	{
		if (m_bIsProduction)
		{
			String strMessage = "Can't override AppDataObjectFactory instance for testing... AppDataObjectFactory has already been initialized.";
			log.Error(strMessage);
			throw new XPException(strMessage);
		}

		m_FactoryInstance = testHelper;
	}
		
	public IPTState GetAppDataObject(int iCommunityID, int iPageID, String strHostPageURI, AActivitySpace asOwner) {
		return AppDataObject.GetAppDataObject(iCommunityID, iPageID, strHostPageURI, asOwner);
	}

	public IPTState GetAppDataObject(int iCommunityID, int iPageID, String strHostPageURI, AActivitySpace asOwner, boolean bResolveSecureBase) {
		return AppDataObject.GetAppDataObject(iCommunityID, iPageID, strHostPageURI, asOwner, bResolveSecureBase);
	}

	public IPTState GetAppDataObject(int iCommunityID, int iPageID, int iGWParams, String strHostPageURI, AActivitySpace asOwner) {
		return AppDataObject.GetAppDataObject(iCommunityID, iPageID, iGWParams, strHostPageURI, asOwner);
	}

	public IPTState GetAppDataObject(int iCommunityID, int iPageID, int iGWParams, String strHostPageURI, AActivitySpace asOwner, boolean bResolveSecureBase) {
		return AppDataObject.GetAppDataObject(iCommunityID, iPageID, iGWParams, strHostPageURI, asOwner, bResolveSecureBase);
	}

	public PTStyleSheetLink GetStyleSheet(int iCommunityID, IPTSession ptSession, AActivitySpace asOwner) {
		return AppDataObject.GetStyleSheet(iCommunityID, ptSession, asOwner);
	}
}
