package com.plumtree.portaluiinfrastructure.helpers;

import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;

public interface IAppDataObjectFactory {

	// Returns the app data state object. This function is used by everyone but the gateway.
	public IPTState GetAppDataObject(int iCommunityID, int iPageID,
		String strHostPageURI, AActivitySpace asOwner);
	
	// Returns the app data state object. This function is used by everyone but the gateway.
	public IPTState GetAppDataObject(int iCommunityID, int iPageID,
			String strHostPageURI, AActivitySpace asOwner, boolean bResolveSecureBase);

	/**
	 * Return GetAppDataObject(int iCommunityID, int iPageID, int iGWParams,
	 *										  String strHostPageURI, AActivitySpace asOwner,
	 *										  boolean bResolveSecureBase)
	 * with the default value of bResolveSecureBase set to true.
	 * 
	 * @param iCommunityID
	 * @param iPageID
	 * @param iGWParams
	 * @param strHostPageURI
	 * @param asOwner
	 * @return
	 */
	public IPTState GetAppDataObject(int iCommunityID, int iPageID, int iGWParams,
			  String strHostPageURI, AActivitySpace asOwner);
	
	/**
	 * Returns the app data state object. This function is used by the gateway directly.
	 * 
	 * The bResolveSecureBase specifies that in security mode 3 the method should resolve
	 * strSecureAppBaseURL by passing it to PTConfigHelper.GetApplicationBaseURL or not
	 * 
	 * @param iCommunityID
	 * @param iPageID
	 * @param iGWParams
	 * @param strHostPageURI
	 * @param asOwner
	 * @param bResolveSecureBase
	 * @return
	 */
	public IPTState GetAppDataObject(int iCommunityID, int iPageID, int iGWParams,
				String strHostPageURI, AActivitySpace asOwner, boolean bResolveSecureBase);


	/**
	 * Calculate the style sheet for this gatewayed page.
	 *
	 * If this page is not coming from a community, then we use the subportal's
	 * style sheet.
	 *
	 * If it is coming from a community, then we first check to see if there is
	 * a community style sheet; if there is not, then we default to the
	 * subportal.
	 */
	public PTStyleSheetLink GetStyleSheet(int iCommunityID,IPTSession ptSession, AActivitySpace asOwner);
	
}