package com.plumtree.portaluiinfrastructure.helpers;

import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.openfoundation.util.XPArrayList;

public interface IBannerSearchHelper {

	/**
	 * looks up the bitmask for search object constraints
	 * this function came from BannerStartSearchControl.GetPreferences()
	 * @param owner AActivityspace to get user session
	 */
	public XPArrayList GetSearchConstraints(AActivitySpace owner);

	/**
	 * helper method to decipher the bitmask value
	 * @param objectTypeBitmask The bitmask value of the object types to search for
	 * 
	 * @return list of Portal Object Types from User Search Preferences.
	 */
	public XPArrayList GetPortalObjectTypes(IPTSessionInfo sessionInfo, int objectTypeBitmask);
	
	/*
	 * Setting the search terms to search within results for pathways
	 * @param queryArray is the array of search terms used
	 */
	public String SetPathwaysSearchHistory(Object[] queryArray);
	
//	public String GetPathwaysSearchString(String searchString);
	
	public String GetBannerSearchPreferenceSortOrder(AActivitySpace _parent);

	/*
	 * helper method to get the string value of object via classid to pass to pathways
	 * @param filterId String representation of the classid 
	 */
	public String GetPathwaysClassIdStringValue(int filterId);

	/*
	 * helper method to set collab items into search constraints for pathways
	 * @param collabFilter the list to add search filter terms
	 */
	public XPArrayList setCollabItems(XPArrayList collabFilter);

	/*
	 * helper method to set content items into search constraints for pathways
	 * @param contentFilter the list to add search filter terms
	 */
	public XPArrayList setContentItems(XPArrayList contentFilter);
	
	/**
	 * Helper method to get a String setting out of the database
	 *
	 * @param sessionInfo the current user's IPTSessionInfo object.
	 * @param settingName the name of the desired setting.
	 * @param def a default value to return if the setting is not found in the database.
	 *
	 * @return the value of the setting, or <code>def</code> if not found.
	 */
	public String GetStringSetting(IPTSessionInfo sessionInfo, String settingName, String def);
	
	/**
	 * Helper method to get an integer setting out of the database
	 *
	 * @param sessionInfo the current user's IPTSessionInfo object.
	 * @param settingName the name of the desired setting.
	 * @param def a default value to return if the setting is not found in the database.
	 *
	 * @return the value of the setting, or <code>def</code> if not found.
	 */
	public int GetIntSetting(IPTSessionInfo sessionInfo, String settingName, int def);
	
	/**
	 * Helper method to get an integer setting from the user's session.
	 *
	 * @param sessionInfo the current user's IPTSessionInfo object.
	 * @param settingName the name of the desired setting.
	 * @param def a default value to return if the setting is not found in the session.
	 *
	 * @return the value of the setting, or <code>def</code> if not found.
	 */
	public int GetIntSessionSetting(IPTSessionInfo sessionInfo, String settingName, int def);
}
