/**
 * 
 */
package com.plumtree.portaluiinfrastructure.helpers;

import com.plumtree.server.IPTSession;

/**
 * The IPathwaysHelper handles common functionality related to
 * Pathways integrations.
 */
public interface IPathwaysHelper 
{
	/**
	 * @param _session the current user session.
	 * @return whether or not Ensemble is installed.
	 */
	public boolean IsPathwaysInstalled(IPTSession _session);

	/**
	 * @param _session the current user session.
	 * @return the ID of the Pathways API web service. -1 if it
	 * is not installed.
	 */
	public int GetAPIWebServiceID(IPTSession _session);
	
	/**
	 * When a Pathways search server issue occurs, this sets timeout value for when to use Pathways again
	 */
	public void StartErrorState();
	
	/**
	 * @return whether or not Pathways timeout has expired.  Returns true if the time out still occurs and false if 
	 * the timeout expired and we can try Pathways again.
	 */
	public boolean IsErrorState();
	
	/**
	 * @param value the boolean value representing if the search is in fall back to legacy mode
	 */
	public void SetLegacySearchMode(boolean value);
	
	/**
	 * This is for advanced search, since it will fall back to legacy search if a search request is not valid for a 
	 * pathways search even though it's enabled and without error
	 * @return the boolean value if the search is currently defaulting to legacy mode
	 */
	public boolean GetLegacySearchMode();
}
