package com.plumtree.portaluiinfrastructure.helpers;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * This helper class provides methods to check markup
 * information for errors.
 */
public class PortletErrorHelper
{
	/**
	 * Check if there was an HTTP error in the markup information.
	 * 
	 * @param objArrMarkup the markup array to check for errors.
	 * @return true if the markup array has error information in it.
	 */
	public boolean IsErrorContentArray(Object[][] objArrMarkup)
	{
		int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0]);
		
		if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_ERRORCODE)
		{
			return true;
		}
		
		return false;
	}

	/**
	 * Get the error code from the markup information.
	 * 
	 * @param objArrMarkup the markup array used to get the error code.
	 * @return the error code from the markup array.
	 */
	public int GetErrorCode(Object[][] objArrMarkup)
	{
		int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0]);
		
		if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_ERRORCODE)
		{
			int iErrorCode = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0]);
			return iErrorCode;
		}
		
		return 0;
	}

	/**
	 * Get the error message from the markup information.
	 * 
	 * @param objArrMarkup the markup array used to get the error message.
	 * @return the error message from the markup array.
	 */
	public String GetErrorMessage(Object[][] objArrMarkup)
	{
		int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1]);
		
		if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_ERRORMESSAGE)
		{
			String strErrorMessage = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1];
			return strErrorMessage;
		}
		
		return null;
	}
}