package com.plumtree.portaluiinfrastructure.intrinsicportlets;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Controls process the events generated by users. This is an abstract
 * intrinsic portlet control that handle repost actions.
 *
 * @author josephc
 */
public abstract class IntrinsicPortletControl implements IControl
{
	/** Parent Activity Space */
	protected AActivitySpace m_asOwner; // Associated Activity Space

	/** Model */
	protected IModel m_model; // Associated model

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public abstract Redirect CheckActionSecurityAndExecute(
		XPHashtable arguments);

	/**
	 * This method is used by the ASManager to return new instances of managed
	 * objects.
	 *
	 * @return A new instance of the managed class (i.e. return new Foo();)
	 */
	abstract public Object Create();

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public abstract String GetName();

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace parent)
	{
		m_model		  = model;
		m_asOwner     = parent;
	}

	/**
	 * This method is a dispatcher. For each repost action it should perform
	 * the right action.
	 *
	 * @param _nAction Action to perform
	 * @param _htFormData Hash table containing form data
	 */
	public abstract void PerformRepostAction(int _nAction,
		XPHashtable _htFormData);
}

