package com.plumtree.portaluiinfrastructure.layout;

import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This class is responsible for determining which Layout Web Service
 * to use for each page.
 */
public interface ILayoutChooser
{
	/**
	 * Calculate the web service ID to use for the current page
	 * from the current Experience Definition.
	 * 
	 * @param Layouts the layout to used to calculate the layout Web Service.
	 * @param AActivitySpace the current Activity Space.
	 * @return int the Web Service ID to use for this page.
	 * -1 means layout is not enabled for this page at this time. 
	 */
	public int GetLayoutWebService(Layouts _layout, AActivitySpace _asOwner);

	/**
	 * Get the web services that are available for the requested layout.
	 * These are stored in a special folder (one folder per layout) in
	 * the Admin Directory.
	 * 
	 * @param _layout the requested layout
	 * @param AActivitySpace the current Activity Space.
	 * @return IPTQueryResult The list of available web services for this
	 * layout with name, description, and object ID information.
	 */
	public IPTQueryResult GetAvailableWebServices(Layouts _layout, AActivitySpace _asOwner);

	/**
	 * @return whether or not page layouts are enabled globally.
	 */
	public boolean GetPageLayoutsEnabled(AActivitySpace _asOwner);

	/**
	 * @return whether or not portlet layouts are enabled globally.
	 */
	public boolean GetPortletLayoutsEnabled(AActivitySpace _asOwner);

	/**
	 *  Gets the web services that are available for the requested layout.
	 *  This function only gets called when global layouts aren't supported but we're in an enabled layout mode.
	 * @param layout
	 * @param owner
	 * @return
	 */
	public int GetLayoutWebServiceBackUp(Layouts layout, AActivitySpace owner);
}