package com.plumtree.portaluiinfrastructure.layout;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The LayoutDisplay is responsible for transforming URLs in the layout,
 * running the layout through the Tag Engine (using the DisplayTree class)
 * and returning the converted HTML.
 */
public interface ILayoutDisplay
{
	/**
	 * This method runs the markup layout through the Tag Engine.
	 * 
	 * This method assumes that at least once in a request, one of the
	 * calls to this method includes layout markup that displays the
	 * Javascript generated in the tag engine.
	 * 
	 * @param _markup The layout markup to convert to HTML.
	 * @param _currentSpace The current Activity Space.
	 * @return The converted HTML.
	 */
	HTMLElement ProcessLayout(Object[][] _markup, AActivitySpace _currentSpace);

	/**
	 * This method runs the markup layout for the main page through the Tag Engine,
	 * and ensures that there is an HTML head tag for JavaScript display.
	 * 
	 * This method assumes that the call to this method includes layout markup
	 * that displays the Javascript generated in the tag engine.
	 * 
	 * This method should only be called once per request.
	 * 
	 * @param _markup The layout markup to convert to HTML.
	 * @param _currentSpace The current Activity Space.
	 * @return The converted HTML with HTML head tag.
	 */
	HTMLElement ProcessMainPageLayout(Object[][] _markup, AActivitySpace _currentSpace);
}