package com.plumtree.portaluiinfrastructure.layout;
import com.plumtree.openfoundation.util.XPArrayList;
import com.plumtree.server.*;

/**
 * This enum contains the different types of XHTML layouts that are used
 * throughout the portal.  Each layout type can have many different
 * layout files associated with it.
 */
public class Layouts
{

	private static XPArrayList m_oLayouts = new XPArrayList() ;

	public static class LAYOUT_TYPE
	{
		public static final int PAGE_TYPE 	= 1;
		public static final int PORTLET_TYPE = 2;
	}

	public static final Layouts BASE_PAGE = new Layouts(
		"Base Page", PT_INTRINSICS.PT_WEBSERVICE_BASE_PAGE_LAYOUT,
		PT_INTRINSICS.PT_ADMIN_FOLDER_BASE_PAGE_LAYOUTS, 3210, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts PROFILE_PAGE = new Layouts(
		"Profile Page", PT_INTRINSICS.PT_WEBSERVICE_PROFILE_PAGE_LAYOUT,
		PT_INTRINSICS.PT_ADMIN_FOLDER_PROFILE_PAGE_LAYOUTS, 3215, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts PORTLET = new Layouts(
		"Portlet", PT_INTRINSICS.PT_WEBSERVICE_DEFAULT_PORTLET_LAYOUT,
		PT_INTRINSICS.PT_ADMIN_FOLDER_PORTLET_LAYOUTS, 3211, LAYOUT_TYPE.PORTLET_TYPE);
	
	public static final Layouts KNOWLEDGE_DIRECTORY = new Layouts(
		"Knowledge Directory", PT_INTRINSICS.PT_WEBSERVICE_KNOWLEDGE_DIRECTORY_LAYOUT,
		PT_INTRINSICS.PT_ADMIN_FOLDER_KNOWLEDGE_DIRECTORY_LAYOUTS, 3212, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts SEARCH_RESULTS = new Layouts(
		"Search Results", PT_INTRINSICS.PT_WEBSERVICE_SEARCH_RESULTS_LAYOUT,
		PT_INTRINSICS.PT_ADMIN_FOLDER_SEARCH_RESULTS_LAYOUTS, 3213, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts PORTLET_SELECTION = new Layouts(
		"Portlet Selection", PT_INTRINSICS.PT_WEBSERVICE_PORTLET_SELECTION_LAYOUT,
		PT_INTRINSICS.PT_ADMIN_FOLDER_PORTLET_SELECTION_LAYOUTS, 3214, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts LOGIN_PAGE = new Layouts(
		"Login Page", PT_INTRINSICS.PT_WEBSERVICE_LOGIN_PAGE_LAYOUT,
		PT_INTRINSICS.PT_ADMIN_FOLDER_LOGIN_PAGE_LAYOUTS, 3229, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts MYACCOUNT_PAGE = new Layouts(
			"MyAccount Page", PT_INTRINSICS.PT_WEBSERVICE_MYACCOUNT_PAGE_LAYOUT,
			PT_INTRINSICS.PT_ADMIN_FOLDER_MYACCOUNT_PAGE_LAYOUTS, 3230, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts ERROR_PAGE = new Layouts(
			"Error Page", PT_INTRINSICS.PT_WEBSERVICE_ERROR_PAGE_LAYOUT, 
			PT_INTRINSICS.PT_ADMIN_FOLDER_ERROR_PAGE_LAYOUTS, 3231, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts COMMUNITY_SELECTION = new Layouts(
			"Community Selection", PT_INTRINSICS.PT_WEBSERVICE_COMMUNITY_SELECTION_LAYOUT,
			PT_INTRINSICS.PT_ADMIN_FOLDER_COMMUNITY_SELECTION_LAYOUTS, 3232, LAYOUT_TYPE.PAGE_TYPE);
	
	public static final Layouts ADVANCED_SEARCH = new Layouts(
			"Advanced Search", PT_INTRINSICS.PT_WEBSERVICE_ADVANCED_SEARCH_PAGE_LAYOUT,
			PT_INTRINSICS.PT_ADMIN_FOLDER_ADVANCED_SEARCH_PAGE_LAYOUTS, 3277, LAYOUT_TYPE.PAGE_TYPE);
		
	private String m_strDisplayName;
	private int m_nDefaultWebServiceID;
	private int m_nWebServiceFolderID;
	private int m_nResourcei18nID;
	private int m_nLayoutType;

	/**
	 * 
	 * @param _strDisplayName Display Name for the Layout Type
	 * @param _nWebServiceID WebService ID of the Layout
	 * @param _nFolderID Admin Folder ID of the Layout Type
	 * @param _nID Externalized String ID of the Layout Type that can be read from ptmsgs_portaladminmsgs.xml
	 * @param _eType The Layout Type, Currently we have LAYOUT_TYPE.PAGE, LAYOUT_TYPE.PORTLET
	 */
	private Layouts(String _strDisplayName, int _nWebServiceID, int _nFolderID, int _nID, int _eType)
	{
		m_strDisplayName = _strDisplayName;
		m_nDefaultWebServiceID = _nWebServiceID;
		m_nWebServiceFolderID = _nFolderID;
		m_nResourcei18nID = _nID;
		m_nLayoutType = _eType;
		m_oLayouts.Add(this);
	}

	/**
	 * 
	 * @return The Arraylist of all Layouts of this enum.
	 */
	public static XPArrayList GetAllLayouts()
	{
		return m_oLayouts;
	}	
	
	/**
	 * @return Externalized String ID of the Layout Type that can be read from ptmsgs_portaladminmsgs.xml
	 */
	public int GetExternalizedStringID()
	{
		return m_nResourcei18nID;
	}

	/**
	 * 
	 * @return The Layout Type, See LAYOUT_TYPE.
	 */
	public int GetLayoutType()
	{
		return m_nLayoutType;
	}

	/**
	 * @return The default web service ID for this layout type.
	 */
	public int GetDefaultWebServiceID()
	{
		return m_nDefaultWebServiceID;
	}

	/**
	 * @return The ID for the folder that contains the web services for this layout type.
	 */
	public int GetWebServiceFolderID()
	{
		return m_nWebServiceFolderID;
	}

	/** 
	 * @return the string representation of this layout type.
	 */
	public String ToString()
	{
		return m_strDisplayName;
	}
}