package com.plumtree.portaluiinfrastructure.navtype;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * Core pluggable navigation interface.  All pluggable navigations must implement this high-level interface, 
 * which lsist the names of view classes used for each area of the page the developer wishes to take over
 * for navigation purposes.  Refer to IPluggableNavRO for all model-related methods to build navigation.  
 *
 * @author JohnO
 * @author DavidP
 * @see IPluggableNavRO
 */
public interface INavTypes
{
	/**
	 * Return the integer order of the navigation type.  Must be greater than 5 for external plugins.
	 * Note that this number must be unique among registered navigation
	 * plugins on any specific install.
	 *
	 * @return integer navigation topic position
	 */
	public int GetID();

	/**
	 * Return the text name of this navigation type shown in the subportal editor.
	 *
	 * @return String plguin name
	 */
	public String GetName(String _strLangID);

	/**
	 * Return the description of this navigation plugin shown in the subportal editor.
	 *
	 * @return String plugin scope
	 */
	public String GetScope(String _strLangID);
	
	/**
	 * Return the names of the javascript file includes as an array of strings
	 * or null if none are used.  A single javascript include is supported
	 * for all subviews in each pluggable navigation instance.  
	 * 
	 * IMPORTANT NOTE:
	 * This function is where IView.DisplayJavaScript() should be called in order
	 * for the navigation view specific javascript to appear in the navigation.
	 * 
	 * @return String[]
	 */
	public HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner);
	
	/**
	 * Return boolean to control whether or not a specific navigation feature
	 * is displayed.  Examples include the topbar, the header (banner), and
	 * the footer.
	 * 
	 * @return boolean
	 * @see NavFeatureEnum
	 * @see NavFeatureHelper
	 */
	public boolean IsFeatureEnabled( NavFeatureEnum feature );
	
	/**
	 * Primary method to implement for pluggable navigation support.
	 * Return stringname of the view class by page area used in pluggable navigation.
	 * Viewnames returned will be registered as IView types associated with the main
	 * display class' MVC hierarchy and used to render the page via pluggable navigation.
	 * Area examples include left and right of page body, and above and below the banner.
	 * IView classes return HTML used to display the page. 
	 *  
	 * @return String
	 * @see NavAreaEnum
	 * @see NavAreaHelper
	 */
	public String GetNavAreaView( NavAreaEnum area );
}

