/*
 * Created on Mar 7, 2003
 */
package com.plumtree.portaluiinfrastructure.navtype;

import com.plumtree.openfoundation.util.*;

/**
 * Helper class to assist in the enumeration of navigation types
 * 
 * @author DavidP
 */
public class NavAreaHelper 
{
	private XPArrayList navTypeArray = null;
	
	public static final NavAreaHelper INSTANCE = new NavAreaHelper();
	
	/**
	 * Constructs helper class with accessors for array of nav types.
	 */
	private NavAreaHelper()
	{
		navTypeArray = new XPArrayList();
		
		for (int i=0;i < NavAreaEnum.m_navAreaEnums.length; ++i)
		{
			navTypeArray.Add(NavAreaEnum.m_navAreaEnums[i]);	
		}
	}
	
	/**
	 * Enumerates the possible nav types available.
	 * @return IXPEnumerator
	 */
	public IXPEnumerator GetCategoryTypes()
	{
		IXPEnumerator eKeys  = null;
		if (navTypeArray != null && navTypeArray.GetSize() > 0)
		{
			eKeys  = navTypeArray.GetEnumerator(); 
		}
		
		return eKeys;
	}
	
	/**
	 * Enumerates the possible nav types available.
	 * @return XPArrayList
	 */
	public XPArrayList GetCategoryTypeArray()
	{
		return navTypeArray; 
	}

	/**
	 * Returns the number of nav types.
	 * @return int
	 */
	public int GetNumCategoryTypes()
	{
		if (navTypeArray != null)
		{
			return navTypeArray.GetSize();
		}
		
		return 0;
	}	

	/**
	 * Get the name if the view class from pluggable navigation to be registered 
	 * in the AActivitySpace and called by DisplayPage to render that area of 
	 * the page
	 * 
	 * @param plugNav
	 * @param pageArea
	 * @return String
	 */
	public String GetNavAreaViewClassName(INavTypes plugNav, NavAreaEnum pageArea)
	{
		return plugNav.GetNavAreaView( pageArea );
	}
}

