/*
 * Created on Mar 27, 2003
 */
package com.plumtree.portaluiinfrastructure.navtype;

import com.plumtree.openfoundation.util.*;

/**
 * Helper class to assist in the enumeration of navigation 
 * feature types
 * 
 * @author DavidP
 */
public class NavFeatureHelper 
{
	private static XPArrayList navFeatureArray = new XPArrayList();
	
	public static final NavFeatureHelper INSTANCE = new NavFeatureHelper();

	static {
		for (int i=0; i < NavFeatureEnum.m_navFeatureEnums.length; ++i)
		{
			navFeatureArray.Add(NavFeatureEnum.m_navFeatureEnums[i]);	
		}		
	}

	/**
	 * Constructs helper class with accessors for array of nav types (handled in static block).
	 */
	public NavFeatureHelper() {}
	
	/**
	 * Enumerates the possible nav types available.
	 * @return IXPEnumerator
	 */
	public IXPEnumerator GetCategoryTypes()
	{
		IXPEnumerator eKeys  = null;
		if (navFeatureArray != null && navFeatureArray.GetSize() > 0)
		{
			eKeys  = navFeatureArray.GetEnumerator(); 
		}
		
		return eKeys;
	}
	
	/**
	 * Enumerates the possible nav types available.
	 * @return XPArrayList
	 */
	public XPArrayList GetCategoryTypeArray()
	{
		return navFeatureArray; 
	}

	/**
	 * Returns the number of nav types.
	 * @return int
	 */
	public int GetNumCategoryTypes()
	{
		if (navFeatureArray != null)
		{
			return navFeatureArray.GetSize();
		}
		
		return 0;
	}	

	/**
	 * Get the name if the view class from pluggable navigation to be registered 
	 * in the AActivitySpace and called by DisplayPage to render that area of 
	 * the page
	 * 
	 * @param plugNav
	 * @param pageArea
	 * @return String
	 */
	public boolean GetNavFeatureEnabled(INavTypes plugNav, NavFeatureEnum featureEnabled)
	{
		return plugNav.IsFeatureEnabled( featureEnabled );
	}
}