package com.plumtree.portaluiinfrastructure.pathways.tagging;

import com.plumtree.openfoundation.util.IXPList;
import com.plumtree.openfoundation.util.XPException;
import com.plumtree.openfoundation.util.XPIllegalStateException;

/**
 * This Interface Provides Methods to Handle getting, Adding/Removing Tags from Pathways
 * @author Ravi Tunuguntla
 */
public interface ITaggingModel 
{
	/**
	 * Gets the List of Tags of that are attached to this Object by pathways.
	 * @param id Object Id
	 * @return List of Tags added to This Object
	 */
	public IXPList GetObjectTags(int id);
	
	/**
	 * Adds/Removes Tag specified for the Object with given ID based on Action specified.
	 * @param tag Name of the Tag that needs to be Added or Removed
	 * @param id Concatenation of classid and Object Id PTCLASSID_PTOJECTID
	 * @param action Operation to perform on the Tag, 0 = Add, 1 = Delete, 2 = Edit (delete old tag and add new tag)
	 * @param ptsource source of the Object to be specified for Pathways it can be PTPORTAL or PTCOLLAB, for more sources see PathwaysConstants. 
	 * @throws XPIllegalStateException Throws this exception if pathways is unavailable and a request to Add/Remove Tags is sent.
	 */
	public void AddRemoveObjectTag(String tag, String id, int action, String ptsource) throws XPIllegalStateException;

	/**
	 * Renames Tag specified for the Object with given ID.
	 * @param tag the Source Tag Name to be used for renaming
	 * @param id Concatenation of classid and Object Id PTCLASSID_PTOJECTID
	 * @param ptsource source of the Object to be specified for Pathways it can be PTPORTAL or PTCOLLAB, for more sources see PathwaysConstants.
	 * @param renameTag the Target Tag Name to be used for renaming 
	 * @throws XPIllegalStateException Throws this exception if pathways is unavailable and a request to Add/Remove Tags is sent.
	 */
	public void RenameObjectTag(String tag, String id, String ptsource, String renamtTag) throws XPIllegalStateException;
	
	/**
	 * True if Pathways is enabled and user can tag items, else false.
	 * @return boolean
	 */
	public boolean IsTaggingEnabled();
	
	/**
	 * This method returns an error that happened when Add/Remove/Rename Tag request is
	 * sent to pathways. This returns null if there is no error.
	 * 
	 * @return XPException that contains the error, if Tagging was success then it returns null.
	 */
	public XPException GetPathwaysTaggingError();
	
	/**
	 * This method sets error that happened when tagging request is sent to pathways.
	 * 
	 */	
	public void SetPathwaysTaggingError(XPException e );
}
