package com.plumtree.portaluiinfrastructure.pathways.tagging;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysConstants;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This Control handles processing of Requests to Add/Remove Tags
 * by redirecting them to the Models that implement ITaggingModel.
 * 
 * @author Ravi Tunuguntla
 *
 */
public class TaggingControl implements IControl 
{
	//TODO Add new Logger for Pathways
	private static OpenLogger logger = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
			"com.plumtree.portalpages.browsing.pathways.TaggingControl");

	public static final String STR_MVC_CLASS_NAME 	= "PathwaysTags";
	public static final String QS_ACTION			= "action";
	public static final String QS_TAG				= "tag";
	public static final String QS_OBJECTID			= "oid";
	public static final String QS_SOURCE			= "ptsource";
	public static final String QS_RENAME_TAG		= "renametag";
	
	public static final int ACTION_ADD_TAG		= 0;
	public static final int ACTION_DELETE_TAG	= 1;
	public static final int ACTION_RENAME_TAG	= 2;
	
	/**
	 * The owning space for this control.
	 */
	protected AActivitySpace m_asOwner;
	
	/**
	 * The DirModel model.
	 */
	protected ITaggingModel m_model;
		
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments) 
	{		
		// We process this as it is request to add/delete tag from KD Page 
		if(null != m_model)
		{
			// Get Arguments for adding or removing the tag
			
			String[] aDataValue;

			// Needed for adding/removing card for this tag
			int nAction = -1;
			
			aDataValue = (String[]) arguments.GetElement(QS_ACTION);
			if(aDataValue != null)
			{				
				nAction = XPConvert.ToInteger(aDataValue[0]);
				logger.Debug("Got the Add/Remove Action of the Tag on this Object :" + nAction);
			} 
			else 
			{
				// TODO: Throw a 400 error via DP since it is a badrequest 
				logger.Error("Failed to get value for Query Parameter : " + QS_ACTION);
				throw new XPNullPointerException("Value for Query Parameter : " + QS_ACTION + " is null" );
			}
			
			String strName = null;
			// Needed Name of Tag to add/remove
			
			aDataValue = (String[]) arguments.GetElement(QS_TAG);
			if(aDataValue != null)
			{				
				strName = XPConvert.ToString(aDataValue[0]);
				
				//Decoding the URL encoded Tag name(s), Since we are handling dojo request this needs to be done for tags
				//with special or asian characters, this will restore the tag name(s) to actual representation.
				
				strName = XPHttpUtility.UrlDecode(strName, LinkConstants.UTF_8_ENCODING);

				logger.Debug("Got the Add/Remove Tag Name for this Object : " + strName);

			} 
			else
			{
				// TODO: Throw a 400 error via DP since it is a badrequest
				logger.Error("Failed to get value for Query Parameter : " + QS_TAG);
				throw new XPNullPointerException("Value for Query Parameter : " + QS_TAG + " is null" );
			}
			
			String strId = null;
			// Needed ID for this card, it is concatenation of CLASSID_OBJECTID
			// For Documents classid is PT_CLASSIDS.PT_CATALOGCARD_ID
			
			aDataValue = (String[]) arguments.GetElement(QS_OBJECTID);
			if(aDataValue != null)
			{				
				strId = XPConvert.ToString(aDataValue[0]);
				logger.Debug("Got the Pathways ID of the Object :" + strId);
			} 
			else
			{
				// TODO: Throw a 400 error via DP since it is a badrequest
				logger.Error("Failed to get value for Query Parameter : " + QS_OBJECTID);
				throw new XPNullPointerException("Value for Query Parameter : " + QS_OBJECTID + " is null" );
			}
			
			String source = PathwaysConstants.PTSOURCE_PORTAL;
			// Needed the source for this object to construct url for pathways tagging operation.
				
			aDataValue = (String[]) arguments.GetElement(QS_SOURCE);
			if(aDataValue != null)
			{
				source = XPConvert.ToString(aDataValue[0]);
				logger.Debug("Got the PTSource of  this Object :" + source);
			} 
			else
			{
				// TODO: Throw a 400 error via DP since it is a badrequest
				logger.Error("Failed to get value for Query Parameter : " + QS_SOURCE);
				throw new XPNullPointerException("Value for Query Parameter : " + QS_SOURCE + " is null" );
			}
			
			// If performing a rename operation, this is the name of the new tag.
			String strRenameTag = null;			
			
			if(nAction == ACTION_RENAME_TAG)
			{
				aDataValue = (String[]) arguments.GetElement(QS_RENAME_TAG);
				
				if(aDataValue != null)
				{
					strRenameTag = XPConvert.ToString(aDataValue[0]);
					logger.Debug("Got Tag Name for renaming:" + strRenameTag);
				} 
				else
				{
					// TODO: Throw a 400 error via DP since it is a badrequest
					logger.Error("Failed to get value for Query Parameter : " + QS_RENAME_TAG);
					throw new XPNullPointerException("Value for Query Parameter : " + QS_SOURCE + " is null" );
				}
				
				// Now process the rename operation on the object.
				m_model.RenameObjectTag(strName, strId, source, strRenameTag);
			}
			else
			{
				// Now process add/delete operation on the object.
				m_model.AddRemoveObjectTag(strName, strId, nAction, source);
			}
		}		
		
		return GetDPRedirect();
	}
		
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space) {
		m_asOwner = space;
		
		m_model = (ITaggingModel) model;
		
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() {
		return new TaggingControl();
	}
	
	/**
	 * @return the redirect to the TaggingREST Display page.
	 */
	public Redirect GetDPRedirect()
	{
		Redirect redirect = new Redirect();
		redirect.SetLinkGetCachedSpace(m_asOwner);
		redirect.SetDisplayPage(TaggingRESTDP.STR_MVC_CLASS_NAME);

		return redirect;
	}
}
