/**
 * 
 */
package com.plumtree.portaluiinfrastructure.pathways.tagging;

import com.plumtree.openfoundation.util.IXPEnumerator;
import com.plumtree.openfoundation.util.XPException;
import com.plumtree.openfoundation.util.XPNullPointerException;
import com.plumtree.openfoundation.web.XPHttpUtility;
import com.plumtree.openlog.OpenLogService;
import com.plumtree.openlog.OpenLogger;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.HTTPHeaderConstants;
import com.plumtree.uiinfrastructure.activityspace.IDisplayPage;
import com.plumtree.uiinfrastructure.activityspace.IWebData;

/**
 * @author Ravi Tunuguntla
 *
 *This display page is used to transmit server side errors to UI.
 *This returns non null HTTP response if there is a server error 
 *while Adding/Removing/Renaming Tags and The error message is 
 *returned in the response
 *
 */
public class TaggingRESTDP implements IDisplayPage {

	
	private static OpenLogger logger = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
			"com.plumtree.portalpages.browsing.pathways.TaggingRESTDP");
	
	public static final String STR_MVC_CLASS_NAME = "PathwaysTags";
	
	protected AActivitySpace m_asOwner;
	protected ITaggingModel m_model;	
	
	public TaggingRESTDP() {
	}

	public void Display(IWebData webData) {
		webData.SetIsHTMLText(false);
		webData.SetHeader(HTTPHeaderConstants.CONTENT_TYPE, "text/json-comment-filtered");
		
		XPException tagErr = m_model.GetPathwaysTaggingError();

		if (null != tagErr) {
				
			// HTML encode the error string.
			String strError = XPHttpUtility.HtmlEncode(tagErr.GetMessage());
			// Setting the HTTP Error code to 400.
			webData.SetStatus(400);
			webData.SetData(strError);
		}
	}

	public AActivitySpace GetOwner() {
		return m_asOwner;
	}

	public void Init(AActivitySpace parent) {
		m_asOwner = parent;
		
		if (null != m_asOwner) {
			for ( IXPEnumerator e = m_asOwner.GetModelsEnumerator(); e.MoveNext();){
				if(e.GetCurrent()  instanceof ITaggingModel) {
					m_model = (ITaggingModel) e.GetCurrent() ;
					break;
				}
			}	
		} else {
			throw new XPNullPointerException("Failed to initialize since Activityspace is null.");
		}
	}

	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}
}
