package com.plumtree.portaluiinfrastructure.profile;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;

/**
 * @author jennifersu
 *
 * Helper class that describes a Property in the User Profile
 *         Layout.
 */
public final class Property
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent("Portal_UserProfile"),
		"com.plumtree.portaluiinfrastructure.profile.Property");

	private Object m_value;
	private String m_name;
	private int m_id;
	private int m_picktype;
	private int m_type;
	private int m_isHREF;
	private int m_isMandatory;
	private int m_isMultiValued;
	private int m_isReadOnly;
	private int m_isVisible;
	private int m_refClassID;
	private String m_refName;

	/**
	 * 
	 * @param _id
	 * @param _name
	 * @param _type
	 * @param _value
	 * @param _picktype
	 * @param _isHREF
	 * @param _isMandatory
	 * @param _isMultiValued
	 * @param _isReadOnly
	 * @param _isVisible
	 * @param _refClassID
	 * @param _arrPickList
	 */
	public Property(int _id, String _name, int _type, Object _value, int _picktype, int _isHREF, int _isMandatory, int _isMultiValued, int _isReadOnly, int _isVisible, int _refClassID, Object[][] _arrPickList)
	{
		m_id			    = XPConvert.ToInteger(new Integer(_id));
		m_name			    = (new XPStringBuilder(_name)).ToString();
		m_type			    = XPConvert.ToInteger(new Integer(_type));
		m_value			    = _value;
		m_picktype		    = XPConvert.ToInteger(new Integer(_picktype));
		m_isHREF		    = XPConvert.ToInteger(new Integer(_isHREF));
		m_isMandatory	    = XPConvert.ToInteger(new Integer(_isMandatory));
		m_isMultiValued     = XPConvert.ToInteger(new Integer(_isMultiValued));
		m_isReadOnly	    = XPConvert.ToInteger(new Integer(_isReadOnly));
		m_isVisible		    = XPConvert.ToInteger(new Integer(_isVisible));
		m_refClassID	    = XPConvert.ToInteger(new Integer(_refClassID));
		m_refName		    = null;
	}

	/**
	 * Gets the ID of this Property object.
	 *
	 * @return The id of this Property object.
	 */
	public int GetID()
	{
		return m_id;
	}

	/**
	 * Gets the name of this Property object.
	 *
	 * @return The name of this Property object.
	 */
	public String GetName()
	{
		return m_name;
	}

	/**
	 * Get the picklist values from the property object
	 *
	 * @return Object[][] an object array of the picklist values. If there is
	 *         nothing it returns null
	 */
	public Object[][] GetPickListValues()
	{
		throw new XPException("This method has been desupported.  Use IPTProperty.GetCharacteristicAsObject2DArray(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTABLECOLS.");
	}

	/**
	 * Gets the pick type of this Property object
	 *
	 * @return int The pick type for this object property
	 */
	public int GetPickType()
	{
		return m_picktype;
	}

	/**
	 * Gets the type of this Property object.
	 *
	 * @return The type of this Property object. Will be one of
	 *         PT_PROPERTY_TYPES.
	 */
	public int GetType()
	{
		return m_type;
	}

	/**
	 * Returns the value of this Property object.
	 *
	 * @return The value of this Property object.
	 */
	public Object GetValue()
	{
		return m_value;
	}

	/**
	 * 
	 *
	 * @return true if the Property is treated as an HREF
	 */
	public boolean IsHREF()
	{
		return XPConvert.ToBoolean(m_isHREF);
	}

	/**
	 * 
	 *
	 * @returntrue if the Property is mandatory
	 */
	public boolean IsMandatory()
	{
		return XPConvert.ToBoolean(m_isMandatory);
	}

	/**
	 * 
	 *
	 * @return true if the Property supports multiple values
	 */
	public boolean IsMultiValued()
	{
		return XPConvert.ToBoolean(m_isMultiValued);
	}

	/**
	 * 
	 *
	 * @return true if the Property is read-only
	 */
	public boolean IsReadOnly()
	{
		return XPConvert.ToBoolean(m_isReadOnly);
	}

	/**
	 * 
	 *
	 * @return true if the Property is visible in the UI
	 */
	public boolean IsVisible()
	{
		return XPConvert.ToBoolean(m_isVisible);
	}

	/**
	 *
	 *
	 * @param iPickType
	 *
	 * @return true if the Property is a pick list
	 */
	/*
	private boolean HasPickList(int iPickType)
	{
		switch (iPickType)
		{
		case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST:
		case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
			return true;

		default:
			return false;
		}
	}
*/
	/**
	 * 
	 *
	 * @param refName
	 */
	public void SetRefName(String refName)
	{
		m_refName = refName;
	}

	/**
	 * 
	 *
	 * @return class ID of the reference type
	 */
	public int GetRefClassID()
	{
		return m_refClassID;
	}

	/**
	 * 
	 *
	 * @return name of the reference value
	 */
	public String GetRefName()
	{
		return m_refName;
	}

	/**
	 * 
	 *
	 * @param _value 
	 */
	public void SetValue(Object _value)
	{
		m_value = _value;
	}
}

