/*
 * Created on Dec 8, 2004
 */
package com.plumtree.portaluiinfrastructure.ptlink;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;

/**
 * Abstract class that defines common CommonOpenerURL data and functions.
 * 
 */
public abstract class ACommonOpenerURL extends APTURL implements IDataObject
{
	/**
	 * Constant  to get/set baseurl.
	 */
	public final static String KEY_COMMONOPENER_APPBASEURL = "baseurl";
	/**
	 * Constant  to get/set user id.
	 */
	public final static String KEY_COMMONOPENER_USERID = "userid";
	/**
	 * Constant  to get/set common opener mode.
	 */
	public final static String KEY_COMMONOPENER_OPENERMODE = "mode";
	
	protected String m_strApplicationBaseURL;
	protected int m_nOpenerMode;
	protected int m_nUserID = PTOpenerLinks.INT_PARAM_EXCLUDEVALUE;
	
	
	/**
	 * Constructor with no Opener mode or user id.	
	 * 
	 * @param strTitle URL title
	 * @param strApplicationBaseURL Application Base URL, E.g. http://www.plumtree.com:8000.
	 */
	public ACommonOpenerURL(String strTitle, String strApplicationBaseURL) 
	{
		super(strTitle);
		m_strApplicationBaseURL = strApplicationBaseURL;
		
		
	}

	/**
	 * Constructor
	 * 
	 * @param strTitle URL title
	 * @param strApplicationBaseURL		 Application Base URL, E.g. http://www.plumtree.com:8000.
	 * @param nMode		CommonOpener mode. 
	 * @param nUserID		User ID.
	 */
	public ACommonOpenerURL(String strTitle, String strApplicationBaseURL,  int nMode, int nUserID) 
	{
		this(strTitle, strApplicationBaseURL);
		m_nUserID = nUserID;
		m_nOpenerMode = nMode;
	}
	
	/**
	 * Constructor with no Opener mode.
	 * 
	 * @param strTitle URL title
	 * @param strApplicationBaseURL		 Application Base URL, E.g. http://www.plumtree.com:8000.
	 * @param nUserID		User ID.
	 */
	public ACommonOpenerURL(String strTitle, String strApplicationBaseURL,  int nUserID) 
	{
		this(strTitle, strApplicationBaseURL);
		m_nUserID = nUserID;
		m_nOpenerMode = -1;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetFullURL()
	 */
	public abstract String GetFullURL(); 
	

	/**
	 * @see com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetURI()
	 */
	public abstract String GetURI();
	
	
	
	/**
	 * Supports <code>KEY_COMMONOPENER_APPBASEURL</code> and <code>KEY_COMMONOPENER_USERID</code> constants. 
	 * @see com.plumtree.portaluiinfrastructure.ptlink.APTURL#GetData(java.lang.String)
	 */
	public String GetData(String strKey)
	{
		String retVal = null;
		
		
		
		if ( KEY_COMMONOPENER_APPBASEURL.equals(strKey) )
		{
			retVal =  m_strApplicationBaseURL;
		} 
		else if ( KEY_COMMONOPENER_USERID.equals(strKey) )
		{
				retVal = XPConvert.ToString(m_nUserID);
		}
		else 
		{
			retVal = super.GetData(strKey);
		}
		
		return retVal;
		
		
	}
	
	/**
	 * 
	 * Supports <code>KEY_COMMONOPENER_APPBASEURL</code> and <code>KEY_COMMONOPENER_USERID</code> constants.
	 * @see com.plumtree.portaluiinfrastructure.ptlink.APTURL#SetURLData(java.lang.String, java.lang.String)
	 */
	public void SetURLData(String strKey, String strValue)
	{
		if ( KEY_COMMONOPENER_APPBASEURL.equals(strKey) )
		{
			m_strApplicationBaseURL = strValue;
		}
		else if ( KEY_COMMONOPENER_USERID.equals(strKey) )
		{
			m_nUserID = XPConvert.ToInteger( strValue);
		}  else {
			super.SetURLData(strKey, strValue);
		}
	}
	
	
}
