	/*
 * Created on Dec 7, 2004
 */
package com.plumtree.portaluiinfrastructure.ptlink;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * Abstract PTURL class with common functionality for all URLs, i.e.
 * URL title, URL icon, icon width and height, Icon Alt and Current marker.
 * 
 */
public abstract class APTURL extends PTURLConstants implements IPTURL, IHierarchicalDataObject 
{
	protected XPArrayList m_listParamNames = null;
	protected XPArrayList m_listParamValues = null;

	protected XPArrayList m_nonControlParamNames = null;
	protected XPArrayList m_nonControlParamValues = null;

	protected String m_Title = "";
	protected String m_IconImg = "";
	protected String m_IconWidth = "";
	protected String m_IconHeight = "";
	protected String m_IconAlt = "";
	protected String m_MarkedAsCurrent = null;
	protected String m_jsaction = "";
	protected String m_ObjectID = "-1";
	protected String m_ClassID = "-1";
	
	/** For hierarchical data only **/
	protected XPHashtable m_children;
	
	/**
   	 * Returns the entire URL with http:// and server name
	 * E.g http://portalserver/portal/server.pt 
	 **/
	abstract public String GetFullURL();
	
	/**
   	 * Returns the URI, the part of the URL after sever name
	 * E.g /portal/server.pt 
	 **/
	abstract public String GetURI();
	
	/**
	 * 
	 * @param strTitle
	 */
	protected APTURL(String strTitle)
	{
		m_Title = strTitle;
	}
	
	/**
	 * 
	 * @param strTitle
	 * @param strIconImg
	 */
	protected APTURL(String strTitle, String strIconImg)
	{
		this(strTitle);		
		m_IconImg = strIconImg;		
	}
	
	/**
	 * Supports the following keys (although not all keys might be set on every URL):
	 * <code>PTURLConstants.KEY_FULLURL
	 * PTURLConstants.KEY_URI
	 * PTURLConstants.KEY_TITLE
	 * PTURLConstants.KEY_ICONIMG
	 * PTURLConstants.KEY_ICONIMGWIDTH
	 * PTURLConstants.KEY_ICONIMGHEIGHT
	 * PTURLConstants.KEY_ICONIMGALT
	 * PTURLConstants.KEY_CURRENTMARKER
	 * PTURLConstants.KEY_OBJECTID
	 * PTURLConstants.KEY_CLASSID
	 * KEY_PARAMS</code>
	 * 
	 * It is also possible to retrieve the value of specific querystring or non-control parameters 
	 * by passing in the name of the parameter as the key
	 * 
	 * E.g. 
	 * To get the value of param1 in the URL below, pass in 'param1' (without the quotes )as the key.
	 * 
	 * http://www.servername.com/portal/server.pt?param1=value1&param2=value2&param3=value3
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)
	 */
	public String GetData(String strKey)
	{
		if ( PTURLConstants.KEY_FULLURL.equals(strKey) )
		{
			return GetFullURL();
		}
		else if ( PTURLConstants.KEY_URI.equals(strKey) )
		{
			return GetURI();
		}
		else if ( PTURLConstants.KEY_TITLE.equals(strKey) )
		{
			return m_Title;
		} 
		else if ( PTURLConstants.KEY_ICONIMG.equals(strKey) )
		{
			return m_IconImg;
		}
		else if ( PTURLConstants.KEY_ICONIMGWIDTH.equals(strKey) )
		{
			return  m_IconWidth;
		}
		else if ( PTURLConstants.KEY_ICONIMGHEIGHT.equals(strKey) )
		{
			return  m_IconHeight;
		}
		else if ( PTURLConstants.KEY_ICONIMGALT.equals(strKey) )
		{
			return  m_IconAlt;
		}
		else if ( PTURLConstants.KEY_CURRENTMARKER.equals(strKey) ) 
		{
			return m_MarkedAsCurrent;
		}
		else if ( PTURLConstants.KEY_JAVASCRIPT_ACTION.equals(strKey) ) 
		{
			return m_jsaction;
		}
		else if ( PTURLConstants.KEY_OBJECTID.equals(strKey) ) 
		{
			return m_ObjectID;
		}
		else if ( PTURLConstants.KEY_CLASSID.equals(strKey) ) 
		{
			return m_ClassID;
		}
		else if ( KEY_PARAMS.equals(strKey) )
		{
			// Assume average length of param name and values are 9
			XPStringBuilder buf = new XPStringBuilder(m_listParamNames.GetSize() * 8 * 2 );
			for ( int i = 0; i < m_listParamNames.GetSize(); i++ ) {
				buf.Append(m_listParamNames.GetElement(i) + "=" + m_listParamValues.GetElement(i) + "&");
				
			}
			// remove last & char.
			buf.RemoveCharAt(buf.GetLength()-1);
			
			return buf.ToString();
		}
		// If no predefined URL components exists, look in the querystring parameters first, then non-control parameters. 
		else
		{
			if ( m_listParamNames != null && m_listParamValues != null )
			{
				int nIndex = m_listParamNames.IndexOf(strKey);
				if ( -1 != nIndex )
					return XPConvert.ToString( m_listParamValues.GetElement(nIndex) );
			}
			if ( m_nonControlParamNames != null && m_nonControlParamValues != null )
			{
				int nIndex = m_nonControlParamNames.IndexOf(strKey);
				if ( -1 != nIndex )
					return XPConvert.ToString( m_nonControlParamValues.GetElement(nIndex) );
			}
		}
		
		return null;
	}
	
	/**
	 * Sets data on the URL.
	 * Supports the following keys:
	 * <code>
	 * PTURLConstants.KEY_TITLE
	 * PTURLConstants.KEY_ICONIMG
	 * PTURLConstants.KEY_ICONIMGWIDTH
	 * PTURLConstants.KEY_ICONIMGHEIGHT
	 * PTURLConstants.KEY_ICONIMGALT
	 * PTURLConstants.KEY_CURRENTMARKER
	 * </code>
	 * @param strKey	Key of the data
	 * @param strValue	Value of the data
	 * 
	 * @see PTURLConstants
	 */
	public void SetURLData(String strKey, String strValue)
	{
		if ( PTURLConstants.KEY_TITLE.equals(strKey) )
		{
			m_Title = strValue;
		} 
		else if ( PTURLConstants.KEY_ICONIMG.equals(strKey) )
		{
			m_IconImg = strValue;
		}
		else if ( PTURLConstants.KEY_ICONIMGWIDTH.equals(strKey) )
		{
			m_IconWidth = strValue;
		}
		else if ( PTURLConstants.KEY_ICONIMGHEIGHT.equals(strKey) )
		{
			m_IconHeight = strValue;
		} 
		else if ( PTURLConstants.KEY_ICONIMGALT.equals(strKey) )
		{
			m_IconAlt = strValue;
		}
		else if ( PTURLConstants.KEY_CURRENTMARKER.equals(strKey) ) 
		{
			m_MarkedAsCurrent = strValue;
		}
		else if (PTURLConstants.KEY_JAVASCRIPT_ACTION.equals(strKey) )  
		{
			m_jsaction = strValue;
		}
		else if (PTURLConstants.KEY_OBJECTID.equals(strKey) )  
		{
			m_ObjectID = strValue;
		}
		else if (PTURLConstants.KEY_CLASSID.equals(strKey) )  
		{
			m_ClassID = strValue;
		}
		else 
		{
			// set an arbitrary name/value combination
			AddNonControlParameter(strKey, strValue);
		}
	}

	/**
	 * Adds a string parameter to the URL.
	 * This parameter is not reflected in the URL itself but can be used to store
	 *   arbitrary name/value combinations on the URL object for use in PT tags
	 *   (i.e., a community link tag could contain a page name and id as well)
	 * 
	 * @param strKey	Name of the parameter.
	 * @param strValue	Value of the parameter as a <code>String</code>.
	 */
	public void AddNonControlParameter(String strKey, String strValue)
	{
		if ( null == m_nonControlParamNames || null == m_nonControlParamValues) {
			m_nonControlParamNames = new XPArrayList();
			m_nonControlParamValues = new XPArrayList();
		}
		m_nonControlParamNames.Add(strKey);
		m_nonControlParamValues.Add(strValue);
		
	}

	/**
	 * Adds a string parameter to the querystring on this URL.
	 * E.g. param=value
	 * 
	 * @param strKey	Name of the parameter.
	 * @param strValue	Value of the parameter as a <code>String</code>.
	 */
	public void AddControlParameter(String strKey, String strValue)
	{
		if ( null == m_listParamNames || null == m_listParamValues ) {
			m_listParamNames = new XPArrayList();
			m_listParamValues = new XPArrayList();
		}
		m_listParamNames.Add(strKey);
		m_listParamValues.Add(XPHttpUtility.UrlEncode( strValue, LinkConstants.UTF_8_ENCODING));
		
	}

	/**
	 * Adds a integer parameter to the querystring on this URL.
	 * E.g. param=1
	 * 
	 * @param strKey		Name of the parameter.
	 * @param nValue		Value of the parameter as an integer.
	 */
	public void AddControlParameter(String strKey, int nValue)
	{
		if ( null == m_listParamNames || null == m_listParamValues ) {
			m_listParamNames = new XPArrayList();
			m_listParamValues = new XPArrayList();
		}
		m_listParamNames.Add(strKey);
		m_listParamValues.Add(  XPHttpUtility.UrlEncode( XPConvert.ToString(nValue), LinkConstants.UTF_8_ENCODING));
		
	}
	
	/**
	 * Helper function to set URL Image with the width and height component.
	 * Equivalent to setting <code>PTURLConstants.KEY_ICONIMG</code>, <code>PTURLConstants.KEY_ICONIMGWIDTH</code> and 
	 * <code>PTURLConstants.KEY_ICONIMGHEIGHT</code> manually. 
	 * 
	 * @param image		<code>PTImageType</code> of the image to use.
	 * 
	 * @see PTImageType
	 */
	public void SetURLImageType(PTImageType image, String strImageServerBaseURL)
	{
		if ( image != null )
		{
			
			SetURLData(PTURLConstants.KEY_ICONIMG, strImageServerBaseURL+image.GetFileName());
			SetURLData(PTURLConstants.KEY_ICONIMGWIDTH, image.GetWidth());
			SetURLData(PTURLConstants.KEY_ICONIMGHEIGHT, image.GetHeight());
		}
		
	}
	
	
	/**
	 * Gets child data for hierarchical data 
	 * @param children
	 */
	public XPArrayList GetHierData(String key)
	{
		if ( m_children == null ) return null;
		return (XPArrayList)m_children.GetElement(key);
	}
	
	/**
	 * Sets child data for hierarchical data 
	 * @param children
	 */
	public void SetHierData(String key, XPArrayList children)
	{
		if ( m_children == null ) m_children = new XPHashtable(); // only create it when needed as most data url are not hierarchical
		m_children.PutElement(key, children);
	}
	
}