package com.plumtree.portaluiinfrastructure.ptlink;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.uiinfrastructure.statichelpers.GeneralHelpers;

// CR: DCA - this class is almost like the FriendlyURL class and in fact uses it when it comes down to actually generating the URL.
// Maybe we should combine the two into one class?
// rob - FriendlyURL class is just a structure to hold the components of a friendly url and an interface to generate the actual url
// (so you don't have to call into the class type descriptor). This class is a wrapper for IDataObject interface so that you can
// get the different url components from tags. Combining both classes would be messy since you would have additional functionality
// in FriendlyURL that isn't needed by anywhere else except tags. No functionality is duplicated, just two layers of interfaces for
// cleaner separation of functionality.
/**
 * Class for generating friendly Urls in Adaptive Tags
 * 
 * @author robertz
 */
public class CommonOpenerFriendlyURL extends ACommonOpenerURL 
{
	
	/**
	 * Class ID in the URL
	 */
	public final static String KEY_FRIENDLYURL_CLASSID = "clsid";
	
	/**
	 * Object ID in the URL
	 */
	public final static String KEY_FRIENDLYURL_OBJECTID = "objid";
	
	/**
	 * Object Name in the URL 
	 */
	public final static String KEY_FRIENDLYURL_OBJECTNAME = "objname";
	
	public final static String KEY_FRIENDLYURL_CHILDNAME = "childname";
	public final static String KEY_FRIENDLYURL_CHILDID = "childid";
	
	protected int m_classId;
	protected int m_objectId;
	protected String m_objectName;
	
	protected int m_childId;
	protected String m_childName;
	
	protected String m_friendlyURL;
	protected String m_friendlyURI;
	
	public CommonOpenerFriendlyURL(String label, int classId, int objectId, AActivitySpace space) 
	{
		super(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space), IOpenerConstants.OPENER_MODE_VIEW);
		m_classId 	= classId;
		m_objectId = objectId;
		
		ConstructFriendlyURL(space);
	}
	
	public CommonOpenerFriendlyURL(String label, int classId, int objectId, String objectName, AActivitySpace space) 
	{
		super(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space), IOpenerConstants.OPENER_MODE_VIEW);
		m_classId 	= classId;
		m_objectId = objectId;
		m_objectName = objectName;
		
		ConstructFriendlyURL(space);
	}
	
	public CommonOpenerFriendlyURL(String label, int classId, int objectId, int childId, AActivitySpace space) 
	{
		super(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space), IOpenerConstants.OPENER_MODE_VIEW);
		m_classId 	= classId;
		m_objectId = objectId;
		m_childId = childId;
		
		ConstructFriendlyURL(space);
	}
	
	public CommonOpenerFriendlyURL(String label, int classId, int objectId, String objectName, int childId, AActivitySpace space) 
	{
		super(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space), IOpenerConstants.OPENER_MODE_VIEW);
		m_classId 	= classId;
		m_objectId = objectId;
		m_objectName = objectName;
		m_childId = childId;
		
		ConstructFriendlyURL(space);
	}
	
	public CommonOpenerFriendlyURL(String label, int classId, int objectId, String objectName, int childId, String childName, AActivitySpace space) 
	{
		super(label, PTConfigService.getPTInstance().GetApplicationBaseURL(space), IOpenerConstants.OPENER_MODE_VIEW);
		m_classId 	= classId;
		m_objectId = objectId;
		m_objectName = objectName;
		m_childId = childId;
		m_childName = childName;
		
		ConstructFriendlyURL(space);
	}
	
	/**
	 * 
	 * @param space
	 */
	private void ConstructFriendlyURL(AActivitySpace space)
	{
		FriendlyURL url = null;
		
		if ( m_objectName == null) {
			// DCA - m_Title is not always the object's name
			//if ( m_childId > 0 ) {
			url = new FriendlyURL(m_classId, m_objectId);
			//} else {
			//	url = new FriendlyURL(m_classId, m_Title, m_objectId);
			//}
		} else {
			url = new FriendlyURL(m_classId, m_objectName, m_objectId);
		}
		if ( m_childName != null) {
			url.SetChildName(m_childName);
		} 
		url.SetChildId(m_childId);
		
		m_friendlyURI = url.GetFriendlyURL(space);

		// construct the friendly URL from the baseURL and Friendly URI
		String baseURL = PTConfigService.getPTInstance().GetApplicationBaseURL(space.GetCurrentNormalizedBaseURL());
		baseURL = GeneralHelpers.Replace(baseURL, "?", "");
		m_friendlyURL = baseURL + m_friendlyURI;
	}
	
	/**
	 * 
	 */
	public String GetFullURL() {
		return m_friendlyURL;
	}

	/**
	 * 
	 */
	public String GetURI() {
		return m_friendlyURI;
	}
	
	/**
	 * Gets URL data.
	 * Supports 
	 * 
	 * <code>KEY_FRIENDLYURL_CLASSID</code>
	 * <code>KEY_FRIENDLYURL_OBJECTID</code>
	 * <code>KEY_COMMONOPENER_OPENERMODE</code>
	 * <code>PTURLConstants.KEY_URLTYPE</code>
	 * <code>KEY_FRIENDLYURL_CLASSID</code>
	 * <code>KEY_FRIENDLYURL_OBJECTID</code>
	 * 
	 * in addition to the common URL and CommonOpener URL data keys.
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)
	 */
	public String GetData(String strKey)
	{
		String retVal = null;
		if ( KEY_FRIENDLYURL_CLASSID.equals(strKey) || PTURLConstants.KEY_CLASSID.equals(strKey) )
		{
			retVal = XPConvert.ToString( m_classId );
		} 
		else if ( KEY_FRIENDLYURL_OBJECTID.equals(strKey) || PTURLConstants.KEY_OBJECTID.equals(strKey) )
		{
			retVal =  XPConvert.ToString( m_objectId );
		}
		else if ( KEY_FRIENDLYURL_OBJECTNAME.equals(strKey)  )
		{
			retVal =  m_objectName;
		}
		else if ( KEY_FRIENDLYURL_CHILDID.equals(strKey))
		{
			retVal = XPConvert.ToString( m_childId );
		}
		else if ( KEY_FRIENDLYURL_CHILDNAME.equals(strKey) )
		{
			retVal = m_childName ;
		} 
		else if ( PTMyPages.STR_PAGE_ID.equals(strKey) ) 
		{
			if (m_classId == PT_CLASSIDS.PT_COMMUNITY_ID || m_classId == PT_CLASSIDS.PT_USER_ID)
			{
				// For communities, the page ID should be the child ID.
				retVal = XPConvert.ToString( m_childId );
			} else
			{
				retVal = XPConvert.ToString( m_objectId );				
			}
		}
		else 
		{
			retVal = super.GetData(strKey);
		}
		
		return retVal;
	}
	
	/**
	 * Sets URL data.
	 * In addition to the common keys, also Supports these:
	 * 
	 * <code>KEY_FRIENDLYURL_CLASSID</code>
	 * <code>KEY_FRIENDLYURL_OBJECTID</code>
	 * <code>KEY_COMMONOPENER_OPENERMODE</code>
	 * 
	 * @param strKey
	 * @param nValue
	 */
	public void SetURLData(String strKey, String  strValue)
	{
		if ( KEY_FRIENDLYURL_CLASSID.equals(strKey) || PTURLConstants.KEY_CLASSID.equals(strKey) )
		{
			m_classId = XPConvert.ToInteger(strValue);
		} 
		else if ( KEY_FRIENDLYURL_OBJECTID.equals(strKey) || PTURLConstants.KEY_OBJECTID.equals(strKey) )
		{
			m_objectId = XPConvert.ToInteger(strValue);
		}
		else if ( KEY_FRIENDLYURL_OBJECTNAME.equals(strKey) )
		{
			m_objectName = strValue;
		}
		else if ( KEY_FRIENDLYURL_CHILDID.equals(strKey) )
		{
			m_childId = XPConvert.ToInteger(strValue);
		}
		else if ( KEY_FRIENDLYURL_CHILDNAME.equals(strKey) )
		{
			m_childName = strValue;
		} 
		else 
		{
			super.SetURLData(strKey, strValue);
		}	
	}

}
