package com.plumtree.portaluiinfrastructure.ptlink;

import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.uiinfrastructure.opener.types.classtypes.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * URL Class for CommonOpenerURL using Activityspace name.
 * 
 */
public class CommonOpenerOpenASURL extends ACommonOpenerURL
{
	/**
	 * Name of the Activityspace the URL is referencing.
	 */
	public final static String KEY_COMMONOPENER_ASNAME = "asname"; 

	/**
	 * URL Type.
	 */
	public final static String URL_TYPE_ASCOMMONOPENER = "ascommonpener";
	
	protected String m_strActivitySpaceName;

	/**
	 * 
	 * @param strTitle
	 * @param strApplicationBaseURL
	 * @param strActivitySpaceName
	 * @param nUserID
	 */
	public CommonOpenerOpenASURL(String strTitle, String strApplicationBaseURL, String strActivitySpaceName, int nUserID) 
	{
		super(strTitle, strApplicationBaseURL, nUserID);
		m_strActivitySpaceName = strActivitySpaceName;
	}
	
	
	public CommonOpenerOpenASURL(String strTitle, String strActivitySpaceName, AActivitySpace owner)
	{
		super(strTitle, ConfigService.getInstance().GetApplicationBaseURL(owner), ((IPTSession)owner.GetUserSession()).GetSessionInfo().GetCurrentUserID() );
		m_strActivitySpaceName = strActivitySpaceName;
		
		AddControlParameter(ASConstants.PARENTSPACEID, owner.GetSpaceID());
		AddControlParameter(ASConstants.PARENTSPACENAME, owner.GetName());
		
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetFullURL()
	 */
	public String GetFullURL()
	{
		return PTOpenerLinks.GetOpenerURLOpenAS
			(m_strActivitySpaceName, 
			HTTPHelpers.GetParameterListAsString(m_listParamNames, m_listParamValues), 
			m_nOpenerMode, 
			m_strApplicationBaseURL, 
			m_nUserID);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetURI()
	 */
	public String GetURI()
	{
		return		
			UIActivitySpaces.QS_ACTIVITY_SPACE_NAME +  "="+m_strActivitySpaceName+"&"+
			HTTPHelpers.GetParameterListAsString(m_listParamNames, m_listParamValues)+
			IPTOpenerConstants.QS_MODE+       "="+m_nOpenerMode+"&"+
			IPTOpenerConstants.QS_USERID+    "="+m_nUserID+"&"
			;
	}
	
	/**
	 * Supports <code>KEY_COMMONOPENER_ASNAME</code> in addition to the common URL and CommonOpener
	 * URL data keys.
	 * @see com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)
	 */
	public String GetData(String strKey)
	{
		String retVal = null;
		if ( KEY_COMMONOPENER_ASNAME.equals(strKey) )
		{
			retVal = m_strActivitySpaceName;
		} 
		else if ( PTURLConstants.KEY_URLTYPE.equals(strKey))
		{
			retVal =  URL_TYPE_ASCOMMONOPENER;
		}
		else 
		{
			retVal = super.GetData(strKey);
		}
		return retVal;
	}
	
	/**
	 * 
	 * @see com.plumtree.portaluiinfrastructure.ptlink.IPTURL#SetURLData(java.lang.String, java.lang.String)
	 */
	public void SetURLData(String strKey, String strValue)
	{
		if ( KEY_COMMONOPENER_ASNAME.equals(strKey) )
		{
			m_strApplicationBaseURL = strValue;
		} 
		else
		{	
			super.SetURLData(strKey, strValue);
		}
	}
}