/*
 * Created on Dec 8, 2004
 */
package com.plumtree.portaluiinfrastructure.ptlink;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 *  URL Class for CommonOpenerURL using Object ID and Class ID pair.
 * 
 * UPDATE FOR PORTAL 6.5: This class has been repurposed to use friendly URL
 * instead of commonopener URL. Just keep this as a facade so that we don't have
 * to change old code
 */
public class CommonOpenerOpenObjIDURL extends ACommonOpenerURL implements IDataObject
{
	/**
	 * Class ID in the URL
	 */
	public final static String KEY_COMMONOPENER_CLASSID = "clsid";
	
	/**
	 * Object ID in the URL
	 */
	public final static String KEY_COMMONOPENER_OBJECTID = "objid";

	public static final String URL_TYPE_OBJCOMMONOPENER = "objcommonopener";
	
	protected int m_nClassID;
	protected int m_nObjectID;
	
	public final static String KEY_COMMONOPENER_PAGEID = "PageID";
	protected int m_nPageID;
	
	
	/**
	 * Add Control Parameters ASConstants.PARENTSPACEID and ASConstants.PARENTSPACENAME. 
	 * 
	 * @param strTitle
	 * @param strApplicationBaseURL
	 * @param nClassID
	 * @param nObjectID
	 * @param nMode
	 * @param nUserID
	 */
	public CommonOpenerOpenObjIDURL(String strTitle, String strApplicationBaseURL, int nClassID, int nObjectID, int nMode, int nUserID) 
	{
		super(strTitle, strApplicationBaseURL, nMode, nUserID);
		m_nClassID 	= nClassID;
		m_nObjectID = nObjectID;
		
	}
	
	/**
	 * Add Control Parameters ASConstants.PARENTSPACEID and ASConstants.PARENTSPACENAME. 
	 * Stores the community page id for later use when the portlet selection layout is trying to access the pageid of the community in
	 * non-friendyURL mode.
	 * 
	 * @param strTitle
	 * @param strApplicationBaseURL
	 * @param nClassID
	 * @param nObjectID
	 * @param nMode
	 * @param nUserID
	 * @param communityPageID
	 */
	public CommonOpenerOpenObjIDURL(String strTitle, String strApplicationBaseURL, int nClassID, int nObjectID, int nMode, int nUserID, int communityPageID) 
	{
		super(strTitle, strApplicationBaseURL, nMode, nUserID);
		m_nClassID 	= nClassID;
		m_nObjectID = nObjectID;
		m_nPageID = communityPageID;
	}
	
	/**
	 * 
	 * @param strTitle
	 * @param nClassID
	 * @param nObjectID
	 * @param nMode
	 * @param owner
	 */
	public CommonOpenerOpenObjIDURL(String strTitle, int nClassID, int nObjectID, int nMode, AActivitySpace owner) 
	{
		super(strTitle, ConfigHelper.GetApplicationBaseURL(owner), nMode, ((IPTSession)owner.GetUserSession()).GetSessionInfo().GetCurrentUserID());
		
		m_nClassID 	= nClassID;
		m_nObjectID = nObjectID;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetFullURL()
	 */
	public String GetFullURL()
	{
		return PTOpenerLinks.GetOpenerURLOpenObjID( m_nClassID, 
			m_nObjectID, 
			HTTPHelpers.GetParameterListAsString(m_listParamNames, m_listParamValues), 
			m_nOpenerMode, 
			m_strApplicationBaseURL, 
			m_nUserID);
		
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.ptlink.IPTURL#GetURI()
	 */
	public String GetURI()
	{
		return
			IPTOpenerConstants.QS_CLASSID+  "="+m_nClassID+"&"+
			IPTOpenerConstants.QS_OBJECTID+"="+m_nObjectID+"&"+
			HTTPHelpers.GetParameterListAsString(m_listParamNames, m_listParamValues)+
			IPTOpenerConstants.QS_MODE+       "="+m_nOpenerMode+"&"+
			IPTOpenerConstants.QS_USERID+    "="+m_nUserID+"&"
			;
	}
	
	/**
	 * Gets URL data.
	 * Supports 
	 * 
	 * <code>KEY_COMMONOPENER_CLASSID</code>
	 * <code>KEY_COMMONOPENER_OBJECTID</code>
	 * <code>KEY_COMMONOPENER_OPENERMODE</code>
	 * <code>PTURLConstants.KEY_URLTYPE</code>
	 * <code>KEY_COMMONOPENER_CLASSID</code>
	 * <code>KEY_COMMONOPENER_OBJECTID</code>
	 * 
	 * in addition to the common URL and CommonOpener URL data keys.
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(java.lang.String)
	 */
	public String GetData(String strKey)
	{
		String retVal = null;
		if ( KEY_COMMONOPENER_CLASSID.equals(strKey) )
		{
			retVal = XPConvert.ToString( m_nClassID);
		} 
		else if ( KEY_COMMONOPENER_OBJECTID.equals(strKey) )
		{
			retVal =  XPConvert.ToString( m_nObjectID);
		}
		else if ( KEY_COMMONOPENER_OPENERMODE.equals(strKey) )
		{
			retVal =  XPConvert.ToString( m_nOpenerMode);
		}
		else if ( PTURLConstants.KEY_URLTYPE.equals(strKey))
		{
			retVal = URL_TYPE_OBJCOMMONOPENER;
		}
		else if ( KEY_COMMONOPENER_CLASSID.equals(strKey))
		{
			retVal = XPConvert.ToString( m_nClassID );
		}
		else if ( KEY_COMMONOPENER_OBJECTID.equals(strKey) )
		{
			retVal = XPConvert.ToString( m_nObjectID );
		}
		else if ( KEY_COMMONOPENER_PAGEID.equals(strKey))
		{
			retVal = XPConvert.ToString(m_nPageID);
		}
		else {
			retVal = super.GetData(strKey);
		}
		
		return retVal;
	}
	
	/**
	 * Sets URL data.
	 * In addition to the common keys, also Supports these:
	 * 
	 * <code>KEY_COMMONOPENER_CLASSID</code>
	 * <code>KEY_COMMONOPENER_OBJECTID</code>
	 * <code>KEY_COMMONOPENER_OPENERMODE</code>
	 * 
	 * @param strKey
	 * @param nValue
	 */
	public void SetURLData(String strKey, String  strValue)
	{
		if ( KEY_COMMONOPENER_CLASSID.equals(strKey) )
		{
			m_nClassID = XPConvert.ToInteger(strValue);
		} 
		else if ( KEY_COMMONOPENER_OBJECTID.equals(strKey) )
		{
			m_nObjectID = XPConvert.ToInteger(strValue);
		}
		else if ( KEY_COMMONOPENER_OPENERMODE.equals(strKey) )
		{
			m_nOpenerMode = XPConvert.ToInteger(strValue);
		} else {
			super.SetURLData(strKey, strValue);
		}	
	}
	
}