/*
 */
package com.plumtree.portaluiinfrastructure.ptlink;

import com.plumtree.portaluiinfrastructure.tags.data.*;

/**
 * PTURL Interface
 */
public interface IPTURL extends IHierarchicalDataObject
{
	/**
   	 * Returns the entire URL with http:// and server name
	 * E.g http://portalserver/portal/server.pt 
	 **/
	public String GetFullURL();
	/**
   	 * Returns the URI, the part of the URL after sever name
	 * E.g /portal/server.pt 
	 **/
	public String GetURI();
	
	/**
	 * Sets URL data.
	 * Each type of URL supports different URL data. 
	 * 
	 * @param strKey		Key of the URL data to set.
	 * @param strValue	Value of the URL data.
	 */
	public void SetURLData(String strKey, String strValue);

	/**
	 * Adds a string parameter to the querystring on this URL.
	 * E.g. param=value
	 * 
	 * @param strKey	Name of the parameter.
	 * @param strValue	Value of the parameter as a <code>String</code>.
	 */
	public void AddControlParameter(String strKey, String strValue);

	/**
	 * Adds a integer parameter to the querystring on this URL.
	 * E.g. param=1
	 * 
	 * @param strKey		Name of the parameter.
	 * @param nValue		Value of the parameter as an integer.
	 */
	public void AddControlParameter(String strKey, int nValue);
	
	/**
	 * Adds a string parameter to the URL.
	 * This parameter is not reflected in the URL itself but can be used to store
	 *   arbitrary name/value combinations on the URL object for use in PT tags
	 *   (i.e., a community link tag could contain a page name and id as well)
	 * 
	 * @param strKey	Name of the parameter.
	 * @param strValue	Value of the parameter as a <code>String</code>.
	 */
	public void AddNonControlParameter(String strKey, String strValue);
	
}