package com.plumtree.portaluiinfrastructure.ptmulticolumnlist;


// Framework Imports
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This interface is implemented by the Model.
 * It contains all the read-only mothods of the Model
 * accessed by the Views.
 *
 * @author Julie Fournier
 */
public interface IPTMultiColumnListModelRO extends IExpListModelRO
{
	/**
	 * Returns the accesslevel of the objects for the tree control to display.
	 *
	 * @return int
	 */
	public int GetAccessLevel();

	/**
	 * Returns the create new actions information.
	 *
	 * @return Object[][]
	 */
	public Object[][] GetCreateNewInfo();

	/**
	 * Returns the URL to the Editor in create mode (new object).
	 *
	 * @param _nClassID
	 * @param _sEditorASName
	 *
	 * @return ASURL URL to the Editor
	 */
	public ASURL GetCreateNewURL(int _nClassID, String _sEditorASName);

	/**
	 * Returns the URL to edit the object.
	 *
	 * @param _nClassID
	 * @param _nObjectID
	 * @param _sEditorASName
	 *
	 * @return ASURL URL to the Editor
	 */
	public ASURL GetEditObjectURL(int _nClassID, int _nObjectID);

	/**
	 * Returns the row currently being edited.
	 * @return int
	 */
	public int GetEditRow();

	/**
	 * Returns the comma-delimited string of classids and objectids for objects
	 * that are to be hidden by the tree.  The format of the string is as
	 * follows: ClassID1,ObjectID1, ClassID2,ObjectID2, etc..
	 *
	 * @return String
	 */
	public String GetHiddenObjects();

	/**
	 * Returns true if this list includes a Plumtree object selected from the
	 * tree object selector
	 * .
	 * @return boolean
	 */
	public boolean GetIncludePTSelect();

	/**
	 * Returns the number of columns other than the columns used by the
	 * Plumtree selected object.
	 *
	 * @return int
	 */
	public int GetNumColumns();

	/**
	 * Returns String of Class ID of the Objects
	 * displayed in the tree.
	 * E.g.: "2,45,3"
	 *
	 * This is the format used by the tree.
	 *
	 * @return String
	 */
	public String GetObjectClassIDs();

	/**
	 * Returns the zero-based display position of the selected Plumtree object,
	 * if applicable.
	 *
	 * @return int
	 */
	public int GetPTObjectPosition();

	/**
	 * Returns the icon to display on each row before the
	 * input text. If the value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon();

	/**
	 * Returns a String of Class IDs and Object IDs of the Objects
	 * to select in the tree.
	 * E.g.: "classID1,ObjID1,classID2,objID2"
	 *
	 * This is the format used by the tree.
	 *
	 * @return String
	 */
	public String GetSelectedItems();

	/**
	 * Returns the leaf type of the tree.
	 *
	 * @return int
	 */
	public int GetTreeLeafType();

	/**
	 * Returns the selection type of the tree.
	 * Converts the boolean value to a string so that it can be
	 * put in the query string for the tree.
	 *
	 * @return String
	 */
	public String GetTreeMultiSelect();

	/**
	 * Returns the query filter for the tree.
	 *
	 * @return String
	 */
	public String GetTreeQueryFilter();

	/**
	 * Returns tree AS ID.
	 *
	 * @return String
	 */
	public String GetTreeSpaceID();

	/**
	 * Returns the Tree sub title.
	 *
	 * @return String
	 */
	public String GetTreeSubTitle();
	/**
	 * Returns the Tree title.
	 *
	 * @return String
	 */
	public String GetTreeTitle();

	/**
	 * @see com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.SelectPTObjectModel#GetDisplayObjects()
	 *
	 */
	public String GetDisplayObjects();
	
	/**
	 * Returns true if it should be possible to edit Objects from this class ID.
	 *
	 * @param _nClassID
	 */
	public boolean IsEditLinkEnabled(int _nClassID);
}

