package com.plumtree.portaluiinfrastructure.ptmulticolumnlist;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is an implementation of the Expandable List framework for the Multi
 * Column Array. Is constains the HTML to display the Array. It gets the data to
 * display from MultiColumnListModel.
 *
 * @author JohnH
 */
public class PTMultiColumnListView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.ptmulticolumnlist.PTMultiColumnListView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "PTMultiColumnListView";

	/**
	 * HTML element names */
	public static final String HTMLINPUT_ITEM     = "in_tx_Item";

	/** Hidden element for the edit row */
	public static final String HTMLHIDDEN_EDITROW = "in_hi_EditField";

	/** HTML input for the tree space id */
	public static final String HTMLINPUT_TREEASID = "in_hi_TreeSpaceID";

	//Javascript functions

	/** Javascript funtion name */
	public static final String JAVASCRIPT_SETEDITROW = "SetEditRow";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PTMultiColumnListView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLInput myInput;

		try
		{
			result.AddInnerHTMLElement(super.Display());
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_EDITROW,
					HTMLHIDDEN_EDITROW);
			myInput.SetValue(XPConvert.ToString(((IPTMultiColumnListModelRO) m_model).GetEditRow()));
			result.AddInnerHTMLElement(myInput);
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "PTMultiColumnListView::Display", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(52, "ptmsgs_infrastructure"));
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		// The URL to open a new tree
		ASURL myNewTree = new ASURL(m_asOwner);

		myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);

		myNewTree.SetSubSpaceKey(((IPTMultiColumnListModelRO) m_model).GetUniqueString(
				PTMultiColumnListModel.SUBSPACE_KEY_SELECTTREE));
		myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		myNewTree.AddControlArgument(StartTreeControl.ROOT_ID,
			XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
		myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
			((IPTMultiColumnListModelRO) m_model).GetTreeMultiSelect());
		myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(
				((IPTMultiColumnListModelRO) m_model).GetTreeLeafType()));
		myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			((IPTMultiColumnListModelRO) m_model).GetUniqueString(
				HTMLINPUT_TREEASID));
		myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			((IPTMultiColumnListModelRO) m_model).GetUniqueString(
				"OnReturnFromTree"));
		myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			((IPTMultiColumnListModelRO) m_model).GetObjectClassIDs());
		myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
			((IPTMultiColumnListModelRO) m_model).GetSelectedItems());
		myNewTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL,
			XPConvert.ToString(
				((IPTMultiColumnListModelRO) m_model).GetAccessLevel()));

		if (null != ((IPTMultiColumnListModelRO) m_model).GetTreeTitle())
		{
			myNewTree.AddControlArgument(StartTreeControl.TITLE,
				((IPTMultiColumnListModelRO) m_model).GetTreeTitle());
		}

		if (null != ((IPTMultiColumnListModelRO) m_model).GetTreeSubTitle())
		{
			myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
				((IPTMultiColumnListModelRO) m_model).GetTreeSubTitle());
		}

		if (!("").equals(
					((IPTMultiColumnListModelRO) m_model).GetHiddenObjects()))
		{
			myNewTree.AddControlArgument(StartTreeControl.HIDDEN_ITEMS,
				((IPTMultiColumnListModelRO) m_model).GetHiddenObjects());
		}

		if (null != ((IPTMultiColumnListModelRO) m_model).GetDisplayObjects())
		{
			myNewTree.AddControlArgument(StartTreeControl.DISPLAYED_ITEMS,
				((IPTMultiColumnListModelRO) m_model).GetDisplayObjects());
		}

		if (!("").equals(
					((IPTMultiColumnListModelRO) m_model).GetTreeQueryFilter()))
		{
			myNewTree.AddControlArgument(StartTreeControl.QUERY_FILTER,
				((IPTMultiColumnListModelRO) m_model).GetTreeQueryFilter());
		}

		// The url to open a previously opened server user tree
		// This needs to have the SpaceID added to it.
		ASURL myOldTree = new ASURL(m_asOwner);
		myOldTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		myOldTree.IsSubSpace();

		XPStringBuilder sb;

		try
		{
			// Open Tree function
			sb = new XPStringBuilder(200);
			sb.Append("function " +
				((IPTMultiColumnListModelRO) m_model).GetUniqueString(
					"OpenTree") + "(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('").Append(myNewTree.GetURLAsString())
			.Append("', '").Append(((IPTMultiColumnListModelRO) m_model).GetUniqueString("_blank3")).Append("', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(myOldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '").Append(((IPTMultiColumnListModelRO) m_model).GetUniqueString("_blank3")).Append("', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			// On return from Tree function
			sb = new XPStringBuilder(200);
			sb.Append(" function " +
				((IPTMultiColumnListModelRO) m_model).GetUniqueString(
					"OnReturnFromTree") + "()");
			sb.Append(" {");
			sb.Append(" 	postToSelf('" +
				((IPTMultiColumnListModelRO) m_model).GetUniqueInt(
					ExpListControl.POSTTOSELF_ACTION_ADD) + "'); return false;");
			sb.Append(" }");

			myScript.AddInnerHTMLString(sb.ToString());

			// Create new object
			sb = new XPStringBuilder(200);
			sb.Append(" function " +
				((IPTMultiColumnListModelRO) m_model).GetUniqueString(
					"CreateNew") + "(varURL)");
			sb.Append(" {");
			sb.Append(
				"    window.open(varURL,'PopUpCreateMode','location=no,menubar=no,height=600,width=800');\n");
			sb.Append(" }");

			myScript.AddInnerHTMLString(sb.ToString());

			// Edit object
			sb = new XPStringBuilder(200);
			sb.Append(" function " +
				((IPTMultiColumnListModelRO) m_model).GetUniqueString(
					"EditObject") + "(varURL,varIndex)");
			sb.Append(" {");
			sb.Append(
				"    window.open(varURL,'PopUpEditMode' + varIndex,'location=no,menubar=no,height=600,width=800');\n");
			sb.Append(" }");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "PTMultiColumnListView::Display", he, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(101, "ptmsgs_infrastructure"));
		}

		try
		{
			// Set the edit field function
			sb = new XPStringBuilder(200);
			sb.Append("function " + JAVASCRIPT_SETEDITROW + "(strEditRow)\n");
			sb.Append("{\n");
			sb.Append("    document." + AFormDP.HTMLFORM_NAME + ".elements['" +
				HTMLHIDDEN_EDITROW + "'].value = strEditRow;\n");
			sb.Append("    " + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
				((PTMultiColumnListModel) m_model).GetUniqueInt(
					PTMultiColumnListRepostControl.POSTTOSELF_ACTION_EDIT) +
				");");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "PTMultiColumnListView::Display", he, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(101, "ptmsgs_infrastructure"));
		}

		return myScript;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		//Get the other cells
		HTMLTableCell myCell;
		HTMLInput myInput;
		PTButtonType myType;
		PTConstruct construct		 = null;
		HTMLAnchor myAnchor			 = null;
		String strItem;

		boolean bEditMode = false;
		int intColWidth;
		int intNumColumns;
		int intInputSize;

		if (((IPTMultiColumnListModelRO) m_model).GetIncludePTSelect())
		{
			intNumColumns = ((IPTMultiColumnListModelRO) m_model).GetNumColumns() +
				1;
		}
		else
		{
			intNumColumns = ((IPTMultiColumnListModelRO) m_model).GetNumColumns();
		}

		intColWidth = 100 / intNumColumns;

		XPStringBuilder sbColPercent = new XPStringBuilder(5);
		sbColPercent.Append(intColWidth).Append("%");

		XPStringBuilder sbFieldName = new XPStringBuilder(100);
		sbFieldName.Append(HTMLINPUT_ITEM);

		int intStartPosition;
		intStartPosition = ((IPTMultiColumnListModelRO) m_model).GetPTObjectPosition();

		int intIndex;
		String strElementName;

		if (_nRowIndex == ((IPTMultiColumnListModelRO) m_model).GetEditRow())
		{
			bEditMode = true;
		}
		else
		{
			bEditMode = false;
		}

		for (int i = 0; i < intNumColumns; i++)
		{
			if (i < intStartPosition)
			{
				intIndex = i + 1;
			}
			else
			{
				intIndex = i + 3;
			}

			if ((i == intStartPosition) &&
					((IPTMultiColumnListModelRO) m_model).GetIncludePTSelect())
			{
				//Get the first cell
				result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData,
						_nRowIndex));
			}
			else
			{
				sbFieldName.Append(intIndex);
				myCell = new HTMLTableCell();
				myCell.SetWidth(sbColPercent.ToString());
				myCell.SetHeight("30");
				myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
				myCell.SetNoWrap(true);
				strElementName = ((IPTMultiColumnListModelRO) m_model).GetUniqueString(sbFieldName.ToString()) +
					_nRowIndex;

				if (bEditMode)
				{
					myInput = new HTMLInput(HTMLInputTypes.TEXT,
							strElementName, "");
					myCell.AddInnerHTMLElement(myInput);
					myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

					strItem = (String) _saData.GetItem(_nRowIndex, intIndex);

					if (null == strItem 
						|| strItem.startsWith(CommonHTMLStrings.SPACE)) // a hack to avoid using default value for input box 
					{
						myInput.SetValue("");
					}
					else
					{
						myInput.SetValue((String) _saData.GetItem(_nRowIndex,
							intIndex));
					}
					
					switch (intNumColumns)
					{
						case 2:
							intInputSize = 70;
							break;
						case 3:
							intInputSize = 50;
							break;
						case 4:
							intInputSize = 30;
							break;
						case 5:
							intInputSize = 20;
							break;
						default:
							intInputSize = 25;
					}
							
					myInput.SetSize(intInputSize);
				}
				else
				{
					strItem = (String) _saData.GetItem(_nRowIndex, intIndex);

					if (null == strItem)
					{
						myCell.AddInnerHTMLString("");
					}
					else
					{
						// HTMLEncode all other values.
						myCell.AddInnerHTMLEncodedString(strItem);
					}
				}

				result.AddInnerHTMLElement(myCell);
			}
		}

		myCell = new HTMLTableCell();
		result.AddInnerHTMLElement(myCell);
		myCell.SetHeight("20");
		myCell.SetNoWrap(true);

		if (bEditMode)
		{
			myType = PTButtonType.BROWSE;
		}
		else
		{
			myType = PTButtonType.EDIT;
		}

		construct     = null;
		myAnchor	  = null;

		try
		{
			//	Get the construct, do update the strings.
			construct = UIConstructFactory.GetConstruct(myType, true,
					this.m_asOwner);
			construct.ReplaceNestedElementsWithHTMLString(myType.TITLE_ELEMENT_NAME,
				"");
			myAnchor = (HTMLAnchor) construct.GetNestedElement(myType.ANCHOR_ELEMENT_NAME);

			//Implement the on click action to edit the field
			myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);

			if (bEditMode)
			{
				myAnchor.SetOnClick(JAVASCRIPT_SETEDITROW +
					"('-1'); return false;");

				ConstructFactory.SetAltOnButtonImages( construct,m_asOwner.GetString(201,
				"ptmsgs_portalinfrastructure") );
				ConstructFactory.SetTitleOnButtonImages( construct,m_asOwner.GetString(201,
				"ptmsgs_portalinfrastructure") );
				
				
			}
			else
			{
				myAnchor.SetOnClick(JAVASCRIPT_SETEDITROW +
					"('" + _nRowIndex + "'); return false;");

				ConstructFactory.SetAltOnButtonImages( construct,m_asOwner.GetString(200,
				"ptmsgs_portalinfrastructure") );
				ConstructFactory.SetTitleOnButtonImages( construct,m_asOwner.GetString(200,
				"ptmsgs_portalinfrastructure") );						
			}
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "PTMultiColumnListView::GetHTMLForRow", e, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(199, "ptmsgs_portalinfrastructure"));
		}

		myCell.AddInnerHTMLElement(construct.GetHTMLElement());

		if (((IPTMultiColumnListModelRO) m_model).GetEnableMoveRowActions())
		{
			result.AddInnerHTMLElement(super.GetHTMLForMoveRowActions(
					_nRowIndex));
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Empty method that sub classes can averride to add
	 * actions to the action bar (like a create object action).
	 *
	 * @param _myRow Action bar row object.
	 * @throws Exception
	 */
	protected void AddHTMLToActionBar(HTMLTableRow _myRow)
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		Object[][] arrCreateNewInfo = (Object[][]) ((IPTMultiColumnListModelRO) m_model).GetCreateNewInfo();

		if (null != arrCreateNewInfo)
		{
			for (int i = 0; i < arrCreateNewInfo.length; i++)
			{
				int nClassID		 = XPConvert.ToInteger(arrCreateNewInfo[i][PTMultiColumnListModel.CREATE_NEW_COL_CLASSID]);
				String sEditorASName = (String) arrCreateNewInfo[i][PTMultiColumnListModel.CREATE_NEW_COL_ASNAME];
				ASURL myURL			 = ((IPTMultiColumnListModelRO) m_model).GetCreateNewURL(nClassID,
						sEditorASName);

				myCell				 = new HTMLTableCell();
				_myRow.AddInnerHTMLElement(myCell);
				myCell.SetHeight("25");
				myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
				myCell.SetNoWrap(true);
				myCell.AddInnerHTMLString(SPACE);

				// Create new icon
				myConstruct     = UIConstructFactory.GetConstruct((PTImageType) arrCreateNewInfo[i][PTMultiColumnListModel.CREATE_NEW_COL_ICON],
						true, this.m_asOwner);
				myImage = (HTMLImg) myConstruct.GetHTMLElement();
				myImage.SetAlt("");
				myImage.SetAlign("absmiddle");

				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(((IPTMultiColumnListModelRO) m_model).GetUniqueString(
						"CreateNew") + "('" + myURL.GetURLAsString() +
					"'); return false;");
				myAnchor.AddInnerHTMLElement(myImage);
				mySpan = new HTMLSpan();
				myAnchor.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

				// Create label
				mySpan.AddInnerHTMLString((String) arrCreateNewInfo[i][PTMultiColumnListModel.CREATE_NEW_COL_LABEL]);
				mySpan.AddInnerHTMLString(SPACE);
				mySpan.AddInnerHTMLString(SPACE);
				myCell.AddInnerHTMLElement(myAnchor);
				myCell.AddInnerHTMLString(SPACE);
			}
		}
	}

	/**
	 * Helper method to return the add action link.
	 *
	 * @return HTMLAnchor
	 * @throws Exception
	 */
	protected HTMLAnchor GetAnchorForAddAction()

	{
		HTMLAnchor myAnchor;

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick(((IPTMultiColumnListModelRO) m_model).GetUniqueString(
				"OpenTree") + "(document." + AFormDP.HTMLFORM_NAME + "." +
			((IPTMultiColumnListModelRO) m_model).GetUniqueString(
				HTMLINPUT_TREEASID) + "); return false;");

		return myAnchor;
	}

	/**
	 * Returns the HTML for the add cell in the action bar.
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForAddAction()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage, myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;
		HTMLInput myInput;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
				true, this.m_asOwner);
		myAddIcon		    = (HTMLImg) myConstruct.GetHTMLElement();
		myAddIcon.SetAlt("");
		myAddIcon.SetAlign("absmiddle");

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct(((IPTMultiColumnListModelRO) m_model).GetAddIcon(),
				true, this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = GetAnchorForAddAction();
		myAnchor.AddInnerHTMLElement(myAddIcon);
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(((IPTMultiColumnListModelRO) m_model).GetAddLabel());
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);
		myCell.AddInnerHTMLString(SPACE);

		// hidden input with the tree space ID
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				((IPTMultiColumnListModelRO) m_model).GetUniqueString(
					HTMLINPUT_TREEASID), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(((IPTMultiColumnListModelRO) m_model).GetTreeSpaceID());

		return myCell;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForNameColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLAnchor myAnchor;

		myCell = new HTMLTableCell();

		int intColWidth				 = 100 / (((IPTMultiColumnListModelRO) m_model).GetNumColumns() +
			1);
		XPStringBuilder sbColPercent = new XPStringBuilder(5);
		sbColPercent.Append(intColWidth).Append("%");
		myCell.SetWidth(sbColPercent.ToString());
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// row icon
		PTImageType imgRowIcon = ((IPTMultiColumnListModelRO) m_model).GetRowIcon();

		if (null != imgRowIcon)
		{
			myCell.AddInnerHTMLElement(GetIcon(imgRowIcon));
		}

		PTConstruct myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
		HTMLImg myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("---");
		myImage.SetWidth(CommonHTMLStrings.FIVE);
		myImage.SetBorder("0");
		myCell.AddInnerHTMLElement(myImage);

		// Object Name
		String sPTObjectName = (String) _saData.GetItem(_nRowIndex,
				PTMultiColumnListModel.EXPLIST_COL_STRING +
				((IPTMultiColumnListModelRO) m_model).GetPTObjectPosition());
		int nClassID		 = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
				PTMultiColumnListModel.EXPLIST_COL_CLASSID +
				((IPTMultiColumnListModelRO) m_model).GetPTObjectPosition()));

		if (((IPTMultiColumnListModelRO) m_model).IsEditLinkEnabled(nClassID))
		{
			// JF- We are displaying the link to Edit the object
			int nObjectID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					PTMultiColumnListModel.EXPLIST_COL_OBJECTID +
					((IPTMultiColumnListModelRO) m_model).GetPTObjectPosition()));
			ASURL myURL   = ((IPTMultiColumnListModelRO) m_model).GetEditObjectURL(nClassID,
					nObjectID);

			myAnchor	  = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

			myAnchor.SetOnClick(((IPTMultiColumnListModelRO) m_model).GetUniqueString(
					"EditObject") + "('" + myURL.GetURLAsString() + "','" +
				_nRowIndex + "'); return false;");

			myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sPTObjectName));
			myCell.AddInnerHTMLElement(myAnchor);
		}
		else
		{
			// JF- We are just displaying the object name
			myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sPTObjectName));
		}

		return myCell;
	}

	/**
	 * Returns the HTML for the sub header.
	 *
	 * @return HTMLTableRow
	 * @throws Exception
	 */
	protected HTMLTableRow GetHTMLForSubHeader()
	{
		HTMLTableRow myRow = super.GetHTMLForSubHeader();

		IXPEnumerator enumItems = myRow.GetInnerHTMLElements(false);

		if (enumItems != null)
		{
			HTMLElement eTemp = null;

			while (enumItems.MoveNext())
			{
				eTemp = (HTMLElement) enumItems.GetCurrent();
			}

			if (null != eTemp)
			{
				//Set the colspan of the last cell to 2 to accomodate the edit button
				((HTMLTableCell) eTemp).SetColSpan("2");
			}
		}

		return myRow;
	}

	/**
	 * Helper method to get the HTML for the icon.
	 * (Each row has an icon before the input text.)
	 *
	 * @return HTMLImg
	 * @throws Exception
	 */
	protected HTMLImg GetIcon(PTImageType _imgRowIcon)

	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		myConstruct     = UIConstructFactory.GetConstruct(_imgRowIcon, true,
				this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		return (myImage);
	}
}


