package com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;

import com.plumtree.server.PT_INTRINSICS;


/**
 * This class contains constants for the Pathways Handlers.  These can
 * be used in both the JSON format and the XML format.
 * @author Ravi Tunuguntla
 * 
 */

public class PathwaysConstants {
	
	/**
	 * PTSOURCE Field for Portal content used by Pathways REST API
	 */
	public static final String PTSOURCE_PORTAL = "PTPORTAL";
	public static final String PTSOURCE_COLLAB = "PTCOLLAB";
	public static final String PTSOURCE_CONTENT = "PTCONTENT";
	
	/**
	 * REST request format is xml type
	 */
	public static final String KEY_XML = "format=xml";
	
	/**
	 * REST request key for object type item
	 */
	public static final String KEY_ITEM = "item";
	
	/**
	 * REST request key for tags metadata of document
	 */
	public static final String KEY_TAGS = "tags"; 

	/** Tag Element names in Rest API Response **/
	
	/**
	 * REST response key for Tag node
	 */
	
	public static final String KEY_TAG = "tag";
	
	/**
	 * REST response value of the Tag node.
	 */
	public static final String TAG_VALUE = "value";
	
	
	/** Click Through URL Link Prefix for the Pathways Tag on a document */  
	public static final String SEARCH_URL_PREFIX = "searchurlprefix";
	
	
	/**
	 * REST response if this used created the tag for Tag node
	 */
	public static final String TAG_OWNER= "isAppliedByCurrentUser";	
	public static final String TAG_COUNT = "count";
	public static final String TAG_NORMALIZED_COUNT = "normalizedCount";
	
	/** Search Response Element names in Rest API Response **/
	public static final String SEARCH_ACTIVITY_RANK = "activityRank";
	public static final String SEARCH_CLASSID = "classId";
	public static final String SEARCH_DESCRIPTION = "description";
	public static final String SEARCH_FOLDER_CLASSID = "folderClassId";
	public static final String SEARCH_FOLDERID = "folderId";
	public static final String SEARCH_FOLDER_NAME = "folderName";
	public static final String SEARCH_ICON_LINK = "iconLink";
	public static final String SEARCH_IS_FAVORITE = "isFavorite";
	public static final String SEARCH_LAST_MODIFIED = "lastModified";
	public static final String SEARCH_NAME = "name";
	public static final String SEARCH_OBJECTID = "objectId";
	public static final String SEARCH_PATH = "path";
	public static final String SEARCH_RANK = "rank";
	public static final String SEARCH_RESULT_SCORE = "resultScore";
	public static final String SEARCH_SOURCE = "source";
	public static final String SEARCH_TAGS = "tags";
	public static final String SEARCH_TYPE = "type";
	public static final String SEARCH_URL = "URL";
	public static final String SEARCH_VIEW_DETAIL_URL = "viewDetailURL";
	
	//these are new items from pathways that don't have a PT_INTRINSIC option
	public static final int INT_RANK = 500;															//<rank>
	public static final int INT_FOLDERID = 501;														//<folderId>
	public static final int INT_VIEW_DETAILS_URL = 502;												//<viewDetailURL>
	
	/** The faux property (faux since it's not saved in the DB, only indexed) that contains
    the owner id of a manually submitted document.  Used for Graffiti expert identification. */
	public static final int INT_PT_OWNER_ID = PT_INTRINSICS.PT_OWNER_ID;	
	
	/** Rest API URL Parameters **/
	public static final String TAGS_RESOURCE = "tags";
	public static final String ITEMS_RESOURCE = "items";
	public static final String VERSION_RESOURCE = "version";
	public static final String VIEWS_RESOURCE = "views";
	public static final String START_AT_ARG = "startAt";
	public static final String VIEW_ID_ARG = "viewId";
	public static final String QUERY_ARG = "query";
	public static final String RESULT_COUNT_ARG = "resultCount";
	public static final String ORDER_ARG = "order";
	public static final String ORDER_BY_ARG = "orderby";
	public static final String TAG_COUNT_ARG = "tagCount";
	public static final String FORMAT_ARG = "format";
	public static final String OBJECT_TYPES_ARG = "objectTypes";
	public static final String ADMINFOLDERS_ARG = "adminFolders";
	public static final String DIRFOLDERS_ARG = "kdFolders";
	public static final String SPELLCHECK_ARG = "spellcheck";
	
	/** 
	 * Prefix used when performing Pathways Searching by tagname
	 * i.e. http://pathways.devnet.plumtree.com:11960/graffiti/api/items?format=XML&startAt=1&viewId=null&query=tag:"test"&resultCount=20&order=DES&orderby=RANK
	 **/ 
	public static final String TAG_QUERY_PREFIX = "tag:";
	
	/* 
	 * REST response for pathways search results
	 */
	public static final String SEARCH_TOTAL_COUNT = "totalCount";

	/*
	 * Pathways orderBy values
	 */
	public static final String RANK_ARG = "RANK";
	public static final String LAST_MODIFIED_DATE_ARG = "LAST_MODIFIED";
	public static final String NAME_ARG = "NAME";
	public static final String ASC_ARG = "ASC";
	public static final String DES_ARG = "DES";
	
	/** Version Response Element names in Rest API Response **/
	public static final String API_VERSION = "version";
	
	/** Views Response Element names in Rest API Response **/
	public static final String VIEWS_ID = "id";
	public static final String VIEWS_LAST_MODIFIED = "lastModified";
	public static final String VIEWS_NAME = "name";
	
	/** Pathways search query terms **/
	//publisher result type
	public static final String PUBLISHER_ITEMS = "PublisherItems";
	
	//collab result type - NOTE:  when choosing collab items, this entire list of items is added
	public static final String[] COLLAB_ITEMS = new String[]{"CollabDiscussion", "CollabDocument", 
		"CollabEvent", "CollabMessage", "CollabProject", "CollabTask"};
	
	//portal result types, need to be singularily listed as Banner Search and Advanced Search have different options
	public static final String ADMIN_FOLDERS 			= "AdminFolders";
	public static final String AUTHENTICATION_SOURCES 	= "AuthenticationSources";
	public static final String COMMUNITIES 				= "Communities";
	public static final String COMMUNITY_PAGES			= "CommunityPages";
	public static final String COMMUNITY_TEMPLATES		= "CommunityTemplates";
	public static final String CONTENT_SOURCES			= "ContentSources";
	public static final String CONTENT_TYPES			= "ContentTypes";
	public static final String CRAWLERS					= "Crawlers";
	public static final String DOCUMENT_FOLDERS			= "DocumentFolders";
	public static final String EXPERIENCE_DEFINITIONS	= "ExperienceDefinitions";
	public static final String EXTERNAL_OPERATIONS		= "ExternalOperations";
	public static final String FEDERATED_SEARCHES		= "Federated Searches";
	public static final String FILTERS					= "Filters";
	public static final String GROUPS					= "Groups";
	public static final String INVITATIONS				= "Invitations";
	public static final String JOBS						= "Jobs";
	public static final String PAGE_TEMPLATES			= "PageTemplates";
	public static final String PORTAL_DOCUMENTS			= "PortalDocuments";
	public static final String PORTLETS					= "Portlets";
	public static final String PORTLET_TEMPLATES		= "PortletTemplates";
	public static final String PROFILE_SOURCES			= "ProfileSources";
	public static final String PROPERTIES				= "Properties";
	public static final String REMOTE_SERVERS			= "RemoteServers";
	public static final String SNAPSHOT_QUERIES			= "SnapshotQueries";
	public static final String USERS					= "Users";
	public static final String WEB_SERVICES				= "WebServices";
}

