package com.plumtree.portaluiinfrastructure.resultwrapper;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * 
 *
 * @author Michael Smedberg
 */
public class ASQueryResultWrapper implements IASQueryResult
{
	
	private IPTQueryResult m_ptResult = null;

	/** MES- Is our result set complete?  See the IsComplete method. */
	private boolean m_bIsComplete = true;

	/**
	 * Creates a new ASQueryResultWrapper object.
	 *
	 * @param ptResult 
	 * @throws XPException 
	 */
	public ASQueryResultWrapper(IPTQueryResult ptResult)
	{
		if (null == ptResult)
		{
			throw new XPException("Invalid QueryResult supplied, it is null");
		}

		m_ptResult = ptResult;
	}

	/**
	 * 
	 *
	 * @param asResult 
	 * @param nPropID 
	 *
	 * @return 
	 */
	public static XPArrayList ConvertToArrayList(IASQueryResult asResult,
		int nPropID)
	{
		XPArrayList list = new XPArrayList(asResult.GetCount());

		for (int i = 0; i < asResult.GetCount(); i++)
		{
			list.Add(asResult.GetFields(i, nPropID));
		}

		return list;
	}

	/**
	 * 
	 *
	 * @param asResult 
	 * @param anPropID 
	 *
	 * @return 
	 */
	public static XPArrayList ConvertToArrayList(IASQueryResult asResult,
		int[] anPropID)
	{
		XPArrayList list = new XPArrayList(asResult.GetCount());

		for (int i = 0; i < asResult.GetCount(); i++)
		{
			String[] objAr = new String[anPropID.length];

			for (int j = 0; j < anPropID.length; j++)
			{
				Object value = asResult.GetFields(i, anPropID[j]);
				objAr[j] = XPConvert.ToString(value);
			}

			list.Add(objAr);
		}

		return list;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCount()
	{
		return m_ptResult.RowCount();
	}

	/**
	 * 
	 *
	 * @param nIndex 
	 * @param nPropertyMask 
	 *
	 * @return 
	 */
	public Object GetFields(int nIndex, int nPropertyMask)
	{
		return m_ptResult.ItemAsObject(nIndex, nPropertyMask);
	}

	/**
	 * MES- IsComplete returns a boolean indicating if the rows we can return
	 * are the complete rowset (i.e. have we truncated the rowset because it's
	 * too large to bring to the client.)
	 *
	 * @return A boolean indicating completeness.
	 */
	public boolean IsComplete()
	{
		//MES- The code that set us up knows if we're complete, 
		//	just return our member value
		return m_bIsComplete;
	}

	/**
	 * MES- SetIsComplete lets the code that sets us up decide
	 * if we have all the data.  For example, if some code creates
	 * a QueryResult by doing a query that's constrained to a given
	 * number of rows, and the query returns that number of rows (and
	 * would therefore probably return more if more were asked for)
	 * the code should call SetIsComplete(false).  The default value
	 * is true.
	 *
	 * @param bIsComplete indicates if the QueryResult we're wrapping
	 * is complete (i.e does it contain all rows that match the Query
	 * constraints, or has it been truncated?)
	 */
	public void SetIsComplete(boolean bIsComplete)
	{
		//MES- Just store the value
		m_bIsComplete = bIsComplete;
	}
}

