package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public class BreadcrumbControl extends SearchResultControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.search.BreadcrumbControl");

	
	public static final String STR_MVC_CLASS_NAME = "crumb";

	
	public static final String KEY_OF_MODEL_TO_RESTORE_DATA = "restorekey";

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *  Factory method to make a breadcrumb link for search results.
	 *   @param model     Current batch of search results
	 *   @param parent    ActivitySpace we're living in
	 *   @param urlText   Desired text within URL
	 *   @param key       Key of model to display
	 */
	public static HTMLElement makeURL(ISearchResultModelRO model,
		AActivitySpace parent, String urlText, String key)

	{
		// Create a URL that directs into the current Activity Space
		ILinkElement url = null;

    boolean embedInForm = SpaceNeedsPassthruURL(parent);

		if (embedInForm)
		{
			url = new PassthruURL();
		}
		else
		{
			url = new ASURL(parent);
			url.SetLinkGetCachedSpace(parent);
			url.SetDisplayPage(parent.GetCurrentPage().GetName());
		}

		// Create a BreadcrumbControl within the search space
		url.SetControl(BreadcrumbControl.STR_MVC_CLASS_NAME);

		// Set superclass data
		addCommonData(model, url);

		// Set link text
		url.AddInnerHTMLString(urlText);

		// Set other data
		url.AddControlArgument(BreadcrumbControl.KEY_OF_MODEL_TO_RESTORE_DATA,
			key);

		return url.GetURLAsHTMLElement();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new BreadcrumbControl();
	}

	/**
	 * @see com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()
	 */
	protected Redirect ExecuteSearchControl(XPHashtable args, String keyOnPage)
		throws SearchExecutionException
	{
		// First result
		String[] values = (String[]) args.GetElement(KEY_OF_MODEL_TO_RESTORE_DATA);

		if (null == values)
		{
			
				log.Error("could not find key of model to restore");
			

			return null;
		}

		String keyOfModelToRestore = values[0];

		// Tell the model to return to the specified model
		_model.RestoreFromBreadcrumb(keyOnPage, keyOfModelToRestore);

		// Don't need to redirect to a different page or space; just
		// redisplay the page
		return null;
	}
}

