package com.plumtree.portaluiinfrastructure.search;


/**
 * @author CraigS
 */
public interface IBaseSearchQueryRO
{
	/**
	 *  Returns the abstract types the search was restricted to, if any.
	 */
	public int GetAbstractTypeRestrictions();

	/**
	 *  Returns the admin folders the search was restricted to, if any.
	 */
	public int[] GetAdminFolderRestrictions();

	/**
	 *  Returns the applications the search was restricted to, if any.
	 */
	public int GetApplicationRestrictions();

	/**
	 *  Utility method to lookup the name of a community given its id.
	 */
	public String GetCommunityNameForID(int id);

	/**
	 *  Returns the communities the search was restricted to, if any.
	 */
	public int[] GetCommunityRestrictions();

	/**
	 *  Returns the Content Server portlets the search was restricted to, if any.
	 */
	public int[] GetPortletRestrictions();

	/**
	 *  Returns the Collab projects the search was restricted to, if any.
	 */
	public int[] GetCollabProjectRestrictions();

	/**
	 *  Utility method to lookup the name of a portlet given its id.
	 */
	public String GetPortletNameForID(int id);

	/**
	 *  Returns the document folders the search was restricted to, if any.
	 */
	public int[] GetDocFolderRestrictions();

	/**
	 *  Utility method to lookup the name of a folder given its id.
	 *  Pass isAdmin = true for admin folders, false for doc folders.
	 */
	public String GetFolderNameForID(int id, boolean isAdmin);

	/**
	 *  Returns true if the folder restrictions included subfolders.
	 */
	public boolean GetIncludeSubfolders();

	/**
	 *  Returns the two-character code for the language restriction, if
	 *  any, or null otherwise.
	 */
	public String GetLanguageRestriction();

	/**
	 *  Returns the types (as PT_CLASSIDs) the search was restricted to, if any.
	 */
	public int[] GetObjectTypeRestrictions();

	/**
	 *  Returns the user's original search string.
	 */
	public String GetSearchString();
	
	/**
	 * 	Returns the original search string with meta search substrings being replaced with
	 * locale specific substrings 
	 * e.g: tag:test will be returned as etiqueta:test in spanish
	 * @return
	 */
	public String GetLocalizedSearchString();
}

