package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.pagination.*;

/**
 * @author CraigS
 */
public interface IBaseSearchResultModelRO extends IModelRO, IPaginationRO,
	IBaseSearchQueryRO
{
	/**
	 *  Returns the keyword-in-context (KWIC) information for
	 *  a result.
         *  This method html-encodes always returns an html-encoded result, except
         *  that keywords are surrounded by highlighting tags.  Note that
         *  html-encoding is NOT applied to the return value of any other
         *  method from this interface.
	 */
	public String GetKWIC(int rank);

	/**
	 *  Returns a result's abstract (app-independent) type: DOCUMENT,
	 *  CONTAINER, or OTHER.
	 */
	public String GetResultAbsType(int rank);

	/**
	 *  Returns a result's application: PTPORTAL, PTCOLLAB, PTCONTENT.
	 */
	public String GetResultApp(int rank);

	/**
	 *  Returns true if a result is a Best Bet.
	 */
	public boolean isResultBestBet(int rank);

	/**
	 *  Information on individual results
	 */
	/**
	 *  Returns a result's class ID.  Defined for portal objects only, returns
	 *  -1 for other types.
	 */
	public int GetResultClassID(int rank);

	/**
	 *  Returns the value of a gadget field for the result. Portlet
	 *  fields are a small set of special case fields:
   *   PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_TYPE
   *   PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_ALIGNMENT
   *   PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_USER_INTERFACES
	 */
	public String GetResultPortletField(int rank, int fieldId);

	/**
	 *  Returns a result's creation date.
	 */
	public XPDateTime GetResultCreated(int rank);

	/**
	 *  Returns the value of an EOD property for a result.
	 */
	public String GetResultEODField(int rank, int propertyId);

	/**
	 *  Returns the ID of the folder in which this result is found.
	 */
	public int GetResultFolderID(int rank);

	/**
	 *  Returns the icon corresponding to an item's application and class,
	 *  and any other relevant info (i.e. file extension)
	 *  This actually returns an HTMLImg.
	 */
	public Object GetResultIcon(int rank);

	/**
	 *  Returns a result's last-modified date.
	 */
	public XPDateTime GetResultLastModified(int rank);

	/**
	 *  Returns a result's name.
	 */
	public String GetResultName(int rank);

	/**
	 *  Returns a result's object ID.  Defined for portal objects only, returns
	 *  -1 for other types.
	 */
	public int GetResultObjectID(int rank);

	/**
	 *  Returns the full path to a result.
	 */
	public String GetResultPath(int rank);

	/**
	 *  Returns a result's size.
	 */
	public int GetResultSize(int rank);

	/**
	 *  Returns a result's app-specific subtype: PTCARD, PTGADGET, etc.
	 */
	public String GetResultSubType(int rank);

	//
	//  Error states
	//

	/**
	 *  Returns any SearchExecutionError that occurred during the
	 *  last search.  If this is non-null, then no search results
	 *  are available (and calling any of the getResultXXX methods
	 *  will result in throwing another exception).  This error
	 *  should be displayed to the user in some way.
	 */
	public SearchExecutionError GetError();

	/**
	 *  Returns any SearchExecutionWarning that occurred during the
	 *  last search.  If this is non-null, then the warning should
	 *  be displayed to the user, but some search results are still
	 *  available (they may not be complete or may not match the
	 *  user's expectations).
	 */
	public SearchExecutionWarning GetWarning();

	/**
	 *  Returns true if the model has been initialized (i.e. if
	 *  a search has been run).
	 */
	public boolean IsInitialized();
}

