package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public interface IGroupedResultsViewHelper
{
  /**
   *  Any of the calls made through this interface may return null.
   *
   *  The order of calls made is:
   *
   *   if results ungrouped:
   *      Init
   *      DisplayJavascript
   *      DisplayCollection                  (example: returns HTMLTable)
   *      DisplayHeader                      (might not need anything here)
   *      DisplayHeaderIfUngrouped           (column headings)
   *      DisplaySingleResult (n times)
   *      DisplayFooterIfUngrouped           (anything else you need)
   *      DisplayFooter                      (anything else you need)
   *
   *   if results grouped:
   *      Init
   *      DisplayJavascript
   *      DisplayCollection                  (example: returns HTMLTable)
   *      DisplayHeader                      (might not need anything here)
   *      DisplayGroupHeader                 (group name, column headings)
   *      DisplaySingleResult (n times)
   *      DisplayGroupFooter                 ("More.." if needed)
   *      DisplayGroupHeader                 (group name, column headings)
   *      DisplaySingleResult (n times)
   *      DisplayGroupFooter                 ("More.." if needed)
   *      DisplayFooter                      (anything else you need)
   */

  /**
   *  Called to set the activityspace, model, and view being used
   */
  public void Init(AActivitySpace owner,
                   ISearchResultModelRO model,
                   GroupedResultsView view);

  /**
   *  Returns javascript for the view.
   */
  public HTMLScript DisplayJavascript();

  /**
   *  Returns the element that all other elements will be added to,
   *  such as an HTMLElementCollection or HTMLTable.
   *
   *  If null is returned, no other methods from this interface will be
   *  called, and the view will not be displayed.
   */
  public HTMLElement DisplayCollection();

  /**
   *  Returns an element that will appear before all results, whether
   *  or not the results are grouped.
   */
  public HTMLElement DisplayHeader();

  /**
   *  Returns an element that will appear after all results regardless
   *  of whether the results are grouped.
   */
  public HTMLElement DisplayFooter();

  /**
   *  Returns the header element (e.g. an HTMLTableRow containing column
   *  headings) that will be used if the results are not grouped.  Not called
   *  if the results are grouped.
   */
  public HTMLElement DisplayHeaderIfUngrouped();

  /**
   *  Returns an element that will appear after all results if the results
   *  are not grouped.  Not called if the results are grouped.
   */
  public HTMLElement DisplayFooterIfUngrouped();

  /**
   *  Returns the header element (e.g. an HTMLTableRow containing column
   *  headings) that will be used if the results are grouped.  Not called
   *  if the results are ungrouped.
   */
  public HTMLElement DisplayGroupHeader(int groupNum);

  /**
   *  Returns an element that will appear after all results in a single group.
   *  Not called if the results are ungrouped.
   */
  public HTMLElement DisplayGroupFooter(int groupNum);

  /**
   *  Returns the element (e.g. an HTMLTableRow) for a single search result.
   *  
   *  The "oddRow" argument helps in making tables where every other item is
   *  shaded, note that this is not the same as (resultNum % 2) for grouped results.
   */
  public HTMLElement DisplaySingleResult(int resultNum, boolean oddRow, int groupNum);
  
  /**
   *  Call this method before calling any of the other methods to do initialization. 
   */ 
  public void InitDisplayResults();
}

