package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.pagination.*;

/**
 * @author CraigS
 */
public interface ISearchResultModel extends IModel, IPagination, ISaveSearchModel
{
	/**
	 *  SearchResultModel holds onto a "page mode" string for the benefit of client
	 *  code.. it doesn't care about the contents.
	 */
	public void SetPageMode(String pageMode);

	/**
	 *  Drill down into the indicated category.
	 *  Pass in the groupby field that was used to generate
	 *  the set of categories you are using; the model should validate
	 *  that it is using the right categories.
	 */
	public void Drilldown(String key, String groupByField, int category);

	/**
	 *  Returns true if the model has been initialized (i.e. if
	 *  a search has been run).  This could be in ISearchResultModelRO,
	 *  but is here for convenience, since the caller probably needs
	 *  to call Search() if this returns false.
	 */
	public boolean IsInitialized();

	/**
	 *   Perform a different categorization on the current result set
	 **/
	public void Reorganize(String key, String groupByField);
	
	/**
	 * Update sort order
	 * 
	 * @param sortOrder
	 * @param additionalInfo
	 */
	public void ChangeSortOrder(String sortOrder, Object additionalInfo);

	/**
	 *  Follow a breadcrumb link with the specified key.
	 */
	public void RestoreFromBreadcrumb(String keyOfPageWhereLinkAppears,
		String keyToRestore);

	/**
	 *  Initialize the model by running the provided query with the
	 *  provided settings.
	 */
	public void Search(String searchString, String basicFields, // only if basic search
		IPTFilter advancedFilter, // only if advanced search
		SearchSettingCollection settings);

	/**
	 *  Initialize the model by running the provided query with the
	 *  provided settings (allSettings).  removableSettings, if non-null,
	 *  are those settings that may be removed on a followup search.
	 */
	public void Search(String searchString, String basicFields, // only if basic search
		IPTFilter advancedFilter, // only if advanced search
		SearchSettingCollection allSettings,
		SearchSettingCollection removableSettings);

	/**
	 *  Search within results already generated for the
	 *  indicated additional query string.
	 */
	public void SearchWithinResults(String key, String additionalQuery);

	/**
	 *  Rerun the search that generated the indicated page; call this
	 *  following any action that may change the result set.
	 */
	public void RefreshResults(String keyOnPage);

	/**
	 *  Tell the model that there was an error on the previous search.
	 */
	public void SetError(SearchExecutionError e);

	/**
	 *  Tell the model that there was a warning on the previous search.
	 */
	public void SetWarning(SearchExecutionWarning e);
	
	/**
	 * Filter the search result based on the filterId
	 */
	public void Filter(String key, int filterId);
	
	/**
	 * Gets the property id that is currently used as the
	 * order by property in the model. 
	 * 
	 * @return	Property Id as a string
	 */
	public String GetSortOrder();
	
}

