package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysTagRestData;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public interface ISearchResultModelRO extends IBaseSearchResultModelRO,
	ISearchQueryRO, ISaveSearchModelRO
{
	/**
	 *  Returns a key that may be used in ISearchResultModel.FollowBreadcrumb
	 *  to use the indicated breadcrumb step (must be between 1 and
	 *  getDrilldownDepth(), inclusive).
	 */
	public String GetBreadcrumbKey(int step)
		throws SearchModelException;

	/**
	 *  Returns a displayable label for the indicated breadcrumb
	 *  (must be between 2 and getDrilldownDepth(), inclusive).
	 */
	public String GetBreadcrumbLabel(int step)
		throws SearchModelException;

	/**
	 *  Returns the number of times the given correction actually matched a document.
	 */
	public int GetCorrectionFrequency(int misspellingIndex, int correctionIndex)
		throws SearchModelException;

	/**
	 *  Returns a key that should be attached to all URLs that access
	 *  this model; this key allows the model to find the search result
	 *  on which a URL was generated if the user hits the BACK button.
	 */
	public String GetCurrentKey()
		throws SearchModelException;

  /**
   *  Returns true if this model has been drilled down into a single
   *  category of the given organization scheme.
   */
  public boolean hasDrilledDownIntoSingleCategory(String orgType)
		throws SearchModelException;

	/**
	 *  Returns the number of drilldown steps the user has taken.
	 */
	public int GetDrilldownDepth()
		throws SearchModelException;

	/**
	 *  Returns true if all results in the group were returned.
	 */
	public boolean isEntireGroupReturned(int group)
		throws SearchModelException;

	/**
	 *  Returns the name of the indicated group.
	 */
	public String GetGroupName(int group)
		throws SearchModelException;

	/**
	 *  Returns an icon (actually an HTMLImg) for the indicated group,
   *  or null if there is no appropriate icon.
	 */
	public Object GetGroupIcon(int group)
		throws SearchModelException;

	/**
	 *  Information on result groups
	 */
	/**
	 * Returns the most recent categorization field
	 **/
	public String GetLastGroupByField()
		throws SearchModelException;

	/**
	 *  SearchResultModel holds onto a "page mode" string for the benefit of client
	 *  code.. it doesn't care about the contents.
	 */
	public String GetPageMode();

	/**
	 *  Returns a single misspelled token.
	 */
	public String GetMisspelledToken(int misspellingIndex)
		throws SearchModelException;

	/**
	 *  Returns the number of corrections for the indicated misspelling.
	 */
	public int GetNumCorrections(int misspellingIndex)
		throws SearchModelException;

	/**
	 *  Returns the number of misspelled tokens.
	 */
	public int GetNumMisspelledTokens()
		throws SearchModelException;

	/**
	 *  Returns the number of result groups.
	 */
	public int GetNumResultGroups()
		throws SearchModelException;

	/**
	 *  Get URL arguments that are sufficient to reconstruct
	 *  this search result if it has been flushed from the cache.
	 *  These are returned as an XPHashtable from a String key to an array
	 *  of String values.
	 */
	public XPHashtable GetReconstructionArgs()
		throws SearchModelException;

	/**
	 *  Same as getReconstructionArgs(), but if pageContext is false,
	 *  omit any args that indicate
	 *  what page the model is on - i.e. the model will come back on page
	 *  1 with the default sort order and organization.
	 */
	public XPHashtable GetReconstructionArgs(boolean pageContext)
		throws SearchModelException;
		
	public XPHashtable GetReconstructionArgs(String prefix, boolean wantPageContext)
		throws SearchModelException;
		
	/**
	 *  Returns an internal key used by Best Bets; do not call otherwise
	 */
	public String GetResultBestBetKey(int rank)
		throws SearchModelException;

	/**
	 *  Returns an URL that may be used for clickthrough in "view" mode.
	 *  Equivalent to GetResultClickthroughURL(rank, allowPopup, false).
	 */
	public HTMLAnchor GetResultClickthroughURL(int rank, boolean allowPopup)
		throws SearchModelException;
		
	/**
	 *  Returns an URL that may be used for clickthrough.
	 */
	public HTMLAnchor GetResultClickthroughURL(int rank, boolean allowPopup, boolean editMode)
		throws SearchModelException;

	/**
	 *  Returns an URL that may be used for clickthrough.
	 */
	public HTMLAnchor GetResultClickthroughURL(int rank, boolean allowPopup, boolean editMode, String extraParameters)
		throws SearchModelException;

	/**
	 *  Returns an edit link that may be used for clickthrough.
	 *  Equivalent to GetResultClickthroughURL(rank, allowPopup, true).
	 */
	public HTMLAnchor GetResultEditLink(int rank, boolean allowPopup)
		throws SearchModelException;

	/**
	 *  Special call for Collab Server results; returns the URL used to open the
	 *  containing project.
	 */
	public String GetResultCollabProjectURL(int rank)
		throws SearchModelException;

	/**
	 *  Special call for Collab Server results; returns the name of the item's
	 *  containing project.
	 */
	public String GetResultCollabProjectName(int rank)
		throws SearchModelException;

	/**
	 *  Special call for Content Server results; returns the "last published by" username.
	 */
	public String GetResultContentLastPubUser(int rank)
		throws SearchModelException;

	/**
	 *  Special call for Content Server results; returns the IDs of this result's parent portlets.
	 */
	public int[] GetResultContentPortletIDs(int rank)
		throws SearchModelException;

	/**
	 *  Returns an URL that may be used to open a "properties" page for the item,
	 *  or null if there is no such page.
	 */
	public HTMLAnchor GetResultPropertiesURL(int rank, boolean allowPopup)
		throws SearchModelException;

	/**
	 *  Information on individual results
	 */
	/**
	 *  Returns the overall relevance rank of a grouped result.
	 */
	public int GetResultRank(int groupNum, int resultNum)
		throws SearchModelException;

	/**
	 *  Returns the number of results in the indicated group
	 *  that were actually returned.
	 */
	public int GetReturnedResultsInGroup(int group)
		throws SearchModelException;

	/**
	 *  Returns arguments that can be used for a followup search with
	 *  the same settings as the current search.
	 *  If removeOptional is true, then any settings that are in the
	 *  "removable" set (as returned by GetRemovableSettings()) are not
	 *  included in the returned XPHashtable.
	 */
	public XPHashtable GetSearchAgainArgs(boolean includeOptional)
		throws SearchModelException;

	/**
	 *  Returns a single corrected token for the indicated misspelling.
	 */
	public String GetSpellingCorrection(int misspellingIndex,
		int correctionIndex)
		throws SearchModelException;

	/**
	 *  Returns the total number of results in the indicated group.
	 *  The total may be an estimate of the form "~ 100".
	 */
	public String GetTotalResultsInGroup(int group)
		throws SearchModelException;

	/**
	 *  Returns settings that were used for this search, but that could
	 *  be removed from followup searches if desired
	 */
	public SearchSettingCollection GetRemovableSettings()
		throws SearchModelException;

	/**
	 *  Returns true if the user's search phrase was spell-corrected.
	 */
	public boolean wasSpellCorrected()
		throws SearchModelException;
	
	public XPDateFormat GetDateFormat(AActivitySpace owner);
	
	public String GetResultStyleClass(String subType);
	
	public boolean ContentInstalled();

	public boolean CollabInstalled();
	
	public int GetSelectedTypeFilter();
	
	/**
	 * Returns the pathways tags associated to the pathways search result item
	 * @param rank - the search result # you want info from
	 */
	public PathwaysTagRestData[] GetPathwaysResultTags(int rank);
	
	/**
	 * Returns the pathways tag cloud associated with the pathways search result
	 */
	public XPHashtable GetTagCloud();
	
	/**
	 * Returns true if it is a Pathways search, otherwise it is a regular search.
	 */
	public boolean IsPathwaysSearch();
	
	/* RANK ENGINE REMOVED FROM NEO RELEASE, DO NOT NEED THIS METHOD
	 * Returns the Pathways score for the result.
	 *
	public double GetPathwaysResultScore(int rank);
	*/
}
