package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.uiinfrastructure.activityspace.*;

/**
 *  @author CraigS
 *
 *  This is an abstract class; it cannot be instantiated.
 *
 *  It simply holds the RegisterSearchClasses() method
 *  that ActivitySpaces use to integrate search with
 *  with their other models, views, and controls.
 */
public abstract class IntegratedSearchAS
{
	/**
	 *  Registers search model, control, and views on the
	 *  supplied ActivitySpace.
	 */
	public static void RegisterSearchClasses(AActivitySpace space)
	{
		// Add the search result model
		space.RegisterModel(SearchResultModel.STR_MVC_CLASS_NAME);

		IModel model = space.GetModel(SearchResultModel.STR_MVC_CLASS_NAME);

		// Add the search interaction controls
		space.RegisterControl(StartSearchControl.STR_MVC_CLASS_NAME, model);
		space.RegisterControl(PaginationControl.STR_MVC_CLASS_NAME, model);
		space.RegisterControl(UpdateSortOrderControl.STR_MVC_CLASS_NAME, model);
		space.RegisterControl(DrilldownControl.STR_MVC_CLASS_NAME, model);
		space.RegisterControl(BreadcrumbControl.STR_MVC_CLASS_NAME, model);
		space.RegisterControl(ReorganizationControl.STR_MVC_CLASS_NAME, model);
		space.RegisterControl(ReconstructSearchControl.STR_MVC_CLASS_NAME, model);
		space.RegisterControl(TypeFilterControl.STR_MVC_CLASS_NAME, model);

		// Add some commonly used search views
		space.RegisterView(PaginationView.STR_MVC_CLASS_NAME, model);

		// The controls need to know what page they are living on
		space.SetTrackCurrentPage(true);
	}
}

