package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public class ReorganizationViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.search.ReorganizationViewHelper");

  /** Name of the script that is invoked when the user selects a new sort order */
  public static final String JAVASCRIPT_RESORT = "submitROR";

  protected static final String CUSTOM_CATNAME_PREFIX="CategoryName_";
  protected static final String CUSTOM_CATFIELD_PREFIX="CategoryField_";     

  private static IXPList _EODdisplayableNames = new XPArrayList(10);
  private static IXPList _EODfields        = new XPArrayList(10);

  private static final int MAX_NUM_GROUPS_DEFAULT = 10;
  private static int _maxNumGroups = MAX_NUM_GROUPS_DEFAULT;

  private static boolean _isInitialized = false;

  public static final String SIMPLE_DRILLDOWN_FORM_NAME = "Drilldown";

  public static int GetMaxNumGroups() {
    if (! _isInitialized) {
      loadConfig();
    }

    return _maxNumGroups;
  }

  public static String[][] GetCustomCategorizationFields() {
    if (! _isInitialized) {
      loadConfig();
    }

    if ((null == _EODfields) || (null == _EODdisplayableNames)) {
      return null;
    }

    int numOptions = _EODfields.GetSize();
    if (0 == numOptions) return null;

    String[][] fields = new String[numOptions][2];
    for (int j = 0; j < numOptions; j++) {
      fields[j][0] = (String) _EODfields.GetElement(j);
      fields[j][1] = (String) _EODdisplayableNames.GetElement(j);
    }

    return fields;
  }

  public static HTMLElement DisplayReorganization(ISearchResultModelRO model,
                                                  AActivitySpace owner)
  {
    return DisplayReorganization(model, owner,
                                 /* showCustomDrilldownOptions= */ true);
  }

  public static HTMLElement DisplayReorganization(ISearchResultModelRO model,
                                                  AActivitySpace owner,
                                                  boolean showCustomDrilldownOptions)
  {
    if (! _isInitialized) {
      loadConfig();
    }

    final int MIN_RESULTS_TO_SHOW_ORG_VIEW = 6;

    // Don't bother showing this view if there aren't many results and we haven't drilled down
    if ((model.GetTotalItems() < MIN_RESULTS_TO_SHOW_ORG_VIEW) &&
        (0 == model.GetDrilldownDepth()))
    {
      return null;
    }

    boolean is508 = (owner.GetAccessStyle() != AccessStyles.STANDARD);

    // Initialize our return value
    HTMLElement result = new HTMLElementCollection();

    // The search server returns info on the number of "groups" discovered
    // during the query.  How many were there?
    int numGroups = model.GetNumResultGroups();

    // We'll put 3 items per row
    final int GROUPS_PER_LINE = 3;

    HTMLTable table = new HTMLTable();
    table.SetWidth("100%");
    table.SetCellSpacing("0");

    table.SetSummary(owner.GetString(1088, "ptmsgs_portalbrowsingmsgs"));

    if (is508)
    {
      table.SetCellPadding("0");
    }
    else
    {
      table.SetCellPadding("5");
    }

    result.AddInnerHTMLElement(table);

    HTMLTableRow row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.OBJECTSEARCH_BG);
    table.AddInnerHTMLElement(row);

    HTMLTableCell cell;

    // Add the pulldown menu indicating the type of categorization
    // desired
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
    row.AddInnerHTMLElement(cell);
    cell.SetHeight("17");
    cell.SetNoWrap(true);
    cell.SetVAlign("middle");

    HTMLSpan span = new HTMLSpan();
    span.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);

    span.AddInnerHTMLString(owner.GetString(1086, "ptmsgs_portalbrowsingmsgs"));
    cell.AddInnerHTMLElement(span);
	HTMLImg sp1Img = SearchUIUtility.GetImage(owner,PTImageType.SPACER,"","1","13");
	sp1Img.SetAlign("absmiddle");
    cell.AddInnerHTMLElement(sp1Img);

    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
    row.AddInnerHTMLElement(cell);

    HTMLSelect select = GetSortOptionsSelectElement(model, owner,
			showCustomDrilldownOptions, is508);

    cell.AddInnerHTMLElement(select);

    // In 508 mode, no javascript, so we need an extra submit button
    if (is508)
    {
      cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
      row.AddInnerHTMLElement(cell);

      HTMLInput submitButton = new HTMLInput(HTMLInputTypes.SUBMIT,
          "in_su_submitROR", "in_su_submitROR");

      submitButton.SetValue(owner.GetString(1087, "ptmsgs_portalbrowsingmsgs"));
      submitButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
      cell.AddInnerHTMLElement(submitButton);
    }

    // Done showing "sort by:" menu.

    AddSpacerCell(owner, row, 8);

    // Cell to hold inner table, that in turn holds group info
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
    cell.SetWidth("100%");
    row.AddInnerHTMLElement(cell);

    HTMLTable innerTable = null;
    HTMLTableRow innerRow = null;
    HTMLTableCell innerCell = null;

    // Create the inner table containing group drilldown links
    innerTable = new HTMLTable();
    innerTable.SetWidth("100%");
    cell.AddInnerHTMLElement(innerTable);

    // Loop over groups
    for (int j = 0; j < numGroups; j++) {
      String groupName = model.GetGroupName(j);
      String numResults = model.GetTotalResultsInGroup(j);
      Object groupIcon = model.GetGroupIcon(j);

      String encodedGroupName = XPHttpUtility.HtmlEncode(groupName);

      // If at the beginning of a row
      if (0 == (j % GROUPS_PER_LINE)) {

        // If there was a previous row
        if (null != innerRow) {
          // Add an extra cell to the previous row, to force left-justification
          innerCell = new HTMLTableCell();
          innerCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
          innerCell.SetWidth("100%");
          innerRow.AddInnerHTMLElement(innerCell);
        }

        // .. and make a new row 
        innerRow = new HTMLTableRow();
        innerTable.AddInnerHTMLElement(innerRow);
      }  // end if at beginning of line

      // Make a cell for the group icon (why is this a separate cell?)
      innerCell = new HTMLTableCell();
      innerCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      innerCell.SetNoWrap(true);
      innerCell.SetAlign("center");
      innerRow.AddInnerHTMLElement(innerCell);

      // If the group has an associated icon
      if (null != groupIcon) {
        // format the icon properly
        HTMLImg icon = (HTMLImg) groupIcon;
        icon.SetBorder("0");
        icon.SetAlign("absmiddle");

        // If more than one group
        if (numGroups > 1) {
          // the icon is a clickable drilldown link
          innerCell.AddInnerHTMLElement(DrilldownControl.makeURL(model, owner, icon, j));
        } else {
          // the icon is not clickable
          innerCell.AddInnerHTMLElement(icon);
        }
      }

      // Now make another cell for the group name
      innerCell = new HTMLTableCell();
      innerCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      innerCell.SetNoWrap(true);
      innerRow.AddInnerHTMLElement(innerCell);

      // If more than one group
      if (numGroups > 1) {
        // each group is a drilldown link

        innerCell.AddInnerHTMLString("<b>");
        HTMLElementCollection tempCollection = new HTMLElementCollection();
        tempCollection.AddInnerHTMLString(encodedGroupName);
        innerCell.AddInnerHTMLElement(DrilldownControl.makeURL(model, owner, tempCollection, j));

        innerCell.AddInnerHTMLString("</b> (" + numResults + ")");
      } else {
        // If only one group, don't show a drilldown link, just the name of the single group
        innerCell.AddInnerHTMLString("<b>" + encodedGroupName + 
                                     "</b> (" + owner.GetString(1824, "ptmsgs_portalbrowsingmsgs") + ")");
      }

      // Finally, space out the cells a bit
      innerCell.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;");
    }  // end loop over groups

    // Now, if there were no groups (i.e. we skipped the preceding for loop completely)
    if (0 == numGroups) {
      // Add an internal row and cell anyway
      innerRow = new HTMLTableRow();
      innerTable.AddInnerHTMLElement(innerRow);
      innerCell = new HTMLTableCell();
      innerCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      innerCell.SetNoWrap(true);
      innerRow.AddInnerHTMLElement(innerCell);

	  String lastGroupByField = model.GetLastGroupByField();
      
      // If we tried to use folder categorization but ended up with 0 categories
      // (this is a quirk of the search server's Partition algorithm.. the Rollup
      // algorithm used for the other categorization options will always return
      // at least one group)
      if ((null != lastGroupByField) && (lastGroupByField.equals(SearchResultModel.GROUPBY_FOLDER))) {
        // Show a "no subfolders found" message so users don't think the page is broken
        innerCell.AddInnerHTMLString(owner.GetString(1827, "ptmsgs_portalbrowsingmsgs"));
      }
    }

    // Finally, if we added one and only one row
    if ((null != innerRow) && (numGroups <= GROUPS_PER_LINE)) {
      // Add an extra cell with 100% width at the far right to force
      // left-justification
      innerCell = new HTMLTableCell();
      innerCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      innerCell.SetWidth("100%");
      innerRow.AddInnerHTMLElement(innerCell);
    }

    return result;
  }

	public static HTMLSelect GetSortOptionsSelectElement(ISearchResultModelRO model,
			AActivitySpace owner, boolean showCustomDrilldownOptions,
			boolean is508)
	{
		HTMLSelect select = new HTMLSelect(ReorganizationControl.GROUP_BY_FIELD, "");
	    select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
	
	    if (! is508)
	    {
	      select.SetOnChange(JAVASCRIPT_RESORT + "();");
	    }
	    
	    String lastGroupByField = model.GetLastGroupByField();
	    String sortOrder      = model.GetSortOrder();
	
	    HTMLOption option = null;
	    boolean foundSelectedOption = false;
	
	    // show "relevance" option
	    boolean isRelevanceRanked = 
	      ((lastGroupByField == null) || lastGroupByField.equals("")) &&
	      (sortOrder.equals(SearchResultModel.SORTORDER_RELEVANCE));
	
	    option = new HTMLOption("");
	    option.AddInnerHTMLString(owner.GetString(819, "ptmsgs_portalbrowsingmsgs"));
	
	    if (isRelevanceRanked) {
	      option.SetSelected(true);
	      foundSelectedOption = true;
	    }
	
	    select.AddInnerHTMLElement(option);
	    
	    // show "name" option
	    option = new HTMLOption("");
	    option.AddInnerHTMLString(owner.GetString(825, "ptmsgs_portalbrowsingmsgs"));
	
	    // if not grouped..
	    if ((lastGroupByField == null) || lastGroupByField.equals("")) {
	      // and sort order was "by name"
	      if (sortOrder.equals(SearchResultModel.SORTORDER_NAME_ASC)) {
	        option.SetSelected(true);
	        foundSelectedOption = true;
	      }
	    }
	
	    option.SetValue("name");
	    select.AddInnerHTMLElement(option);
	    
	    // show "last modified" option
	    option = new HTMLOption("");
	    option.AddInnerHTMLString(owner.GetString(820, "ptmsgs_portalbrowsingmsgs"));
	
	    // if not grouped..
	    if ((lastGroupByField == null) || lastGroupByField.equals("")) {
	      // and sort order was last-modified
	      if (sortOrder.equals(SearchResultModel.SORTORDER_MODIFIED_DESC)) {
	        option.SetSelected(true);
	        foundSelectedOption = true;
	      }
	    }
	
	    option.SetValue("lastmodified");
	    select.AddInnerHTMLElement(option);
	
	    // show "folder" option
	    option = new HTMLOption("");
	    option.AddInnerHTMLString(owner.GetString(821, "ptmsgs_portalbrowsingmsgs"));
	    if (lastGroupByField.equals(SearchResultModel.GROUPBY_FOLDER)) {
	      option.SetSelected(true);
	      foundSelectedOption = true;
	    }
	    option.SetValue(SearchResultModel.GROUPBY_FOLDER);
	    select.AddInnerHTMLElement(option);
	
	    // show "object type" option
	    {
	      boolean showObjectTypeOption = true;
	
	      // Get object type restrictions
	      int[] objectTypes = model.GetObjectTypeRestrictions();
	      int apps = model.GetApplicationRestrictions();
	
	      // If we were restricted to a single portal object type, 
	      // suppress the "object types" option
	      if ((apps == PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL) &&
	          ((null != objectTypes) && (1 == objectTypes.length))) {
	        showObjectTypeOption = false;
	      }
	
	      // But be sure we show the option if it's selected!
	      if (lastGroupByField.equals(SearchResultModel.GROUPBY_OBJECTTYPE)) {
	        showObjectTypeOption = true;
	      }
	
	      if (showObjectTypeOption) {
	        option = new HTMLOption("");
	        option.AddInnerHTMLString(owner.GetString(822,"ptmsgs_portalbrowsingmsgs"));
	
	        if (lastGroupByField.equals(SearchResultModel.GROUPBY_OBJECTTYPE)) {
	          option.SetSelected(true);
	          foundSelectedOption = true;
	        }
	        option.SetValue(SearchResultModel.GROUPBY_OBJECTTYPE);
	        select.AddInnerHTMLElement(option);
	      }
	    }
	
	    if (showCustomDrilldownOptions) {
	      // options to categorize by customized EOD fields
	      // specified in x_config.xml
	      for (int catIndex = 0; catIndex < _EODdisplayableNames.GetSize();
	           catIndex++) {
	        try {
	          String displayableName = (String) (_EODdisplayableNames.GetElement(catIndex));
	          String field = (String) (_EODfields.GetElement(catIndex));
	          option = new HTMLOption("");
	          option.AddInnerHTMLString(displayableName);
	
	          if (lastGroupByField.equals(field)) {
	            option.SetSelected(true);
	            foundSelectedOption = true;
	          }
	
	          option.SetValue(field);
	
	          select.AddInnerHTMLElement(option);
	        }
	        catch (Exception e) {
	          //log error, but don't bomb out completely, just
	          // don't display this particular field
	        
	          log.Error(e, "OrganizationView unable to display search.");
	        }
	      }
	    }  // end if showCustomDrilldownOptions
	    
		// Now, uhh, what if we're sorted in some order we don't know anything about?
		if (! foundSelectedOption) {
			// Add one more option to indicate this, but if selected, we'll just default
			// back to relevance
			
			option = new HTMLOption("");
			option.AddInnerHTMLString(owner.GetString(1828, "ptmsgs_portalbrowsingmsgs"));  // "other property"
			option.SetSelected(true);
			select.AddInnerHTMLElement(option);
		}
		return select;
	}
  
  /**
   * 
   *
   * @param couldBeNull 
   */
  private static void getMaxNumGroupsFromVarPack(PTConfigVarPack varPack)
  {
      try
      {
      	String strValueInFile = varPack.GetConfigValueAsString("Search","MaxNumGroups",
						 "value");
		if ((strValueInFile != null) && (!"".equals(strValueInFile)))
		{
	        int valueInFile= XPConvert.ToInteger(strValueInFile);
			if (valueInFile > 0) {
		    	_maxNumGroups=valueInFile;
			}
		}
      }
      catch (Exception nfe)
      {
		  log.Warn(nfe, "MaxNumCategories setting in PTConfig.xml has been ignored because it is not a valid integer"); 
      }

    // If we got this far and the value is still invalid, use a default
    if (_maxNumGroups <= 0) {
      log.Warn("MaxNumCategories setting (" + XPConvert.ToString(_maxNumGroups) + ") in PTConfig.xml has been ignored because it is not a positive integer"); 
      _maxNumGroups = MAX_NUM_GROUPS_DEFAULT;
    }
  }
 
  /**
   * loads configuration information from PTconfig.xml
   *
   * The primary purpose of this method is to allow for the possibility of
   * adding another categorization option, i.e., another field (e.g. an EOD field)
   * on the basis of which results can be grouped.  Here is an example of xml that would be
   * found within the <Search> section of PTConfig.xml:
   *
   * <CategoryName_1 value="Department"/>
   * <CategoryField_1 value="PT137"/>
   * <CategoryName_2 value="Region"/>
   * <CategoryField_2 value="PT241"/>
   *
   * The result of loading this xml will be to offer (in addition to the standard
   * categorization options) the options to categorize according to fields PT137
   * and PT241. The pulldown options displayed to the end user will be "Department"
   * and "Region" respectively.
   **/
  private static void loadConfig()
  {
    try
    {
      IApplication application = ApplicationManager.GetInstance()
        .GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());

      PTConfigVarPack vpPTConfig = (PTConfigVarPack) application.GetVarPackManager()
        .GetVariablePackage(PTConfigVarPack.VARPACK_ID);  

      // if set, at most this many categories will be displayed
      // for search results   
      getMaxNumGroupsFromVarPack(vpPTConfig); 
      boolean moreCustomCategories=true;
      int loopCount=1;
      while (moreCustomCategories)
      {
	  
    	try
	    {

	      String categoryName=
		  vpPTConfig.GetConfigValueAsString("Search",
						    CUSTOM_CATNAME_PREFIX + 
						    loopCount,
						    "value"); 
	      if (categoryName==null || categoryName.trim().equals(""))
	      {
			  moreCustomCategories=false;
			  break;
	      }
	      else
	      {
			  String categoryField=
			      vpPTConfig.GetConfigValueAsString("Search",
								CUSTOM_CATFIELD_PREFIX + 
								loopCount,
								"value"); 
			
			  if (categoryField==null || categoryField.trim().equals(""))
			  {
			      log.Warn("No value found for custom search category with name " + categoryName + ". This custom categorization will not be implemented."); 
			  }
			  else
			  {
			      _EODdisplayableNames.Add(categoryName);
			      _EODfields.Add(categoryField);
			  }
	      }
	    }
	    catch (Exception e)
        {
			
				log.Error(e, "Trouble parsing info for custom category " + loopCount +
					      ". \"name\" and \"value\" attributes are required ");
		    
	    }
		finally {
	      loopCount++;
	    }

  	    // it's very unlikely, but just in case we get into an 
	    // infinite loop somehow, break out after a while
	    if (loopCount > 100) {
	      moreCustomCategories=false;
	    }
      }
      _isInitialized = true;
    }
    catch (Exception e)
    {
	
		  log.Error(e, "Trouble parsing search categorization customization info: ");
    }
  }
 
  protected static void AddSpacerCell(AActivitySpace owner, HTMLTableRow row, int width)

  {
    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetWidth("8");

    HTMLImg spacer = null;

    try
    {
      spacer = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER,
          true, owner).GetHTMLElement();
    }
    catch (Exception e)
    {
      throw XPException.GetInstance(e);
    }

    spacer.SetWidth(XPConvert.ToString(width));
    spacer.SetHeight("8");
    spacer.SetBorder("0");
    spacer.SetAlt("");
    cell.AddInnerHTMLElement(spacer);
  }

  public static HTMLElement DisplaySimpleDrilldownView(ISearchResultModelRO model, AActivitySpace owner)
  {
    // How are we grouped and how many groups are there?
    String groupBy = model.GetLastGroupByField();
    int numGroups = model.GetNumResultGroups();

    // If we appear to be ungrouped, don't show this view.
    if (null == groupBy) {
      return null;
    }

    // This view only supports subfolder and object-type grouping.  If we're grouped
    // some custom way, show nothing.  Customers may wish to use OrganizationView
    // instead in this case.
    if (! (groupBy.equals(SearchResultModel.GROUPBY_OBJECTTYPE) ||
           groupBy.equals(SearchResultModel.GROUPBY_FOLDER))) {
      return null;
    }

    // We handle object-type grouping and subfolder grouping a little differently.
    // 
    // For object-type grouping, at the top level, show a menu of available object types.
    // Once the user has drilled down into a single type, show the same menu, but make
    // the selected option the type that is being shown.  Allow the user to re-expand the
    // search to "all results".
    //
    // For folder grouping, always show a menu of available subfolders (if there are any).
    // If we're not at the top level, show a "Go Back" link to return to the previous
    // search.

    // Figure out which of these options we're doing.
    boolean isObjectTypeGrouping = groupBy.equals(SearchResultModel.GROUPBY_OBJECTTYPE);
    boolean isAtTopLevel = ! (model.hasDrilledDownIntoSingleCategory(groupBy));

    // Construct the form that will hold this whole row
    HTMLForm form = new HTMLForm(SIMPLE_DRILLDOWN_FORM_NAME);
    form.SetMethod("get");
    form.SetName(SIMPLE_DRILLDOWN_FORM_NAME);
    form.SetAction(ConfigHelper.GetApplicationBaseURLToAS(owner.GetCurrentNormalizedBaseURL(), 
		owner.GetName(), owner.IsSubSpace()));

    // Set target as the same space
    HTMLInput targetSpace = new HTMLInput(HTMLInputTypes.HIDDEN,
        ASConstants.SPACENAME_INPUT, ASConstants.SPACENAME_INPUT, "");
    targetSpace.SetValue(owner.GetName());
    form.AddInnerHTMLElement(targetSpace);

    // Add our current space ID, so the framework doesn't create
    // another instance of the space
    HTMLInput targetSpID = new HTMLInput(HTMLInputTypes.HIDDEN,
        ASConstants.SPACEID_INPUT, ASConstants.SPACEID_INPUT, "");
    targetSpID.SetValue(owner.GetSpaceID());
    form.AddInnerHTMLElement(targetSpID);

    // Set target as DrilldownControl
    HTMLInput targetControl = new HTMLInput(HTMLInputTypes.HIDDEN,
        ASConstants.CONTROL_INPUT, ASConstants.CONTROL_INPUT, "");
    targetControl.SetValue(DrilldownControl.STR_MVC_CLASS_NAME);
    form.AddInnerHTMLElement(targetControl);

    // Add a hidden input for the search key
    HTMLInput depth = new HTMLInput(HTMLInputTypes.HIDDEN,
        SearchResultControl.KEY_DATA, SearchResultControl.KEY_DATA, "");
    form.AddInnerHTMLElement(depth);

    // If we're in object-type mode and not at the top level, make it look to the control
    // like the user has backed up to the top level and re-selected a different object type.
    // Otherwise, just use the current key.
    String parentKeyWhoseGroupsToShow = null;
    if (isObjectTypeGrouping && (! isAtTopLevel)) {
      parentKeyWhoseGroupsToShow = model.GetBreadcrumbKey(model.GetDrilldownDepth() - 1);
      depth.SetValue(parentKeyWhoseGroupsToShow);
    } else {
      depth.SetValue(model.GetCurrentKey());
    }

    // Tell DrilldownControl which way we are currently grouped so it knows how
    // to interpret the group we will select
    HTMLInput groupByInput = new HTMLInput(HTMLInputTypes.HIDDEN, "in_hi_temp", "in_hi_temp", "");
    groupByInput.SetValidateName(false);
    groupByInput.SetName(DrilldownControl.GROUPBY_DATA);
    groupByInput.SetID(DrilldownControl.GROUPBY_DATA);
    groupByInput.SetValue(model.GetLastGroupByField());
    form.AddInnerHTMLElement(groupByInput);

    HTMLTable table = new HTMLTable();
    form.AddInnerHTMLElement(table);

    table.SetCellPadding("6");
    table.SetCellSpacing("0");
    table.SetWidth("100%");

    HTMLTableRow row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);
    row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetNoWrap(true);
    cell.SetVAlign("middle");

    // Special case of zero or one groups
    if (1 >= numGroups) {

      // If we're at the top level, just don't bother showing this view at all.
      // Throw away everything we've constructed up to this point

      if (isAtTopLevel) {
        return null;
      }

      // If we're not at the top level, in folder grouping, and found no useful
      // groups, then just show a "Go Back" link and don't bother with the pulldown.

      if (! isObjectTypeGrouping) {
        cell.AddInnerHTMLElement(MakeSimpleDDGoBackLink(model, owner));
        return form;
      }
    }

    // Add the "Go Back" link if necessary (whenever we're in folder mode and not at the top level).
    if ((! isObjectTypeGrouping) &&
        (! isAtTopLevel)) {

      cell.AddInnerHTMLElement(MakeSimpleDDGoBackLink(model, owner));

      // Add a separator cell
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      cell.SetNoWrap(true);
      cell.SetVAlign("middle");
      cell.AddInnerHTMLString("|");

      // Make a new cell for the rest of the row
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      cell.SetNoWrap(true);
      cell.SetVAlign("middle");
      cell.SetWidth("100%");
    }

    // Next, add the pulldown of groups.

    // Add the string "View by Subfolder" or "View by Object Type"
    String visibleGroupByName = "";

    if (groupBy.equals(SearchResultModel.GROUPBY_OBJECTTYPE)) {
      visibleGroupByName = owner.GetString(822,"ptmsgs_portalbrowsingmsgs");
    } else if (groupBy.equals(SearchResultModel.GROUPBY_FOLDER)) {
      visibleGroupByName = owner.GetString(1768,"ptmsgs_portalbrowsingmsgs");
    }

    cell.AddInnerHTMLString("<b>");
    cell.AddInnerHTMLString(XPResourceManager.FormatMessage(owner.GetString(1765, "ptmsgs_portalbrowsingmsgs"),
                                                            visibleGroupByName));
    cell.AddInnerHTMLString("</b>");
    cell.AddInnerHTMLString("  ");

    HTMLSelect select = new HTMLSelect("in_se_temp", "");
    select.SetValidateName(false);
    select.SetName(DrilldownControl.CATEGORY_DATA);
    select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
    cell.AddInnerHTMLElement(select);

    // "all results" option
    HTMLOption allOption = new HTMLOption("");
    select.AddInnerHTMLElement(allOption);
    allOption.SetValue(DrilldownControl.CATEGORY_FOR_NO_DRILLDOWN);
    if (isObjectTypeGrouping) {
      // "All Results"
      allOption.AddInnerHTMLString(owner.GetString(1767, "ptmsgs_portalbrowsingmsgs"));
    } else {
      // "Select Folder..."
      allOption.AddInnerHTMLString(owner.GetString(1770, "ptmsgs_portalbrowsingmsgs"));
      allOption.AddInnerHTMLString("&hellip;");
    }

    // Add other groups.. sort these
    XPSortedDictionary map = new XPSortedDictionary();
    String selectedGroup = null;

    if (null == parentKeyWhoseGroupsToShow) {
      for (int j = 0; j < numGroups; j++) {
        map.PutElement(XPHttpUtility.HtmlEncode(model.GetGroupName(j)), XPConvert.ToString(j));
      }
    } else {
      // NOTE: If we're in object-type mode and actually showing the original (parent)
      // set of groups (i.e. all object types in the original search), we have to get
      // the model to back itself up to that 

      XPHashtable siblingGroups = ((SearchResultModel) model).GetGroupsForAncestorKey(parentKeyWhoseGroupsToShow);
      selectedGroup = ((SearchResultModel) model).GetLastDrilldownGroup();

      IXPDictionaryEnumerator sibEnum = siblingGroups.GetEnumerator();
      while (sibEnum.MoveNext()) {
        IXPDictionaryEntry sibEntry = sibEnum.GetCurrentDictionaryEntry();
        map.PutElement(XPHttpUtility.HtmlEncode((String) sibEntry.GetKey()), XPConvert.ToString(sibEntry.GetValue()));
      }
    }

    // If we didn't find a group to preselect, make the "All Results" group the selected one
    if (null == selectedGroup) {
      allOption.SetSelected(true);
    }

    // Now enumerate the (sorted) options and display them
    IXPDictionaryEnumerator e = map.GetEnumerator();
    while (e.MoveNext()) {
      IXPDictionaryEntry entry = e.GetCurrentDictionaryEntry();

      HTMLOption option = new HTMLOption("");
      select.AddInnerHTMLElement(option);
      option.AddInnerHTMLString((String) (entry.GetKey()));

      String optionValue = (String) (entry.GetValue());
      option.SetValue(optionValue);

      // Is this the preselected group?
      if ((null != selectedGroup) &&
          (optionValue.equals(selectedGroup))) {
        option.SetSelected(true);
      }
    }

    // Add space between pulldown and "go" button
    cell.AddInnerHTMLString(" ");

    HTMLInput submitButton = new HTMLInput(HTMLInputTypes.SUBMIT,
                                           "in_su_submitDD", "in_su_submitDD");

    submitButton.SetValue(owner.GetString(1766, "ptmsgs_portalbrowsingmsgs"));
    submitButton.SetTitle(XPResourceManager.FormatMessage(owner.GetString(1810, "ptmsgs_portalbrowsingmsgs"),
							  visibleGroupByName));
    submitButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
    cell.AddInnerHTMLElement(submitButton);

    // All done
    return form;
  }

  private static HTMLElement MakeSimpleDDGoBackLink(ISearchResultModelRO model, AActivitySpace owner) {

    int parentFolderDepth = model.GetDrilldownDepth() - 1;
    String goBackText = owner.GetString(1769, "ptmsgs_portalbrowsingmsgs");

    HTMLElement backLink = BreadcrumbControl.makeURL(model, owner,
                                                     goBackText,
                                                     model.GetBreadcrumbKey(parentFolderDepth));
    backLink.SetTitle(goBackText);

    HTMLElementCollection c = new HTMLElementCollection();

    HTMLImg icon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_FOLDER_UP,
                                                             true, owner).GetHTMLElement();
    icon.SetAlign("absmiddle");
    icon.SetBorder("0");
    HTMLImg icon2 = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER,
                                                              true, owner).GetHTMLElement();
    icon2.SetAlign("absmiddle");
    icon2.SetBorder("0");

    c.AddInnerHTMLElement(icon);
    c.AddInnerHTMLElement(icon2);
    c.AddInnerHTMLString(" ");
    c.AddInnerHTMLElement(backLink);

    return c;
  }
}

