package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.statichelpers.GatewayHelpers;
import com.plumtree.server.*;
import com.plumtree.server.search.*;
import com.plumtree.server.search.admin.*;
import com.plumtree.server.search.ptapps.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;

/**
 * @author samirm
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SearchKeywordHelper
{
	AActivitySpace m_asOwner;
	public SearchKeywordHelper(AActivitySpace owner)
	{
		m_asOwner = owner;
	}
	
	/* Returns a list of keywords (XPArrayList of Strings) associated with a particular object.  An empty list
         * will be returned if no keywords are found.
         * It is assumed that:
         *   - the user running this query has access to the document (otherwise how would they get the id & type)
         *   - a document with the given type and id exists.
         */
	public IXPList getPortalObjectKeywords(int classID, int objectID)
	{
		// OK, call find best bets by target.
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
		
		IPTSearchFactory searchFactory = ptSession.GetSearchFactory();
		IPTSAdmin searchAdmin = searchFactory.createAdmin();
		IPTSearchBestBetMaintenance bbMaint = searchAdmin.createBestBetMaintenance();
		String strId = XPConvert.ToString(classID) + "." + XPConvert.ToString(objectID);
		String strType = SearchResultModel.PORTAL_APP;
		IXPList listTargets = bbMaint.FindTriggersWithFirstTarget(strId, strType);
		return listTargets;
	}

	/* Returns null if no Keyword exists or if the user does not have access to the target document.
     *    Accessing user is determined from UserSession in activity space.
     */
	public BestBetResult getObject(String strKeyword)
	{
	    BestBetResult bbResult = null;
		IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();

		IPTSearchFactory searchFactory = ptSession.GetSearchFactory();
		IPTSAdmin searchAdmin = searchFactory.createAdmin();
		IPTSearchBestBetMaintenance bbMaint = searchAdmin.createBestBetMaintenance();

		IPTSField[] arrFieldsToReturn = new IPTSField[8];
		arrFieldsToReturn[0] = searchFactory.PortalCollection().Name();
		arrFieldsToReturn[1] = searchFactory.PortalCollection().ObjectID();
		arrFieldsToReturn[2] = searchFactory.PortalCollection().ClassID();
		arrFieldsToReturn[3] = searchFactory.ContentCollection().WebServiceID();
		arrFieldsToReturn[4] = searchFactory.ContentCollection().URL();
		arrFieldsToReturn[5] = searchFactory.CollabCollection().PortletOrWSID();
		arrFieldsToReturn[6] = searchFactory.CollabCollection().URL();
		arrFieldsToReturn[7] = searchFactory.CollabCollection().URLPrefix();

		IPTSResult result = bbMaint.FindFirstTargetForTrigger(strKeyword, arrFieldsToReturn);
		
		if(result != null) // There was a target that this user has access to.
		{
			// This is the result we want to check.  If the searching user has access to
			// this result, return it, otherwise return null.
			
			// Need to figure out how to tell if the ptUser above has access to
			// this document.
			
			// Create the best bet result object.
			bbResult = new BestBetResult();
			
			bbResult.setName(result.getFieldAsString(searchFactory.PortalCollection().Name()));
			
			String strResultApp = result.getFieldAsString(searchFactory.PortalCollection().Application());
			if(strResultApp.equals(PTSConstants.PORTAL_PREFIX)) // Portal
			{
				bbResult.setType("PTPORTAL");
				bbResult.setPortalObjectId(result.getFieldAsInt(searchFactory.PortalCollection().ObjectID()));
				String strRetrievedClassID = result.getFieldAsString(searchFactory.PortalCollection().ClassID());
				bbResult.setPortalClassId(XPConvert.ToInteger(strRetrievedClassID));
			}
			else // Collab or content.
			{
			    IPTSField fieldURL = null;
			    IPTSField fieldPortletOrWS = null;
			    if(strResultApp.equals(PTSConstants.CONTENT_PREFIX))
			    {
			        fieldURL = searchFactory.ContentCollection().URL();
			        fieldPortletOrWS = searchFactory.ContentCollection().WebServiceID();
					bbResult.setType("PTCONTENT");
			    }
			    else if(strResultApp.equals(PTSConstants.COLLAB_PREFIX))
			    {
			        fieldURL = searchFactory.CollabCollection().URL();
			        fieldPortletOrWS = searchFactory.CollabCollection().PortletOrWSID();
					bbResult.setType("PTCOLLAB");
			    }
			    else
			    {
				       final String BAD_RESULT_APP_MESSAGE =  "Found an invalid application type \"" + strResultApp + "\" while looking up a Best Bet target.";
					   throw new XPException(BAD_RESULT_APP_MESSAGE);
			    }

				String url = result.getFieldAsString(fieldURL);
				String portletOrWSID = result.getFieldAsString(fieldPortletOrWS); 
				
				int gatewayObjectId = 0;
		        int gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
			    String appPrefix = "";

		        if ((null == portletOrWSID) || (portletOrWSID.length() < 1)) portletOrWSID = "0";
		        
	            try
	            {
	                gatewayObjectId = XPConvert.ToInteger(portletOrWSID);
		        }
	            catch (Exception e)
	            {
	                if(strResultApp.equals(PTSConstants.COLLAB_PREFIX))
		            {
				       final String BAD_COLLAB_MESSAGE =
					        "Got invalid Collab portlet or webservice ID.  For Collab 3.0, complete Collab installation by using the Project Selector portlet to open a project.  For Collab 4.0, visit the Collaboration Server Administration utility, which should automatically fix this problem.  If these steps do not solve the problem, check for Collab installer errors or an incorrect Collab configuration.";
					   throw new XPException(BAD_COLLAB_MESSAGE);
		            }
		            gatewayObjectId = 0;
		        }

			    if(strResultApp.equals(PTSConstants.COLLAB_PREFIX))
			    {
			        appPrefix = result.getFieldAsString(searchFactory.CollabCollection().URLPrefix());
			        if (gatewayObjectId < 0)
			        {
			          gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
			          gatewayObjectId = -1 * gatewayObjectId;
			        }

			    }

			    String gatewayPfx = GatewayHelpers.ConstructPrefPageLink(m_asOwner,
			            /* objectID= */ gatewayObjectId, 
			            /* communityID= */ 0,
			            /* pageID= */ 0,
			            /* prefType= */ 0,
			            /* classID= */ gatewayClassId);

			    bbResult.setCollabOrContentGatewayedURL(gatewayPfx + GatewayHelpers.CreateGatewayFriendlyURL(appPrefix + url));
			}
		}
		return bbResult;
	}
}
