package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * @author CraigS
 *  Helper class containing a batch of search settings, plus methods
 *  to do useful things with them.
 */
public class SearchSettingCollection
{
	/**
	 *  String equivalents of PT_SEARCH_SETTING settings
	 */
	public static final String PT_SEARCHSETTING_LANGUAGE_S			  = "lang";

	
	public static final String PT_SEARCHSETTING_LIMITBYLOCALE_S		  = "lbl";

	
	public static final String PT_SEARCHSETTING_SKIPRESULTS_S		  = "first";

	
	public static final String PT_SEARCHSETTING_MAXRESULTS_S		  = "page";

	
	public static final String PT_SEARCHSETTING_APPS_S				  = "apps";

	
	public static final String PT_SEARCHSETTING_ABSTYPES_S			  = "abstype";

	
	public static final String PT_SEARCHSETTING_OBJTYPES_S			  = "objtype";

	
	public static final String PT_SEARCHSETTING_DDFOLDERS_S			  = "ddfolder";

	
	public static final String PT_SEARCHSETTING_ADMINFOLDERS_S		  = "adfolder";

	
	public static final String PT_SEARCHSETTING_OBJIDS_S			  = "objids";

	
	public static final String PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S  = "subfolders";

	
	public static final String PT_SEARCHSETTING_COMMUNITY_ID_S		  = "community";

	
	public static final String PT_SEARCHSETTING_KWIC_S				  = "kwic";

	
	public static final String PT_SEARCHSETTING_SPELLCHECK_S		  = "spell";

	
	public static final String PT_SEARCHSETTING_BESTBETS_S			  = "bbs";

	
	public static final String PT_SEARCHSETTING_THESAURUS_S			  = "thesaurus";

	
	public static final String PT_SEARCHSETTING_ORDERBY_S			  = "orderby";

	
	public static final String PT_SEARCHSETTING_ACCESS_LEVEL_S		  = "access";

	
	public static final String PT_SEARCHSETTING_GROUPBYPROP_S		  = "groupby";

	
	public static final String PT_SEARCHSETTING_QUERYTYPE_S			  = "querytype";

	
	public static final String PT_SEARCHSETTING_INITIALSEARCHSTRING_S = "initialsearchstring";

	
	public static final String PT_SEARCHSETTING_GADGET_FIELDS_S    = "gadfields";

	
	public static final String PT_SEARCHSETTING_GADGET_TYPE_S	   = "gadtype";

	
	public static final String PT_SEARCHSETTING_GADGET_ALIGNMENT_S = "gadalign";

	public static final String PT_SEARCHSETTING_ASSOC_PORTLET_ID_S = "portletid";

	public static final String PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID_S = "projectid";

	public static final String PT_SEARCHSETTING_GADGET_SEARCH_TYPE_S = "gadsrchtype";

	public static final String PT_SEARCHSETTING_USER_IS_GUEST_S = "userisguest";

  public static final String GADGET_SEARCH_TYPE_BANNERSEARCH = "bannersearch";
  public static final String GADGET_SEARCH_TYPE_NONCOMMUNITYFOLDER = "noncommunityfolder";

	/**
	 *  Map from PT_SEARCH_SETTING to Object, contains things
	 *  we need to set on an IPTSearchRequest object later
	 */
	protected XPHashtable _settings = null;

	public SearchSettingCollection()
	{
		_settings = new XPHashtable();
	}

	/**
	 *  Static helper method to map a string (i.e. a URL parameter)
	 *  to a PT_SEARCH_SETTING value.
	 */
	public static int getSettingIdFromString(String s)
	{
		if (s.equals(PT_SEARCHSETTING_LANGUAGE_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE;
		}

		if (s.equals(PT_SEARCHSETTING_LIMITBYLOCALE_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE;
		}

		if (s.equals(PT_SEARCHSETTING_SKIPRESULTS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS;
		}

		if (s.equals(PT_SEARCHSETTING_MAXRESULTS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS;
		}

		if (s.equals(PT_SEARCHSETTING_APPS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS;
		}

		if (s.equals(PT_SEARCHSETTING_ABSTYPES_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES;
		}

		if (s.equals(PT_SEARCHSETTING_OBJTYPES_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES;
		}

		if (s.equals(PT_SEARCHSETTING_DDFOLDERS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS;
		}

		if (s.equals(PT_SEARCHSETTING_ADMINFOLDERS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS;
		}

		if (s.equals(PT_SEARCHSETTING_OBJIDS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS;
		}

		if (s.equals(PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS;
		}

		if (s.equals(PT_SEARCHSETTING_COMMUNITY_ID_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID;
		}

		if (s.equals(PT_SEARCHSETTING_KWIC_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC;
		}

		if (s.equals(PT_SEARCHSETTING_SPELLCHECK_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK;
		}

		if (s.equals(PT_SEARCHSETTING_BESTBETS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS;
		}

		if (s.equals(PT_SEARCHSETTING_THESAURUS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS;
		}

		if (s.equals(PT_SEARCHSETTING_ORDERBY_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY;
		}

		if (s.equals(PT_SEARCHSETTING_ACCESS_LEVEL_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL;
		}

		if (s.equals(PT_SEARCHSETTING_GROUPBYPROP_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP;
		}

		if (s.equals(PT_SEARCHSETTING_QUERYTYPE_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE;
		}

		if (s.equals(PT_SEARCHSETTING_INITIALSEARCHSTRING_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING;
		}

		if (s.equals(PT_SEARCHSETTING_GADGET_FIELDS_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS;
		}

		if (s.equals(PT_SEARCHSETTING_GADGET_TYPE_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE;
		}

		if (s.equals(PT_SEARCHSETTING_GADGET_ALIGNMENT_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT;
		}

		if (s.equals(PT_SEARCHSETTING_GADGET_SEARCH_TYPE_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE;
		}

		if (s.equals(PT_SEARCHSETTING_ASSOC_PORTLET_ID_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID;
		}

		if (s.equals(PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID;
		}

		if (s.equals(PT_SEARCHSETTING_USER_IS_GUEST_S))
		{
			return PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST;
		}

		return 0;
	}

	/**
	 *  Static helper method to map a PT_SEARCH_SETTING
	 *  to the URL parameter used to encode it
	 */
	public static String getStringFromSettingId(int s)
	{
		switch (s)
		{
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE:
			return PT_SEARCHSETTING_LANGUAGE_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE:
			return PT_SEARCHSETTING_LIMITBYLOCALE_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS:
			return PT_SEARCHSETTING_SKIPRESULTS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS:
			return PT_SEARCHSETTING_MAXRESULTS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS:
			return PT_SEARCHSETTING_APPS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES:
			return PT_SEARCHSETTING_ABSTYPES_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES:
			return PT_SEARCHSETTING_OBJTYPES_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS:
			return PT_SEARCHSETTING_DDFOLDERS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS:
			return PT_SEARCHSETTING_ADMINFOLDERS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS:
			return PT_SEARCHSETTING_OBJIDS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS:
			return PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID:
			return PT_SEARCHSETTING_COMMUNITY_ID_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC:
			return PT_SEARCHSETTING_KWIC_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK:
			return PT_SEARCHSETTING_SPELLCHECK_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS:
			return PT_SEARCHSETTING_BESTBETS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS:
			return PT_SEARCHSETTING_THESAURUS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY:
			return PT_SEARCHSETTING_ORDERBY_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL:
			return PT_SEARCHSETTING_ACCESS_LEVEL_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP:
			return PT_SEARCHSETTING_GROUPBYPROP_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE:
			return PT_SEARCHSETTING_QUERYTYPE_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS:
			return PT_SEARCHSETTING_GADGET_FIELDS_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE:
			return PT_SEARCHSETTING_GADGET_TYPE_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT:
			return PT_SEARCHSETTING_GADGET_ALIGNMENT_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE:
			return PT_SEARCHSETTING_GADGET_SEARCH_TYPE_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID:
			return PT_SEARCHSETTING_ASSOC_PORTLET_ID_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID:
			return PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST:
			return PT_SEARCHSETTING_USER_IS_GUEST_S;

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_TIMEOUT:
		
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING:default:

			// Not supported; can't change these settings via URL parameters
			return null;
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public static IXPList GetPageContextSettings()
	{
		XPArrayList l = new XPArrayList();
		l.Add(new Integer(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP));
		l.Add(new Integer(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS));
		l.Add(new Integer(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY));

		return l;
	}

	/**
	 *  Get an enumeration of the settings stored in the collection
	 */
	public IXPEnumerator GetSettingIDs()
	{
		return _settings.GetKeys();
	}

	/**
	 *  Get the size of the map
	 */
	public int GetSize()
	{
		return _settings.GetSize();
	}

	/**
	 *  Get an enumeration of the settings stored in the collection
	 */
	public Object GetSettingValue(int key)
	{
		return _settings.GetElement(new Integer(key));
	}

	/**
	 *  Helper method that indicates whether this collection simply
	 *  restricts a search to a community.  Used by the UI to replace
	 *  the "Search with Same Restrictions" message with "Search in Same Community"
	 *  when possible.
	 */
	public boolean IsSimpleCommunityRestriction()
	{
		return ((_settings.GetSize() == 1) &&
		(_settings.ContainsKey(new Integer(
				PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID))));
	}

	/**
	 *  Helper method that indicates whether this collection simply
	 *  restricts a search to a folder (possibly including subfolders).
	 *  Used by the UI to replace the "Search with Same Restrictions" message
	 *  with "Search in Same Folder" when possible.
	 */
	public boolean IsSimpleFolderRestriction()
	{
		int numFolderRestrictions    = 0;
		int numIgnorableRestrictions = 0;

		// Count folder restrictions
		if (_settings.ContainsKey(
					new Integer(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS)))
		{
			numFolderRestrictions++;
		}

		if (_settings.ContainsKey(
					new Integer(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS)))
		{
			numFolderRestrictions++;
		}

		// Count restrictions we don't care about
		if (_settings.ContainsKey(
					new Integer(
						PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS)))
		{
			numIgnorableRestrictions++;
		}

		if (_settings.ContainsKey(
					new Integer(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS)))
		{
			numIgnorableRestrictions++;
		}

		return (_settings.GetSize() == (numFolderRestrictions +
		numIgnorableRestrictions));
	}

	/**
	 *  Add a setting to the map (for use only within the search package)
	 */
  public void add(int setting, Object value)
	{
		_settings.PutElement(new Integer(setting), value);
	}

	/**
	 *  Add a setting to the map
	 */
	public void add(int setting, boolean value)
	{
		_settings.PutElement(new Integer(setting), new Boolean(value));
	}

	/**
	 *  Add a setting to the map
	 */
	public void add(int setting, int value)
	{
		_settings.PutElement(new Integer(setting), new Integer(value));
	}

	/**
	 *  Add a setting to the map
	 */
	public void add(int setting, String value)
	{
		_settings.PutElement(new Integer(setting), value);
	}

	/**
	 *  Add a setting to the map
	 */
	public void add(int setting, int[] value)
	{
		_settings.PutElement(new Integer(setting), value);
	}

	/**
	 *  Helper method for debugging
	 */
	public String dump()
	{
		XPStringBuilder buf = new XPStringBuilder(200);

		IXPEnumerator e = _settings.GetKeys();

		while (e.MoveNext())
		{
      Object key = e.GetCurrent();
      buf.Append(getStringFromSettingId(XPConvert.ToInteger(key)));
			buf.Append("=");
			buf.Append(_settings.GetElement(key));
			buf.Append("\n");
		}

		return buf.ToString();
	}

	/**
	 *  Encode all settings in the provided IPTSearchRequest, ready
	 *  for URL encoding, into the provided XPHashtable.  The map keys are
	 *  Strings (e.g. PT_SEARCHSETTING_OBJTYPES_S) prepended with the
	 *  provided prefix.  The values are String[]-ified setting values.
	 *
	 *  inclusions and exclusions are IXPCollections of Integers.
	 *  If the inclusions collection is non-null, only settings contained
	 *  within it are included in the returned map.
	 *  Any settings contained in the exclusions collection are omitted
	 *  from the returned map.
	 */
	public static void encodeRequestSettings(IPTSearchRequest request,
		XPHashtable map, String keyPrefix, IXPCollection inclusions,
		IXPCollection exclusions)
	{
		// Don't encode querytype or initialsearchstring
		//    encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE,
		//                        request, map, keyPrefix);
		//    encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING,
		//                        request, map, keyPrefix);
		encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE,
			request, map, keyPrefix, inclusions, exclusions);
		encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP,
			request, map, keyPrefix, inclusions, exclusions);
		encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE,
			request, map, keyPrefix, inclusions, exclusions);
		encodeStringSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST,
			request, map, keyPrefix, inclusions, exclusions);

		encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE,
			
		/* default= */ false, request, map, keyPrefix, inclusions, exclusions);
		encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
			
		/* default= */ true, request, map, keyPrefix, inclusions, exclusions);
		encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC, 
		/* default= */ true, request, map, keyPrefix, inclusions, exclusions);
		encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK, 
		/* default= */ false, request, map, keyPrefix, inclusions, exclusions);
		encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, 
		/* default= */ false, request, map, keyPrefix, inclusions, exclusions);
		encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS, 
		/* default= */ false, request, map, keyPrefix, inclusions, exclusions);
		encodeBoolSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS,
			
		/* default= */ false, request, map, keyPrefix, inclusions, exclusions);

		encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS, 
		/* default= */ 0, request, map, keyPrefix, inclusions, exclusions);
		encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, 
		/* default= */ 0, request, map, keyPrefix, inclusions, exclusions);
		encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, 
		/* default= */ 10, request, map, keyPrefix, inclusions, exclusions);
		encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, 
		/* default= */ 0, request, map, keyPrefix, inclusions, exclusions);
		encodeIntSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES, 
		/* default= */ 0, request, map, keyPrefix, inclusions, exclusions);

		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS,
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS,
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS,
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID,
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE,
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT,
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID, 
			request, map, keyPrefix, inclusions, exclusions);
		encodeIntArraySetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID, 
			request, map, keyPrefix, inclusions, exclusions);

		// Now, remove any settings that were in the exclusions list
		if (null != exclusions)
		{
			IXPEnumerator eExclusions = exclusions.GetEnumerator();

			while (eExclusions.MoveNext())
			{
				int setting = XPConvert.ToInteger(eExclusions.GetCurrent());
				map.RemoveElement(keyPrefix +
					getStringFromSettingId(setting));
			}
		}
	}

	/**
	 *  Parse the URL-ified String[] setting value and return an
	 *  Object that can be passed to add() (and from there into
	 *  IPTSearchRequest.SetSettings()).
	 */
	public static Object parseURLString(int id, String[] value)
	{
		switch (id)
		{
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST:

			// string
			return value[0];

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS:

			// boolean
			return new Boolean(XPConvert.ToInteger(value[0]) != 0);

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL:

			// int
			return new Integer(XPConvert.ToInteger(value[0]));

		case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID:
		case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID:

			// array of integers
			int[] r = new int[value.length];

			for (int j = 0; j < value.length; j++)
			{
				r[j] = XPConvert.ToInteger(value[j]);
			}

			return r;

		default:
			// Others not supported
		}

		return null;
	}

	/**
	 *  Merge another batch of settings into ours
	 */
	public void merge(SearchSettingCollection otherSet)
	{
		IXPEnumerator otherKeys = otherSet._settings.GetKeys();

		while (otherKeys.MoveNext())
		{
			int key  = XPConvert.ToInteger(otherKeys.GetCurrent());
			int setting  = key;
			Object value = otherSet._settings.GetElement(new Integer(key));

			this.add(setting, value);
		}
	}

	/**
	 *  Return a stringified version of v that can be used in an URL
	 */
	public static String[] stringifySettingValue(int id, Object v)

	{
		try
		{
			switch (id)
			{
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_INITIALSEARCHSTRING:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_USER_IS_GUEST:
				// string
				return new String[] { (String) v };

			case PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_FIELDS:
			{
				// boolean
				boolean b = XPConvert.ToBoolean(v);

				if (b)
				{
					return new String[] { "1" };
				}
				else
				{
					return new String[] { "0" };
				}
			}

			case PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_ACCESS_LEVEL:
			{
				// int
				int i = XPConvert.ToInteger(v);

				return new String[] { XPConvert.ToString(i) };
			}

			case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJIDS:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_TYPE:
			case PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_ALIGNMENT:
                        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID:
                        case PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID:
				// array of integers
				return stringifyIntArray((int[]) v);

			default:
				// Others not supported
			}
		}
		catch (Exception e)
		{
			throw new XPException("Attempted to add a constraint with an incorrect type to a search request.  The search setting id was " + id + ".", e);
		}

		return null;
	}

	/**
	 *  Update an IPTSearchRequest with our settings
	 */
	public void updateRequest(IPTSearchRequest request)
	{
		IXPEnumerator keys = _settings.GetKeys();

		while (keys.MoveNext())
		{
			int key  = XPConvert.ToInteger(keys.GetCurrent());
			int setting  = key;
			Object value = _settings.GetElement(new Integer(key));

			request.SetSettings(setting, value);
		}
	}

	/**
	 * 
	 *
	 * @param settingId 
	 * @param inclusions 
	 * @param exclusions 
	 *
	 * @return 
	 */
	private static boolean checkExclusion(int settingId,
		IXPCollection inclusions, IXPCollection exclusions)
	{
		Object id = new Integer(settingId);

		if ((null != exclusions) && (exclusions.Contains(id)))
		{
			return false;
		}

		if ((null == inclusions) || (inclusions.Contains(id)))
		{
			return true;
		}

		return false;
	}

	/**
	 * 
	 *
	 * @param settingId 
	 * @param defaultValue 
	 * @param request 
	 * @param map 
	 * @param keyPrefix 
	 * @param inclusions 
	 * @param exclusions 
	 */
	private static void encodeBoolSetting(int settingId, boolean defaultValue,
		IPTSearchRequest request, XPHashtable map, String keyPrefix,
		IXPCollection inclusions, IXPCollection exclusions)
	{
		if (!checkExclusion(settingId, inclusions, exclusions))
		{
			return;
		}

		Object o = request.GetSettingsAsObject(settingId);

		if (null == o)
		{
			return;
		}

		boolean b = XPConvert.ToBoolean(o);

		if (b != defaultValue)
		{
			if (b)
			{
				map.PutElement(keyPrefix + getStringFromSettingId(settingId),
					new String[] { "1" });
			}
			else
			{
				map.PutElement(keyPrefix + getStringFromSettingId(settingId),
					new String[] { "0" });
			}
		}
	}

	/**
	 * 
	 *
	 * @param settingId 
	 * @param request 
	 * @param map 
	 * @param keyPrefix 
	 * @param inclusions 
	 * @param exclusions 
	 */
	private static void encodeIntArraySetting(int settingId,
		IPTSearchRequest request, XPHashtable map, String keyPrefix,
		IXPCollection inclusions, IXPCollection exclusions)
	{
		if (!checkExclusion(settingId, inclusions, exclusions))
		{
			return;
		}

		Object o = request.GetSettingsAsObject(settingId);

		if (null == o)
		{
			return;
		}

		Object[] a = (Object[]) o;

		if (0 < a.length)
		{
			String[] s = new String[a.length];

			for (int j = 0; j < a.length; j++)
			{
				s[j] = XPConvert.ToString(a[j]);
			}

			map.PutElement(keyPrefix + getStringFromSettingId(settingId), s);
		}
	}

	/**
	 * 
	 *
	 * @param settingId 
	 * @param defaultValue 
	 * @param request 
	 * @param map 
	 * @param keyPrefix 
	 * @param inclusions 
	 * @param exclusions 
	 */
	private static void encodeIntSetting(int settingId, int defaultValue,
		IPTSearchRequest request, XPHashtable map, String keyPrefix,
		IXPCollection inclusions, IXPCollection exclusions)
	{
		if (!checkExclusion(settingId, inclusions, exclusions))
		{
			return;
		}

		Object o = request.GetSettingsAsObject(settingId);

		if (null == o)
		{
			return;
		}

		int value = XPConvert.ToInteger(o);

		if (value != defaultValue)
		{
			map.PutElement(keyPrefix + getStringFromSettingId(settingId),
				new String[] { XPConvert.ToString(value) });
		}
	}

	/**
	 * 
	 *
	 * @param settingId 
	 * @param request 
	 * @param map 
	 * @param keyPrefix 
	 * @param inclusions 
	 * @param exclusions 
	 */
	private static void encodeStringSetting(int settingId,
		IPTSearchRequest request, XPHashtable map, String keyPrefix,
		IXPCollection inclusions, IXPCollection exclusions)
	{
		if (!checkExclusion(settingId, inclusions, exclusions))
		{
			return;
		}

		Object o = request.GetSettingsAsObject(settingId);

		if (null == o)
		{
			return;
		}

		String value = (String) o;

		if (0 < value.length())
		{
			map.PutElement(keyPrefix + getStringFromSettingId(settingId),
				new String[] { value });
		}
	}

	/**
	 * 
	 *
	 * @param r 
	 *
	 * @return 
	 */
	private static String[] stringifyIntArray(int[] r)
	{
		String[] s = new String[r.length];

		for (int j = 0; j < r.length; j++)
		{
			s[j] = XPConvert.ToString(r[j]);
		}

		return s;
	}
}
 // class SearchSettingCollection

