package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author CraigS
 */
public class TypeFilterControl extends SearchResultControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.search.DrilldownControl");

	public static final String STR_MVC_CLASS_NAME = "typefilter";
	public static final String FILTER_DATA = "filterId";

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *  Factory method to make a drilldown link.
	 *   @param model     Current batch of search results
	 *   @param linkText  Desired link text
	 *   @param category  Desired category to drill down into
	 */
	public static ILinkElement makeURL(ISearchResultModelRO model, AActivitySpace parent)
	{
		// Create a URL that directs into the current Activity Space
		ILinkElement url = null;

		boolean embedInForm = SpaceNeedsPassthruURL(parent);
		if (embedInForm)
		{
			url = new PassthruURL();
		}
		else
		{
			url = new ASURL(parent);
			url.SetLinkGetCachedSpace(parent);
			url.SetDisplayPage(parent.GetCurrentPage().GetName());
		}

		// Set a DrilldownControl as the URL's target
		url.SetControl(TypeFilterControl.STR_MVC_CLASS_NAME);

		// Set superclass data
		addCommonData(model, url);
		
		// Set other data
		//url.AddControlArgument(PaginationControl.PAGE_SIZE_DATA, pageSize);

		return url;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TypeFilterControl();
	}

	/**
	 * @see com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()
	 */
	protected Redirect ExecuteSearchControl(XPHashtable args, String key)
		throws SearchExecutionException
	{
		// category
		String[] values = (String[]) args.GetElement(FILTER_DATA);
		if (null == values)
		{
			log.Error("could not find category data in query string.");
			return null;
		}


		int filterId;
		try
		{
			filterId = XPConvert.ToInteger(values[0]);
		}
		catch (Exception e)
		{
			log.Error("could not parse categgory data in query string: " + values[0]);
			return null;
		}

		// Tell the model to filter
		_model.Filter(key, filterId);

		// Don't need to redirect to a different page or space; just
		// redisplay the page
		return null;
	}
}

