package com.plumtree.portaluiinfrastructure.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

public class UpdateSortOrderControl extends SearchResultControl 
{

	public static final String STR_MVC_CLASS_NAME = "orderby";
	
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.search.UpdateSortOrderControl");
	public static final String ORDER_BY_DATA = "order";

	/**
	 * @see com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()
	 */
	protected Redirect ExecuteSearchControl(XPHashtable args, String key)
	{
		String orderBy;

		// Sort order
		String[] values = (String[]) args.GetElement(ORDER_BY_DATA);

		if (null != values) {
			orderBy = values[0];
		} else {
			log.Error("could not find order by data in query string");
			return null;
		}

		// Tell the model to go to the new page
		_model.ChangeSortOrder(orderBy, key);

		// Don't need to redirect to a different page or space; just
		// redisplay the page
		return null;
	}
	
	/**
	 *  Factory method to make a pagination link for some search results.
	 *   @param model     Current batch of search results
	 *   @param parent    ActivitySpace we're living in
	 *   @param urlText   Desired text within URL
	 *   @param orderBy   Sort order within which newFirst is to be interpreted
	 *   @param newFirst  Desired first result on new page
	 */
	public static ASURL makeURL(IBaseSearchResultModelRO model,
			AActivitySpace parent, String orderBy)	
	{
		// Create a URL that directs into the current Activity Space
		ASURL url = null;

		if ( !model.IsInitialized() ) {
			return null;
		}
		
//		boolean embedInForm = SpaceNeedsPassthruURL(parent);
//
//		if (embedInForm)
//		{
//			url = new PassthruURL();
//		}
//		else
//		{
			url = new ASURL(parent);
			url.SetLinkGetCachedSpace(parent);
			url.SetDisplayPage(parent.GetCurrentPage().GetName());
//		}

		// Create a PaginationControl within the search space
		url.SetControl(UpdateSortOrderControl.STR_MVC_CLASS_NAME);

		// Set superclass data
		// NOTE: We know we're always passed a fullblown
		// ISearchResultModelRO, since there's only one
		// implementation of either interface (SearchResultModel).
		try {
			addCommonData((ISearchResultModelRO) model, url);
		} catch (XPException e) {
			return null;
		}

		// Set link text
		//url.AddInnerHTMLString(urlText);

		// Set other data
		if ( orderBy != null ) {
			url.AddControlArgument(PaginationControl.ORDER_BY_DATA, orderBy);
		}

		return url;
	}
	
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UpdateSortOrderControl();
	}

}
