package com.plumtree.portaluiinfrastructure.search.exceptions;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *  Error6321Exception indicates that an exception occured for which there is no internationalized
 *  message. The english text of the exception will be embedded as a comment in the returned page.
 */
public class Error6321Exception extends SearchExecutionError
{
	
	
	
	public static final String UNKNOWN_ERROR     = "Error Message: No further information available.";

		// This wraps the "real" java exception that we don't have an internationalized message for.
	private XPException _exception = null;
		
	/**
	 * Creates a new Error6321Exception object.
	 *
	 * @param msg The internationalized message.
	 * @param exception The un-internationalized exception.
	 */
	public Error6321Exception(String msg, XPException exception)
	{
		super(msg);
		_exception = exception;
	}
	
	public XPException GetException() 
	{
		return _exception;
	}
	
	public HTMLComment GetComment()
	{
		// Error is one for which no internationalized message exists. Embed the english error
		// in a comment in the page.
		if(_exception != null)
		{
			XPStringBuilder sb = new XPStringBuilder();
			sb.Append("Error Message: " + _exception.GetMessage() + "\n");
			sb.Append(_exception.GetStackTrace());
			return new HTMLComment(XPHttpUtility.HtmlEncode(sb.ToString()));
		}
		else
			return new HTMLComment(UNKNOWN_ERROR);
	}
}

