package com.plumtree.portaluiinfrastructure.search.pathways;

import com.plumtree.openfoundation.util.XPArrayList;
import com.plumtree.openfoundation.util.XPStringBuilder;
/**
 * @author lmah
 * Pathways Query Arguments class to contain the query parameters for the Pathways search
 *
 */
public class PathwaysQueryArguments {
	
	//json or xml
	public String format = null;
	//defines the order of search results, ie: asc, des
	public String order = "DES";
	//results to sort by, ie:  rank, path
	public String orderBy = "RANK";
	//starting result count at
	public int startAt = -1;
	//limit result set to an existing view
	public String viewId = null;
	//search query
	public String query = "";
	//maximum number of results to return
	public int resultCount = -1;
	//restrict search to specific object types
	public XPArrayList objectTypes = null;
	//total count of search results
	public int totalCount = -1;
	//list of admin folders to restrict
	public int[] adminFolders = null;
	//list of directory folders to restrict
	public int[] dirFolders = null;
	//list of property constraints for advanced search
	public XPArrayList advPropertyConstraints = null;
	//boolean value for if all advanced property constraints should be AND'ed or OR'ed together
	boolean topLevelSearchCriteriaOperatorAND = false;
	//boolean value for if this is advanced sarch or not
	boolean _isAdvancedSearch = false;
	//boolean value for spellcheck
	boolean _isSpellCheck = false;
	public static String opAND = "AND";
	public static String opOR = "OR";
	

	public PathwaysQueryArguments(String argFormat, String argOrder, String argOrderBy, int argStartAt, String argViewId, 
			String argQuery, int argResultCount, XPArrayList argObjectTypes)
	{
		format = argFormat;
		startAt = argStartAt;
		viewId = argViewId;
		query = argQuery;
		resultCount = argResultCount;
		objectTypes = argObjectTypes;
	}
	
	public String GetFormat()
	{
		return format;
	}
	
	public String GetOrder()
	{
		return order;
	}
	
	public String GetOrderBy()
	{
		return orderBy;
	}
	
	public int GetStartAt()
	{
		return startAt;
	}
	
	public String GetViewId()
	{
		return viewId;
	}
	
	public String GetQuery()
	{
		return query;
	}
	
	public int GetResultCount()
	{
		return resultCount;
	}
	
	public int GetTotalCount()
	{
		return totalCount;
	}
	
	//may not need this function, leaving here just in case
	public int[] GetIntAdminFolders()
	{
		return adminFolders;
	}
	
	public String GetStringAdminFolders()
	{		
		if (null == adminFolders)
		{
			return null;
		}
		else
		{
			XPStringBuilder strAdminFolder = new XPStringBuilder();
			for (int i=0; i<adminFolders.length; i++)
			{
				strAdminFolder.Append(adminFolders[i]).Append(",");
			}
			//removing the trailing comma from the string
			return strAdminFolder.Substring(0, (strAdminFolder.GetLength() -1));
		}

	}
	
	//may not need this function, leaving here just in case
	public int[] GetDirFolders()
	{
		return dirFolders;
	}
	
	public String GetStringDirFolders()
	{
		if (null == dirFolders)
		{
			return null;
		}
		else
		{
			XPStringBuilder strDirFolder = new XPStringBuilder();
			for (int i=0; i<dirFolders.length; i++)
			{
				strDirFolder.Append(dirFolders[i]).Append(",");
			}
			return strDirFolder.Substring(0, (strDirFolder.GetLength() -1));
		}
	}
	
	public XPArrayList GetObjectTypes()
	{
		return objectTypes;
	}
	
	public boolean GetSpellCheck()
	{
		return _isSpellCheck;
	}
	
	public XPArrayList GetAdvancedPropertyContraints()
	{
		return advPropertyConstraints;
	}
	
	public String GetAdvancedSearchTopPropertyOperator()
	{
		//top operator value to either AND or OR all advanced search property constraints
		if (topLevelSearchCriteriaOperatorAND)
			return opAND;
		else
			return opOR;
	}
	
	public boolean isAdvancedSearch()
	{
		return _isAdvancedSearch;
	}
	
	public void SetFormat(String argFormat)
	{
		format = argFormat;
	}
	
	public void SetOrder(String argOrder)
	{
		order = argOrder;
	}
	
	public void SetOrderBy(String argOrderBy)
	{
		orderBy = argOrderBy;
	}
	
	public void SetStartAt(int argStartAt)
	{
		startAt = argStartAt;
	}
	
	public void SetViewId(String argViewId)
	{
		viewId = argViewId;
	}
	
	public void SetQuery(String argQuery)
	{
		query = argQuery;
	}
	
	public void SetResultCount(int argResultCount)
	{
		resultCount = argResultCount;
	}
	
	public void SetObjectTypes(XPArrayList argObjectTypes)
	{
		objectTypes = argObjectTypes;
	}
	
	public void SetTotalCount(int argTotalCount)
	{
		totalCount = argTotalCount;
	}
	
	public void SetAdminFolders(int[] folders)
	{
		if (null != folders)
		{
			adminFolders = folders;
		}
	}
	
	public void SetDirFolders(int[] folders)
	{
		if (null != folders)
		{
			dirFolders = folders;
		}
	}
	
	public void SetAdvancedPropertyConstraints(XPArrayList constraints, boolean booleanOperator)
	{
		advPropertyConstraints = constraints;
		topLevelSearchCriteriaOperatorAND = booleanOperator;
	}
	
	public void SetIsAdvancedSearch(boolean value)
	{
		_isAdvancedSearch = value; 
	}
	
	public void SetSpellCheck(boolean globalValue, boolean value)
	{
		if (globalValue)
		{
			//global spellchecking turned on, so the setting of the customer can be used
			_isSpellCheck = value;
		}
		//do nothing if it's false since _isSpellCheck is set to false
	}
}
