/**
 * 
 */
package com.plumtree.portaluiinfrastructure.search.pathways;

import com.plumtree.openfoundation.util.XPConvert;
import com.plumtree.openfoundation.util.XPDateTime;
import com.plumtree.openfoundation.util.XPHashtable;
import com.plumtree.openfoundation.util.XPNotImplementedException;
import com.plumtree.openfoundation.util.XPStringUtility;
import com.plumtree.openlog.OpenLogService;
import com.plumtree.openlog.OpenLogger;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.*;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.server.IPTSearchQuery;
import com.plumtree.server.IPTSearchResponse;
import com.plumtree.server.PT_CLASSIDS;
import com.plumtree.server.PT_INTRINSICS;
import com.plumtree.server.PT_RESULTCODES;
import com.plumtree.server.PT_SEARCH_INTERNAL_FIELD;
import com.plumtree.server.impl.core.Global;
import com.plumtree.server.impl.core.PTBase;
import com.plumtree.server.impl.search.legacy.LegacySearchRequest;
import com.plumtree.server.search.IPTSField;
import com.plumtree.server.search.IPTSResult;
import com.plumtree.server.search.exceptions.PTSNoFieldValueException;
/**
 * @author lmah
 * 
 */
public class PathwaysSearchResponse extends PTBase implements IPTSearchResponse
{
	/* PathwaysSearchRestData object */
	private PathwaysSearchRestData[] _searchResultsData;
	private XPHashtable tagCloudList;	
	private PathwaysQueryArguments pathwaysQueryArg;

	final static String KWIC_START_TAG = "<span class=\"listHiliteText\">";
    final static String PATHWAYS_HILITE = "<span class=\"ptHighlight\">";
    final static String DOCUMENT_ABSTYPE = "DOCUMENT";
    final static String FOLDER_ABSTYPE = "FOLDER";
    final static String OTHER_ABSTYPE = "OTHER";

	
	//TODO make a helper class of the pathways query args instead of passing in as hashtable, queryargs = int.
	
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PATHWAYS),
			"com.plumtree.portaluiinfrastructure.search.pathways.PathwaysSearchResponse");

	public PathwaysSearchResponse(PathwaysSearchRestData[] searchRestData,
			PathwaysQueryArguments pathwaysQueryArgument) {

		//making copies to be used later
		_searchResultsData = searchRestData;
		pathwaysQueryArg = pathwaysQueryArgument;
		
		if ( null != _searchResultsData ) {
			tagCloudList = new XPHashtable();
			this.setTagCloudList(_searchResultsData);
		}
	}
	
	/* 
	 * get the tags associated to the search result
	 */
	public PathwaysTagRestData[] getSearchResultsTagData(int rank)
	{
		return _searchResultsData[rank].tags;
	}
	
	/*
	 * gets the tagCloudList
	 */
	private void setTagCloudList(PathwaysSearchRestData[] searchRestData) {
		PathwaysTagRestData[] cloudTag = null;

		if (null==searchRestData)
		{
			//should never be here
			log.Warn("PathwaysSearchResponse.setTagCloudList:  null value for searchResultData, this should never happen");
		}
		else
		{
			for (int i = 0; i < searchRestData.length; i++) {

				cloudTag = searchRestData[i].tags;

				if (!(cloudTag == null)) {
					for (int j=0; j < cloudTag.length; j++)
					{
						tagCloudList.PutElement(cloudTag[j].name, cloudTag[j]);
					}
				}
			}
		}
	}

	public XPHashtable getTagCloudList() {
		return tagCloudList;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#Clear()
	 */
	public void Clear() {
		_searchResultsData = null;
		tagCloudList = null;
//		fieldList = null;
//		fieldElements = null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetCorrectedToken(int, int)
	 */
	public String GetCorrectedToken(int misspellingIndex, int correctionIndex) {
		throw new XPNotImplementedException("GetCorrectedToken is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetCorrectionFrequency(int,
	 * int)
	 */
	public int GetCorrectionFrequency(int misspellingIndex, int correctionIndex) {
		throw new XPNotImplementedException("GetCorrectionFrequency is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetFieldsAsDouble(int, int)
	 */
	public double GetFieldsAsDouble(int rank, int propertyID) {

		Object oField = GetFieldsAsObject(rank, propertyID);
		
		if ( (null == oField))
		{
			return -1;
		}
		else 
		{
			return XPConvert.ToDouble(oField);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetFieldsAsInt(int, int)
	 */
	public int GetFieldsAsInt(int rank, int propertyID) {
		
		Object oField = GetFieldsAsObject(rank, propertyID);
		
		if ( (null == oField) )
		{
			return -1;
		}
		else
		{
			return XPConvert.ToInteger(oField);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetFieldsAsObject(int, int)
	 * This is going to be helper method to grab value of any property id
	 */
	public Object GetFieldsAsObject(int rank, int propertyID) {

		Object oValue = (Object)GetPathwaysPropertyId(rank, propertyID);
		return oValue;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetFieldsAsString(int, int)
	 */
	public String GetFieldsAsString(int rank, int propertyID) {

		Object oField = GetFieldsAsObject(rank, propertyID);
		
		if ( (null == oField))
		{
			return null;
		}
		else 
		{
			return XPConvert.ToString(oField);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetFieldsAsXPDateTime(int,
	 * int)
	 */
	public XPDateTime GetFieldsAsXPDateTime(int rank, int propertyID) {
		Object oField = GetFieldsAsObject(rank, propertyID);
		
		if ( (null == oField))
		{
			return null;
		}
		else 
		{
			return (XPDateTime)oField;			
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetGroupLabel(int)
	 */
	public String GetGroupLabel(int groupIndex) {
		throw new XPNotImplementedException("GetGroupLabel is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetIsBestBet(int)
	 */
	public boolean GetIsBestBet(int rank) {
		log.Debug("GetIsBestBet is not supported for Pathways Search, we always return false");
		//we are returning false instead of throwing error b/c the searchResultData tag calls this function
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetKWICFieldsAsDouble(int,
	 * int)
	 */
	public double GetKWICFieldsAsDouble(int rank, int propertyID) {
		throw new XPNotImplementedException("GetKWICFieldsAsDouble not supported.");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetKWICFieldsAsInt(int, int)
	 */
	public int GetKWICFieldsAsInt(int rank, int propertyID) {
		throw new XPNotImplementedException("GetKWICFieldsAsInt not supported.");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetKWICFieldsAsObject(int,
	 * int)
	 * This is usually the case where the description is returned... so I'm calling the regular
	 * getFieldAsObject to return the descrption by pathways, which has already been shortened to
	 * relevant info of:  ... xxxx searchStr xxxx ...
	 */
	public Object GetKWICFieldsAsObject(int rank, int propertyID) {
		return GetFieldsAsObject(rank, propertyID);
	}
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetKWICFieldsAsString(int,
	 * int)
	 */
	public String GetKWICFieldsAsString(int rank, int propertyID) {
		String strDescription = Global.GetAPIMethodValueAsString(GetKWICFieldsAsObject(rank, propertyID));
		
		/*
		 * pathways returns a highlighted value for the keywords that is unrecognized by the search results model, I am replacing that string
		 *to what it's suppose to be to get the highlighted keyword to show up.
		 *For Example: 
		 *...of your favorite films with DVD Rollbacks, from $9 . See all: DVD Rollbacks Get the <span class="ptHighlight">Wal</span>-Mart Wire: 
		 *See our privacy policy . This number represents the amount of money <span class="ptHighlight">Wal</span>-Mart...
		 *  is what pathways returns, portal ues <span class="listHiliteText">
		 */
		
	    strDescription = strDescription.replace(PATHWAYS_HILITE, KWIC_START_TAG);
		return strDescription;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetKWICFieldsAsXPDateTime(int,
	 * int)
	 */
	public XPDateTime GetKWICFieldsAsXPDateTime(int rank, int propertyID) {
		throw new XPNotImplementedException("GetKWICFieldsAsXPDateTime not supported.");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetMisspelledToken(int)
	 */
	public String GetMisspelledToken(int index) {
		throw new XPNotImplementedException("GetMisspelledToken is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetNumCorrections(int)
	 */
	public int GetNumCorrections(int index) {
		throw new XPNotImplementedException("GetNumCorrections is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetNumGroups()\
	 * using this to group results into group of "documents", etc, etc
	 */
	public int GetNumGroups() {
		//I am not grouping any of the search results from pathways, so it's always 0.  Which means that all items are ungrouped
		return 0;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetNumMisspelledTokens()
	 */
	public int GetNumMisspelledTokens() {
		log.Debug("GetNumMisspelledTokens is not supported in pathways search, will always return 0");
		//we are returning 0 as searchResultData tag uses this method
		return 0;
		
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetQueryForAllOthers()
	 */
	public IPTSearchQuery GetQueryForAllOthers() {
		throw new XPNotImplementedException("GetQueryForAllOthers is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetQueryForGroup(int)
	 */
	public IPTSearchQuery GetQueryForGroup(int groupIndex) {
		throw new XPNotImplementedException("GetQueryForGroup is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @ param group, the index in the search result you want to grab the rank of
	 * @ param rowWithinGroup, this is not used for pathways
	 */
	public int GetRank(int group, int rowWithinGroup) {
		
		return XPConvert.ToInteger(_searchResultsData[group].rank);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.plumtree.server.IPTSearchResponse#GetRankForUncategorizedDoc(int)
	 */
	public int GetRankForUncategorizedDoc(int rankWithinAllOthers) {
		throw new XPNotImplementedException("GetRankForUncategorizedDoc is not implemented in this phase");
		}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultACL(int) 
	 * TODO
	 * pathways doesn't return acl's nor can you access the acl of the search
	 * item, may need to do more work than in the rest api to accomplish this.
	 */
	public String GetResultACL(int rank) {
		throw new XPNotImplementedException("GetResultACL is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultAbsType(int)
	 * searchresultsdata tag requires this function in order to display search results
	 */
	public String GetResultAbsType(int rank) {
		
		String type = _searchResultsData[rank].type;
		
		if (type.equals(DOCUMENT_ABSTYPE))
		{
			return XPStringUtility.ToUpperCase(type);
		}
		else if (type.equals(FOLDER_ABSTYPE))
		{
			return XPStringUtility.ToUpperCase(type);
		}
		else
		{
			return OTHER_ABSTYPE;
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultApp(int)
	 */
	public String GetResultApp(int rank) {
		return _searchResultsData[rank].source;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultFolderACL(int) TODO
	 * pathways doesn't have ACL access, will have to figure out how to access
	 * it
	 */
	public String GetResultFolderACL(int rank) {
		throw new XPNotImplementedException("GetResultFolderACL is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultInternalField(int,
	 * int)
	 *  ie;  returns folder id that result is found in.
	 */
	public String GetResultInternalField(int rank, int nInternalFieldID) {
		log.Debug("GetResultInternalField is not supported for Pathways, always returns null");
		//searchResultData tag uses this method
		return null;
	}
	
	  /**
	   *  Helper method to look up a doc by rank in the internal array.
	   *  Validates that overallRank is not out of range.
	   */
	  private String findResultByRank(int rank) {
	    // Validate rank
	    if ((rank < 0) || (rank >= _searchResultsData.length)) {
	      ThrowException("Invalid rank.", PT_RESULTCODES.PT_E_INVALIDARG);
	    }

	    // Return the doc
	    return _searchResultsData[rank].rank;
	  }

	  /**
	   *  Helper method to get the value of a String field, or return "" if it
	   *  does not exist (for backwards compatibility with 5.0.x/5.1.x behavior)
	   */
	  private String getFieldAsStringOrEmptyString(IPTSResult r, IPTSField f) {
	    String s = null;

	    try {
	      s = r.getFieldAsString(f);
	    } catch (PTSNoFieldValueException e) {
	      s = "";
	    }

	    if (null == s) s = "";
	    return s;
	  }
	  
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultPath(int)
	 */
	public String GetResultPath(int rank) {
		Object oField = GetFieldsAsObject(rank, PT_INTRINSICS.PT_PROPERTY_FOLDERPATH);
		
		if ( (null == oField) )
		{
			return null;
		}
		else 
		{
			return XPConvert.ToString(oField);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultSize(int)
	 */
	public int GetResultSize(int rank) {
		//throw new XPNotImplementedException("GetResultSize is not implemented in this phase");
		
		//non-adaptive layout requires this function to return something, instead of throwing error, i'm returning
		//negative number
		return -1;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultSubType(int)
	 * returns <source>
	 */
	public String GetResultSubType(int rank) {
		
		//localizeObjectTypeName() in search model compares these values
		String source = _searchResultsData[rank].source;
		
		if (source.equals(PathwaysConstants.PTSOURCE_COLLAB) || source.equals(PathwaysConstants.PTSOURCE_CONTENT) )
		{
			return source;
		}
		//it's a ptportal object, and we must iterate through the objects.
		else if (source.equals(PathwaysConstants.PTSOURCE_PORTAL))
		{
			String strCurrType = _searchResultsData[rank].classId;
			int currType = XPConvert.ToInteger(strCurrType);
			
			//we need this as the native SearchResultsModel.GetResultStyleClass(String subType) uses it.
			//only checking for PTADMINFOLDER AND PTFOLDER as those are the 2 specific things it checks.
			
			switch (currType) {
				case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
					source = "PTADMINFOLDER";				
					break;
				case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
					source = "PTFOLDER"; 		//kd folder
					break;
				case PT_CLASSIDS.PT_USER_ID:
					source = "PTUSER";  		//users
					break;
				case PT_CLASSIDS.PT_CRAWLER_ID:
					source = "PTCRAWLER";  		//not sure why i put this here
					break;
				case PT_CLASSIDS.PT_CATALOGCARD_ID:
					source = "PTCARD";			//documents
					break;
				case PT_CLASSIDS.PT_COMMUNITY_ID:
					source = "PTCOMMUNITY";		//community
					break;
				case PT_CLASSIDS.PT_PAGE_ID:
					source = "PTPAGE";			//community pages
					break;
				case PT_CLASSIDS.PT_GADGET_ID:
					source = "PTGADGET";		//portlets
					break;
				default:
					//do nothing
					break;				
			}			
			
			return source;
		}
		else
		{
			return null;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetResultsReturned()
	 */
	public int GetResultsReturned() {
		
		int numResultCount = pathwaysQueryArg.GetResultCount();
		
		// If search results is null for some reason, just return 0 to prevent layout
		// tags from erroring out due to null value results being returned.
		if ( null == _searchResultsData )
		{
			return 0;
		}
		// Check to see if the search length is equal to the result count.
		// Case for displaying remaining search results less than page size.  
		else if ( _searchResultsData.length != numResultCount )
		{
			return _searchResultsData.length;
		}
		else
		{
			return numResultCount;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetReturnedResultsInGroup(int)
	 */
	public int GetReturnedResultsInGroup(int groupIndex) {
		throw new XPNotImplementedException(
				"GetReturnedResultsInGroup is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.plumtree.server.IPTSearchResponse#GetReturnedResultsNotInAnyGroup()
	 */
	public int GetReturnedResultsNotInAnyGroup() {
		return 0;
//		throw new XPNotImplementedException(
//				"GetReturnedResultsNotInAnyGroup is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetSkipped()
	 */
	public int GetSkipped() {
		// getting skipped, means that the startAt number -1 is the skipped. ie;
		// if we start at 20, then 19 were skipped.
		int skipped = pathwaysQueryArg.GetStartAt();
		return skipped - 1;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetTotalMatches()
	 */
	public int GetTotalMatches() {
		int totalCount = pathwaysQueryArg.GetTotalCount();
		return totalCount;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetTotalResultsInGroup(int)
	 */
	public String GetTotalResultsInGroup(int groupIndex) {
		throw new XPNotImplementedException(
				"GetTotalResultsInGroup is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetTotalResultsNotInAnyGroup()
	 */
	public Object GetTotalResultsNotInAnyGroup() {
		throw new XPNotImplementedException(
				"GetTotalResultsNotInAnyGroup is not implemented in this phase");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.plumtree.server.IPTSearchResponse#GetWarning()
	 */
	public int GetWarning() {
		throw new XPNotImplementedException(
				"GetWarning is not implemented in this phase");
	}

	/* 
	 * Helper Method to lookup the propertyID that the user wants to look up of the search result
	 * return the item node that the user is looking for.
	 * @param propertyid Property id to search for
	 * 
	 * _searchResultsData is the current searchResultsData item that was initialized in the constructor, we will cycle through
	 * this data item to get the property values
	 */
	private String GetPathwaysPropertyId(int rank, int propertyid)
	{
		String propertyValue = null;
				
		switch (propertyid) {
 	    	case PT_INTRINSICS.PT_PROPERTY_OBJECTNAME:
 	    		propertyValue = _searchResultsData[rank].name;
 	    		break;
			case PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY:
				propertyValue = _searchResultsData[rank].description;
			    break;
			case PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED:
				propertyValue = _searchResultsData[rank].lastModified;
				break;
			case PT_INTRINSICS. PT_PROPERTY_DOCUMENTURL:
				propertyValue = _searchResultsData[rank].URL;
				break;
			case PT_INTRINSICS.PT_PROPERTY_OBJECTRESULTTYPE:
				propertyValue = _searchResultsData[rank].type;
				break;
			case PT_INTRINSICS.PT_PROPERTY_OBJECTID:
				propertyValue = _searchResultsData[rank].objectId;
			break;
			case PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEURL:
				propertyValue = _searchResultsData[rank].iconLink;
				break;
			case PT_INTRINSICS.PT_PROPERTY_CLASSID:
				propertyValue = _searchResultsData[rank].classId;
				break;
			case PT_INTRINSICS.PT_PROPERTY_FOLDERPATH:
				propertyValue = _searchResultsData[rank].path;
				break;
			case PathwaysConstants.INT_RANK:
				propertyValue = _searchResultsData[rank].rank;
				break;
			case PT_INTRINSICS.PT_PROPERTY_SEARCHSCORE:
				propertyValue = _searchResultsData[rank].resultScore;
				break;
			case PathwaysConstants.INT_FOLDERID:
				propertyValue = _searchResultsData[rank].folderId;
				break;
			case PathwaysConstants.INT_VIEW_DETAILS_URL:
				propertyValue = _searchResultsData[rank].viewDetailURL;
				break;
			default:
				propertyValue = "";
				break;
		}
		return propertyValue;	
	
	}
}