package com.plumtree.portaluiinfrastructure.securitymatrix;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to display an empty DP during the save process.
 *
 * @author RickyW
 */
public class ABOBlankSelectDP extends EditorDP
{
	/** class name **/
	public static final String STR_MVC_CLASS_NAME = "ABOBlankSelectDP";

	/** Editor Repost Control Name */
	private String m_strRepostControlName = SecurityMatrixRepostControl.STR_MVC_CLASS_NAME;

	/**
	 * Customizes the spacing on the left and right sides of the content
	 * table.  The default value is 15.  Set to 0 if you don't want views
	 * to be indented.
	 */
	public ABOBlankSelectDP()
	{
		super();
		super.SetContentTableCellSpacing("15");
	}

	/**
	 * Sets the editor repost control to be used in this display page.
	 * If this method is not called the default is the SecurityMatrixRepostControl.
	 * 
	 * @param _strEditorRepostControl An EditorRepostControl's name.
	 */
	public void SetRepostControlName(String _strEditorRepostControl)
	{
		m_strRepostControlName = _strEditorRepostControl;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(1699, "ptmsgs_portaladminmsgs");
	}

	/* */

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * This blank page does not have any HTML.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		return new HTMLElementCollection();
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		// create script container for return
		HTMLScriptCollection myScriptCollection = super.DisplayJavaScriptFromChild();

		// create our script
		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb  = new XPStringBuilder(200);

		// create new URL for our pop-up
		ASURL ABOPopUp = new ASURL(m_asOwner);
		ABOPopUp.SetLinkGetCachedSpace(m_asOwner);
		ABOPopUp.SetControl(m_strRepostControlName);
		ABOPopUp.SetDisplayPage(ABOPopupSelectDP.STR_MVC_CLASS_NAME);

		// open a pop-up window to the URL
		sb.Append("window.open('").Append(ABOPopUp.GetURLAsString()).
			Append("', '_blank1', 'location=no,menubar=no, scrollbars=yes, resizable=yes, height=200,width=510');\n");
		myScript.AddInnerHTMLString(sb.ToString());
		myScriptCollection.AddInnerHTMLElement(myScript);

		return myScriptCollection;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()
	 */
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return new HTMLElementCollection();
	}
}

