package com.plumtree.portaluiinfrastructure.securitymatrix;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rickyw
 *
 * This is the pop-up page where we let the user see his ABO link.
 */
public class ABOPopupResultsView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.securitymatrix.ABOPopupResultsView");

	/** object class name */
	public static final String STR_MVC_CLASS_NAME = "ABOPopupResultsView";

	/** html object names */
	public static final String HTMLBUTTON_CLOSE = "in_bu_Close";

	/** javascript constants */
	public static final String JAVASCRIPT_CLOSE = "closeAndRefreshParent";
	
	/** job name not localized at server so we hardcode it here */
	public static final String JOBNAME_PREFIX = "Async operation for ";
	/** localized strings */

	/** configure logger */
	/** member mvc objects */
	protected AActivitySpace m_asOwner;
	protected IFolderSecurityABOModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ABOPopupResultsView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		String strErrors = "";
		
		HTMLElement result   = new HTMLElementCollection();
		HTMLSpan mySpan;
		HTMLTable myTable;
		HTMLInput myInput;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			// table for everything
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetBorder("0");
			myTable.SetWidth("100%");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("10");

			// add link to created job
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();			
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);

			int nID = m_asModel.GetABOJobID();
			String sName = m_asModel.GetCreatedJobName();

			// that is, if the job was created
			if (nID != -1 && !(("").equals(sName)))
			{
				//MES- Did we get the folder name?  We might not have rights...
				String sFolderName = m_asModel.GetFolderNameForCreatedJobs();
				if (("").equals(sFolderName))
				{
					//MES- 3138 == The job "{0}" has been created for this operation.  Check the Automation Server Manager for status.
	 				mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(
		 					m_asOwner.GetString(3138, "ptmsgs_portaladminmsgs"),
							XPHttpUtility.HtmlEncode(sName)));					
				}
				else
				{
	 				mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(
	 					m_asOwner.GetString(2473, "ptmsgs_portaladminmsgs"),
						XPHttpUtility.HtmlEncode(sName),
						XPHttpUtility.HtmlEncode(sFolderName)));
				}
			}
			else if (nID != -1)
			{
				mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(
					m_asOwner.GetString(2633, "ptmsgs_portaladminmsgs"), XPConvert.ToString(nID)));
			}
			else
			{
				//MES- We have no information about the job!  It almost certainly wasn't created.
				//	3139 == The Portal was unable to create a job to run this operation.  Your changes will not be propagated.
				mySpan.AddInnerHTMLString(m_asOwner.GetString(3139, "ptmsgs_portaladminmsgs"));
			}

			// Add buttons
			result.AddInnerHTMLElement(new HTMLComment(
					"Begin: Footer buttons table"));

			// 1st Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// add buttons - add close button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(m_asOwner.GetString(1693, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick(JAVASCRIPT_CLOSE + "(); return false;");

			result.AddInnerHTMLElement(new HTMLComment(
					"End: Footer buttons table"));
		}
		catch (HTMLException he)
		{
			log.Error(he, m_asOwner.GetString(2198, "ptmsgs_portaladminmsgs") + he.getMessage());

			strErrors += m_asOwner.GetString(2198, "ptmsgs_portaladminmsgs") + SecurityMatrixModel.BR_ELEMENT;
		}

		// if error, raise to ui
		if (!"".equals(strErrors))
		{
			((SecurityMatrixModel) m_asModel).RaiseError(strErrors);
		}
		
		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		String strErrors = "";

		// create our own functions
		XPStringBuilder sb = new XPStringBuilder(300);
		sb.Append("\n");
		sb.Append("function ").Append(JAVASCRIPT_CLOSE).Append("()\n");
		sb.Append("{\n");
		sb.Append("  opener.").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(")
		.Append(SecurityMatrixRepostControl.POSTTOSELF_ACTION_CANCEL)
		.Append(");\n");
		sb.Append("  window.close();\n");
		sb.Append("}\n");
		sb.Append("\n");

		HTMLScript myScript = null;
		
		try
		{
			// add our functions
			myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, m_asOwner.GetString(2197, "ptmsgs_portaladminmsgs") + he.getMessage());

			strErrors += m_asOwner.GetString(2197, "ptmsgs_portaladminmsgs") + SecurityMatrixModel.BR_ELEMENT;
		}

		// if error, raise to ui
		if (!"".equals(strErrors))
		{
			((SecurityMatrixModel) m_asModel).RaiseError(strErrors);
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		m_asModel     = (IFolderSecurityABOModelRO) model;
	}
}

