package com.plumtree.portaluiinfrastructure.securitymatrix;


// Foundation Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List
 * framework for the Select PTObject list.
 * Is constains the HTML to display the object Array.
 * It gets the data to display from SelectPTObjectModel.
 *
 * @author Julie Fournier
 */
public class MultiObjectsSecurityView extends ObjectSecurityView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.securitymatrix.MultiObjectsSecurityView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "MultiObjectsSecurity";
	
	/**
	 * HTML Object set row value */
	public static final String HTMLINPUT_SETROW = "in_hi_SetRow";
	
	/**
	 * HTML Object set column value */
	public static final String HTMLINPUT_SETCOLUMN = "in_hi_SetColumn";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MultiObjectsSecurityView();
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));

		int[] arrColumns = ((IMultiObjectsSecurityModelRO) m_model).GetColumns();

		int k = MultiObjectsSecurityModel.EXPLIST_COL_MAX;

		while (k < arrColumns.length)
		{
			int nRowAccessLevelIDToSelect = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					arrColumns[k]));
			boolean bRowAccessFlag			  = XPConvert.ToBoolean(_saData.GetItem(_nRowIndex,
					arrColumns[k + 2]));

			String sInputSelectName = ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLSELECT_ACCESS_LEVEL) +
				_nRowIndex + k;

			result.AddInnerHTMLElement(GetHTMLForAccessLevelCell(
					sInputSelectName, nRowAccessLevelIDToSelect,
					bRowAccessFlag, _nRowIndex));
			k = k + 3;
		}
		
		HTMLTableCell myCell;
		HTMLImg myImage;
		PTConstruct myConstruct;
		HTMLAnchor myAnchor;
		HTMLInput myInput;
		
		// Row icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ROW,
				true, m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt(m_asOwner.GetString(427, "ptmsgs_portalinfrastructure"));
		myImage.SetAlign("absmiddle");

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetAlign(CommonHTMLStrings.CENTER);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("SetRow(" + _nRowIndex + "); return false;");
		myAnchor.AddInnerHTMLElement(myImage);
		
		myCell.AddInnerHTMLElement(myAnchor);
		
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_SETROW + _nRowIndex, "");
		myInput.SetValue(XPConvert.ToString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ));
		myCell.AddInnerHTMLElement(myInput);
		
		result.AddInnerHTMLElement(myCell);

		return result;
	}
	
	/**
	 * Returns the HTML for the last row of the main table.
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTableRow GetHTMLForBottomRow()
	{
		HTMLTableRow myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
		HTMLTableCell myCell;
		
		HTMLImg myImage;
		PTConstruct myConstruct;
		HTMLInput myInput;
		HTMLAnchor myAnchor;
		
		// Row icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_COLUMN,
				true, m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt(m_asOwner.GetString(426, "ptmsgs_portalinfrastructure"));
		myImage.SetAlign("absmiddle");
		
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetColSpan("2");
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myCell.AddInnerHTMLString(m_asOwner.GetString(361,"ptmsgs_portalinfrastructure"));
		
		int[] arrColumns = ((IMultiObjectsSecurityModelRO) m_model).GetColumns();
		int k = MultiObjectsSecurityModel.EXPLIST_COL_MAX;

		// JF- We loop through the column array and print out each one
		while (k < (arrColumns.length  - 2))
		{
			// Row 1 - Cell i
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetHeight("20");
			myCell.SetNoWrap(true);
			myCell.SetAlign(CommonHTMLStrings.CENTER);
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.SetOnClick("SetColumn(" + k + "); return false;");
			myAnchor.AddInnerHTMLElement(myImage);
		
			myCell.AddInnerHTMLElement(myAnchor);
			
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_SETCOLUMN + k, "");
			myInput.SetValue(XPConvert.ToString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ));
			myCell.AddInnerHTMLElement(myInput);
			
			k = k + 3;
		}
		
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		
		
		
		return myRow;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Empty method that sub classes can averride to add
	 * actions to the action bar (like a create object action).
	 *
	 * @param _myRow Action bar row object.
	 * @throws Exception
	 */
	protected void AddHTMLToActionBar(HTMLTableRow _myRow)
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		_myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// Reset icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_RESET,
				true, m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf('" +
			((IMultiObjectsSecurityModelRO) m_model).GetUniqueInt(
				MultiObjectsSecurityControl.POSTTOSELF_ACTION_RESET) +
			"'); return false;");
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Reset label
		mySpan.AddInnerHTMLString(m_asOwner.GetString(149,
				"ptmsgs_portalinfrastructure"));
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);
		myCell.AddInnerHTMLString(SPACE);
	}

	/**
	 * Returns the HTML for the space below the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLBelowActionBar()
	{
		HTMLTable myTable = new HTMLTable();

		HTMLTableRow myRow;
		HTMLTableCell myCell;

		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);

		myCell.AddInnerHTMLString(m_asOwner.GetString(150,
				"ptmsgs_portalinfrastructure"));

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("0");
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myCell.SetAlign(CommonHTMLStrings.RIGHT);
		
		HTMLAnchor help = HTMLConstructHelpers.GetHelpAnchor(m_asOwner);
		myCell.AddInnerHTMLElement(help);

		return myTable;
	}
	
	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();
		
		XPStringBuilder sb;
		
		int[] arrColumns = ((IMultiObjectsSecurityModelRO) m_model).GetColumns();

		try
		{
			sb = new XPStringBuilder(200);
			sb.Append("function SetRow(varRowID)\n");
			sb.Append("{\n");
			sb.Append("  var i = " + MultiObjectsSecurityModel.EXPLIST_COL_MAX + ";\n");
			sb.Append("  var intNewVal = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETROW + "\" + varRowID + \".value\");\n");
			sb.Append("  \n");
			sb.Append("  while (i < " + (arrColumns.length  - 2) + ") \n");
			sb.Append("  {\n");
			sb.Append("    var strSelectName = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + 
				((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLSELECT_ACCESS_LEVEL) +
				"\" + varRowID + i); " );
			sb.Append("    if (strSelectName) {\n");
			sb.Append("      strSelectName.value = intNewVal;\n");
			sb.Append("    }\n");
			sb.Append("    i = i + 3;\n");
			sb.Append("  }\n");
			
			sb.Append("  UpdateInputValue(eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETROW + "\" + varRowID));\n");
			sb.Append("}\n");
			
			myScript.AddInnerHTMLString(sb.ToString());
			
			sb = new XPStringBuilder(200);
			sb.Append("function SetColumn(varColumnID)\n");
			sb.Append("{\n");
			sb.Append("  var i = 0;\n");
			sb.Append("  var intNewVal = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETCOLUMN + "\" + varColumnID + \".value\");\n");
			sb.Append("  \n");
			sb.Append("  while (i < " + ((IMultiObjectsSecurityModelRO) m_model).GetReadOnlyItems().GetCount() + ") \n");
			sb.Append("  {\n");
			sb.Append("    var strSelectName = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + 
				((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLSELECT_ACCESS_LEVEL) +
				"\" + i + varColumnID); " );
			sb.Append("    if (strSelectName) {\n");
			sb.Append("      strSelectName.value = intNewVal;\n");
			sb.Append("    }\n");
			sb.Append("    i = i + 1;\n");
			sb.Append("  }\n");
			
			sb.Append("  UpdateInputValue(eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETCOLUMN + "\" + varColumnID));\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
			
			sb = new XPStringBuilder(200);
			sb.Append("function UpdateInputValue(varInput)\n");
			sb.Append("{\n");
			sb.Append("  if (" + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE + " == varInput.value) \n");
			sb.Append("  {\n");
			sb.Append("    varInput.value = " + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ + ";\n");
			sb.Append("  }\n");
			sb.Append("  else if (" + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ + " == varInput.value) \n");
			sb.Append("  {\n");
			sb.Append("    varInput.value = " + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT + ";\n");
			sb.Append("  }\n");
			sb.Append("  else if (" + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT + " == varInput.value) \n");
			sb.Append("  {\n");
			sb.Append("    varInput.value = " + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT + ";\n");
			sb.Append("  }\n");
			sb.Append("  else if (" + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT + " == varInput.value) \n");
			sb.Append("  {\n");
			sb.Append("    varInput.value = " + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN + ";\n");
			sb.Append("  }\n");
			sb.Append("  else if (" + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN + " == varInput.value) \n");
			sb.Append("  {\n");
			sb.Append("    varInput.value = " + PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE + ";\n");
			sb.Append("  }\n");
			sb.Append("}\n");
			
			myScript.AddInnerHTMLString(sb.ToString());
			
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "MultiObjectsSecurityView::DisplayJavascript An error occured when trying to display the JavaScript.");
			
		}

		return myScript;
	}
}

