package com.plumtree.portaluiinfrastructure.securitymatrix;


// Plumtree server
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Misc Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author Julie Fournier
 */
public class SecurityMatrixEditorAS extends PTEditorAS
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SecurityMatrixEditor";

	/**
	 * Storage name for Security Matrix.
	 */
	public static final String STR_MVC_STORAGE_NAME_MULTI_SECURITY = "MultiObjectsSecuritySecurityMatrixEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SecurityMatrixEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(151, "ptmsgs_portalinfrastructure"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (SecurityMatrixRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = SecurityMatrixModel.STR_MVC_CLASS_NAME;
		super.Init();

		IModel myModel = GetModel(SecurityMatrixModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new SecurityMatrixDP());
		RegisterPage(new ABOBlankSelectDP());
		RegisterPage(new ABOPopupSelectDP());
		RegisterPage(new ABOBlankResultsDP());
		RegisterPage(new ABOPopupResultsDP());

		// Register Views
		RegisterView(ABOPopupSelectView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ABOPopupResultsView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(SecurityMatrixRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Set default page
		SetCurrentPage(SecurityMatrixDP.STR_MVC_CLASS_NAME);

		// Register multi objects security pages
		RegisterModel(MultiObjectsSecurityModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_SECURITY);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySecModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_SECURITY);
		RegisterView(MultiObjectsSecurityView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_SECURITY, mySecModel);
		RegisterControl(MultiObjectsSecurityControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_SECURITY, mySecModel);
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if (SecurityMatrixDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_EditSecurity");
		}
	}
}

