package com.plumtree.portaluiinfrastructure.securitymatrix;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This class keeps an up-to-date state of all the settings.
 * This class is used by the Section and by the Repost Control.
 *
 * @author Julie Fournier
 */
public class SecurityMatrixModel extends EditorModel
	implements ISecurityMatrixModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.securitymatrix.SecurityMatrixModel");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SecurityMatrix";

	public static final String BR_ELEMENT = "<BR>";

	/** job id for ABO security change */
	private int m_nABOJobID;

	/** job name for ABO security change */
	private String m_sABOJobName;
	
	/** folder name job created in */
	private String m_sABOFolderJobCreatedInName;

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		return ((MultiObjectsSecurityModel) m_asOwner.GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).InitializeMultiObjsSecurityPage(_htFormData,
			(IPTSession) m_asOwner.GetUserSession());
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SecurityMatrixModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		((MultiObjectsSecurityModel) m_asOwner.GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).Finish();
	}

	/**
	* Returns the Class name.
	*
	* @return String
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		if (_sPageName.equals(SecurityMatrixDP.STR_MVC_CLASS_NAME))
		{
			((MultiObjectsSecurityModel) m_asOwner.GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).SaveSection(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * 
	 * @return the current IPTAccessList of the folder whose security is being edited
	 */
	public IPTAccessList GetCurrentFolderACL()
	{
		return ((MultiObjectsSecurityModel) m_asOwner.GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).GetCurrentFolderACL();
	}

	/**
	 * @param _ptOldACL - the IPTAccessList from before the ACL was changed
	 * @return true, if an admin acl was added or an acl was changed to admin.
	 */
	public boolean IsAdminModifiedOnFolder(IPTAccessList _ptOldACL)
	{
		return ((MultiObjectsSecurityModel) m_asOwner.GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).IsAdminModifiedOnFolder(_ptOldACL);
	}

	/**
	* Creates a job to propagate security.
	* 
	* @param bPropagateAllACLs - If true propagate all acls to child objects
	* 			and subfolders, if false propagate only admin acls.
	*/
	public void PropagateSecurityUsingABO(boolean bPropagateAllACLs)
	{
		IPTServerContext ptSC;
		IPTAdminFolder ptFolder;
		IPTScheduledOperation ptOp;

		// get our session
		IPTSession mySession = (IPTSession) m_asOwner.GetUserSession();
				
		try
		{
			// can only edit one admin folder at a time so the first
			// element of the object array will be the folder we want 
			ptFolder = (IPTAdminFolder)((MultiObjectsSecurityModel) m_asOwner.
				GetModel(SecurityMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SECURITY)).
				GetObjectArray().GetElement(0);

			// lock the folder for edit								
			ptSC = (IPTServerContext) ptFolder;
			ptSC.LockObject();

			int nAdminFolderJobType;
			if ( bPropagateAllACLs )
			{
				nAdminFolderJobType = PT_ADMIN_FOLDER_JOB_TYPES.PT_ADMIN_FOLDER_JOB_PROPAGATEACL_REPLACE;
			}
			else
			{
				nAdminFolderJobType = PT_ADMIN_FOLDER_JOB_TYPES.PT_ADMIN_FOLDER_JOB_PROPAGATEACL_ADMINSONLY;
			}

			// set the job type
			ptFolder.SetJobType(nAdminFolderJobType);

			// save and unlock
			ptSC.Store();
			ptSC.UnlockObject();
			
			// create job to propagate security
			ptOp = (IPTScheduledOperation) ptFolder;
			m_nABOJobID = ptOp.ScheduleImmediateJob();

			// get the job's localized name
			IPTJob myTempJob = (IPTJob) mySession.
				GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).
				Open(m_nABOJobID, false);
			m_sABOJobName = myTempJob.GetLocalizedName();
		}
		catch (Exception ex)
		{
			m_nABOJobID = -1;

			
				log.Error(m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) + 
					PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
			

			// display error
			RaiseError(m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) + BR_ELEMENT);
		}
		
		try {
			// get the folder that the job was created in's localized name
			IPTAdminFolder myTempAdminFolder = (IPTAdminFolder) mySession.GetAdminCatalog().
				OpenAdminFolder(PT_INTRINSICS.PT_ADMIN_FOLDER_INTRINSICOPS, false);
			m_sABOFolderJobCreatedInName = myTempAdminFolder.GetLocalizedName();
		} catch (Exception ex) {
			// DCA - could not get folder name, user must not have access.
			m_sABOFolderJobCreatedInName = "";
			log.Error(ex, "SecurityMatrixModel:PropagateSecurityUsingABO Could not get localized name of folder with Id: " 
					+ PT_INTRINSICS.PT_ADMIN_FOLDER_INTRINSICOPS);
		}
	}

	/**
	 * Retrieves the id of the job created by ABO.
	 */
	public int GetABOJobID()
	{
		return m_nABOJobID;
	}

	/**
	 * Retrieves the name of the job created by ABO.
	 */
	public String GetCreatedJobName()
	{
		return m_sABOJobName;
	}
	
	/**
	 * Retrieves the name of the folder that ABO created the job in.
	 */
	public String GetFolderNameForCreatedJobs()
	{
		return m_sABOFolderJobCreatedInName;
	}

	// helper classes
	public void RaiseError(String strError)
	{
		UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, strError, strError);

		myError.SetActivitySpace(m_asOwner.GetName());
		myError.SetDisplayOnSeparatePage(false);
		myError.SetClearWithActivitySpaceChange(true);
		myError.SetImmediateClear(true);

		UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
			m_asOwner.GetApplication());
	}
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetClassID()
	 */
	public int GetClassID() {
		// XXX Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObject()
	 */
	public IPTObject GetObject() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectDescription()
	 */
	public String GetObjectDescription() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectID()
	 */
	public int GetObjectID() {
		// XXX Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectName()
	 */
	public String GetObjectName() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetParentFolderPath()
	 */
	public String GetParentFolderPath() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetPTSession()
	 */
	public IPTSession GetPTSession() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#ABOJobIDToDisplay()
	 */
	public boolean ABOJobIDToDisplay() {
		// XXX Auto-generated method stub
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetEditObjectURL(int, int)
	 */
	public ASURL GetEditObjectURL(int _nClassID, int _nObjectID) {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetNumSubPortals()
	 */
	public int GetNumSubPortals() {
		// XXX Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetRegularFolderID()
	 */
	public String GetRegularFolderID() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetSelectedSubPortalID()
	 */
	public String GetSelectedSubPortalID() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetSubPortalID(int)
	 */
	public String GetSubPortalID(int pos) {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetSubPortalName(int)
	 */
	public String GetSubPortalName(int pos) {
		// XXX Auto-generated method stub
		return null;
	}

}

