package com.plumtree.portaluiinfrastructure.sso.integrations;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.sso.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;

/**
 * Simple class used to test SSO.
 *
 * @author Mike Jahr
 */
public class SSOTest implements ISSOIntegration
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_SSO),
		"com.plumtree.portaluiinfrastructure.sso.integrations.SSOTest");

	/**
	 * Creates a new SSOTest object.
	 */
	public SSOTest()
	{
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetLoginInfo()
	 */
	public SSOLoginInfo GetLoginInfo(IXPRequest request)
	{
		String strUserName = request.GetHeader("PT_USERNAME");
		if (strUserName == null || strUserName.length() == 0) strUserName = "SSOTestUser";
		
		return new SSOLoginInfo(request.GetHeader("PT_DOMAIN"), strUserName, request.GetHeader("PT_PASSWORD"));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSSOProductName()
	 */
	public String GetSSOProductName()
	{
		return "Plumtree Test SSO";
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureCookies()
	 */
	public String[] GetSecureCookies()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureHeaders()
	 */
	public String[] GetSecureHeaders()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Initialize()
	 */
	public boolean Initialize(XPHashtable mapSettings)
	{
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Logout()
	 */
	public boolean OnLogout(IXPResponse response, String sReturnURL)
	{
        String sURL = "http://qweb2/gsroot/sso/redirect.asp?url=" + XPHttpUtility.UrlEncode(sReturnURL, "UTF-8");
        response.Redirect(sURL);

        log.Info("SSOTest is redirecting to " + sURL);
        
        return true;
	}
}

