package com.plumtree.portaluiinfrastructure.sso.integrations;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.sso.*;

/**
 * Handles SSO integration with Windows Integrated Authentication, aka NTLM.
 *
 * @author Mike Jahr
 */
public class WindowsIntegratedAuth implements ISSOIntegration
{
	private static final String[] HEADERS = null;
	private static final String[] COOKIES = null;
	private boolean m_bUseDomain = true;

	/**
	 * Creates a new WindowsIntegratedAuth object.
	 */
	public WindowsIntegratedAuth()
	{
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetLoginInfo()
	 */
	public SSOLoginInfo GetLoginInfo(IXPRequest request)
	{
		String sUserName;

		try
		{
			// Should use request.GetBasicAuthUserName(), but that returns AUTH_USER
			// instead of LOGON_USER.  AUTH_USER is only there if basic auth is turned
			// on.  If Windows integrated auth is turned on, only LOGON_USER will be
			// there.  Basic auth should have both AUTH_USER and LOGON_USER.
			// GetServerVariable() has been deprecated because XDK cannot guarantee
			// mapped behavior between Java and .NET.  However, WIA is typically used
			// in an IIS environment only.
			sUserName = XPConvert.ToString(request.GetServerVariable("LOGON_USER"));
		}
		catch (Exception e)
		{
			throw XPException.GetInstance(e);
		}
		
		if (!m_bUseDomain)
		{
			// mj: if there's no domain, this will just return the whole string
			sUserName = sUserName.substring(sUserName.indexOf('\\') + 1);
		}
		
		return new SSOLoginInfo(sUserName, request.GetBasicAuthPassword());
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSSOProductName()
	 */
	public String GetSSOProductName()
	{
		return "Windows Integrated Authentication";
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureCookies()
	 */
	public String[] GetSecureCookies()
	{
		return COOKIES;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#GetSecureHeaders()
	 */
	public String[] GetSecureHeaders()
	{
		return HEADERS;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Initialize()
	 */
	public boolean Initialize(XPHashtable mapSettings)
	{
		XPArrayList list = (XPArrayList) mapSettings.GetElement("UseDomain");
		if (list != null && list.GetSize() > 0)
		{
			m_bUseDomain = "1".equals(list.GetElement(0));
		}
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.sso.ISSOIntegration#Logout()
	 */
	public boolean OnLogout(IXPResponse response, String sReturnURL)
	{
        return false;
	}
}

