package com.plumtree.portaluiinfrastructure.statichelpers;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This class contains helper methods to get variables from the PTconfigVarPack
 * and configVarPack.
 * 
 * @author Don Hayler
 */
public class PTConfigHelper extends ConfigHelper
{
	/**
	 * Helper method to access an int variable from x_config.xml.
	 *
	 * @param strSection strSection
	 * @param strSubSection strSubSection
	 * @param strAttribute strAttribute
	 * @param space the current space
	 *
	 * @return int the requested variable
	 */
	public static int GetConfigVariableAsInt(String strSection,
		String strSubSection, String strAttribute, AActivitySpace space)
	{
		return ((PTConfigVarPack) space.GetApplication().GetVarPackManager()
		.GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsInt(strSection,
			strSubSection, strAttribute);
	}

	/**
	 * Helper method to access a String variable from x_config.xml.
	 *
	 * @param strSection strSection
	 * @param strSubSection strSubSection
	 * @param strAttribute strAttribute
	 * @param space the current space
	 *
	 * @return String the requested variable
	 */
	public static String GetConfigVariableAsString(String strSection,
		String strSubSection, String strAttribute, AActivitySpace space)
	{
		return ((PTConfigVarPack) space.GetApplication().GetVarPackManager()
		.GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsString(strSection,
			strSubSection, strAttribute);
	}

	/**
	 * Helper method to access a String variable from x_config.xml.
	 *
	 * @param strSection strSection
	 * @param strSubSection strSubSection
	 * @param strAttribute strAttribute
	 * @param application the current IApplication
	 *
	 * @return String the requested variable
	 */
	public static String GetConfigVariableAsString(String strSection,
		String strSubSection, String strAttribute, IApplication app)
	{
		return ((PTConfigVarPack) app.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValueAsString(strSection,
			strSubSection, strAttribute);
	}

	/**
	 * Helper method to access a String variable from x_config.xml.
	 *
	 * @param strSection strSection
	 * @param strSubSection strSubSection
	 * @param strAttribute strAttribute
	 * @param space the current space
	 *
	 * @return String the requested variable
	 */
	public static Object[] GetConfigVariables(String strSection,
		String strSubSection, String strAttribute, AActivitySpace space)
	{
		return ((PTConfigVarPack) space.GetApplication().GetVarPackManager()
		.GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValues(strSection,
			strSubSection, strAttribute);
	}

	/**
	 * Helper method to access a String variable from x_config.xml.
	 *
	 * @param strSection strSection
	 * @param strSubSection strSubSection
	 * @param strAttribute strAttribute
	 * @param space the current space
	 *
	 * @return String the requested variable
	 */
	public static Object[] GetConfigVariables(String strSection,
		String strSubSection, String strAttribute, IApplication application)
	{
		return ((PTConfigVarPack) application.GetVarPackManager()
		.GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetConfigValues(strSection,
			strSubSection, strAttribute);
	}

	/**
	 * This method returns the PT class type description manager.
	 */
	public static final ClassTypeDescManager GetPTClassTypeDescrManager()
	{
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());

		return (ClassTypeDescManager) application.GetCachingManager().GetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER);
	}

	/**
	 * Returns the SSO relative URL ending with a question mark. E.g.:
	 * SSOLoginPage?
	 *
	 * @return String
	 */
	public static final String GetSSORelativeURL()
	{
		IApplication application;
		String sSSORelativeURL;

		application     = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		sSSORelativeURL     = ((PTConfigVarPack) application.GetVarPackManager()
			.GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetSSORelativeURL();

		return sSSORelativeURL + "?";
	}

	/**
	 * Returns the SSO base URL ending with a question mark. E.g.:
	 * /SSOLoginPage?
	 *
	 * @return String
	 */
	public static final String GetSSOBaseURL()
	{
		IApplication application;
		String sSSOBaseURL;

		application     = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		sSSOBaseURL     = ((PTConfigVarPack) application.GetVarPackManager()
			.GetVariablePackage(PTConfigVarPack.VARPACK_ID)).GetSSOBaseURL();

		return sSSOBaseURL + "?";
	}
	
	/**
	 * Checks whether the classId supports friendly URLs
	 * 
	 * @param classId
	 * @return
	 */
	public static final boolean UseFriendlyURLS(int classId)
	{
		// Friendly URL defined for a particular classId if there are friendly url token defined 
		return UseFriendlyURLS(classId, null);
	}
	
	/**
	 * Checks whether the classId supports friendly URLs
	 * 
	 * @param classId
	 * @param queryStringArgs
	 * @return
	 */
	public static final boolean UseFriendlyURLS(int classId, String queryStringArgs)
	{
		// Friendly URL defined for a particular classId if there are friendly url token defined 
		String res = ((IFriendlyURLManager)PTConfigHelper.GetTypeDescrManager()).LookupFriendlyURLKeyFromClassId(XPConvert.ToString(classId));
		boolean useFriendly = true;
		useFriendly = (res == null) ? false : true;

		// check for specific cases when we shouldn't use friendly URLs
		if ( useFriendly && queryStringArgs != null ) 
		{
			// directory edit mode button, we don't have access to the directory constants since they are defined in portalpages
			// project, DirMode of 2 means edit mode
			if ( queryStringArgs.indexOf("DirMode=2") != -1 ) {
				useFriendly = false;
			}
			
			
		}
		
		return useFriendly;
	}
}

