package com.plumtree.portaluiinfrastructure.statichelpers;


// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;

/**
 * Helper static methods for the XUI.
 *
 * @author Julie Fournier
 */
public class XUIHelperMethods
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.statichelpers.XUIHelperMethods");

	/** XUI Editor Type: Authentication Source */
	public static final String XUI_AUTHSOURCE_SERVICEID = "plumtree-com:rap:auth";

	/** XUI Editor Type: Crawler */
	public static final String XUI_CRAWLER_SERVICEID = "plumtree-com:cws:crawl";

	/** XUI Editor Type: Card */
	public static final String XUI_DOCUMENT_SERVICEID = "plumtree-com:cws:card";

	/** XUI Editor Type: Data Source */
	public static final String XUI_DATASOURCE_SERVICEID = "plumtree-com:cws:ds";

	/** XUI Editor Type: Profile Source */
	public static final String XUI_PROFILESOURCE_SERVICEID = "plumtree-com:pws:profile";

	/** XUI Editor Type: Search */
	public static final String XUI_SEARCH_SERVICEID = "plumtree-com:sws:search";

	/** XUI Editor Type: Migration Import */
	public static final String XUI_MIGRATION_IMPORT_SERVICEID = "plumtree-com:mws:import";

	/** XUI Editor Type: Migration Export */
	public static final String XUI_MIGRATION_EXPORT_SERVICEID = "plumtree-com:mws:export";

	/** Time out for the XUI requests to the remote server */
	public static final int XUI_TIMEOUT_IN_SECONDS = 90;

	/** name of the XSL transformer file */
	public static final String XUI_XSL_TRANSFORMER = "XUI.xsl";

	/** Query String param: web service ID */
	public static final String QS_XUI_WEBSERVICE_ID = "webServiceID";

	/** Query String param: data source ID */
	public static final String QS_XUI_DATASOURCE_ID = "dataSourceID";

	/**
	 * Returns the Data Source ID from the QS.
	 *
	 * @param _htFormData
	 *
	 * @return 
	 */
	public static int GetDataSourceIDFromQS(XPHashtable _htFormData)
	{
		int nDataSourceID = -1;

		if (!_htFormData.ContainsKey(QS_XUI_DATASOURCE_ID))
		{
			
				log.Error("XUIHelperMethods::GetDataSourceIDFromQS The data source ID was " +
					"not found in the Query String. The Editor cannot be started.");
			
		}
		else
		{
			String[] data = (String[]) _htFormData.GetElement(QS_XUI_DATASOURCE_ID);

			try
			{
				nDataSourceID = XPConvert.ToInteger(data[0]);
			}
			catch (Exception e)
			{
				
					log.Error("XUIHelperMethods::GetDataSourceIDFromQS The data source ID was invalid: " +
						data +
						". The Editor cannot be started. The following exception happened:" +
						e);
				
			}
		}

		return nDataSourceID;
	}
}

