package com.plumtree.portaluiinfrastructure.subscribematrix;


// Foundation Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List
 * framework for the Select PTObject list.
 * Is constains the HTML to display the object Array.
 * It gets the data to display from SelectPTObjectModel.
 *
 * @author Julie Fournier
 */
public class MultiObjectsSubscribeView extends SelectPTObjectView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.subscribematrix.MultiObjectsSubscribeView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "MultiObjectsSubscribe";
	
	/**
	 * HTML Object name: subscribe checkbox */
	public static final String HTMLCHECKBOX_SUBSCRIBE = "in_cb_Subscribe";

	/**
	 * HTML Object set row value */
	public static final String HTMLINPUT_SETROW = "in_hi_SetRow";
	
	/**
	 * HTML Object set column value */
	public static final String HTMLINPUT_SETCOLUMN = "in_hi_SetColumn";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MultiObjectsSubscribeView();
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));

		int[] arrColumns = ((IMultiObjectsSubscribeModelRO) m_model).GetColumns();

		int k = MultiObjectsSubscribeModel.EXPLIST_COL_MAX;

		while (k < arrColumns.length)
		{
			int nRowAccessLevelIDToSelect = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					arrColumns[k]));

			String sInputName = ((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLCHECKBOX_SUBSCRIBE) +
				_nRowIndex + k;

			result.AddInnerHTMLElement(GetHTMLForAccessLevelCell(
					sInputName, nRowAccessLevelIDToSelect));
			k = k + 3;
		}
		
		HTMLTableCell myCell;
		HTMLImg myImage;
		PTConstruct myConstruct;
		HTMLAnchor myAnchor;
		HTMLInput myInput;
		
		// Row icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_CHECK_ROW,
				true, m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt(m_asOwner.GetString(522, "ptmsgs_portalinfrastructure"));
		myImage.SetAlign("absmiddle");

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetAlign(CommonHTMLStrings.CENTER);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("SetRow(" + _nRowIndex + "); return false;");
		myAnchor.AddInnerHTMLElement(myImage);
		
		myCell.AddInnerHTMLElement(myAnchor);
		
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_SETROW + _nRowIndex, "");
		myInput.SetValue("1");
		myCell.AddInnerHTMLElement(myInput);
		
		result.AddInnerHTMLElement(myCell);

		return result;
	}
	
	/**
	 * Returns the HTML for the Access Level drop-down cell.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForAccessLevelCell(String _sInputName, int _nRowAccessLevelIDToSelect)
	{
		HTMLTableCell myCell;
		HTMLInput myCheckBox;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.SetAlign(CommonHTMLStrings.CENTER);

		if (_nRowAccessLevelIDToSelect < PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ)
		{
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}
		else
		{
			myCheckBox = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE, _sInputName, "checkbox1");
			myCheckBox.SetValue("1");
			myCheckBox.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell.AddInnerHTMLElement(myCheckBox);
		}

		return myCell;
	}

	/**
	 * No Action Bar for bulk subscribe
	 */
	protected HTMLTable GetHTMLForActionBar()
	{
		return null;
	}

	/**
	 * Returns the HTML for the last row of the main table.
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTableRow GetHTMLForBottomRow()
	{
		HTMLTableRow myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
		HTMLTableCell myCell;
		
		HTMLImg myImage;
		PTConstruct myConstruct;
		HTMLInput myInput;
		HTMLAnchor myAnchor;
		
		// Column icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_CHECK_COLUMN,
				true, m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt(m_asOwner.GetString(521, "ptmsgs_portalinfrastructure"));
		myImage.SetAlign("absmiddle");
		
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myCell.AddInnerHTMLString(m_asOwner.GetString(361,"ptmsgs_portalinfrastructure"));
		
		int[] arrColumns = ((IMultiObjectsSubscribeModelRO) m_model).GetColumns();
		int k = MultiObjectsSubscribeModel.EXPLIST_COL_MAX;

		// JF- We loop through the column array and print out each one
		while (k < (arrColumns.length  - 2))
		{
			// Row 1 - Cell i
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetHeight("20");
			myCell.SetNoWrap(true);
			myCell.SetAlign(CommonHTMLStrings.CENTER);
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.SetOnClick("SetColumn(" + k + "); return false;");
			myAnchor.AddInnerHTMLElement(myImage);
		
			myCell.AddInnerHTMLElement(myAnchor);
			
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_SETCOLUMN + k, "");
			myInput.SetValue("1");
			myCell.AddInnerHTMLElement(myInput);
			
			k = k + 3;
		}
		
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		
		
		
		return myRow;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the space below the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLBelowActionBar()
	{
		HTMLTable myTable = new HTMLTable();

		HTMLTableRow myRow;
		HTMLTableCell myCell;

		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);

		myCell.AddInnerHTMLString(m_asOwner.GetString(516,
				"ptmsgs_portalinfrastructure"));

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("0");
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myCell.SetAlign(CommonHTMLStrings.RIGHT);
		
		HTMLAnchor help = HTMLConstructHelpers.GetHelpAnchor(m_asOwner);
		myCell.AddInnerHTMLElement(help);

		return myTable;
	}
	
	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();
		
		XPStringBuilder sb;
		
		int[] arrColumns = ((IMultiObjectsSubscribeModelRO) m_model).GetColumns();

		try
		{
			sb = new XPStringBuilder(200);
			sb.Append("function SetRow(varRowID)\n");
			sb.Append("{\n");
			sb.Append("  var i = " + MultiObjectsSubscribeModel.EXPLIST_COL_MAX + ";\n");
			sb.Append("  var intNewVal = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETROW + "\" + varRowID + \".value\");\n");
			sb.Append("  \n");
			sb.Append("  while (i < " + (arrColumns.length  - 2) + ") \n");
			sb.Append("  {\n");
			sb.Append("    var strCheckBoxName = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + 
				((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLCHECKBOX_SUBSCRIBE) +
				"\" + varRowID + i); " );
			sb.Append("    if (strCheckBoxName) {\n");
			sb.Append("      strCheckBoxName.checked = (1==intNewVal) ? true : false;\n");
			sb.Append("    }\n");
			sb.Append("    i = i + 3;\n");
			sb.Append("  }\n");
			
			sb.Append("  UpdateInputValue(eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETROW + "\" + varRowID));\n");
			sb.Append("}\n");
			
			myScript.AddInnerHTMLString(sb.ToString());
			
			sb = new XPStringBuilder(200);
			sb.Append("function SetColumn(varColumnID)\n");
			sb.Append("{\n");
			sb.Append("  var i = 0;\n");
			sb.Append("  var intNewVal = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETCOLUMN + "\" + varColumnID + \".value\");\n");
			sb.Append("  \n");
			sb.Append("  while (i < " + ((IMultiObjectsSubscribeModelRO) m_model).GetReadOnlyItems().GetCount() + ") \n");
			sb.Append("  {\n");
			sb.Append("    var strCheckBoxName = eval(\"document." + EditorDP.HTMLFORM_NAME + "." + 
				((IObjectSecurityModelRO) m_model).GetUniqueString(HTMLCHECKBOX_SUBSCRIBE) +
				"\" + i + varColumnID); " );
			sb.Append("    if (strCheckBoxName) {\n");
			sb.Append("      strCheckBoxName.checked = (1==intNewVal) ? true : false;\n");
			sb.Append("    }\n");
			sb.Append("    i = i + 1;\n");
			sb.Append("  }\n");
			
			sb.Append("  UpdateInputValue(eval(\"document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SETCOLUMN + "\" + varColumnID));\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
			
			sb = new XPStringBuilder(200);
			sb.Append("function UpdateInputValue(varInput)\n");
			sb.Append("{\n");
			sb.Append("  if (1 == varInput.value) \n");
			sb.Append("  {\n");
			sb.Append("    varInput.value = 0;\n");
			sb.Append("  }\n");
			sb.Append("  else \n");
			sb.Append("  {\n");
			sb.Append("    varInput.value = 1;\n");
			sb.Append("  }\n");
			sb.Append("}\n");
			
			myScript.AddInnerHTMLString(sb.ToString());
			
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "MultiObjectsSecurityView::DisplayJavascript An error occured when trying to display the JavaScript.");
			
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForSubHeader()
	 */
	protected HTMLTableRow GetHTMLForSubHeader()
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLAnchor myAnchor;
		HTMLInput myInput;
		HTMLImg myImage;
		PTConstruct myConstruct;

		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

		Object[][] oArrExpListColInfo = ((IExpListModelRO) m_model).GetArrExpListColInfo();
		int nColumnID;

		// JF- We loop through the column array and print out each one
		for (int i = 0; i < oArrExpListColInfo.length; i++)
		{
			// Row 1 - Cell i
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_WIDTH]);
			myCell.SetColSpan((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
			myCell.SetHeight("20");
			myCell.SetNoWrap(((IExpListModelRO) m_model).GetWrapColumnHeaders());
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			myCell.AddInnerHTMLString(SPACE);

			// JF- Print out the column title with information we get from the array (oArrExpListColInfo)
			if (XPConvert.ToBoolean(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ENABLESORT]))
			{
				// JF- If the sort is enabled for this column we need to know what to display:
				// - If the list is not sorted by this column, we display just a link to sort by this column
				// - If the list is currently sorted by this column, we display an arrow that shows the current 
				//   sort direction and a link to reverse the sort.
				
				nColumnID = XPConvert.ToInteger(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID]);

				// JF- The list is currently sorted by this column
				if (nColumnID == ((IExpListModelRO) m_model).GetMainColumnSort())
				{
					// JF- We build the link to reverse the sort
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick("postToSelf('" +
						((IExpListModelRO) m_model).GetUniqueInt(
							ExpListControl.POSTTOSELF_ACTION_REVERSESORT) +
						"'); return false;");
					myCell.AddInnerHTMLElement(myAnchor);
					myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);

					// JF- We figure out the sort direction to know which arrow to display
					if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IExpListModelRO) m_model).GetMainColumnSortDirection())
					{
						myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
								true, this.m_asOwner);
						myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

						myImage.SetAlt(m_asOwner.GetString(55,
								ResourceConstants.INFRASTRUCTURE));
						myImage.SetAlign("absmiddle");
						myAnchor.AddInnerHTMLElement(myImage);
					}
					else
					{
						myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
								true, this.m_asOwner);
						myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

						myImage.SetAlt(m_asOwner.GetString(54,
								ResourceConstants.INFRASTRUCTURE));
						myImage.SetAlign("absmiddle");
						myAnchor.AddInnerHTMLElement(myImage);
					}
				}

				// JF- The list is currently NOT sorted by this column
				else
				{
					// JF- We build the link to sort by this column
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString(
							"SortBy") + "('" +
						oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID] +
						"'); return false;");
					myCell.AddInnerHTMLElement(myAnchor);
					myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
				}
			}

			// JF- The sort was not enabled, just print out the title
			// (we don't need to worry about the link or the arrows)
			else
			{
				PTImageType img = (PTImageType) oArrExpListColInfo[i][MultiObjectsSubscribeModel.EXPLIST_COLUMN_IMG];
				if (null != img)
				{
					HTMLImg htmlImg = (HTMLImg)img.GetHTMLElement();
					htmlImg.SetAlt((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
					myCell.AddInnerHTMLElement(htmlImg);
				}
				myCell.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
			}
		}

		return myRow;
	}
}

