package com.plumtree.portaluiinfrastructure.subscribematrix;


// Plumtree server
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Misc Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author Michael DeCourcey
 */
public class SubscribeMatrixEditorAS extends PTEditorAS
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SubscribeMatrixEditor";

	/**
	 * Storage name for Security Matrix.
	 */
	public static final String STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE = "MultiObjectsSubscribeSubscribeMatrixEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SubscribeMatrixEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(517, "ptmsgs_portalinfrastructure"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (SubscribeMatrixRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = SubscribeMatrixModel.STR_MVC_CLASS_NAME;
		super.Init();

		IModel myModel = GetModel(SubscribeMatrixModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new SubscribeMatrixDP());
		RegisterPage(new ABOSubBlankResultsDP());
		RegisterPage(new ABOSubPopupResultsDP());

		// Register Controls
		RegisterControl(SubscribeMatrixRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Set default page
		SetCurrentPage(SubscribeMatrixDP.STR_MVC_CLASS_NAME);

		// Register multi objects security pages
		RegisterModel(MultiObjectsSubscribeModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySecModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE);

		// Register Views
		RegisterView(ABOSubPopupResultsView.STR_MVC_CLASS_NAME, mySecModel);
		RegisterView(MultiObjectsSubscribeView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE, mySecModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE, mySecModel);
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if (SubscribeMatrixDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_BulkAdd");
		}
	}
}

