package com.plumtree.portaluiinfrastructure.subscribematrix;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This class keeps an up-to-date state of all the settings.
 * This class is used by the Section and by the Repost Control.
 *
 * @author Julie Fournier
 */
public class SubscribeMatrixModel extends EditorModel
	implements IObjEditorModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.subscribematrix.SubscribeMatrixModel");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SubscribeMatrix";

	public static final String BR_ELEMENT = "<BR>";
	
	private boolean m_bHasExecutedFinish;

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		m_bHasExecutedFinish = false;
		
		return ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).InitializeMultiObjsSubscribePage(_htFormData,
			(IPTSession) m_asOwner.GetUserSession());
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SubscribeMatrixModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).Finish();
		
		if (-1 == ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).GetJobID())
		{
			// display error
			RaiseError(m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) + BR_ELEMENT);
		}
		
		m_bHasExecutedFinish = true;
	}
	
	/**
	 * @return true if Finish() has been executed already
	 */
	public boolean HasExecutedFinish()
	{
		return m_bHasExecutedFinish;
	}

	/**
	* Returns the Class name.
	*
	* @return String
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		if (_sPageName.equals(SubscribeMatrixDP.STR_MVC_CLASS_NAME))
		{
			((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).SaveSection(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * 
	 * @return the current IPTAccessList of the folder whose security is being edited
	 */
	public IPTAccessList GetCurrentFolderACL()
	{
		return ((MultiObjectsSubscribeModel) m_asOwner.GetModel(SubscribeMatrixEditorAS.STR_MVC_STORAGE_NAME_MULTI_SUBSCRIBE)).GetCurrentFolderACL();
	}

	// helper classes
	public void RaiseError(String strError)
	{
		UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, strError, strError);

		myError.SetActivitySpace(m_asOwner.GetName());
		myError.SetDisplayOnSeparatePage(false);
		myError.SetClearWithActivitySpaceChange(true);
		myError.SetImmediateClear(true);

		UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
			m_asOwner.GetApplication());
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetClassID()
	 */
	public int GetClassID() {
		// XXX Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObject()
	 */
	public IPTObject GetObject() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectDescription()
	 */
	public String GetObjectDescription() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectID()
	 */
	public int GetObjectID() {
		// XXX Auto-generated method stub
		return 0;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetObjectName()
	 */
	public String GetObjectName() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetParentFolderPath()
	 */
	public String GetParentFolderPath() {
		// XXX Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.IObjEditorModelRO#GetPTSession()
	 */
	public IPTSession GetPTSession() {
		// XXX Auto-generated method stub
		return null;
	}

}

