package com.plumtree.portaluiinfrastructure.tags.common;

import com.plumtree.portaluiinfrastructure.tags.*;

/**
 * This class contains constants that are used by multiple
 * pagination data tags to ensure consistency.
 */
public class PaginationDataConstants
{
	public static final String TAG_NAME = "paginationdata";

	// NOTE: Pagination Data Tags should also use the common ID and
	// Scope attributes from CommonTagAttributeConstants

	// Data for the pages list attribute
	public static final String ATTRIB_PAGESLIST_NAME = "pageslist";
	public static final String ATTRIB_PAGESLIST_DESCRIPTION = "The list of pagination pages.";

	// Data for the number of pages attribute
	public static final String ATTRIB_NUM_PAGES_NAME = "pagestodisplay";
	public static final String ATTRIB_NUM_PAGES_DEFAULT = "2";
	public static final String ATTRIB_NUM_PAGES_DESCRIPTION = "The number of pages to display " +
		"before and after the current page (if there are any). The default is " +
		ATTRIB_NUM_PAGES_DEFAULT + ".";

	// variables for the main data object
	public static final String TOTAL_RESULTS = "total";
	public static final String NUM_PER_PAGE = "numperpage";
	public static final String PREVIOUS_URL = "previousurl";
	public static final String NEXT_URL = "nexturl";
	public static final String LAST_PAGE = "lastpage";
	public static final String FIRST_PAGE_URL = "firstpageurl";
	public static final String LAST_PAGE_URL = "lastpageurl";

	// variables shared between the main data object and the pages objects
	public static final String START_COUNT      = "start";
	public static final String END_COUNT        = "end";

	// variables for the pages objects
	public static final String PAGINATION_URL   = "url";
	public static final String PAGE_NUMBER      = "number";

	// Strings for the main data
	public static final String MAIN_DESCRIPTION_PREFIX = 
		"Generates the data for the pagination links for ";
	public static final String MAIN_DESCRIPTION_SUFFIX = ATag.EncodeForTagDoc(
		"and stores it in memory using the variable name specified by the " +
		"<code>" + CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. ");

	public static final String MAIN_DATA_DESCRIPTION = ATag.EncodeForTagDoc(
		"The main data is stored as a DataObject with the following variables:<br>" +
		"<ul>" +
		"<li> <code>" + TOTAL_RESULTS + "</code> - The total number of results." +
		"<li> <code>" + NUM_PER_PAGE + "</code> - The number of results to display per page." +
		"<li> <code>" + START_COUNT + "</code> - The first result displayed on the current page." +
		"<li> <code>" + END_COUNT + "</code> - The last result displayed on the current page." +
		"<li> <code>" + LAST_PAGE + "</code> - The index of the last page." +
		"<li> <code>" + PREVIOUS_URL + "</code> - The URL to the previous page." +
		"<li> <code>" + NEXT_URL + "</code> - The URL to the next page." +
		"<li> <code>" + FIRST_PAGE_URL + "</code> - The URL to the first page." +
		"<li> <code>" + LAST_PAGE_URL + "</code> - The URL to the last page." +  
		"</ul>");

	// Strings for the page list data
	public static final String PAGES_DATA_DESCRIPTION = ATag.EncodeForTagDoc(
		"Additionally, the list of page links to display is stored in memory using the " +
		"variable name specified by the <code>" + ATTRIB_PAGESLIST_NAME + "</code> attribute. " +
		"Each result is a DataObject with the following variables:<br>" +
		"<ul>" +
		"<li> <code>" + PAGE_NUMBER + "</code> - The index of the page." +
		"<li> <code>" + START_COUNT + "</code> - The first result displayed on the page." +
		"<li> <code>" + END_COUNT + "</code> - The last result displayed on the page." +
		"<li> <code>" + PAGINATION_URL + "</code> - The URL to the page; will not be " +
		"present if the page is the current page." +
		"</ul>" +
		"Use tags from the Logic tags library to iterate over the list and display the results.");

	// TODO: Add example
	/**
	 * This example should be displayed after the pagination data tag is displayed. 
	 */
	public static final String EXAMPLE = null;
}