package com.plumtree.portaluiinfrastructure.tags.data;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;

/**
 * This class is wrapper around XPHashtable that allows it
 * to be used as a data collection in Tag memory.
 */
public class HashtableDataObject implements IHierarchicalDataObject
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		"com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject");

	/**
	 * The underlying hashtable object.
	 */
	protected final XPHashtable m_hashtable;
	protected XPHashtable m_hiertable = null; // only create this if needed

	/**
	 * Default id for hierarchical data.
	 * NOTE: This definition should realy be in IHierarchicalDataObject but C# doesn't allow constant definitions on interfaces.
	 */
	public static final String HIERDATA_DEFAULTKEY = "children";

	/**
	 * Constructor for the Hashtable wrapper data object that
	 * takes a pre-constructed hashtable.
	 * 
	 * @param _hashtable A pre-constructed hashtable.
	 */
	public HashtableDataObject(XPHashtable _hashtable)
	{
		m_hashtable = _hashtable;
	}

	/**
	 * Constructor for the Hashtable wrapper data object.
	 */
	public HashtableDataObject()
	{
		m_hashtable = new XPHashtable();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.data.IDataObject#GetData(String)
	 */
	public String GetData(String _strKey)
	{
		String strResult;

		try
		{
			strResult = (String) m_hashtable.GetElement(_strKey);
		} catch (Exception e)
		{
			log.Warn("Attempt to access data with key " + _strKey +
				" failed.  No such data exist.");

			strResult = null;
		}

		return strResult;
	}
	
	public XPArrayList GetHierData(String _strKey)
	{
		if ( m_hiertable == null ) return null;
		
		return (XPArrayList)m_hiertable.GetElement(_strKey);
	}

	/**
	 * Sets a name value pair on the hashtable.
	 * 
	 * @param _strKey The name used to store the value.
	 * @param _strValue The value to be stored.
	 */
	public void SetData(String _strKey, String _strValue)
	{
		m_hashtable.PutElement(_strKey, _strValue);
	}
	
	/**
	 * Sets hierarchical data  
	 * NOTE: The value is not displayable from tags, this is just used
	 * for hierarchical data tags. 
	 * @param _strKey
	 * @param _strValue
	 */
	public void SetHierData(String _strKey, XPArrayList list)
	{
		if ( m_hiertable == null) { m_hiertable = new XPHashtable(3); }
		m_hiertable.PutElement(_strKey, list);
	}

	/**
	 * Get the underlying hashtable object.
	 * 
	 * @return XPHashtable The underlying hashtable object.
	 */
	public XPHashtable GetHashTable()
	{
		return m_hashtable;
	}
}
