package com.plumtree.portaluiinfrastructure.tags.data;


/**
 * Data objects are used to store collections of variables
 * in Tag memory so that they can be accessed automatically
 * using attribute value replacement.
 * <p>
 * For instance, if an IDataObject is stored in memory
 * (ATag.SetVariable or SetSharedVariable) under the key
 * "links" and has data stored in it under the keys "url"
 * and "name", it could be used as follows:
 * <p>
 * &lt;pt:core.html pt:tag="a" href="$url" title="$name"&gt;
 * <br>
 * &lt;pt:logic.value value="$links.name"/&gt;
 * <br>
 * &lt;/pt:core.html&gt;
 */
public interface IDataObject
{
	/**
	 * Gets the data stored with a particular key.
	 * 
	 * @param _strKey The key for the requested data
	 * @return String The requested data
	 */
	public String GetData(String _strKey);
	
	
}
