/*
 * Created on Jun 1, 2005
 */
package com.plumtree.portaluiinfrastructure.tags.data;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;

/**
 * Helper object that defines and provides a protocol for setting single or a list of PTURL DO data
 * in different Tag Scopes.
 */
public class TagDataSetterPTURLDOData 
{
	// TODOCR DONH: Why is this list called PTURLDOData?  There's nothing in
	// it that's specific to PTURLDO's.  It seems like this should either be
	// generalized, or moved into one of the nav tag libraries if it's nav
	// specific.  It doesn't seem like it belongs here.  It's not part of the
	// framework.  This is something specifically for the nav taglibs, right?

	public static final Scope DEFAULT_TAGSCOPE = Scope.PORTLET_REQUEST;
	
	/** Use an instance of the Getter **/
	TagDataGetterPTURLDOList m_ptURLGetter = null;
	
	/** **/
	Scope m_scope = null;
	
	public TagDataSetterPTURLDOData()
	{
		m_scope = DEFAULT_TAGSCOPE;
		m_ptURLGetter = new TagDataGetterPTURLDOList(m_scope);
		
	}
	
	public TagDataSetterPTURLDOData(Scope scope)
	{
		m_ptURLGetter = new TagDataGetterPTURLDOList(scope);
		m_scope = scope;
	}
	
	/**
	 * Sets the Tag scope to set PTURL data on 
	 * 
	 * @param scope
	 */
	public void SetScope(Scope scope)
	{
		m_scope = scope;
	}
	
	/**
	 * Sets provided list on the Tag Scope. 
	 * 
	 * The list is added  onto any existing list already on the tag Tag Scope.
	 * @param tag
	 * @param tagAttrib
	 * @param xpList
	 */
	public void SetDataCollectionOnTagScope(ITagState state, String strKey, IXPList xpList)
	{
		// Don't need to add anything if the list is empty
		if ( null == xpList || xpList.GetSize() == 0)
		{
			return;
		}
		
		IXPList memList = m_ptURLGetter.GetMemoryData(state, strKey);
		
		if ( null ==  memList ) {
			memList = CreateMemoryData(state, strKey);
		}
		// Note that we add the list to the existing list, not replacing it
		memList.AddRange(xpList);
		
	}
	
	/**
	 * Sets the provided IPTURL object on the Tag Scope.
	 * 
	 * The IPTURL entry is appended to any existing list already on the Tag Scope.
	 * @param state
	 * @param strKey
	 * @param obj
	 */
	public void SetDataEntryOnTagScope(ITagState state, String strKey, IPTURL obj)
	{
		if ( null == obj )
		{
			return;
		}
		IXPList memList = m_ptURLGetter.GetMemoryData(state, strKey);
		
		if ( null ==  memList ) {
			memList = CreateMemoryData(state, strKey);
		}

		memList.Add(obj);
		
	}
	
	/**
	 * Method to create new data instance into Tag Scope
	 * @param tag
	 * @param tagAttrib
	 * 
	 * @return
	 */
	IXPList CreateMemoryData(ITagState state, String strKey)
	{
			
			XPArrayList memList = new XPArrayList();
			state.SetSharedVariable(strKey, memList, m_scope, true);
			
			return memList;
	}
	
}
