package com.plumtree.portaluiinfrastructure.tags.displaytree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class displays an HTML fragment.
 * 
 * This is a framework only class and should not be
 * used by external developers.
 * 
 * @author donh
 */
public class HTMLDisplayElement implements IDisplayElement
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tags.displaytree.HTMLDisplayElement");

	protected Object m_Fragment;

	public HTMLDisplayElement(Object _fragment)
	{
		m_Fragment = _fragment;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#Display(TagVisitor)
	 */
	public HTMLElement Display(TagVisitor _tagVisitor)
	{
		HTMLElement result = new HTMLElementCollection();

		String strFragment;

		try
		{
			strFragment = (String) m_Fragment;

			result.AddInnerHTMLString(strFragment);
		} catch (Exception e)
		{
			log.Error(e, "Unable to convert portlet text fragment " +
				m_Fragment + " to string.");

			XPException xpe = XPException.GetInstance(e);

			result.AddInnerHTMLElement(new HTMLComment
				("Unable to convert portlet text fragment " +
				m_Fragment + " to string. " +
				xpe.GetMessage() + ": " + xpe.GetStackTrace()));
		}

		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#Release()
	 */
	public void Release() {}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#HasChildElements(ITagMetaData[], Object[], TagLibraryMetaData, int)
	 */
	public boolean HasChildElements(ITagMetaData[] _childTags, Object[] _results, TagLibraryMetaData _library, int _nCurrentDepth)
	{
		// HTML doesn't have any child elements, so just return false to continue the search.
		return false;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#HasParentElement(ITagMetaData, TagLibraryMetaData)
	 */
	public int HasParentElement(ITagMetaData _parentTag, TagLibraryMetaData _library)
	{
		// HTML Display Elements do not store their parent tags, so just ignore this method.
		// Technically, this should probably still search up the tree,
		// but no one should call this method on HTML elements.
		return 0;
	}
}
