package com.plumtree.portaluiinfrastructure.tags.displaytree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.xml.*;
import com.plumtree.server.*;
import com.plumtree.server.impl.portlet.providers.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This class is used to preprocess the main page to make sure
 * that it has a place where the JavaScript can go.
 */
public class HeadPreprocessor implements IHeadPreprocessor
{
	/**
	 * This constant is used to insert a head tag around the head
	 * includes.
	 */
	public static final String OPEN_HEAD_TAG = "<head>";

	/**
	 * This constant is used to insert a head tag around the head
	 * includes.
	 */
	public static final String CLOSE_HEAD_TAG = "</head>";

	/**
	 * This is the name of the common library.
	 */
	public static final String COMMON_LIBRARY = "common";

	/**
	 * This is the name of the Head Includes tag in the common library.
	 */
	public static final String HEAD_INCLUDES_TAG_NAME = "headincludes";

	/**
	 * The fully qualified name of the head includes tag in the common library.
	 */
	public static final String HEAD_INCLUDES_TAG_FULL_NAME = COMMON_LIBRARY +
		TagDisplayElement.LIBRARY_SEPARATOR + HEAD_INCLUDES_TAG_NAME;

	/**
	 * The full name of the ptui include tag.
	 */
	public static final String JS_INCLUDE_TAG_FULL_NAME = "ptui" +
		TagDisplayElement.LIBRARY_SEPARATOR + "include";

	/**
	 * The name of the include tag attribute used to specify the JSComponent.
	 */
	public static final String JS_INCLUDE_TAG_NAME_ATTR = "name";

	/**
	 * The name of the include tag attribute used to specify the locale.
	 */
	public static final String JS_INCLUDE_LOCALE_ATTR = "locale";

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IHeadPreprocessor#PreprocessHead(Object[][],
	 *  ISessionManager, IEnvironment, boolean)
	 */
	public Object[][] PreprocessHead(Object[][] _objArrMarkup, ISessionManager _Session,
		IEnvironment _Environment, boolean _bForceHead)
	{
		FragmentListConverter converter = new FragmentListConverter();

		XPArrayList fragments = converter.ConvertMarkupToList(_objArrMarkup);

		PreprocessHead(fragments, _Session, _Environment, _bForceHead);
		
		return converter.ConvertListToMarkup(fragments);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IHeadPreprocessor#PreprocessHead(XPArrayList,
	 *  ISessionManager, IEnvironment, boolean)
	 */
	public void PreprocessHead(XPArrayList _markupList, ISessionManager _Session,
		IEnvironment _Environment, boolean _bForceHead)
	{
		boolean bFoundHead = false;
		boolean bFoundHTML = false;
		boolean bFoundHeadIncludesTag = false;
		boolean bFoundXMLTags = false;
		int nAutoJSTransformTagIndex = -1;

		// Search the fragments for the head markers
		for (int i = 0; i < _markupList.GetSize(); i++)
		{
			IMarkupFragment fragment = (IMarkupFragment) _markupList.GetElement(i);

			if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML)
			{
				bFoundHTML = true;
			} else if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD)
			{
				bFoundHead = true;
			} else if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML)
			{
				bFoundXMLTags = true;
				if (XPStringUtility.Compare(fragment.GetXMLFragment().GetName(0),
					HEAD_INCLUDES_TAG_FULL_NAME) == 0)
				{
					bFoundHeadIncludesTag = true;
				} else if (XPStringUtility.Compare(fragment.GetXMLFragment().GetName(0),
						AutoJSTransformTagConstants.TAG_FULL_NAME) == 0)
				{
					nAutoJSTransformTagIndex = i;
				}
			}
		}

		// Only add the head tags if we need to.  This makes sure we don't accidentally corrupt
		// JavaScript files.
		if (_bForceHead || bFoundXMLTags)
		{
			IMarkupFragment autoJSTransformTag = null;
			if (nAutoJSTransformTagIndex != -1)
			{
				// We need to move this tag to after the <head> tag.
				autoJSTransformTag = (IMarkupFragment) _markupList.RemoveAt(nAutoJSTransformTagIndex);
				Object[][] arrXML = autoJSTransformTag.GetXMLFragment().GetObjectXML();
				// Create a new array one longer
				Object[][] newXML = new Object[PT_XML_ARRAY_COLS.PT_XML_ARRAY_NUM_COLS][arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE].length + 1];

				newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][0] = arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][0];
				newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE][0] = arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE][0];
				newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_VALUE][0] = arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_VALUE][0];

				// Add a new attribute that specifies whether this is the main page or not
				newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][1] = AutoJSTransformTagConstants.ATTR_MAIN_PAGE;
				newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE][1] = XPConvert.ToString(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT);				
				newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_VALUE][1] = XPConvert.ToString(true);

				int newIndex = 1;
				// Skip the first one and copy the rest
				for (int i = 1; i < arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE].length; i++)
				{
					newIndex++;
					newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][newIndex] = arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][i];
					newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE][newIndex] = arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE][i];
					newXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_VALUE][newIndex] = arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_VALUE][i];
				}

				autoJSTransformTag = new TransformerMarkupFragment(new XMLFragment(newXML));
			}

			// The Head Includes tag can be added at several different places on the
			// main page.  This list is in order, and the tag will only get added in
			// the first place possible.
			//
			// 1) If the tag is already present, don't add it
			// 2) If we can find the end of the <head> tag, add it before there
			// 3) If we can find the beginning <html> tag, add it after there
			// 4) Add it at the very beginning (and tell the tag to add a <head> element).
			//
			// In addition, if the tag needs to add a <head> element, we need to add
			// a second Head Includes tag at the end.  This allows us to clean up
			// <head></head> tags if nothing was added (i.e. gatewaying a .js file).
			
			if (!bFoundHeadIncludesTag && !bFoundHead && !bFoundHTML)
			{
				// Insert HeadIncludes tag at beginning.
				int newIndex = 0;
				_markupList.Insert(newIndex++, new TransformerMarkupFragment(OPEN_HEAD_TAG));
				_markupList.Insert(newIndex++, new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD));
				if (autoJSTransformTag != null)
				{
					_markupList.Insert(newIndex++, GetJSIncludesTag(_Environment.GetLocale()));
					_markupList.Insert(newIndex++, autoJSTransformTag);
				}
				_markupList.Insert(newIndex++, GetHeadIncludesTag());
				_markupList.Insert(newIndex++, new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD));
				_markupList.Insert(newIndex++, new TransformerMarkupFragment(CLOSE_HEAD_TAG));
	
				return;
			}
	
			for (int i = 0; i < _markupList.GetSize(); i++)
			{
				IMarkupFragment fragment = (IMarkupFragment) _markupList.GetElement(i);
	
				if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML)
				{
					if (!bFoundHeadIncludesTag && !bFoundHead)
					{
						// Insert HeadIncludes tag.
						int newIndex = i + 1;
						_markupList.Insert(newIndex++, new TransformerMarkupFragment(OPEN_HEAD_TAG));
						_markupList.Insert(newIndex++, new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD));
						if (autoJSTransformTag != null)
						{
							_markupList.Insert(newIndex++, GetJSIncludesTag(_Environment.GetLocale()));
							_markupList.Insert(newIndex++, autoJSTransformTag);
						}
						_markupList.Insert(newIndex++, GetHeadIncludesTag());
						_markupList.Insert(newIndex++, new TransformerMarkupFragment(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD));
						_markupList.Insert(newIndex++, new TransformerMarkupFragment(CLOSE_HEAD_TAG));
						break;
					}
				} else if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD)
				{
					if (autoJSTransformTag != null)
					{
						_markupList.Insert(i + 1, GetJSIncludesTag(_Environment.GetLocale()));
						_markupList.Insert(i + 2, autoJSTransformTag);
					}
				} else if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD)
				{
					if (!bFoundHeadIncludesTag)
					{
						// Insert HeadIncludesTag
						_markupList.Insert(i, GetHeadIncludesTag());
						break;
					}
				}
			}
		}
	}

	/**
	 * @return The markup fragment containing the head includes singleton tag.
	 */
	protected IMarkupFragment GetHeadIncludesTag()
	{
		XPArrayList tagAttributes = new XPArrayList();

		// NOTE: We don't need to worry about whether or not a pt xmlns attribute
		// is present, because we're already past the transformer.
		tagAttributes.Add( new Object[] { new Integer( PT_XML_TYPES.PT_XML_TYPES_PTUI ),
			HEAD_INCLUDES_TAG_FULL_NAME, null } );
		tagAttributes.Add( new Object[] { new Integer( PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE ),
				null, null } );

		XMLFragment headIncludesTag = new XMLFragment(tagAttributes);

		return new TransformerMarkupFragment(headIncludesTag);
	}

	/**
	 * @return The markup fragment containing the JS includes singleton tag.
	 */
	protected IMarkupFragment GetJSIncludesTag(String _strLocale)
	{
		XPArrayList tagAttributes = new XPArrayList();

		// NOTE: We don't need to worry about whether or not a pt xmlns attribute
		// is present, because we're already past the transformer.
		tagAttributes.Add( new Object[] { new Integer( PT_XML_TYPES.PT_XML_TYPES_PTUI ),
			JS_INCLUDE_TAG_FULL_NAME, null } );
		tagAttributes.Add( new Object[] { new Integer( PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT ),
			JS_INCLUDE_TAG_NAME_ATTR, ConfigHelper.JSCOMPONENT_JSPORTLET } );
		tagAttributes.Add( new Object[] { new Integer( PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT ),
			JS_INCLUDE_LOCALE_ATTR, _strLocale } );
		tagAttributes.Add( new Object[] { new Integer( PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE ),
				null, null } );

		XMLFragment jsIncludesTag = new XMLFragment(tagAttributes);

		return new TransformerMarkupFragment(jsIncludesTag);
	}
}