package com.plumtree.portaluiinfrastructure.tags.displaytree;

import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the base class for the different kinds of display
 * elements that are used when processing tags.
 * 
 * This is a framework only class and should not be
 * used by external developers.
 * 
 * @author donh
 */
public interface IDisplayElement
{
	/**
	 * Displays this element and it's child elements and
	 * returns the result.
	 * 
	 * @param _tagVisitor
	 * @return HTMLElement The result of displaying this element
	 */
	public HTMLElement Display(TagVisitor _tagVisitor);

	/**
	 * This method is called to release any data that needs
	 * special handling before being allowed to go out of
	 * scope.
	 */
	public void Release();

	/**
	 * This method searches for child tags of the current tag and
	 * fills in the results array with an Object if the tag has
	 * been found.
	 * 
	 * This method will not work if _results is not an array of null
	 * objects of the same length as _childTags.
	 * 
	 * @param _childTags An array of ITagMetaData objects for each child
	 * tag to search for.
	 * @param _results An array of null Objects.  On execution, when a child
	 * tag is found, the location in the _results array that corresponds to
	 * the location of the tag in the _ChildTags array will be filled in with an
	 * Integer containing the positive depth of the child tag.
	 * @param _library The Tag Library of the tags to look for.
	 * @param _nCurrentDepth The depth of the current tag.
	 * @return boolean implies that all of the Child Tags have been found.
	 */
	public boolean HasChildElements(ITagMetaData[] _childTags, Object[] _results,
		TagLibraryMetaData _library, int _nCurrentDepth);

	/**
	 * This method searches for a parent tag of the current tag.
	 * 
	 * @param _ParentTag The ITagMetaData of the tag to look for.
	 * @param _library The Tag Library of the tag to look for.
	 * @return int 0 implies the parent tag was not found and a
	 * positive integer implies that the parent tag was found n
	 * levels above the current tag.
	 */
	public int HasParentElement(ITagMetaData _parentTag,
		TagLibraryMetaData _library);
}
