package com.plumtree.portaluiinfrastructure.tags.displaytree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This class handles preprocessing the markup list to
 * ensure that the HEAD element is in the proper format.
 * 
 * It also adds the HeadIncludes tag to the markup.
 */
public interface IHeadPreprocessor
{
	/**
	 * This function pre-processes the head element of this HTML
	 * document to make sure it is in the proper format.  If
	 * necessary, this will add the HeadIncludes tag as well as
	 * create the HEAD element if it does not exist.
	 * 
	 * This should only be called for main pages.
	 * 
	 * NOTE: PreprocessHead needs to be called at least once per request,
	 * otherwise the shared JavaScript will not be added to the page.
	 * Otherwise, the GetSharedJavaScriptForMultipleMarkupAsElement
	 * method needs to be called or the shared JavaScript will not be
	 * displayed.
	 * 
	 * @param Object[][] _objArrMarkup An Object[][] of markup
	 * @param ISessionManager _Session
	 * @param IEnvironment _Environment
	 * @param boolean _bForceHead Whether or not to force the
	 * markup array list to include a head element, regardless
	 * of other factors.
	 * @return Object[][] objArrMarkup the new Object[][] markup.
	 */
	public Object[][] PreprocessHead(Object[][] _objArrMarkup, ISessionManager _Session,
			IEnvironment _Environment, boolean _bForceHead);

	/**
	 * This function pre-processes the head element of this HTML
	 * document to make sure it is in the proper format.  If
	 * necessary, this will add the HeadIncludes tag as well as
	 * create the HEAD element if it does not exist.
	 * 
	 * This should only be called for main pages.
	 * 
	 * NOTE: PreprocessHead needs to be called at least once per request,
	 * otherwise the shared JavaScript will not be added to the page.
	 * Otherwise, the GetSharedJavaScriptForMultipleMarkupAsElement
	 * method needs to be called or the shared JavaScript will not be
	 * displayed.
	 * 
	 * @param XPArrayList _markupList A list of IMarkupFragments
	 * @param ISessionManager _Session
	 * @param IEnvironment _Environment
	 * @param boolean _bForceHead Whether or not to force the
	 * markup array list to include a head element, regardless
	 * of other factors.
	 */
	public void PreprocessHead(XPArrayList _markupList, ISessionManager _Session,
		IEnvironment _Environment, boolean _bForceHead);
}