/**
 * 
 */
package com.plumtree.portaluiinfrastructure.tags.helper;

import com.plumtree.openfoundation.util.*;

/**
 * Class to store data for a tag cache entry
 * 
 * @author rozhang
 */
public class TagCacheEntry
{
	/** Cache value **/
	protected Object m_cacheData = null;
	/** The time when this entry expires **/
	protected XPDateTime m_expiration = null;
	
	/**
	 * Constructor
	 * 
	 * @param cacheData
	 * @param expiration
	 */
	public TagCacheEntry(Object cacheData, XPDateTime expiration)
	{
		m_cacheData = cacheData;
		m_expiration = expiration;
		
		if ( m_expiration == null ) {
			throw new XPIllegalArgumentException("No expiration time was provided!");
		}
	}
	
	/**
	 * Expire entry by setting the expiration time to 1hr ago.
	 */
	public void ExpireEntry()
	{
		XPDateTime now = new XPDateTime();
		XPDateTime expired = new XPDateTime(now.GetTimeInMilliSeconds() - (long)(1000 * 60 * 60));
		m_expiration = expired;
	}
	
	/**
	 * Check if entry expired
	 * 
	 * @return
	 */
	public boolean IsEntryExpired()
	{
		XPDateTime now = new XPDateTime();
		return now.After(m_expiration);
	}
	
	/**
	 * Get the cached value
	 * @return
	 */
	public Object GetCacheData()
	{
		return m_cacheData;
	}
	
	
}
