package com.plumtree.portaluiinfrastructure.tags.helper;

import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to traverse the tag display tree
 * and pass common data to each element as it is displayed.
 * 
 * @author donh
 */
public class TagVisitor
{
	protected TagState m_TagState;
	protected IEnvironment m_Environment;
	protected TagDisplayElement m_CurrentTag;

	protected HTMLElementCollection m_SharedJavascript;

	/**
	 * Constructor for TagVisitor.  This should only be
	 * called by the tag framework.
	 * 
	 * @param _tagState  The TagState object for this
	 * portlet request.
	 * @param _environment The environment for this HTTP
	 * request.
	 */
	public TagVisitor(TagState _tagState,
		IEnvironment _environment, HTMLElementCollection _sharedJavaScript)
	{
		m_TagState = _tagState;
		m_Environment = _environment;
		m_CurrentTag = null;
		m_SharedJavascript = _sharedJavaScript;
	}

	/**
	 * The environment for the current HTTP request.
	 * 
	 * @return IEnvironment The environment for the
	 * current HTTP request. 
	 */
	public IEnvironment GetEnvironment()
	{
		return m_Environment;
	}

	/**
	 * The TagState for the current portlet request.
	 * 
	 * @return TagState The TagState for the current
	 * portlet request.
	 */
	public TagState GetState()
	{
		return m_TagState;
	}

	/**
	 * The Shared JavaScript collection for the current
	 * http request.
	 * 
	 * @return HTMLElementCollection The Shared JavaScript
	 * collection.
	 */
	public HTMLElementCollection GetJavaScriptCollection()
	{
		return m_SharedJavascript;
	}

	/**
	 * Sets the current Tag Display Element from the display
	 * tree so the TagVisitor can search the tree.
	 * 
	 * @param _currentTag The current TagDisplayElement in
	 * the display tree.
	 */
	public void SetCurrentTag(TagDisplayElement _currentTag)
	{
		m_CurrentTag = _currentTag;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#HasParentElement(ITagMetaData, TagLibraryMetaData)
	 */
	public int HasParentTag(ITagMetaData _parentTag, TagLibraryMetaData _library)
	{
		// This method check for a matching parent tag above the current tag.
		return m_CurrentTag.HasParentTag(_parentTag, _library);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.displaytree.IDisplayElement#HasChildElements(ITagMetaData[], Object[], TagLibraryMetaData)
	 */
	public boolean HasChildTags(ITagMetaData[] _childTags, Object[] _results, TagLibraryMetaData _library)
	{
		// This method checks for matching child tags below the current tag.
		return m_CurrentTag.HasChildTags(_childTags, _results, _library, 0);
	}
}
