package com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sorted.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This model extends the SortedMultiColumnListModel to 
 * set the width of the Version column to a smaller size.
 * 
 * @author DonH
 */
public class TagLibListModel extends SortedMultiColumnListModel
{
	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "TagLibList";

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _bEnableSort for each column
	 * @param _nDefaultSortColumn the zero based column id for the default column to sort by.
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _nListKey In case you have multiple Expandable Lists on the same
	 *        DP, they should have a different key (otherwise, just set it to
	 *        1).
	 */
	public void InitializeMultiColumnList(String _sSectionTitle,
		String[] _sSectionSubTitle, Boolean[] _bEnableSort, int _nDefaultSortColumn,
		PTImageType _imgAddIcon, String _sAddLabel, int _nListKey)
	{
		// Set the width based on the number of columns
		// Last column is small, so don't include it.
		int intColWidth    = 100 / (m_intNumColumns - 1);
		XPStringBuilder sb = new XPStringBuilder(5);
		sb.Append(intColWidth).Append("%");

		m_nDefaultSortColumn = _nDefaultSortColumn;

		Object[][] arrExpListColInfo = new Object[m_intNumColumns][5];

		for (int i = 0; i < m_intNumColumns; i++)
		{
			arrExpListColInfo[i][EXPLIST_COLUMN_ID]			    = new Integer(i +
					1);
			arrExpListColInfo[i][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle[i];
			arrExpListColInfo[i][EXPLIST_COLUMN_WIDTH]		    = sb.ToString();
			arrExpListColInfo[i][EXPLIST_COLUMN_COLSPAN]	    = "1";
			arrExpListColInfo[i][EXPLIST_COLUMN_ENABLESORT]     = _bEnableSort[i];
		}

		// Explicitly set the last column width to a smaller number
		arrExpListColInfo[m_intNumColumns - 1][EXPLIST_COLUMN_WIDTH] = "80";

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TagLibListModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}