package com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sorted.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Display each tag library.
 * 
 * @author DonH
 */
public class TagLibListView extends MultiColumnListView
{
	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "TagLib";

	/**
	 * Returns the HTML for the row _nRowIndex. Each row contains just an icon
	 * and input text for each column.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 *
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableCell myCell;

		int intColWidth				 = 100 / ((IMultiColumnListModelRO) m_model).GetNumColumns();
		XPStringBuilder sbColPercent = new XPStringBuilder(5);
		sbColPercent.Append(intColWidth).Append("%");

		myCell = new HTMLTableCell();
		myCell.SetWidth(sbColPercent.ToString());
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		// row icon
		PTImageType imgRowIcon = ((IMultiColumnListModelRO) m_model).GetRowIcon();

		if (null != imgRowIcon)
		{
			myCell.AddInnerHTMLElement(GetHTMLForIcon(imgRowIcon));
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}

		for (int i = 1;
			i <= ((IMultiColumnListModelRO) m_model).GetNumColumns();
			i++)
		{
			if (i > 1) //Only add a new cell if this isn't the first one
			{
				myCell = new HTMLTableCell();
				myCell.SetWidth(sbColPercent.ToString());
				myCell.SetHeight("30");
				myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
				myCell.SetNoWrap(true);
			}

			myCell.AddInnerHTMLString((String) _saData.GetItem(_nRowIndex, i));
			result.AddInnerHTMLElement(myCell);
		}

		if (((IMultiColumnListModelRO) m_model).GetEnableMoveRowActions())
		{
			result.AddInnerHTMLElement(super.GetHTMLForMoveRowActions(
				_nRowIndex));
		}

		// input text
		return result;
	}

	/**
	 * Returns the HTML for the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 */
	protected HTMLTable GetHTMLForActionBar()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		myTable = new HTMLTable();
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("0");

		// 1st Row begin (there is only one row)
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);

		// Reload button cell
		myRow.AddInnerHTMLElement(GetHTMLForReloadAction());

		// Empty Cell
		myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());

		// Reload all button cell
		myRow.AddInnerHTMLElement(GetHTMLForReloadAllAction());

		// Empty Cell
		myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());

		// Last Empty Cell
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetHeight("25");
		myCell.AddInnerHTMLString(SPACE);

		// 1st Row ends
		return myTable;
	}

	/**
	 * Returns the HTML for the reload cell in the action bar.
	 *
	 * @return HTMLTableCell
	 */
	protected HTMLTableCell GetHTMLForReloadAction()
	{
		SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage, myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		// Add icon
		myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_REFRESH,
			true, this.m_asOwner);
		myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
		// Reload
		myAddIcon.SetAlt(m_asOwner.GetString(773, ResourceConstants.PORTALCOMMONMSGS));
		myAddIcon.SetAlign("absmiddle");

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.AddInnerHTMLString(SPACE);
		myAnchor.SetOnClick("if(0 != " +
			myMultiColumnListModel.GetUniqueString("CountCheckedRows") +
			"()){postToSelf('" +
			TagLibRepostControl.POSTTOSELF_ACTION_RELOAD + "');}else{" +
			"alert('" +
			// Please select at least one library to reload.
			m_asOwner.GetString(775, ResourceConstants.PORTALCOMMONMSGS) +
			"');} return false;");
		myAnchor.AddInnerHTMLElement(myAddIcon);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label - Reload
		mySpan.AddInnerHTMLString(m_asOwner.GetString(773, ResourceConstants.PORTALCOMMONMSGS));
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);

		return myCell;
	}

	/**
	 * Returns the HTML for the reload all cell in the action bar.
	 *
	 * @return HTMLTableCell
	 */
	protected HTMLTableCell GetHTMLForReloadAllAction()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage, myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		// Add icon
		myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_REFRESH,
			true, this.m_asOwner);
		myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
		// Reload All
		myAddIcon.SetAlt(m_asOwner.GetString(774, ResourceConstants.PORTALCOMMONMSGS));
		myAddIcon.SetAlign("absmiddle");

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.AddInnerHTMLString(SPACE);
		myAnchor.SetOnClick("postToSelf('" +
			TagLibRepostControl.POSTTOSELF_ACTION_RELOAD_ALL + "'); return false;");
		myAnchor.AddInnerHTMLElement(myAddIcon);

		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label - Reload All
		mySpan.AddInnerHTMLString(m_asOwner.GetString(774, ResourceConstants.PORTALCOMMONMSGS));
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);

		return myCell;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TagLibListView();
	}
}