package com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to display the currently loaded tag libraries.
 *
 * @author donh
 */
public class TagLibManagerAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tags.manager.taglibutility.TagLibEditorAS");

	public static final String STR_MVC_CLASS_NAME = "TagLib";

	private static final String sClassName = "com.plumtree.portaluiinfrastructure.tags.manager.taglibutility.TagLibEditorAS";

	public static final String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "TagLibList";
	
	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		// Tag Library Manager
		return GetString(771, ResourceConstants.PORTALCOMMONMSGS);
	}

	/**
	 * Returns the class name of the tag lib manager Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (TagLibRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = TagLibModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(TagLibModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new TagLibDP());

		// Register Controls
		RegisterControl(TagLibRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Register the Section, the Model and the Control
		// used by the multi column array.
		RegisterModel(TagLibListModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myMultiColumnListModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
		RegisterView(TagLibListView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myMultiColumnListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myMultiColumnListModel);

		// Set default page
		SetCurrentPage(TagLibDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// BEGIN Sub menu "Tag Library Manager"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(771, ResourceConstants.PORTALCOMMONMSGS));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, TagLibDP.STR_MVC_CLASS_NAME);
		// END Sub menu "Tag Library Manager"

		// Help Topic
		SetHelpTopic("PT_TagLibraryManager");

		// TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );

				int iTitleId = 147;
				int iTipId = 148;
				int iSecondaryTipId = 149;

				// Tag Libraries
				tm.SetTipTitle( GetString( iTitleId, ResourceConstants.TIPS) );

				// Main tip
				tm.SetTip( new HTMLGenericElement( GetString( iTipId, ResourceConstants.TIPS) ));

				// Secondary tip
				tm.SetSecondarTip( new HTMLGenericElement( GetString( iSecondaryTipId, ResourceConstants.TIPS ) ));
			}
			catch (Exception ex)
			{
				log.Error(ex, "Couldn't generate tip.");
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TagLibManagerAS();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}