package com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sorted.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This is the Model class for the Tag Lib Editor.
 *
 * @author donh
 */
public class TagLibModel extends EditorModel implements IEditorModelRO
{
	public static final String STR_MVC_CLASS_NAME = "TagLib";

	/**
	 * The display name column ID.
	 */
	public static final int DISPLAY_NAME = 0;

	/**
	 * The version column ID.
	 */
	public static final int VERSION = 1;

	/**
	 * The name column ID.
	 */
	public static final int NAME = 2;

	/**
	 * The original data for the list.
	 */
	String[][] m_strArrLibs = null;

	/**
	 * Inits the Model with the Activity Space.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		// Set to read only so we only get finish button
		m_bIsEditorReadOnly = true;

		super.Init(parent);
	}

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access
	 *         this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		if (!PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) m_asOwner.GetUserSession()))
		{
			return false;
		}

		if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		StartTagLibList();

		return true;
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		if (_sPageName.equals(TagLibDP.STR_MVC_CLASS_NAME))
		{
			((MultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST)).SaveSection(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Helper method to start the Growable List.
	 */
	public void StartTagLibList()
	{
		SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		String strHostName = ConfigHelper.GetConfigVariableAsString
			(ConfigConstants.SYSTEM_PROPERTIES_SECTION, ConfigConstants.MACHINE_NAME_SUBSECTION,
			ConfigConstants.VALUE_ATTRIBUTE, m_asOwner.GetApplication());

		// Tag Libraries: Hostname: xxx
		String strListTitle = XPResourceManager.FormatMessage(m_asOwner.GetString
			(779, ResourceConstants.PORTALCOMMONMSGS),strHostName);

		myMultiColumnListModel.InitializeMultiColumnList
			(strListTitle,
			new String[] {
				// Name
				m_asOwner.GetString(776, ResourceConstants.PORTALCOMMONMSGS),
				// Version
				m_asOwner.GetString(777, ResourceConstants.PORTALCOMMONMSGS),
			},
			// Turn on sorting for both columns
			new Boolean[] {Boolean.TRUE, Boolean.TRUE},
			// Sort by name by default
			0,
			// Not used
			PTImageType.ICON_HOME, "",
			// list key
			1);

		// Do we want a row icon?
		// Optional setting
		//     Use the method below to set the icon to display on each row before the input text.
		//     (By default there will be no icon.)
		//myGrowableListModel.SetRowIcon(PTImageType.PENCIL_SMALL);

		// Set list to readonly until bug#45342 is fixed - reload can
		// recycle the .net app, and doesn't really work in Java.
		// Read only lists don't display the action bar (reload buttons) or
		// the checkboxes.
		myMultiColumnListModel.SetIsListReadOnly(true);

		PopulateTagLibList();
	}

	/**
	 * Helper method to populate the Growable List.
	 */
	public void PopulateTagLibList()
	{
		SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		// Populate the list
		XPArrayList displayNames = new XPArrayList();
		XPArrayList versions = new XPArrayList();
		XPArrayList names = new XPArrayList();

		XPHashtable libraries = TagLibManager.getInstance().GetLibraries();
		IXPEnumerator libraryNames = libraries.GetKeys();

		while (libraryNames.MoveNext())
		{
			String strLibName = (String) libraryNames.GetCurrent();
			XPArrayList libMetadataList= (XPArrayList)libraries.GetElement(strLibName);

			for (int i = 0; i < libMetadataList.GetSize(); i++)
			{
				TagLibraryMetaData tagLibraryMetaData = 
					(TagLibraryMetaData)libMetadataList.GetElement(i);

				displayNames.Add(tagLibraryMetaData.GetDisplayName());
				versions.Add(XPConvert.ToString(tagLibraryMetaData.GetVersion()));
				names.Add(tagLibraryMetaData.GetName());
			}
		}

		m_strArrLibs = new String[3][displayNames.GetSize()];

		String[][] strData = new String[2][displayNames.GetSize()];

		for (int i = 0; i < m_strArrLibs[0].length; i++)
		{
			m_strArrLibs[DISPLAY_NAME][i] = (String) displayNames.GetElement(i);
			m_strArrLibs[VERSION][i] = (String) versions.GetElement(i);
			m_strArrLibs[NAME][i] = (String) names.GetElement(i);

			strData[DISPLAY_NAME][i] = (String) displayNames.GetElement(i);
			strData[VERSION][i] = (String) versions.GetElement(i);
		}

		// Pre populate the list (By default the list will be empty.).
		myMultiColumnListModel.AddRowsToList(strData);

		// Set the message and instructions to display when the list is empty.
		// message: There are no tag libraries loaded in this portal server.
		// instructions: To load a tag library, edit the tag library configuration
		// files and click the Reload All button.
		myMultiColumnListModel.SetEmptyListMessages(m_asOwner.GetString(780, ResourceConstants.PORTALCOMMONMSGS),
			m_asOwner.GetString(781, ResourceConstants.PORTALCOMMONMSGS));
	}

	/**
	 * Reload the selected libraries.
	 * 
	 * @param _nRowsToReload An int[] of the row IDs of the libraries to reload.
	 */
	public void ReloadCheckedLibraries(int[] _nRowsToReload)
	{
		SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		PTGrowableSortedArrayWrapper data = myMultiColumnListModel.GetItems();

		String[][] strData = new String[2][_nRowsToReload.length];
		boolean bFailedToReload = false;

		for (int i = 0; i < _nRowsToReload.length; i++)
		{
			// The first column of the SAW is the row IDs.
			String strDisplayName = (String) data.GetItem(_nRowsToReload[i], DISPLAY_NAME + 1);
			String strLibVersion = (String) data.GetItem(_nRowsToReload[i], VERSION + 1);

			for (int j = 0; j < m_strArrLibs[0].length; j++)
			{
				// Note: It is theoretically possible for two libraries to have the same
				// display name, in which case this will only reload the first one.
				if ((0 == XPStringUtility.Compare(strDisplayName, m_strArrLibs[DISPLAY_NAME][j])) &&
					(0 == XPStringUtility.Compare(strLibVersion, m_strArrLibs[VERSION][j])))
				{
					String strLibName = m_strArrLibs[NAME][j];
					double dLibVersion = XPConvert.ToDouble(strLibVersion);

					TagLibManager.getInstance().ReloadTagLibrary(strLibName, dLibVersion);

					if (null != TagLibManager.getInstance().GetLibraryTags(strLibName, dLibVersion))
					{
						strData[DISPLAY_NAME][i] = strDisplayName;
						strData[VERSION][i] = strLibVersion;
					} else
					{
						bFailedToReload = true;
					}
					break;
				}
			}
		}

		data.RemoveRows(_nRowsToReload);

		if (bFailedToReload)
		{
			// Reset the tag lib list.
			this.StartTagLibList();

			throw new XPException("Unable to reload one or more tag libraries.  Resetting list.");
		}

		myMultiColumnListModel.AddRowsToList(strData);
	}

	/**
	 * Reload all tag libraries (standard and custom).
	 */
	public void ReloadAllLibraries()
	{
		TagLibManager.getInstance().ReloadAllTagLibraries();

		SortedMultiColumnListModel myMultiColumnListModel = (SortedMultiColumnListModel) m_asOwner.GetModel(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		PTGrowableSortedArrayWrapper data = myMultiColumnListModel.GetItems();

		// Clear the list
		data.ClearArray();

		PopulateTagLibList();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 */
	public void Finish() {}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TagLibModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}
