package com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * This is the RepostControl class for the Tag Lib Editor.
 * It handles the Repost actions for that Editor.
 *
 * @author donh
 */
public class TagLibRepostControl extends EditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tags.manager.taglibutility.TagLibRepostControl");

	public static final String STR_MVC_CLASS_NAME = "TagLib";

	/** Will reload one or more tag libraries in the list. */
	public static final int POSTTOSELF_ACTION_RELOAD = 50;

	/** Will reload all tag libraries. */
	public static final int POSTTOSELF_ACTION_RELOAD_ALL = 51;

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformReadOnlyAction(int _nAction)
	{
		super.PerformReadOnlyAction(_nAction);

		// You need to call the PerformRepostAction on the multi column array control
		((ExpListControl) m_asOwner.GetControl(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST)).PerformRepostAction(_nAction,
			m_htFormData);

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_RELOAD:
			ExpListModel myExpListModel = (ExpListModel) m_asOwner.GetModel
				(TagLibManagerAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

			// We use the same mechanism as deleting rows.
			// Note: this will throw a null pointer exception if there are
			// no checked rows, so we check for this in javascript.
			int[] selectedItems = myExpListModel.GetArrayOfObjToDelete(m_htFormData);

			try
			{
				((TagLibModel)m_model).ReloadCheckedLibraries(selectedItems);
			} 
			catch (Exception e)
			{
				m_nPageStatus = PAGE_STATUS_INVALID;
				
				IXPEnumerator arrErrors = UIErrorHandler.GetErrors(m_asOwner.GetSubSession(), m_asOwner.GetApplication(), m_asOwner, true, true);
				
				if (!arrErrors.MoveNext())
				{
					GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE), 
						"EditorRepostControl::PerformAction", 
						e, false, UIErrorLevel.SERIOUS,
						// Unable to reload selected tag libraries.
						m_asOwner.GetString(782, ResourceConstants.PORTALCOMMONMSGS));
				}
				else
				{
					log.Error(e, "Unable to reload selected tag libraries.");
				}
			}

			break;

		case POSTTOSELF_ACTION_RELOAD_ALL:
			try
			{
				((TagLibModel)m_model).ReloadAllLibraries();
			} 
			catch (Exception e)
			{
				m_nPageStatus = PAGE_STATUS_INVALID;
				
				IXPEnumerator arrErrors = UIErrorHandler.GetErrors(m_asOwner.GetSubSession(), m_asOwner.GetApplication(), m_asOwner, true, true);
				
				if (!arrErrors.MoveNext())
				{
					GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE), 
						"EditorRepostControl::PerformAction", 
						e, false, UIErrorLevel.SERIOUS,
						// Unable to reload all tag libraries.
					m_asOwner.GetString(783, ResourceConstants.PORTALCOMMONMSGS));
				}
				else
				{
					log.Error(e, "Unable to reload all tag libraries.");
				}
			}

			break;
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TagLibRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}