package com.plumtree.portaluiinfrastructure.tags.metadata;

/**
 * This class provides programmatic access to the
 * tag meta data for name, description, and example.
 * <p>
 * Tag classes need to have exactly one public static final
 * ITagMetaData member variable that provides the name,
 * description, and example text for this Tag.
 * <p>
 * E.G.
 * <br>
 * &lt;pt:thistag/&gt;
 * <br>
 * would need
 * <br>
 * public static final ITagMetaData = new TagMetaData("thistag",
 * 		"This tag displays some HTML ...");
 */
public interface ITagMetaData
{
	/**
	 * Gets the name of the tag
	 * 
	 * @return String The name of the tag
	 */
	public String GetName();

	/**
	 * Gets the description of the tag
	 *  
	 * @return String The description of the tag
	 */
	public String GetDescription();

	/**
	 * Gets the example text for this tag
	 * <p>
	 * Note that example text containing HTML formatting must
	 * be in xml CDATA format
	 * 
	 * @return String The example for this tag
	 */
	public String GetExample();
}
