package com.plumtree.portaluiinfrastructure.tags.metadata;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;

/**
 * This class also enforces all lower case for the names of tags.
 * 
 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData
 */
public class TagMetaData implements ITagMetaData
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData");

	protected String m_strName;
	protected String m_strDescription;
	protected String m_strExample;

	/**
	 * This constructor takes the name and description
	 * of the tag.  It also converts the name to all
	 * lower case for standards compliance. 
	 * 
	 * @param String _strName The name of the tag
	 * @param String _strDescription The description of the tag
	 */
	public TagMetaData(String _strName, String _strDescription)
	{
		m_strName = XPStringUtility.ToLowerCase(_strName);
		m_strDescription = _strDescription;
		m_strExample = null;

		if (!m_strName.equals(_strName))
		{
			log.Warn("Tag " + _strName + " uses uppercase letters " +
				"in its name, which are automatically converted to " +
				"lowercase.  This can cause confusion when using the " +
				"tag in HTML.");
		}
	}

	/**
	 * This constructor takes the name, description, and
	 * example text for this tag.  It also converts the name to
	 * all lower case for standards compliance. 
	 * <p>
	 * Note that example text containing HTML must enclose it in
	 * an xml CDATA tag:
	 * <br>
	 * "example blah &lt;![CDATA[&lt;mylib:mytag attr1=\"foo\"&gt;]]&gt; example"
	 * 
	 * @param String _strName The name of the tag
	 * @param String _strDescription The description of the tag
	 * @param String _strExample The example text for the tag.
	 * Note that example text containing HTML formatting must
	 * be in xml CDATA format
	 */
	public TagMetaData(String _strName, String _strDescription,
		String _strExample)
	{
		m_strName = XPStringUtility.ToLowerCase(_strName);
		m_strDescription = _strDescription;
		m_strExample = _strExample;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetName()
	 */
	public String GetName()
	{
		return m_strName;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetDescription()
	 */
	public String GetDescription()
	{
		return m_strDescription;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetExample()
	 */
	public String GetExample()
	{
		return m_strExample;
	}
}
