package com.plumtree.portaluiinfrastructure.tags.metadata.legacy;

import com.plumtree.portaluiinfrastructure.tags.metadata.*;

/**
 * This class does not convert the name to all
 * lower case for standards compliance, and is therefore
 * suitable only for legacy Plumtree Transformer Tags.
 *  
 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData
 */
public class LegacyTagMetaData implements ITagMetaData
{
	protected String m_strName;
	protected String m_strDescription;
	protected String m_strExample;

	/**
	 * This constructor takes the name and description
	 * of the tag.  It does not convert the name to all
	 * lower case for standards compliance, and is therefore
	 * suitable only for legacy Plumtree Transformer Tags. 
	 * 
	 * @param String _strName The name of the tag
	 * @param String _strDescription The description of the tag
	 */
	public LegacyTagMetaData(String _strName, String _strDescription)
	{
		m_strName = _strName;
		m_strDescription = _strDescription;
		m_strExample = null;
	}

	/**
	 * This constructor takes the name, description, and
	 * example text of the tag.  It does not convert the name
	 * to all lower case for standards compliance, and is therefore
	 * suitable only for legacy Plumtree Transformer Tags. 
	 * 
	 * @param String _strName The name of the tag
	 * @param String _strDescription The description of the tag
	 * @param String _strExample The example text for the tag.
	 * Note that example text containing HTML formatting must
	 * be in xml CDATA format
	 */
	public LegacyTagMetaData(String _strName, String _strDescription,
		String _strExample)
	{
		m_strName = _strName;
		m_strDescription = _strDescription;
		m_strExample = _strExample;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetName()
	 */
	public String GetName()
	{
		return m_strName;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetDescription()
	 */
	public String GetDescription()
	{
		return m_strDescription;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ITagMetaData#GetExample()
	 */
	public String GetExample()
	{
		return m_strExample;
	}
}
