/**
 * 
 */
package com.plumtree.portaluiinfrastructure.tags.tagdef;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class TagOutputDefinitionManager
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		"com.plumtree.portaluiinfrastructure.tags.tagdef.TagOutputDefinitionManager");
	
	public final static int TAGDEFINITION_WEBSERVICEID = 120;
	
	/** **/
	public final static String TAGKEY_PREFIX = "$TAGDEF";
	/** **/
	public final static String TAGDEF_MAP_KEY = "TagDefinitionStorage";
	
	private Object TAGDEF_MAP_CREATELOCK = new Object();
	
	/**
	 * Singleton
	 */
	protected static TagOutputDefinitionManager m_testInstance = null;
	
	/**
	 * Test Singleton
	 */
	protected static TagOutputDefinitionManager m_instance = new TagOutputDefinitionManager();
	
	/**
	 * Used by Unit test
	 */
	public static void SetTestInstance(TagOutputDefinitionManager testInstance)
	{
		m_testInstance = testInstance;
	}
	
	public static TagOutputDefinitionManager GetInstance()
	{
		if ( m_testInstance == null ) {
			return m_instance;
		} else {
			return m_testInstance;
		}
	}
	
	/**
	 * 
	 * @param tagLibName
	 * @param tagName
	 * @param version
	 * @return
	 */
	protected String CreateTagDefKey(String defId, String version)
	{
		return TAGKEY_PREFIX+"-"+defId+"-"+version;
	}

	/**
	 * 
	 * @param tagLibName
	 * @param tagName
	 * @param version
	 * @param def
	 * @param state
	 * @return false if an entry with the defid and version already exists and is read only, true if succesful
	 */
	public boolean StoreTagOutputDefinition(String defId, String version, boolean readOnly, TagHelper tag)
	{
		XPHashtable map = GetTagDefMap(tag);
		String defKey = CreateTagDefKey(defId, version);
		
		TagOutputDefEntry oldEntry = (TagOutputDefEntry)map.GetElement(defKey);
		
		if ( oldEntry != null && oldEntry.IsReadOnly()) {
			return false;
		} else {
			XPArrayList bodyElements = tag.GetTagBodyElements();
			// @TODO find out the current webservice id/portlet file for where the template tag is run.
			// passing in empty values for now
			TagOutputDefEntry entry = new TagOutputDefEntry(bodyElements, readOnly, 0, "");
			map.PutElement(defKey, entry);
			return true;
		}
	}
	
	/**
	 * Helper to get specified Tag definition
	 * 
	 * @param defId
	 * @param version
	 * @param tag
	 * @return
	 */
	protected TagOutputDefEntry RetrieveTagDefinition(String defId, String version, TagHelper tag)
	{
		XPHashtable map = GetTagDefMap(tag);
		TagOutputDefEntry tagDef = (TagOutputDefEntry)map.GetElement(CreateTagDefKey(defId, version));
		
		return tagDef;
		
	}
	/**
	 * Retrieves Tag Definition and inserts it into current Tag body
	 * 
	 * @param tagLibName
	 * @param tagName
	 * @param version
	 * @param state
	 * @return
	 */
	public HTMLElement RetrieveAndSetTagDefinition(String defId, String version, TagHelper tag)
	{
		XPHashtable map = GetTagDefMap(tag);
		TagOutputDefEntry tagDef = (TagOutputDefEntry)map.GetElement(CreateTagDefKey(defId, version));
		
		// if tag def entry wasn't found, reload tag definition files
		if ( tagDef == null ) {
			/* The commented out section is code to handle multiple tag definition files and cache the definitions on the application
			AActivitySpace space = (AActivitySpace)m_tagHelper.GetEnvironment();
			// @TODO cache tag def webservice ids on application for 15min or so
			int[] wsIds = RetrieveTagOutputDefWebServiceIds(space);
			log.Info("Reloading Tag Definition files.");
			ProcessTagDefinitions(wsIds, space, false); 
			
			// now try find the entry again
			tagDef = (TagOutputDefEntry)map.GetElement(CreateTagDefKey(defId, version));
			if ( tagDef == null ) {
				// still not found after reloading tag defs, must be referencing an invalid tag definition, return null 
				return null;
			}
			*/
			
			/* Current approach: just allow on tag definition file with hardcoded webservice object id and cache the def on the request only (to avoid multiple tag def requests per page request) */
			int wsIds[] = new int[] { TAGDEFINITION_WEBSERVICEID }; // use int array, processtagdefinitions was original made to support requests to multiple webservice objects
			AActivitySpace space = (AActivitySpace)tag.GetEnvironment();
			
			// Get the tag definition from tag definition file
			ProcessTagDefinitions(wsIds, space, false);
			
			tagDef = RetrieveTagDefinition(defId, version, tag);
			if ( tagDef == null ) {
				// to tag def exists for the requested id, version
				log.Warn("No Tag Definition exists for id: '"+defId+"' and version:"+version);
				return null;
			}
		} 
		
		tag.InjectTagBody(tagDef.GetEntryValue());
		return tag.ProcessTagBody();
	}
	
	/**
	 * Gets the Tag Definition Map
	 * 
	 * @param tag
	 * @return
	 */
	protected XPHashtable GetTagDefMap(TagHelper tag)
	{
		TagState state = tag.GetState();
		XPHashtable tdMap;
		Object value = state.GetSharedVariable(TAGDEF_MAP_KEY, Scope.HTTP_REQUEST);
		if ( value == null ) {
			tdMap = new XPHashtable();
			synchronized (TAGDEF_MAP_CREATELOCK) {
				// check again in case some other thread inserted between last check and here
				if ( state.GetSharedVariable(TAGDEF_MAP_KEY, Scope.HTTP_REQUEST) == null ) {
					state.SetSharedVariable(TAGDEF_MAP_KEY, tdMap, Scope.HTTP_REQUEST, true);
				}
			} 
		} else {
			tdMap = (XPHashtable)value;
		}
		return tdMap;
	}
	
	
	/**
	 * Calls the Portlet Stack to retrieve markup from Tag Definition file and run Tag Definitions tags that sets
	 * the tag definitions in the request
	 * @TODO might want to return some status code?
	 * 
	 * @param wsIds
	 * @param space
	 * @param testMode
	 */
	protected void ProcessTagDefinitions(int[] wsIds, AActivitySpace space, boolean testMode)
	{
		IPTSession ptSession = (IPTSession) space.GetUserSession();
		IPTWebServiceManager ptWebServiceManager = (IPTWebServiceManager)ptSession.GetWebServices();
		// DCA - getting app data state object to let the webservice know the state of the application
		// This is mostly for portlet settings, like what community the portlet is on, which doesn't really apply here since we're not 
		// really a portlet, but we're trying to reuse code instead of reinventing the wheel.
		Object appDataStateObject = AppDataObjectFactory.GetInstance().GetAppDataObject(0/* Community Id */, 0/* Page Id */, PTConfigHelper.GetMainServerApplicationURL(false), space);
		// We have to use the same states object for both calls.  If we get it again
		// from the session, it will be different and this won't work (for request mode,
		// which we use).
		IPTStates pStates = ptSession.GetStates();
		
		// 
		XPArrayList wsProvs = new XPArrayList();
		XPArrayList wsInfo  = new XPArrayList();
		// Call BeginProcessing on all webservices 
		for ( int i = 0; i < wsIds.length; i++ )
		{
			int currWsId = wsIds[i];
			try 
			{
				IPTGadgetInfo ptWebServiceInfo = ptWebServiceManager.GetWebServiceInfo(currWsId);
			
				IPTAsyncGadgetProvider wsProvider = ptWebServiceManager.GetWebServiceProvider(currWsId, null);
				if (null == wsProvider) {
					throw new XPIllegalArgumentException("Unable to find Webservice with id: "+currWsId+ ".");
				}
	
				// NOTE: We have to use state mode request because otherwise concurrent requests can
				// stomp on each other. Bug#65482
				// Just use the method that doesn't have the state mode, because that defaults to request mode.
				wsProvider.BeginProcessing(PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, ptSession, ptWebServiceInfo, pStates, null /* Admin Settings - not needed */, appDataStateObject, null /* IPTUserInterface - not needed */);
				
				wsProvs.Add(wsProvider);
				wsInfo.Add(ptWebServiceInfo);
			} catch (Exception e) {
				throw new XPIllegalStateException("Error receiving Tag Definition from Webservice with id: "+currWsId, e);
			} 
		}
		// Get the markup content and process it from all webservices 
		for ( int i = 0; i < wsProvs.GetSize(); i++ )
		{
			IPTAsyncGadgetProvider currProv = (IPTAsyncGadgetProvider)wsProvs.GetElement(i);
			IPTGadgetInfo currWSInfo		= (IPTGadgetInfo)wsInfo.GetElement(i);
			
			Object[][] tagDefMarkup = currProv.GetHTMLText(PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, ptSession, currWSInfo, pStates, null /* Admin Settings */, appDataStateObject, null /* IPTUserInterface */);

			PortletErrorHelper errorHelper = new PortletErrorHelper();

			if (errorHelper.IsErrorContentArray(tagDefMarkup) && !testMode)
			{
				int nErrorCode = errorHelper.GetErrorCode(tagDefMarkup);
				String strError = errorHelper.GetErrorMessage(tagDefMarkup);

				throw new XPIllegalStateException("Tag Definition file with Webservice id: " + currWSInfo.GetObjectID() + " returned error code: " + nErrorCode + " and error message: " +strError);
			}
			try {
				// @TODO pass in current wsid to the activity space somehow?
				// Process tags that declare tag defs
				HTMLElement result = DisplayTree.ProcessTagMarkup(space, tagDefMarkup);
				if ( result != null ) {
					String resultStr = result.GetDisplayString();
					if ( resultStr.indexOf("Exception") != -1 ) { // log a warning and display the reeturn content if it contains the word Exception
						// @TODO do all dot net exception have the word exception in it??
						log.Warn("Tag Definition file from Webservice id: "+currWSInfo.GetObjectID()+ " returned unexpected content: "+resultStr);
					}
				}
			} catch (Exception e) {
				// ignore the exception and go on to next webservice
				log.Error("Error processesing Tag Definition markup from Webservice id: "+currWSInfo.GetObjectID(), e);
			}
			
		}
	}
	
	
	/** Not currently used
	public int[] RetrieveTagOutputDefWebServiceIds(AActivitySpace space)
	{
		IPTAdminCatalog catalog = ((IPTSession) space.GetUserSession()).GetAdminCatalog();

		IPTObjectManager webServiceManager = catalog.GetObjectManager(PT_CLASSIDS.PT_WEBSERVICE_ID);

		// NOTE: We are currently querying for all web services in the folder.
		// This could be large and could cause a performance issue.
		IPTQueryResult tagDefServices = webServiceManager.Query(PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_DESCRIPTION | PT_PROPIDS.PT_PROPID_OBJECTID,
			PT_INTRINSICS.PT_ADMIN_FOLDER_TAG_DEFINITIONS, PT_PROPIDS.PT_PROPID_NAME, 0, -1, null);
		
		if ( tagDefServices.RowCount() == 0 ) {
			log.Warn("Tag Definition files were requested with No Tag Definition Webservices created.");
		}
		
		int[] wsIds = new int [tagDefServices.RowCount()];
		for ( int i = 0; i < tagDefServices.RowCount(); i++ ) {
			wsIds[i] = tagDefServices.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
		}
		
		return wsIds;
	}
	*/
	
}
