package com.plumtree.portaluiinfrastructure.tags.tasks;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;

/**
 * This is a helper class for TagState Tasks.
 * <p>
 * When debug mode is on, tags will display HTML comments before
 * and after they are executed to aid in debugging.  Tags may
 * also have custom behavior in debug mode.
 */
public class TagStateTasks
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tags.tasks.TagStateTasks");

	/**
	 * The key that the debug mode boolean is stored with
	 * in PORTLET_REQUEST scope.
	 */
	protected static final String DEBUG_MODE_KEY = "bDebug";

	/**
	 * Check if the current tag is in debug mode.
	 * <p>
	 * When debug mode is on, tags will display HTML comments before
	 * and after they are executed to aid in debugging.  Tags may
	 * also have custom behavior in debug mode.
	 * 
	 * @param ITagState _state The current TagState object
	 * @return boolean True implies debug mode
	 */
	public static boolean GetIsDebugMode(ITagState _state)
	{
		try
		{
			Object oDebug = _state.GetSharedVariable(DEBUG_MODE_KEY, Scope.PORTLET_REQUEST);

			if (null != oDebug)
			{
				return XPConvert.ToBoolean(oDebug);
			}
		} catch (Exception e)
		{
			log.Warn(e, "Unable to properly get debug mode variable from portlet request scope.");
		}

		return false;
	}

	/**
	 * Set debug mode for the current PORTLET_REQUEST.
	 * <p>
	 * When debug mode is on, tags will display HTML comments before
	 * and after they are executed to aid in debugging.  Tags may
	 * also have custom behavior in debug mode.
	 * 
	 * @param boolean _bDebug True implies debug mode
	 * @param ITagState _state The current TagState object
	 */
	public static void SetIsDebugMode(boolean _bDebug, ITagState _state)
	{
		_state.SetSharedVariable(DEBUG_MODE_KEY, new Boolean(_bDebug), Scope.PORTLET_REQUEST, false);
	}
}
