package com.plumtree.portaluiinfrastructure.tags.xml;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * This helper class converts IMarkupFragment lists to (evil) Object[][] markup arrays.
 */
public class FragmentListConverter
{
	/**
	 * Converts an XPArrayList of IMarkupFragments to an (evil) Object[][] markup array.
	 * 
	 * @param _fragments an XPArrayList of IMarkupFragments
	 * @return an (evil) Object[][] markup array
	 */
	public Object[][] ConvertListToMarkup(XPArrayList _fragments)
	{
		Object[][] objArrMarkup = new Object[2][_fragments.GetSize()];

		for (int i = 0; i < _fragments.GetSize(); i++)
		{
			IMarkupFragment fragment = (IMarkupFragment) _fragments.GetElement(i);

			objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
				new Integer( fragment.GetFragmentType() );

			// TODO: This probably means that I need to rework how this works
			// so I can make it smoother.  Plus, we probably just shouldn't be
			// converting a lot, since this needs to be performant.
			if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML)
			{
				objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] =
					fragment.GetXMLFragment().GetObjectXML();				
			} else
			{
				objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] =
					fragment.GetFragment();
			}
		}

		return objArrMarkup;
	}

	/**
	 * Converts an (evil) Object[][] markup array to an XPArrayList of IMarkupFragments.
	 * 
	 * @param _objArrMarkup an (evil) Object[][] markup array
	 * @return an XPArrayList of IMarkupFragments
	 */
	public XPArrayList ConvertMarkupToList(Object[][] _objArrMarkup)
	{
		XPArrayList fragments = new XPArrayList();

		for (int i = 0; i < _objArrMarkup[0].length; i++)
		{
			switch (XPConvert.ToInteger(_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i]))
			{
			case PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED:
				fragments.Add(new TransformerMarkupFragment((String)
					_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i]));
				
				break;

			case PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML:
				IXMLFragment xmlFragment = new XMLFragment((Object[][])
					_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i]);
				fragments.Add(new TransformerMarkupFragment(xmlFragment));
				
				break;

			default:
				fragments.Add(new TransformerMarkupFragment(XPConvert.ToInteger(
					_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i]) ));

				break;
			}
		}

		return fragments;
	}
}