package com.plumtree.portaluiinfrastructure.tags.xml;

import com.plumtree.openfoundation.util.*;

/**
 * This interface is used to access data in a markup fragment.
 *
 * IMPORTANT: DO NOT ADD ANY SETTERS to the IMarkupFragment interface!
 * i.e. do NOT add a method like SetFragmentValue(...)
 * A shallow copy of markup array is put into the portlet content cache.
 * This means that if an actual object (i.e. MarkupFragment) that's inside the array changes in PostProcess,
 * then what's inside the cache changes as well! 
 * So instead of having setters on a MarkupFragment, in PostProcess we create new MarkupFragments and place 
 * them into the array that will be returned to the UI.
 * This assures that the cached markup array will not be affected by PostProcess.
 */
public interface IMarkupFragment
{
	/**
	 * @return int The fragment type (should be from PT_MARKUP_FRAGMENT_TYPES).
	 */
	public int GetFragmentType();

	/**
	 * Get the string fragment.  This can only be called for Fragments of type
	 * PTMarkupFragmentTypes.PT_MARKUP_FRAGMENT_TYPE_FINISHED.
	 * 
	 * @return the String.
	 * @throws XPFormatException if the fragment is of the wrong type.
	 */
	public String GetStringFragment();

	/**
	 * Get the xml fragment.  This can only be called for Fragments of type
	 * PTMarkupFragmentTypes.PT_MARKUP_FRAGMENT_TYPE_PT_XML.
	 * 
	 * @return the XML Fragment.
	 * @throws XPFormatException if the fragment is of the wrong type. 
	 */
	public IXMLFragment GetXMLFragment();

	/**
	 * Get the fragment.  This can be called for any type of Fragment.
	 * 
	 * @return The underlying fragment object.
	 */
	public Object GetFragment();
}