package com.plumtree.portaluiinfrastructure.tags.xml;

/**
 * This interface is used to access data in an xml markup fragment.
 *
 * IMPORTANT: DO NOT ADD ANY SETTERS to the IMarkupFragment interface!
 * i.e. do NOT add a method like SetFragmentValue(...)
 * A shallow copy of markup array is put into the portlet content cache.
 * This means that if an actual object (i.e. MarkupFragment) that's inside the array changes in PostProcess,
 * then what's inside the cache changes as well! 
 * So instead of having setters on a MarkupFragment, in PostProcess we create new MarkupFragments and place 
 * them into the array that will be returned to the UI.
 * This assures that the cached markup array will not be affected by PostProcess.
 */
public interface IXMLFragment
{
	/**
	 * @return int The XML type (should be from PT_XML_TYPES).
	 */
	public int GetType(int _nRowIndex);

	/**
	 * @return The name of the tag or attribute.
	 */
	public String GetName(int _nRowIndex);

	/**
	 * @return The value of an attribute.
	 */
	public String GetValue(int _nRowIndex);

	/**
	 * @return The number of rows in the XML fragment.
	 */
	public int GetNumberOfRows();

	/**
	 * @return The underlying object XML.
	 */
	public Object[][] GetObjectXML();
}