package com.plumtree.portaluiinfrastructure.tags.xml;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/** 
 * Implementation of IMarkupFragment.
 */
public class TransformerMarkupFragment implements IMarkupFragment
{
	private Object m_objFragment;
	// NOTE: This should be a 1.5 enum, but it's just an int now.
	private int m_eType;

	/**
	 * Construct a marker fragment with no body.
	 * 
	 * @param _type The type of the marker fragment.
	 */
	public TransformerMarkupFragment(int _type)
	{
		m_eType = _type;
	}

	/**
	 * Construct a finished fragment.
	 * 
	 * @param sMarkup the markup
	 */	
	public TransformerMarkupFragment(String sMarkup)
	{
		m_objFragment = sMarkup;
		m_eType = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
	}

	/**
	 * A parsed PT XML tag for later post-processing.
	 * 
	 * @param tag
	 */
	public TransformerMarkupFragment(IXMLFragment tag)
	{
		m_objFragment = tag;
		m_eType = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
	}

	/**
	 * @see com.plumtree.transformer.xml.IMarkupFragment#GetFragmentType()
	 */
	public int GetFragmentType()
	{
		return m_eType;
	}

	/**
	 * @see com.plumtree.transformer.xml.IMarkupFragment#GetStringFragment()
	 */
	public String GetStringFragment()
	{
		if (PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED != m_eType)
		{
			throw new XPFormatException("Fragments of type " + m_eType + " cannot be converted to Strings. " +
				"Only finished fragments can be converted to strings.");
		}

		return (String) m_objFragment;
	}

	/**
	 * @see com.plumtree.transformer.xml.IMarkupFragment#GetXMLFragment()
	 */
	public IXMLFragment GetXMLFragment()
	{
		if (PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML != m_eType)
		{
			throw new XPFormatException("Fragments of type " + m_eType + " cannot be converted to xml fragments. " +
				"Only PT XML fragments can be converted to XML Fragment objects.");
		}

		return (IXMLFragment) m_objFragment;
	}

	/**
	 * @see com.plumtree.transformer.xml.IMarkupFragment#GetFragment()
	 */
	public Object GetFragment()
	{
		return m_objFragment;
	}
}