package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.uiinfrastructure.tree.*;

/**
 * @author Don Hayler
 */
public interface IObjectTreeModelRO extends ITreeModelRO
{
	/**
	 * This method returns the current access level.
	 *
	 * @return int access level
	 */
	public int GetAccessLevel();

	/**
	 * This method returns the class IDs to be displayed in this tree.
	 *
	 * @return int[] the class IDs to display
	 */
	public int[] GetDisplayedClassIDs();

	/**
	 * This method returns whether the tree is displaying search results, or
	 * just the normal tree.
	 *
	 * @return boolean true implies search results, false implies tree
	 */
	public boolean GetDisplayingSearchResults();

	/**
	 * This method returns the class ID of the folders in the tree.
	 *
	 * I.E.  admin folders or card catalogs.
	 *
	 * @return int class ID of folders in the tree.
	 */
	public int GetFolderClassID();

	/**
	 * This method returns the values used in the gadget alignment query filter.
	 */
	public int[] GetPortletAlignment();

	/**
	 * This method returns the values used in the gadget web service ID query filter.
	 */
	public int[] GetPortletWebServiceID();

	/**
	 * This method returns the values used in the gadget type query filter.
	 */
	public int[] GetPortletType();

	/**
	 * This method returns the user type values used in the user query filter.
	 */
	public int[] GetUserTypeFilter();
	
	/**
	 * This method returns the CLSID values used in the web service/data
	 * source query filter.
	 */
	public String[] GetFilterCLSID();

	/**
	 * This method returns the propid for the CLSID values used in the
	 * web service/data source query filter.
	 */
	public int GetFilterCLSIDPropID();


	/**
	 * This method returns the class ID to be filtered.
	 *
	 * @return the class ID to apply the above filter to
	 */
	public int GetFilterClassID();

	/**
	 * This method returns whether or not the given item should be displayed.
	 *
	 * @param int nClassID
	 * @param int nObjectID
	 *
	 * @return boolean true implies display the item
	 */
	public boolean GetItemDisplayed(int nClassID, int nObjectID);

	/**
	 * This method returns whether or not the given item should be selected.
	 *
	 * @param int nClassID
	 * @param int nObjectID
	 *
	 * @return boolean true implies the item is selected
	 */
	public boolean GetItemSelected(int nClassID, int nObjectID);

	/**
	 * This method returns whether or not a search has been started.
	 *
	 * This is used to tell whether or not there should be a tabbed link
	 * to the search view (no if it hasn't been started yet).
	 *
	 * @return boolean true implies should add link (search started).
	 */
	public boolean GetSearchStarted();

	/**
	 * This method returns whether or not search is enabled.
	 * 
	 * Search will always be enabled except when displaying a pre-selected list.
	 *
	 * @return boolean true implies the search box should be displayed.
	 */
	public boolean GetSearchEnabled();
}

