package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * @author Don Hayler
 */
public class ServerStartTreeControl extends AStartTreeControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.ServerStartTreeControl");

	
	public static final String STR_MVC_CLASS_NAME = "ServerStartTree";

	/** Query String arguments for this control */

	/**
	 * pass in the integer ID for the interface type you wish to display
	 * see ServerTreeModel for details.
	 * */
	public static final String INTERFACE_TYPE = "InterfaceType";

	/** generic initialization data for the Interface. */
	public static final String INIT_DATA = "InitData";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{		
		// locations to hide
		String[] sValue = (String[]) arguments.GetElement(HIDDEN_ITEMS);

		if (sValue != null)
		{
			((IServerTreeModel)m_asModel).SetLocationsToHide(sValue[0]);
		}	
		
		Redirect result = super.CheckActionSecurityAndExecute(arguments);

		int nInterfaceType;

		sValue = (String[]) arguments.GetElement(INTERFACE_TYPE);

		if ((sValue != null) && (sValue[0] != null))
		{
			nInterfaceType = XPConvert.ToInteger(sValue[0]);
		}
		else
		{
			
				log.Error("Unable to find interface type in query string.");
			

			return result;
		}

		sValue = (String[]) arguments.GetElement(INIT_DATA);

		if ((sValue != null) && (sValue[0] != null))
		{
			((ServerTreeModel) m_asModel).SetIterator(nInterfaceType, sValue[0]);
		}
		else
		{
			((ServerTreeModel) m_asModel).SetIterator(nInterfaceType, null);
		}

		// locations to select
		sValue = (String[]) arguments.GetElement(SELECTED_ITEMS);

		if (sValue != null)
		{
			((IServerTreeModel)m_asModel).SetLocationsToSelect(sValue[0]);
		}

  		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ServerStartTreeControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

