package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.commpages.*;
import com.plumtree.portaluiinfrastructure.tree.sitemap.*;
import com.plumtree.server.*;
import com.plumtree.server.treeiterator.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 * This class allows you to browse IPTTreeIterator interfaces the same way
 * you browse admin and card objects.
 */
public class ServerTreeModel extends ATreeModel implements ITreeModel,
	ITreeModelRO, IRepostModel, IServerTreeModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.ServerTreeModel");

	
	public static final String STR_MVC_CLASS_NAME = "ServerTree";

	/** Interface types -- This should probably be an enum */
	public static final int m_nPROP_PICK_TREE = 1;

	/** Site Map Type*/
	public static final int s_nSITEMAP_TREE = 2;
	
	/** Community Page Type */
	public static final int m_nCOMMPAGE_TREE = 3;

	/** Private data members*/
	protected IPTTreeIterator m_ptIterator = null;
	
	private XPHashtable m_tableHiddenLocs;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ServerTreeModel();
	}

	// Expand or collapse a node in the tree
	public void ExpandNode(boolean bExpand, int nNodeID)
	{
		super.ExpandNode(bExpand, nNodeID);

		TreeCompositeNode node = (TreeCompositeNode) m_Root.GetNode(nNodeID);

		if (node == null)
		{
			
				log.Error("Could not find node ID " + nNodeID);
			

			return;
		}

		node.m_bExpanded = bExpand;

		if ((node.m_bChildrenLoaded == false) && (bExpand))
		{
			if ((node.m_strLocation != null) &&
					(!"".equals(node.m_strLocation)))
			{
				// What happens if this doesn't work right (we no longer have access, object has been deleted, etc...)?
				m_ptIterator.MoveTo(node.m_strLocation);
			}
			else
			{
				// We should never get here, but this is here just to be safe.
				m_ptIterator.MoveToRoot();
			}

			Object[][] childNodes = (Object[][]) m_ptIterator.Children(0, -1);

			if (null != childNodes)
			{
				TreeCompositeNode myFolder;
				TreeLeafNode myLeaf;

				int numChildren = childNodes[0].length;

				for (int i = 0; i < numChildren; i++)
				{
					String childName     = (String) childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME][i];
					String childLocation = (String) childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IDENTIFIER][i];
					String childDescription = (String) childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_DESC][i];

					int childType = XPConvert.ToInteger(childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_TYPE][i]);
					
					HTMLImg childImage = null;
					HTMLImg childOpenImage = null;
					Object objImage = childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_IMAGE_UUID][i];
					Object objChildImage = childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_OPEN_IMAGE_UUID][i];

					if (objImage instanceof PTImageType)
					{
						PTConstruct myConstruct     = UIConstructFactory.GetConstruct(
							(PTImageType) objImage, true, this.m_asOwner);
						childImage		    = (HTMLImg) myConstruct.GetHTMLElement();
						childImage.SetAlt(m_asOwner.GetString(364, "ptmsgs_portalinfrastructure"));
						childImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					}

					if (objChildImage instanceof PTImageType)
					{
						PTConstruct myConstruct     = UIConstructFactory.GetConstruct(
							(PTImageType) objChildImage, true, this.m_asOwner);
						childOpenImage		    = (HTMLImg) myConstruct.GetHTMLElement();
						childOpenImage.SetAlt(m_asOwner.GetString(365, "ptmsgs_portalinfrastructure"));
						childOpenImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					}

					if (PT_TREE_ITERATOR_CHILD_TYPES.PT_TREE_ITERATOR_CHILD_TYPE_CONTAINER == childType)
					{
						// Composite Node
						myFolder				   = new TreeCompositeNode(GetNextUniqueID());
						myFolder.SetName(childName);
						myFolder.SetDescription(childDescription);
						myFolder.m_strLocation	   = childLocation;

						//JH- Make sure the image passed back is an Image type - needed for the community page tree iterator, but
						//potentially not for the other types
						if (objImage instanceof PTImageType)
						{
							myFolder.m_Image = childImage;
							myFolder.m_OpenImage = childOpenImage;
						}
							
						if(m_tableHiddenLocs == null || 
							m_tableHiddenLocs.GetElement(childLocation) == null)
						{
							node.AddCompositeChild(myFolder);
						}

						//						myFolder.m_nClassID = PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
						
							log.Info("In node " + nNodeID +
								", loaded composite child " +
								myFolder.GetEncodedName());
						
					}
					else
					{
						// Leaf Node
						myLeaf = GetLeafIfAlreadySelected(childLocation);
						
						if(myLeaf == null) 
						{
							myLeaf					 = new TreeLeafNode(GetNextUniqueID());
						}
						
						myLeaf.SetName(childName);
						myLeaf.m_strLocation     = childLocation;

						//JH- Make sure the image passed back is an Image type - needed for the community page tree iterator, but
						//potentially not for the other types
						if (objImage instanceof PTImageType)
						{
							myLeaf.m_Image = childImage;
						}

						//						myLeaf.m_nClassID = m_ptObjMgrs[j].GetManagedClassID();
						if(m_tableHiddenLocs == null || 
							m_tableHiddenLocs.GetElement(childLocation) != null)
						{
							node.AddLeafChild(myLeaf);
						}

						
							log.Info("In node " + nNodeID + ", loaded leaf child " +
								myLeaf.GetEncodedName());
						
					}
				}
			}

			node.m_bChildrenLoaded = true;

			
				log.Info("Loaded children of folder # " + nNodeID);
			
		}
	}

	///////////////////////////
	// RO Methods from IModelRO
	///////////////////////////

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	////////////////////////////
	// Write Methods from IModel
	////////////////////////////

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
	}


	///////////////////////////////
	// RO Methods from ITreeModelRO
	///////////////////////////////
	public void SetClassIDsToDisplay(int[] nIDs)
	{
		// TODO: implement
	}

	/////////////////////////////////////
	// Write Methods from ServerTreeModel
	/////////////////////////////////////

	/**
	 * This method initializes the model to a particular IPTTreeIterator
	 *
	 * Each iterator type will need custom code in this method.
	 *
	 * strInitData can be null.
	 */
	public void SetIterator(int nInterfaceType, String strInitData)
	{
		switch (nInterfaceType)
		{
		case m_nPROP_PICK_TREE:

			// Get tree iterator
			m_ptIterator = GetPickTree(strInitData);

			break;

		case s_nSITEMAP_TREE:

			// Get Site Map tree iterator
			m_ptIterator = GetSiteMapTree(strInitData);

			break;

		case m_nCOMMPAGE_TREE:
		
			//Get the Community Page tree iterator
			m_ptIterator = GetCommPageTree(strInitData);
			
			break;
			
		default:

			
				log.Error("Iterator set to invalid type: " + nInterfaceType);
			

			return;
		}

		// Move to root rather than just assume we're already there.
		m_ptIterator.MoveToRoot();

		Object[][] currentNode = (Object[][]) m_ptIterator.CurrentLocInfo();
		m_Root				 = new TreeCompositeNode(GetNextUniqueID());
		m_Root.SetName((String) currentNode[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME][0]);
		m_Root.SetDescription((String) currentNode[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_DESC][0]);
		m_Root.m_strLocation = m_ptIterator.GetLocation();

		//		if (currentNode[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_TYPE][0] !=
		//			PT_TREE_ITERATOR_CHILD_TYPES.PT_TREE_ITERATOR_CHILD_TYPE_CONTAINER)
		//		{
		//			if ( log.IsErrorEnabled() )
		//			{
		//				log.Error("Root of iterator is not a composite node.");
		//			}
		//		}
		if (!m_bShowRoot)
		{
			ExpandNode(true, m_Root.m_nTreeNodeID);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToDisplay(int[])
	 */
	public void SetObjectIDsToDisplay(int[] nIDs)
	{
		// Not currently necessary
	}

	/**
	 * @see com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToHide(int[])
	 */
	public void SetObjectIDsToHide(int[] nIDs)
	{
		// Not currently necessary
	}

	/**
	 * 
	 *
	 * @param nIDs 
	 */
	public void SetObjectIDsToSelect(int[] nIDs)
	{
		// Not currently necessary or relevant
	}
	
	/**
	 * Note: because of the fact that locations may contain commas (','), we use
	 * the semi-colon (';') to delimit the locations.  Be sure to pass in
	 * strings with semi-colon delimted strings.
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tree.IServerTreeModel#SetLocationsToSelect(String[])
	 */
	public void SetLocationsToSelect(String strLocs)
	{				
		TreeLeafNode node;
		
		if(m_Root != null)
		{
			int nStartIndex = 0;
			while (nStartIndex < strLocs.length()) 
			{
				int nEndIndex = GetNextIndex(strLocs, nStartIndex);
				String strLocation = strLocs.substring(nStartIndex, nEndIndex);	
				nStartIndex = nEndIndex + 1;
			
				// Since we are refreshing, the object may already exist
				// Check if the object is already in the tree
				node = m_Root.GetNode(strLocation);

				if (node == null)
				{					
					node				 = new TreeCompositeNode(-1);
					node.m_strLocation	 = GeneralHelpers.Replace(strLocation, ";;", ";"); // DCA - return to original form
					node.SetName("Error - Name not found.");
					node.m_nObjectID	   = -1;
					node.m_nClassID		   = -1;			
				}
				
				if (node != null)
				{
					node.m_bSelected = true;
					m_xpmSelectedItems.PutElement(GetKeyFromNode(node), node);
				}

			}	
			
		}
	}
	
	/**
	 * Note: This method is only to be used by SetLocationsToSelect(String) to obtain the
	 * endIndex of the location starting from nStartIndex. A StringTokenizer could not be used
	 * since the location could contain ";" themselves. Locations have been semicolon encoded
	 * (2 semicolons in a row == 1 semicolon in a location).
	 */
	private int GetNextIndex(String strLocs, int nStartIndex) {
		int nEndIndex = strLocs.length();
		int nSubIndex = 0;
		String strDelimiter = null;
		int nSemicolon = 0;
		while (nSemicolon % 2 == 0) 		// DCA - if the amount of semicolons is even, 
		{									//we've been finding real semicolons and not the delimiter
			nSubIndex = strLocs.indexOf(";", nStartIndex);
			if (nSubIndex > -1) {
				nSemicolon++;
				if (nSubIndex + 2 > strLocs.length()) {
					nEndIndex = strLocs.length();
					break;	
				}
				strDelimiter = strLocs.substring(nSubIndex + 1, nSubIndex + 2);
				nEndIndex = nSubIndex;
			} else {
				nEndIndex = strLocs.length();
				break;
			}
			while (nSubIndex > -1 && ";".equals(strDelimiter)) 
			{
				nSubIndex = strLocs.indexOf(";", nSubIndex + 1);
				if (nSubIndex > -1) {
					nSemicolon++;
					if (nSubIndex + 2 > strLocs.length()) {
						nEndIndex = strLocs.length();
						break;	
					}
					strDelimiter = strLocs.substring(nSubIndex + 1, nSubIndex + 2);
					nEndIndex = nSubIndex;
					nStartIndex = nSubIndex + 1;
				}
			}
		}
		return nEndIndex;
	}
	
	/**
	 * Note: because of the fact that locations may contain commas (','), we use
	 * the semi-colon (';') to delimit the locations.  Be sure to pass in
	 * strings with semi-colon delimted strings.
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tree.IServerTreeModel#SetLocationsToHide(String)
	 */
	public void SetLocationsToHide(String strLocs)
	{				
		m_tableHiddenLocs = new XPHashtable();
		
		XPStringTokenizer strTok = new XPStringTokenizer(strLocs, ";");
	
		while(strTok.HasMoreTokens())
		{
			String strLocation = strTok.GetNextElement();
			m_tableHiddenLocs.PutElement(strLocation, "");
		}	
		
	}
	
	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.tree.ATreeModel#GetKeyFromNode(TreeLeafNode)
	 */
	protected String GetKeyFromNode(TreeLeafNode node)
	{
		return node.m_strLocation;	
	}

	/**
	 * Retrieve pick tree from a property using the property ID
	 */
	private IPTTreeIterator GetPickTree(String strInitData)
	{
		int nPropertyID;

		IPTTreeIterator ptPickTree = null;

		try
		{
			// Get the property ID from the init data
			nPropertyID = XPConvert.ToInteger(strInitData);

			IPTObjectManager ptOMProperty = ((IPTSession) m_asOwner.GetUserSession()).GetProperties();
			IPTProperty ptProperty		  = (IPTProperty) ptOMProperty.Open(nPropertyID, false);

			if (PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE != ptProperty.GetCharacteristicsAsInt(
						PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTYPE))
			{
				log.Error("Property " + nPropertyID + " does not have a pick tree.");
			}
			else
			{
				IPTPickListEditor ptPickListEditor = (IPTPickListEditor) ptProperty.GetPickList();
				ptPickTree = (IPTTreeIterator) ptPickListEditor.GetInterfaces(
						"IPTTreeIterator");
			}
		}
		catch (Exception e)
		{
			log.Error(m_asOwner.GetString(260, "ptmsgs_portalinfrastructure"));

			throw new XPException(m_asOwner.GetString(260,
					"ptmsgs_portalinfrastructure"), e);
		}

		return ptPickTree;
	}

	/**
	 * Retrieve pick tree from a property using the property ID
	 */
	private IPTTreeIterator GetSiteMapTree(String strInitData)
	{
		int nSiteMapFolderID;

		IPTTreeIterator ptPickTree = null;

		try
		{
			// Get the property ID from the init data
			nSiteMapFolderID = XPConvert.ToInteger(strInitData);

			SiteMapTreeIterator objSiteMapIterator = new SiteMapTreeIterator();
			objSiteMapIterator.RealInitializeIterator(nSiteMapFolderID,
				(IPTSession) m_asOwner.GetUserSession());
			// PAI - print tree should not be called because it will iterate over the entire tree.
			//SiteMapTreeIterator.printTree(objSiteMapIterator, "");
			ptPickTree = (IPTTreeIterator) objSiteMapIterator;
		}
		catch (Exception e)
		{
			log.Error(m_asOwner.GetString(260, "ptmsgs_portalinfrastructure"));

			throw new XPException(m_asOwner.GetString(260,
					"ptmsgs_portalinfrastructure"), e);
		}

		return ptPickTree;
	}

	/**
	 * Retrieve pick tree from a property using the property ID
	 */
	private IPTTreeIterator GetCommPageTree(String strInitData)
	{
		int nAdminFolderID;

		IPTTreeIterator ptPickTree = null;

		try
		{
			// Get the property ID from the init data
			nAdminFolderID = XPConvert.ToInteger(strInitData);

			CommunityPageTreeIterator objCommPageIterator = new CommunityPageTreeIterator();
			objCommPageIterator.RealInitializeIterator(nAdminFolderID,
				(IPTSession) m_asOwner.GetUserSession());
			// PAI - print tree should not be called because it will iterate over the entire tree.
			//CommunityPageTreeIterator.printTree(objCommPageIterator, "");
			ptPickTree = (IPTTreeIterator) objCommPageIterator;
		}
		catch (Exception e)
		{
			log.Error(m_asOwner.GetString(260, "ptmsgs_portalinfrastructure"));

			throw new XPException(m_asOwner.GetString(260,
					"ptmsgs_portalinfrastructure"), e);
		}

		return ptPickTree;
	}
}

