package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * @author Don Hayler
 *
 * This Activity Space implements the Tree Control.
 */
public class TreeAS extends ATreeAS
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "Tree";

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TreeAS();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		// This must be called first to get frames right
		super.Init();

		RegisterControl(StartTreeControl.STR_MVC_CLASS_NAME, null);
	}

	/**
	 * 
	 *
	 * @param bObjectTree 
	 *
	 * @return 
	 */
	public IModel RuntimeRegister(boolean bObjectTree)
	{
		// Tree objects
		if (bObjectTree)
		{
			RegisterModel(AdminTreeModel.STR_MVC_CLASS_NAME, TREEMODEL);
		}
		else
		{
			RegisterModel(DirectoryTreeModel.STR_MVC_CLASS_NAME, TREEMODEL);
		}

		IModel myModel = GetModel(TREEMODEL);

		// Set model on previously registered controls
		((StartTreeControl) GetControl(StartTreeControl.STR_MVC_CLASS_NAME)).Init(myModel,
			this);

		RegisterAfterModel(myModel);

		return myModel;
	}

	protected void RegisterAfterModel(IModel myModel)
	{
		RegisterView(TreeWithSearchBarView.STR_MVC_CLASS_NAME,
			TreeDP.TREE_BAR_STORAGE_NAME, myModel);
		RegisterView(TreeView.STR_MVC_CLASS_NAME, myModel);
		
		RegisterControl(TreeSearchRepostControl.STR_MVC_CLASS_NAME,
			TreeRepostControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(RefreshTreeControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(TreeSelectControl.STR_MVC_CLASS_NAME, myModel);
		
		// objects to handle both search and tree
		// Register this DP in place of the default tree frame DP.
		UnRegisterPage(TreeFrameDP.STR_MVC_CLASS_NAME);
		
		IDisplayPage myFrameSet = new TreeSearchFrameDP();
		RegisterPage(myFrameSet, TreeFrameDP.STR_MVC_CLASS_NAME);
		
		// This must be set explicitly so it is the default page
		SetCurrentPage(myFrameSet);
		
		// Register this DP in place of the default tree DP.
		UnRegisterPage(TreeDP.STR_MVC_CLASS_NAME);
		
		AFormDP myPage = (AFormDP) new TreeWithSearchDP();
		myPage.AddToValidationFunction(TreeView.JAVASCRIPT_SUBMIT_TO_PARENT);
		RegisterPage(myPage, TreeDP.STR_MVC_CLASS_NAME);
		
		// Register DP for selected items view in bottom frame
		RegisterPage(new TreeSelectDP());
		
		// These get registered with the tree model, not the search model.
		RegisterView(TreeSearchBoxView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(TreeSelectView.STR_MVC_CLASS_NAME, myModel);
		
		// Search objects
		// Call IntegratedSearchAS.RegisterSearchClasses to register search stuff.
		IntegratedSearchAS.RegisterSearchClasses(this /*, TreeRepostControl.STR_MVC_CLASS_NAME */);
		
		// Get our instance of SearchResultModel; the views that display
		// results will need it.
		IModel searchModel = GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
		
		// The search view needs both models
		RegisterView(TreeSearchView.STR_MVC_CLASS_NAME, searchModel);
		((TreeSearchView) GetView(TreeSearchView.STR_MVC_CLASS_NAME)).InitTreeModel((IObjectTreeModelRO) myModel);
	}
}

