package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This control is used to dynamically update the selected items list when
 * the user de/selects an item.
 * 
 * @author DonH
 */
public class TreeSelectControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.TreeSelectControl");

	/** class MVC name */
	public static final String STR_MVC_CLASS_NAME = "TreeSelect";

	/** Select or deselect */
	public static final String SELECT = "Select";

	/** single id to select */
	public static final String SELECTEDID = "SelectedID";

	/** tree model */
	protected IObjectTreeModel m_Model;

	/** owning activity space */
	protected AActivitySpace m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// De/select a node in the tree
		boolean bSelect = XPConvert.ToBoolean(((String[]) arguments.GetElement(
					SELECT))[0]);
		int nSelectedID = XPConvert.ToInteger(((String[]) arguments.GetElement(
			SELECTEDID))[0]);

		m_Model.SelectNode(nSelectedID, bSelect);

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		try
		{
			m_Model = (IObjectTreeModel) model;
		} catch (XPClassCastException e)
		{
			
				log.Error(e, "Error initializing TreeSelect control with model.");
			
		}

		m_asOwner = space;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TreeSelectControl();
	}
}
