package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 * This displays the selected list in the bottom sub-frame of the tree pop-up
 * For search integration only
 */
public class TreeSelectDP implements IDisplayPage
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.TreeSelectDP");

	/** Tree Select object name */
	public static final String STR_MVC_CLASS_NAME = "TreeSelect";

	/** parent activity space */
	protected AActivitySpace m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display(IWebData)
	 */
	public void Display(IWebData webData)
	{
		HTMLPage myPage = new HTMLPage();

		// Set the HTMLPage as the data to be sent to the browser.
		webData.SetData(myPage);

		HTMLHead myHead = new HTMLHead();
		myPage.SetHead(myHead);

		HTMLBody myBody = new HTMLBody();
		myPage.SetBody(myBody);
		myBody.SetMarginHeight("0");
		myBody.SetMarginWidth("0");
		myBody.SetLeftMargin("0");
		myBody.SetTopMargin("0");
		myBody.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);

		try
		{
			myHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());

			myHead.AddInnerHTMLElement(m_asOwner.GetView(
					TreeSelectView.STR_MVC_CLASS_NAME).DisplayJavascript());

			myBody.AddInnerHTMLElement(m_asOwner.GetView(
					TreeSelectView.STR_MVC_CLASS_NAME).Display());
		}
		catch (Exception e)
		{
			
				log.Error(e, "Unable to display selected items in tree pop-up.");
			
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetParent()
	 */
	public AActivitySpace GetOwner()
	{
		return m_asOwner;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
	}
}

