package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This view displays the selected items from the tree
 * 
 * @author Don Hayler
 */
public class TreeSelectView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.TreeSelectView");

	/** Tree Select object name */
	public static final String STR_MVC_CLASS_NAME = "TreeSelect";


	/**
	 * JS function to refresh the page.
	 */
	public static final String JAVASCRIPT_REFRESH = "refresh";

	/**
	 * JS function to de/select an item and refresh the page.
	 */
	public static final String JAVASCRIPT_SELECT = "selectItem";

	/** parent activity space */
	protected AActivitySpace m_asOwner;

	/** model */
	protected ITreeModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TreeSelectView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		XPArrayList selectedItems = m_asModel.GetSelectedItems();
		int nSize				  = selectedItems.GetSize();
		XPStringBuilder sbSelectedItems = new XPStringBuilder(nSize * 20);

		TreeLeafNode current;

		for (int i = 0; i < nSize; i++)
		{
			current = (TreeLeafNode) selectedItems.GetElement(i);

			sbSelectedItems.Append(current.GetEncodedName());

			if (i != (nSize - 1))
			{
				sbSelectedItems.Append(", ");
			}
		}

		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		try
		{
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding("5");

			// Row for You have selected:
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myCell.SetHeight("20");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.DIALOGUE_SUBHEAD);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(263,
					"ptmsgs_portalinfrastructure"));

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetHeight("50");
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

			// Add selected items
			myCell.AddInnerHTMLString(sbSelectedItems.ToString());

			// TODO: add a link to clear the items
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Display: Failed to display the selected objects's names.");
			
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		boolean bSelected = (m_asModel.GetSelectedItems().GetSize() > 0);

		// This function returns whether or not there are any selected items.
		XPStringBuilder sb = new XPStringBuilder(200);
		sb.Append("\n");
		sb.Append("parent.").Append(FrameSetDP.BODY_FRAME).Append(".")
		.Append(TreeView.JAVASCRIPT_SELECTED_ITEMS).Append(" = ")
		.Append(bSelected).Append(";\n");

		ASURL viewSelectedURL = new ASURL(m_asOwner);
		viewSelectedURL.SetLinkGetCachedSpace(m_asOwner);
		viewSelectedURL.SetDisplayPage(TreeSelectDP.STR_MVC_CLASS_NAME);

		sb.Append("\n");
		sb.Append("function ").Append(JAVASCRIPT_REFRESH).Append("()\n");
		sb.Append("{\n");
		sb.Append("  window.location = '").Append(viewSelectedURL.GetURLAsString()).Append("';\n");
		sb.Append("}\n");

		ASURL selectURL = new ASURL(m_asOwner);
		selectURL.SetLinkGetCachedSpace(m_asOwner);
		selectURL.SetDisplayPage(TreeSelectDP.STR_MVC_CLASS_NAME);
		selectURL.SetControl(TreeSelectControl.STR_MVC_CLASS_NAME);

		sb.Append("\n");
		sb.Append("function ").Append(JAVASCRIPT_SELECT).Append("(varInput)\n");
		sb.Append("{\n");
		sb.Append("  nID = varInput.value;\n");
		sb.Append("  bSelect = varInput.checked;\n");
		sb.Append("  window.location = '").Append(selectURL.GetURLAsString())
		.Append(LinkConstants.AMPERSAND).Append(TreeSelectControl.SELECTEDID)
		.Append(LinkConstants.EQUALS).Append("' + nID + '")
		.Append(LinkConstants.AMPERSAND).Append(TreeSelectControl.SELECT)
		.Append(LinkConstants.EQUALS).Append("' + bSelect;\n");
		sb.Append("  return(true);\n");
		sb.Append("}\n");

		HTMLScript result = new HTMLScript("text/javaScript");

		try
		{
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element.");
			

			return null;
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		m_asModel     = (ITreeModelRO) model;
	}
}

