package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 * This generates the tree bar with the optional link to switch from tree to
 * search and back.
 */
public class TreeWithSearchBarView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.TreeWithSearchBarView");

	/** name of the tree search bar view*/
	public static final String STR_MVC_CLASS_NAME = "TreeSearchBar";

	/** Javascript constants */
	public static final String JAVASCRIPT_SWITCH_VIEW = "switchView";
	private AActivitySpace m_asOwner;


	/** internal data */
	private IObjectTreeModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TreeWithSearchBarView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLTable myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellSpacing("0");
		myTable.SetCellPadding("3");
		myTable.SetSummary("Action title bar table");

		HTMLTableRow myTableRow;
		HTMLTableCell myTableCell;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		try
		{
			// Title
			myTableRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myTableRow);
			myTableRow.SetStyleClass(PTStyleClass.DIALOGUE_HEADER_BG);

			myTableCell = new HTMLTableCell();
			myTableRow.AddInnerHTMLElement(myTableCell);
			myTableCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
			myTableCell.SetHeight("20");

			myTableCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

			mySpan = new HTMLSpan();
			myTableCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.DIALOGUE_SUBTITLE);

			mySpan.AddInnerHTMLString("&nbsp;");
			mySpan.AddInnerHTMLEncodedString(m_asModel.GetActionSubTitle());

			if (m_asModel.GetSearchStarted())
			{
				myTableCell = new HTMLTableCell();
				myTableRow.AddInnerHTMLElement(myTableCell);
				myTableCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
				myTableCell.SetHeight("20");
				myTableCell.SetAlign("right");
				myTableCell.SetNoWrap(true);

				mySpan = new HTMLSpan();
				myTableCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(JAVASCRIPT_SWITCH_VIEW +
					"(); return false;");

				if (m_asModel.GetDisplayingSearchResults() == true)
				{
					// In search view, add link to tree
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(264,
							"ptmsgs_portalinfrastructure"));
				}
				else
				{
					// In tree view, add link to search
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(265,
							"ptmsgs_portalinfrastructure"));
				}

				mySpan.AddInnerHTMLElement(myAnchor);
			}

			if (m_asModel.GetHelpEnabled())
			{
				myTableCell = new HTMLTableCell();
				myTableRow.AddInnerHTMLElement(myTableCell);
				myTableCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
				myTableCell.SetHeight("20");
				myTableCell.SetAlign("right");
				myTableCell.SetNoWrap(true);

				mySpan = new HTMLSpan();
				myTableCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

				mySpan.AddInnerHTMLElement(HTMLConstructHelpers.GetHelpAnchor(m_asOwner));
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "Display: The following error occured when trying to display the HTML.");
			
		}

		return myTable;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * Warning: This can return null (which cannot be added to an HTMLScriptCollection
	 */
	public HTMLScript DisplayJavascript()
	{
		if (m_asModel.GetSearchStarted())
		{
			XPStringBuilder sb = new XPStringBuilder(150);
			sb.Append("\n");

			// switch header function
			sb.Append("function ").Append(JAVASCRIPT_SWITCH_VIEW).Append("()\n");
			sb.Append("{\n");

			// Switch view type
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".")
			.Append(TreeWithSearchDP.HTMLINPUT_DISPLAYING_SEARCH)
			.Append(".value = '")
			.Append(XPConvert.ToString(!m_asModel.GetDisplayingSearchResults()))
			.Append("';\n");

			// and repost
			sb.Append("  postToSelf(")
			.Append(RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST).Append(");\n");
			sb.Append("}\n");

			HTMLScript result = new HTMLScript("text/javaScript");

			try
			{
				result.AddInnerHTMLString(sb.ToString());
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element.");
				

				return null;
			}

			return result;
		}

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IObjectTreeModelRO) model;
		m_asOwner     = parent;
	}
}

