package com.plumtree.portaluiinfrastructure.tree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 * This displays the tree and a search box just above it
 */
public class TreeWithSearchDP extends AFormDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.TreeWithSearchDP");

	/** name of this object */
	public static final String STR_MVC_CLASS_NAME = "TreeWithSearch";

	/** hidden input constants */
	/** true implies search, false implies tree
	 * @see com.plumtree.portaluiinfrastructure.tree.IObjectTreeModelRO#GetDisplayTreeOrSearch()
	 */
	public static final String HTMLINPUT_DISPLAYING_SEARCH = "in_hi_DisplayingSearch";

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()
	 */
	public String GetFormTitle()
	{
		// This page is displayed in a frame, so doesn't need a title.
		return "";
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Add the tree bar named anchor so we can link back to here.
		HTMLAnchor myAnchor = new HTMLAnchor("");
		myAnchor.SetName(ATreeAS.TREE_BAR_ANCHOR);
		result.AddInnerHTMLElement(myAnchor);

		// Always display this so it can display the viewtype hidden input and
		// refresh the header frame
		result.AddInnerHTMLElement(m_asOwner.GetView(
				TreeSearchBoxView.STR_MVC_CLASS_NAME).Display());

		result.AddInnerHTMLElement(m_asOwner.GetView(
				TreeDP.TREE_BAR_STORAGE_NAME).Display());

		if (((IObjectTreeModelRO) m_asOwner.GetModel(ATreeAS.TREEMODEL)).GetDisplayingSearchResults() == true)
		{
			result.AddInnerHTMLElement(m_asOwner.GetView(
					TreeSearchView.STR_MVC_CLASS_NAME).Display());
		}
		else
		{
			result.AddInnerHTMLElement(m_asOwner.GetView(
					TreeView.STR_MVC_CLASS_NAME).Display());
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayJavaScriptFromChild()
	 *
	 * This is a helper method that all classes that inherit from AFormDP can override
	 * if they like.  The method provides a hook into the head so that DP's can add javascript.
	 * Simply override and return and HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection scripts = new HTMLScriptCollection();
		HTMLScript myScript;

		// Always display this so it can display the viewtype hidden input and
		// refresh the header frame.  Warning - this may not return any javascript
		myScript = m_asOwner.GetView(TreeSearchBoxView.STR_MVC_CLASS_NAME)
			.DisplayJavascript();

		if (myScript != null)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		// Warning - this may not return any javascript
		myScript = m_asOwner.GetView(TreeDP.TREE_BAR_STORAGE_NAME)
			.DisplayJavascript();

		if (myScript != null)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		if (((IObjectTreeModelRO) m_asOwner.GetModel(ATreeAS.TREEMODEL)).GetDisplayingSearchResults() == true)
		{
			scripts.AddInnerHTMLElement(m_asOwner.GetView(
					TreeSearchView.STR_MVC_CLASS_NAME).DisplayJavascript());
		}
		else
		{
			scripts.AddInnerHTMLElement(m_asOwner.GetView(
					TreeView.STR_MVC_CLASS_NAME).DisplayJavascript());
		}

		// Add javascript to automatically refresh the bottom pane
		XPStringBuilder sb = new XPStringBuilder(100);
		sb.Append("\n");

		// Only refresh if the bottom pane exists and has the refresh function
		sb.Append("if ((parent.").Append(FrameSetDP.BOTTOM_FRAME)
		.Append(") && (parent.").Append(FrameSetDP.BOTTOM_FRAME).Append(".")
		.Append(TreeSelectView.JAVASCRIPT_REFRESH).Append("))\n");
		sb.Append("  parent.").Append(FrameSetDP.BOTTOM_FRAME).Append(".")
		.Append(TreeSelectView.JAVASCRIPT_REFRESH).Append("();\n");

		HTMLScript reloadScript = new HTMLScript("text/javaScript");

		try
		{
			reloadScript.AddInnerHTMLString(sb.ToString());
			scripts.AddInnerHTMLElement(reloadScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add reload javascript to the HTMLScript element.");
			
		}

		return scripts;
	}
}

