package com.plumtree.portaluiinfrastructure.tree.template;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class InheritTemplateView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.browsing.editors.community.templatetree.InheritTemplateView");

	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "InheritTemplate";
	
	/** Checkbox for Inherit Page Template */
	public static final String HTMLBUTTON_CHECKBOX = "in_cb_InheritTemplate";
	
	private IInheritTemplateModelRO m_Model;
	
	private AActivitySpace m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result = new HTMLElementCollection();

		HTMLTable innerTable = new HTMLTable();
		result.AddInnerHTMLElement(innerTable);
		innerTable.SetBorder(CommonHTMLStrings.ZERO);

		HTMLTableRow myRow = new HTMLTableRow();
		innerTable.AddInnerHTMLElement(myRow);

		HTMLTableCell myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetColSpan(CommonHTMLStrings.TWO);
		
		HTMLSpan mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(529, ResourceConstants.PORTALINFRASTRUCTURE));

		myRow = new HTMLTableRow();
		innerTable.AddInnerHTMLElement(myRow);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetNoWrap(true);
		myCell.SetVAlign(CommonHTMLStrings.TOP);

		// Add select all check box (check all)
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLBUTTON_CHECKBOX, /* in_cb_InheritTemplate */
			m_asOwner.GetString(528, ResourceConstants.PORTALINFRASTRUCTURE));
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue("true");
		myInput.SetChecked(m_Model.IsTemplateInherited());

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);

		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(528, ResourceConstants.PORTALINFRASTRUCTURE));

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_Model = (IInheritTemplateModelRO) model;
		m_asOwner = parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new InheritTemplateView();
	}

}
