package com.plumtree.portaluiinfrastructure.tree.template;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * @author michaeld
 */
public class TemplateTreeAS extends TreeAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portaluiinfrastructure.tree.template.TemplateTreeAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "TemplateTree";
	
	/** Inherit Page Temp plug in */
	public static final String PLUGIN_INHERIT_TEMPLATE = "InheritTemplate";

	/** The name of the javascript array member variable for the class id */
	public static final String INHERIT_OBJECT = "Inherit";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TemplateTreeAS();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		super.Init();

		RegisterModel(TemplateTreeModel.STR_MVC_CLASS_NAME, TREEMODEL);
		
		IModel myModel = GetModel(TREEMODEL);

		// Set model on previously registered controls
		((StartTreeControl) GetControl(StartTreeControl.STR_MVC_CLASS_NAME)).Init(myModel, this);
		
		RegisterAfterModel(myModel);
		
		// objects to handle both search and tree
		// Register this DP in place of the default tree frame DP.
		UnRegisterPage(TreeFrameDP.STR_MVC_CLASS_NAME);
		
		IDisplayPage myFrameSet = new TemplateTreeFrameDP();
		RegisterPage(myFrameSet, TreeFrameDP.STR_MVC_CLASS_NAME);
		
		// This must be set explicitly so it is the default page
		SetCurrentPage(myFrameSet);
		
		// Header DP
		UnRegisterPage(TreeHeaderDP.STR_MVC_CLASS_NAME);
		AFormDP myHeader = new TemplateTreeHeaderDP();
		myHeader.AddToValidationFunction(TemplateTreeHeaderDP.JAVASCRIPT_SUBMIT_TREE);
		RegisterPage(myHeader, TreeHeaderDP.STR_MVC_CLASS_NAME);
		
		RegisterControl(TemplateTreeRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Inherit Template plug in
		RegisterModel(InheritTemplateModel.STR_MVC_CLASS_NAME, PLUGIN_INHERIT_TEMPLATE);
		myModel = GetModel(PLUGIN_INHERIT_TEMPLATE);
		
		RegisterPage(new InheritTemplateDP());
		
		RegisterView(InheritTemplateView.STR_MVC_CLASS_NAME, PLUGIN_INHERIT_TEMPLATE, myModel);
	}

	/**
	 * Override this method to attach additional information specific to your implementation of the tree.
	 * Below is an example of how to do this.
	 * 
	 * 		XPStringBuilder sb = new XPStringBuilder();
	 * 		sb.Append("myArray[").Append(iSelectedItemIndex).Append("].")
	 * 			.Append(OBJECT_CLASS_ID).Append(" = '")
	 * 			.Append(((TreeLeafNode) mySelectedItems.GetElement(iSelectedItemIndex)).m_nClassID)
	 * 			.Append("';\n");
	 * 		return sb.ToString();
	 * 
	 * @param index of the selected Item
	 * @return String
	 */
	public String GetTreeSpecificArrayDataToAppend(int iSelectedItemIndex)
	{
		XPStringBuilder sb = new XPStringBuilder();
		sb.Append("myArray[").Append(iSelectedItemIndex).Append("].")
			.Append(INHERIT_OBJECT).Append(" = '")
			.Append(XPConvert.ToString(((IInheritTemplateModelRO)GetModel(PLUGIN_INHERIT_TEMPLATE)).IsTemplateInherited()))
			.Append("';\n");
		
		return sb.ToString();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IFormAS#GetRepostControlName()
	 */
	public String GetRepostControlName()
	{
		return TemplateTreeRepostControl.STR_MVC_CLASS_NAME;
	}
}
