package com.plumtree.portaluiinfrastructure.tree.template;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author michaeld
 */
public class TemplateTreeModel extends AdminTreeModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.browsing.editors.community.templatetree.TemplateTreeModel");

	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "TemplateTree";
	
	private boolean m_bDisplayInheritTemplate = false;

	public boolean GetDisplayInheritTemplate()
	{
		return m_bDisplayInheritTemplate;
	}
	
	public void SetDisplayInheritTemplate(boolean _bDisplayInheritTemplate)
	{
		m_bDisplayInheritTemplate = _bDisplayInheritTemplate;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.tree.ITreeModel#ResetTree()
	 */
	public void ResetTree()
	{
		super.ResetTree();
		
		((InheritTemplateModel)m_asOwner.GetModel(TemplateTreeAS.PLUGIN_INHERIT_TEMPLATE)).ResetInheritTemplate();
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(java.lang.String, com.plumtree.openfoundation.util.XPHashtable)
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		log.Debug("Begin TemplateTreeModel.SavePage");
		
		int result = RepostControl.PAGE_STATUS_VALID;
		
		if ((InheritTemplateDP.STR_MVC_CLASS_NAME).equals(_sPageName))
		{
			((IRepostModel)m_asOwner.GetModel(TemplateTreeAS.PLUGIN_INHERIT_TEMPLATE)).SavePage(_sPageName, _htFormData);
			
			m_bDisplayInheritTemplate = false;
		}
		else
		{
			result = super.SavePage(_sPageName, _htFormData);

			// SE: Bug 57030 - Fix for Vodafone. We should only display the Inherit Template Page when we detect that
			// the user has selected a template.
			// TemplateTreeRepostControl.SetRepostAction determines whether or not to set the action to 
			// POSTTOSELF_ACTION_FINISH by checking if the action is POSTTOSELF_ACTION_SELECTTEMPLATE (action number 99) 
			// and if m_bDisplayInheritTemplate is true.
			// The POSTTOSELF_ACTION_FINISH action will close the pop-up window without calling the Inherit Template page first.
			// We should set m_bDisplayInheritTemplate to true only when we detect a POSTTOSELF_ACTION_SELECTTEMPLATE 
			// action from the form post data. This means the user has selected a template and clicked "Ok" and the Inherit Template
			// page should be displayed right after that.
			int nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
			if (_htFormData.ContainsKey(RepostControl.HTMLINPUT_POSTTOSELF))
			{
				String[] data = (String[]) _htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);

				if ((0 != data.length) && (null != data[0]))
				{
					nAction = XPConvert.ToInteger(data[0]);
				}
			}
			
			if (TemplateTreeRepostControl.POSTTOSELF_ACTION_SELECTTEMPLATE == nAction)
			{
				m_bDisplayInheritTemplate = true;
				log.Debug("TemplateTreeRepostControl.POSTTOSELF_ACTION_SELECTTEMPLATE detected, display InheritTemplate page on next repost");
			}
		}
		
		log.Debug("End TemplateTreeModel.SavePage");
		return result;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TemplateTreeModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}
