package com.plumtree.portaluiinfrastructure.mock.application.varpacks;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.web.BaseVarPack;

public class MockPTSearchLocaleVarPack extends BaseVarPack {
	/** The string ID of this variable package. */
	public static final String VARPACK_ID = "MockPTSearchLocaleVarPack";

	// OpenConfig component type
	public static final String PORTAL_SEARCHLOCALES_COMPONENT_TYPE = "http://www.plumtree.com/config/component/types/portal/searchlocales";

	private static final String POPULAR_SUFFIX = "popular=";

	private XPArrayList m_xpAllLocaleCodes;
	private XPArrayList m_xpPopularLocaleCodes;

	@Override
	protected void ExpireContent() {
		// TODO Auto-generated method stub

	}
	
	/**
	 * This method will return the All the Language Codes for a particular locale
	 */
	public String[] GetAllLanguageCodes()
	{
		int nNumCodes = m_xpAllLocaleCodes.GetSize();
		String[] languageCodes = new String[nNumCodes];
		for(int i=0; i<nNumCodes; i++)
		{
			languageCodes[i] = (String) m_xpAllLocaleCodes.GetElement(i);
		}

		return languageCodes;
	}

	/**
	 * This method will return the All the Localized Language names for a particular locale
	 */
	public String[] GetAllLanguageNames(String strLocale)
	{
		return (new String[]{"Africaans", "English"});
	}
	
	@Override
	protected Object GetValue(String arg0) {
		return null;
	}

	@Override
	public String GetVarPackID() {
		return VARPACK_ID;
	}

	@Override
	public IXPEnumerator GetVarPackKeys() {
		// TODO Auto-generated method stub
		return null;
	}

	/*
	 * (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.web.BaseVarPack#Load()
	 */
	protected void Load()
	{
		//do nothing, all code moved to LoadForTest for unit testing purposes.
	}
	
	/**
	 * This method loads the SearchLocales.xml file into memory
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Load()
	 */
	public void LoadForTest()
	{
		// Load Search Locale Codes
		try
		{
			m_xpAllLocaleCodes = new XPArrayList();
			m_xpPopularLocaleCodes = new XPArrayList();

			String[] settings = new String[] {"af popular=false", "en popular=true"};
			for(int j=0;j<settings.length;j++)
			{
	
				String strName = settings[j];
				
				boolean bValue = false;

				//looking for the locale code
				int suffixNdx = XPStringUtility.IndexOf(strName, POPULAR_SUFFIX);
				String strCode = XPStringUtility.Substring(strName, 0, suffixNdx);

				m_xpAllLocaleCodes.Add(strCode);
				
				//looking for the popular value
				int popularNdx = XPStringUtility.LastIndexOf(strName, POPULAR_SUFFIX);
				//lastindexof seems to return the beginning index, so adding the length of keyword to get correct index
				String boolCode = XPStringUtility.Substring(strName, popularNdx + POPULAR_SUFFIX.length());
				
				bValue = XPConvert.ToBoolean(boolCode);
				
				if (bValue)	// if popular
				{
						m_xpPopularLocaleCodes.Add(strCode);
				}
			}

			//the rest of the code has been removed as it's not necessary for unit tests.  It mainly handled localization
			//of languages, which I don't think necessary for unit testing the tag.
		}
		catch (Exception e)
		{
			//do nothing
		}
	}

	/**
	 * This method reloads the SearchLocales.xml file into memory. It clears the
	 * current data and then delegates to Load().
	 *
	 * @see com.plumtree.xpsupport.web.BaseVarPack#Reload()
	 */
	protected void Reload()
	{
		// We don't really need to null these out, but we do anyways.
		m_xpAllLocaleCodes		   = null;
		m_xpPopularLocaleCodes     = null;

		Load();
	}

}
