package com.plumtree.portaluiinfrastructure.mock.restconsumerframework.pathways;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.*;
import com.plumtree.server.IPTSession;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.portaluiinfrastructure.search.pathways.PathwaysQueryArguments;

/**
 * Mock version of the PathwaysRestAPIService for use in testing the Pathways tag
 * library data tags.
 * 
 * @author BobbyT
 */
public class MockPathwaysRestAPIService implements IPathwaysRestAPIService 
{
	private String MOCK_BASE_URL = "http://mock.base.com/portal/server.pt";
	private String m_strPathwaysAPIBaseURL = "http://mock.base.com/graffiti/api/";
	private String m_strPathwaysAPIGatewayedBaseURL = "http://mock.base.com/PTARGS_0_0_0_0_0_0/http;//pathways.base.com/graffiti/api/";
	private boolean m_bIsPathwaysEnabled = true;
	private String m_strPathwaysVersion = "Pathways REST API V.1.5";
	private XPHashtable m_hashTagCloudData = new XPHashtable();
	private PathwaysViewsRestData[] m_viewsData = null;
	private PathwaysSearchRestData[] m_searchData = null;
	private int m_totalCount = -1;
	
	/********* Methods used to set up mock data **********/
	
	public void SetAPIVersion(String version)
	{
		m_strPathwaysVersion = version;
	}
	
	public void SetTagCloud(String view, PathwaysTagRestData[] tagCloudData)
	{
		m_hashTagCloudData.PutElement(view, tagCloudData);
	}
	
	public void SetViews(PathwaysViewsRestData[] viewsData)
	{
		m_viewsData = viewsData;
	}

	public void SetPathwaysEnabled(boolean isEnabled)
	{
		m_bIsPathwaysEnabled = isEnabled;
	}
	
	public void SetPathwaysAPIBaseURL(String url)
	{
		m_strPathwaysAPIBaseURL = url;
	}
	
	public void SetPathwaysAPIGatewayedBaseURL(String url)
	{
		m_strPathwaysAPIGatewayedBaseURL = url;
	}
	
	public void SetPathwaysSearchData()
	{
		PathwaysSearchRestData test = new PathwaysSearchRestData();
		String testURL = "http://LMAH-test.fakenetwork.com/portal/server.pt?open=18&amp;objID=299in_hi_userid=1";

		test.classId = XPConvert.ToString(0);
		test.name = "item" + 0;
		test.objectId = XPConvert.ToString(200 + 0);
		test.rank = XPConvert.ToString(0+1);
		test.source = "PTPORTAL";
		test.type = "PTPORTLET";
		test.URL = testURL;
		
		PathwaysSearchRestData[] testData = {test, test, test, test, test, test, test};
		
		m_searchData = testData;
	}
	
	public void SetTotalCount(PathwaysSearchRestData[] searchData)
	{
		m_totalCount = searchData.length;
	}
	
	/********************************************************************
	 * Methods used to retrieve Mock data.  These should match the methods
	 * called in the data tags and models.
	 ********************************************************************/

	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#GetAPIVersion()
	 * 
	 * Method is disabled and not used currently. Uncomment when re-enabled and needs to be tested.
	 */
//	public String GetAPIVersion() 
//	{
//		return m_strPathwaysVersion;
//	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#GetTagCloud(java.lang.String, java.lang.String, java.lang.String, java.lang.String)
	 */
	public PathwaysTagRestData[] GetTagCloud(String view, String format,
			String query, String tagCount) 
	{
		PathwaysTagRestData[] tempTagCloud = null;
		int count = XPConvert.ToInteger(tagCount);
		PathwaysTagRestData[] currentTagCloud = null;
		
		if (m_hashTagCloudData.ContainsKey(view))
		{
			currentTagCloud = (PathwaysTagRestData[])m_hashTagCloudData.GetElement(view);
		}
		else
		{
			currentTagCloud = new PathwaysTagRestData[0];
		}
		
		// Return only specified amount of tags. If current tag cloud is less than
		// what is specified, return everything.
		if (count < currentTagCloud.length)
		{
			tempTagCloud = new PathwaysTagRestData[count];
			for (int i = 0; i < count; i++) 
			{
				tempTagCloud[i] = currentTagCloud[i];
			}
		}
		else
		{
			tempTagCloud = currentTagCloud;
		}
		
		return tempTagCloud;
	}	

	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#GetViews()
	 */
	public PathwaysViewsRestData[] GetViews()
	{
		return m_viewsData;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#IsPathwaysEnabled()
	 */
	public boolean IsPathwaysEnabled() 
	{
		return m_bIsPathwaysEnabled;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#GetPathwaysAPIBaseURL()
	 */
	public String GetPathwaysAPIBaseURL(IPTSession session)
	{
		return m_strPathwaysAPIBaseURL;		
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#GetPathwaysGatewayedAPIBaseURL()
	 */
	public String GetPathwaysAPIGatewayedURL(AActivitySpace space, IPTSession session)
	{
		return m_strPathwaysAPIGatewayedBaseURL;		
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#GetTotalCount()
	 */
	public int GetTotalCount()
	{
		return m_totalCount;
	}
	
	public PathwaysSearchRestData[] DoSearch(PathwaysQueryArguments pqargs)
	{
		PathwaysSearchRestData[] pathwaysSearchData = null;
		
		int count = pqargs.GetResultCount();
		int intStartAt = pqargs.GetStartAt();
		
		//order, orderby, and objectTypes will not be tested.
		
		int sizeData = m_searchData.length;
		
		//if the size of the result count is greater than the actual mock items of search data, make it equal
		if (count > sizeData)
		{
			pathwaysSearchData = m_searchData;
		}
		//start at the correct start value
		else if (intStartAt > 0)
		{
			//startAt needs to start the count to the correct location			
			pathwaysSearchData = new PathwaysSearchRestData[count];
			for (int i=intStartAt; i<=count; i++)
			{
				pathwaysSearchData[i-1] = m_searchData[i-1];
			}
		}
		//set the total count of the search request
		SetTotalCount(m_searchData);
		
		return pathwaysSearchData;
	}
	
	/************* Unimplemented methods **********************/
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#AddRemoveTagRest(java.lang.String, java.lang.String, String, String)
	 */
	public void AddRemoveTagRest(String tname, String fullId, int action, String ptsource)
	{
		// TODO Auto-generated method stub

	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.IPathwaysRestAPIService#RenameTagRest(java.lang.String, java.lang.String, String, String)
	 */
	public void RenameTagRest(String tname, String fullId, String ptsource, String renametag)
	{
		// TODO Auto-generated method stub

	}

	public boolean IsAdaptiveLayoutMode() {
		// TODO Auto-generated method stub
		return true;
	}
}
