package com.plumtree.portaluiinfrastructure.mock.tags;

import com.plumtree.openfoundation.mockobjects.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.mock.httpmemorymanagement.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.uiinfrastructure.web.*;

public class MockEnvironment extends AActivitySpace implements IEnvironment
{
	public static final String MOCK_I18N_FILE = "ptmsgs_mockstrings";
	public static final int MOCK_I18N_STRING_ID = 12;
	public static final String MOCK_I18N_STRING = "mock string";
	public static final String MOCK_I18N_PLACEHOLDER_STRING = "localized placeholder string";

	public static String MOCK_BASE_URL = "http://mock.base.com/portal/server.pt?";

	public String m_asName = null;
	public String m_dpName = null;
	
	public IXPRequest m_request;
	public IXPResponse m_response;
	public MockPTSession m_userSession;
	public AActivitySpace m_parentSpace = null;

	public String m_MockI18NStringFile = null;
	public String m_MockI18NString = null;
	public int m_nMockI18NStringIndex;
	public int m_nLastI18NStringIndex = -1;
	public String m_strLastI18NStringFile = null;

	public AccessStyles m_accessStyle = AccessStyles.STANDARD;

	public XPHashtable m_models = new XPHashtable();
	public XPHashtable m_views = new XPHashtable();

	public MockEnvironment()
	{
		// create parent space
		this(true);
	}
	
	public MockEnvironment(boolean createParentSpace)
	{
		m_request = XPRequestSimulator.CreateGetLocalhost();
		m_response = XPResponseSimulator.Create();

		setup(createParentSpace);
		
	}

	protected void setup(boolean createParentSpace)
	{
		m_userSession = new MockPTSession();
		super.SetUserSession(m_userSession);
		this.SetSubSession(new MockSessionManager());
		this.GetSubSession().SetAttribute(ASConstants.PREVIOUS_REQUEST_URL, MOCK_BASE_URL);
		this.GetSubSession().SetAttribute(ASConstants.PREVIOUS_REQUEST_IS_POST, new Boolean(false));
		
		
		this.SetPersistentSubSession(new MockSessionManager());
		this.SetApplication(new Application("",""));
		
		// Create a parent space but dont have the parent space create a parent space
		if (createParentSpace) {
			m_parentSpace = new MockEnvironment(false);
		}
		
	}
	
	public void SetCurrentPage(IDisplayPage idp) {
		super.SetTrackCurrentPage(true);
		super.SetCurrentPage(idp);
	}

	public IModel GetModel(String arg0) {
		return (IModel)m_models.GetElement(arg0);
	}
	
	public IView GetView(String arg0) {
		return (IView)m_views.GetElement(arg0);
	}
	
	public boolean GetModelExists(String strModelName) {
		return m_models.ContainsKey(strModelName);
	}

	public void SetAccessStyle(AccessStyles _style)
	{
		m_accessStyle = _style;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetAccessStyle()
	 */
	public AccessStyles GetAccessStyle()
	{
		return m_accessStyle;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetCurrentHTTPRequest()
	 */
	public IXPRequest GetCurrentHTTPRequest()
	{
		return m_request;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetCurrentHTTPResponse()
	 */
	public IXPResponse GetCurrentHTTPResponse()
	{
		return m_response;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetCurrentNormalizedBaseURL()
	 */
	public String GetCurrentNormalizedBaseURL()
	{
		return MOCK_BASE_URL;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetCurrentRequestURL()
	 */
	public String GetCurrentRequestURL()
	{
		if ( MOCK_BASE_URL != null ) {
			return MOCK_BASE_URL;
		} else {
			return m_request.GetRequestURL();
		}
	}
	
	
	/**
	 * Sets the current Request URL and computes the normalized
	 * base url.
	 *
	 * This method must be called at the beginning of every request.
	 *
	 * @param the current request url
	 */
	public void SetCurrentRequestURL(String strCurrentRequestURL)
	{
		super.SetCurrentRequestURL(strCurrentRequestURL);
		MOCK_BASE_URL = strCurrentRequestURL;
	}
	

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetErrorData()
	 */
//	public IErrorData[] GetErrorData()
//	{
//		// TODO Auto-generated method stub
//		return new IErrorData[0];
//	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetLanguage()
	 */
	public String GetLanguage()
	{
		// TODO Auto-generated method stub
		return "en";
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetLocale()
	 */
	public String GetLocale()
	{
		// TODO Auto-generated method stub
		return "en-us";
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetTimeZone()
	 */
	public String GetTimeZone()
	{
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetString(int, java.lang.String)
	 */
	public String GetString(int _nID, String _strStringFile)
	{
		m_nLastI18NStringIndex = _nID;
		m_strLastI18NStringFile = _strStringFile;

		if (0 == XPStringUtility.Compare(_strStringFile, MOCK_I18N_FILE))
		{
			switch (_nID) {
			case MOCK_I18N_STRING_ID:
				return MOCK_I18N_STRING;
	
			default:
				break;
			}
		}

		if ((m_MockI18NStringFile != null) &&  
			(0 == XPStringUtility.Compare(_strStringFile, m_MockI18NStringFile)) &&
			(m_nMockI18NStringIndex == _nID))
		{
			return m_MockI18NString;
		}

		return MOCK_I18N_PLACEHOLDER_STRING;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#GetUserSession()
	 */
	public Object GetUserSession()
	{
		return m_userSession;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#SetUserSession()
	 */
	public void SetUserSession(Object userSession)
	{
		m_userSession = (MockPTSession) userSession;
		
		super.SetUserSession(m_userSession);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.tags.IEnvironment#HasErrors()
	 */
	public boolean HasErrors()
	{
		// TODO Auto-generated method stub
		return false;
	}

	public IVarPack GetVarPack(String arg0) {
		// TODO Auto-generated method stub
		return null;
	}

	// Overridden methods from AActivitySpace

	public AActivitySpace GetParentSpace()
	{
		// rob: this shouldn't be here, sometimes you want the parentspace to be null
		// but then if we initialize parentspace during creating we get into an infinite loop
		// with parentspaes creating their own parentspaces.
		// @TODO needs fixing somehow
//		if (m_parentSpace == null)
//		{
//			m_parentSpace = new MockEnvironment();
//		}

		return m_parentSpace;
	}

	// Abstract methods from AActivitySpace

	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		// TODO Auto-generated method stub
		return false;		
	}

	public Object Create()
	{
		// TODO Auto-generated method stub
		return null;
	}

	public String GetName()
	{
		return m_asName;
	}
}