package com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.community.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.server.mock.directory.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.uiinfrastructure.web.*;

public class PTDocFoldersTest extends TestCase 
{
	public static final String DIRECTORYFOLDER_KEYWORD = "directory";
	
	protected PTDocFolders testObject = null;
	protected AActivitySpace space = null;
	protected MockPTSession userSession = null;
	
	/**
	 */
	public PTDocFoldersTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() 
   	{
   		testObject = new PTDocFolders();
   		space = new BaseOpenerAS();
   		userSession = new MockPTSession();
   		space.SetUserSession(userSession);
   		
   		IApplication application = new Application("","");
		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
		
		XPHashtable htLookupTable = new XPHashtable();
		htLookupTable.PutElement(PT_CLASSIDS.PT_CATALOGFOLDER_ID+"", DIRECTORYFOLDER_KEYWORD);
		IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
		friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, friendlyURLManager);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown()  
	{
		testObject = null;
		space = null;
		userSession = null;
	}
   	
	/**
	 * Test for url with just directory folder name
	 */
	public void testGetRedirectViewObjectDocumentName() 
	{
		// setup the mock object data
		int directoryId = 300;
		MockPTCatalog.setDirectoryMapping("Directory Folder", new int[] {directoryId});
		// setup mock tokenzier
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/directory_folder", "/", false);
		IFriendlyURLParser fURLParser = new FriendlyURLParser(DIRECTORYFOLDER_KEYWORD, XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
		
		// test
		Redirect redirect = testObject.GetRedirectViewObject(fURLParser, space, userSession);
		
		// check result
		String activityspace = redirect.GetSpaceName();
		Assert.assertEquals("Redirect object has the wrong activity space name.", activityspace, PTDocFolders.DIRECTORY_ASNAME);
		String dirId = redirect.GetControlArgument(PTDocFolders.DIRECTORY_PARAM_FOLDERID);
		Assert.assertEquals("Redirect object has the wrong directory Id.", XPConvert.ToInteger(dirId), directoryId);
	}
	
	/**
	 * Test for url with just directory folder name and id
	 */
	public void testGetRedirectViewObjectDocumentNameAndId() 
	{
		String strName = "Directory Folder";
		String strNormalizedName = FriendlyURL.NormalizeObjectName(strName);

		// setup the mock object data
		int directoryId = 300;
		// ROB: Object names are "normalized" to all lower case and space becomes _ in constructed urls
		MockPTCatalog.setDirectoryMapping(strName, new int[] {directoryId});
		// setup mock tokenizer
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + strNormalizedName + "/"+directoryId, "/", false);
		IFriendlyURLParser fURLParser = new FriendlyURLParser(DIRECTORYFOLDER_KEYWORD, XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
		
		// test
		Redirect redirect = testObject.GetRedirectViewObject(fURLParser, space, userSession);
		
		// check result
		String activityspace = redirect.GetSpaceName();
		Assert.assertEquals("Redirect object has the wrong activity space name.", activityspace, PTDocFolders.DIRECTORY_ASNAME);
		String dirId = redirect.GetControlArgument(PTDocFolders.DIRECTORY_PARAM_FOLDERID);
		Assert.assertEquals("Redirect object has the wrong directory Id.", XPConvert.ToInteger(dirId), directoryId);
		
	}
	
	/**
	 * Test for url with duplicate directory folder name  
	 */
	public void testGetRedirectViewObjectDuplicateDocumentName() 
	{
		String origDirName = "Folder";
		String strNormalizedName = FriendlyURL.NormalizeObjectName(origDirName);

		// setup the mock object data
		int directoryId1 = 300;
		int directoryId2 = 302;
		MockPTCatalog.setDirectoryMapping(origDirName, new int[] {directoryId1, directoryId2});
		// setup mock tokenzier
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + strNormalizedName, "/", false);
		IFriendlyURLParser fURLParser = new FriendlyURLParser(DIRECTORYFOLDER_KEYWORD, XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
		
		// test
		Redirect redirect = testObject.GetRedirectViewObject(fURLParser, space, userSession);
		
		// check result
		String activityspace = redirect.GetSpaceName();
		Assert.assertEquals("Redirect object has the wrong activity space name.", activityspace, "SearchResult");
		String dirName = redirect.GetControlArgument(SearchResultControl.USER_QUERY);
		// control arguments are lower cased
		Assert.assertEquals("Redirect object has the wrong directory name for search query.", dirName, XPStringUtility.ToLowerCase(origDirName));
	}

	/**
	 * Test for constructing a friendly URL
	 *
	 */
	public void testURLConstruction()
	{
		int directoryId = 300;
		String directoryName = "My Directory Folder";
		MockPTCatalog.setDirectoryMapping(directoryName, new int[] {directoryId});
		
		FriendlyURL url = new FriendlyURL(PT_CLASSIDS.PT_CATALOGFOLDER_ID, 300);
		String strURL = testObject.ConstructFriendlyURL(url, space);
		Assert.assertEquals("/"+DIRECTORYFOLDER_KEYWORD+"/"+FriendlyURL.NormalizeObjectName(directoryName)+"/"+300, strURL);
		// object ids disabled code
		// Assert.assertEquals("/"+DIRECTORYFOLDER_KEYWORD+"/"+FriendlyURL.NormalizeObjectName(directoryName), strURL);
	}
	
	/**
	 * Test with special characters
	 *
	 */
	public void testGetRedirectViewObjectWithSpecialCharacters() 
	{
		int origDocId = 300;
		MockPTCatalog.setDirectoryMapping(PTCommunitiesTest.SPECIALCHARS_NORMALIZED_STRING, new int[] {origDocId});
		
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/"+PTCommunitiesTest.SPECIALCHARS_NORMALIZED_STRING+"/", "/", false);
		KDFriendlyURLParser cfURLParser = new KDFriendlyURLParser("directory", 
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID), stURLTokens);
		Redirect redirect = testObject.GetRedirectViewObject(cfURLParser, space, userSession);
		
		String activityspace = redirect.GetSpaceName();
		Assert.assertEquals("Redirect object has the wrong activity space name.", activityspace, PTDocFolders.DIRECTORY_ASNAME);
		
		String docId = redirect.GetControlArgument(PTDocFolders.DIRECTORY_PARAM_FOLDERID);
		Assert.assertEquals("Redirect object has the wrong document folder Id.", origDocId, XPConvert.ToInteger(docId));
		
		
	}
	

	/**
	 * @TODOs 
	 * - Add tests for constructing urls, specifically that the right format is used i.e. full paths vs dir name + obj id
	 * - Add test for constructing Urls using taskapi and mediator (need portal mock startup mode for that), too many variables
	 * that need to be initialized
	 */
	
}
