package com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.server.mock.directory.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.uiinfrastructure.web.*;

public class PTDocumentsTest extends TestCase {
	
	protected int documentId = 200;
	protected PTDocuments testObject = null;
	protected AActivitySpace asParent = null;
	protected MockPTSession userSession = null;
	protected String documentName = "Document Name.doc";
	/**
	 */
	public PTDocumentsTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		testObject = new PTDocuments();
   		asParent = new BaseOpenerAS();
   		userSession = new MockPTSession();
   		asParent.SetUserSession(userSession);
   		
   		// DCA - set up MockPTCatalog
   		int[] arrResult = new int[] {documentId};
   		MockPTCatalog.setDocumentMapping(documentName, arrResult);
   		
   		IApplication application = new Application("","");
		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
		
		XPHashtable htLookupTable = new XPHashtable();
		htLookupTable.PutElement(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), "document");
		IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
		friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, friendlyURLManager);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown()  
	{
		testObject = null;
		asParent = null;
		userSession = null;
	}
   	
	/**
	 * DCA - test to handle document name
	 */
	public void testGetRedirectViewObjectDocumentName() {
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/document name.doc/", "/", false);
		IFriendlyURLParser fURLParser = new DocumentFriendlyURLParser("document", XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), stURLTokens);
		Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent, userSession);
		
		String activityspace = redirect.GetSpaceName();
		Assert.assertEquals("Redirect object has the wrong activity space name.", activityspace, PTDocuments.DOCUMENT_AS_NAME);
		String docId = redirect.GetControlArgument(PTDocuments.STR_CARD_ID);
		Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(docId), documentId);
	}
	
	/**
	 * DCA - test to handle document Id
	 */
	public void testGetRedirectViewObjectDocumentId() {
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/"+documentId+"/document name.doc/", "/", false);
		IFriendlyURLParser fURLParser = new DocumentFriendlyURLParser("document", XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), stURLTokens);
		Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent, userSession);
		
		String activityspace = redirect.GetSpaceName();
		Assert.assertEquals("Redirect object has the wrong activity space name.", activityspace, PTDocuments.DOCUMENT_AS_NAME);
		String docId = redirect.GetControlArgument(PTDocuments.STR_CARD_ID);
		Assert.assertEquals("Redirect object has the wrong community Id.", XPConvert.ToInteger(docId), documentId);
	}
	
	/**
	 * DCA - test to handle when a document is not found
	 */
	public void testGetRedirectViewObjectNotFound() {
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/doc name/", "/", false);
		IFriendlyURLParser fURLParser = new DocumentFriendlyURLParser("document", XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), stURLTokens);
		Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent, userSession);
		
		String activityspace = redirect.GetSpaceName();
		Assert.assertEquals("Redirect object has the wrong activity space name.", activityspace, PTDocuments.SEARCH_AS_NAME);
		String communityName = redirect.GetControlArgument(SearchResultControl.USER_QUERY);
		Assert.assertEquals("Redirect object has the wrong search query.", "doc name", communityName);
	}	
	
	/**
	 * DCA - test ConstructFriendlyURL method
	 */
	public void testConstructFriendlyURL() {
		FriendlyURL url = new FriendlyURL(PT_CLASSIDS.PT_CATALOGCARD_ID, documentId);
		String strURL = testObject.ConstructFriendlyURL(url, asParent);
		String strExpected = "/document/"+documentId+"/"+XPHttpUtility.UrlEncode( FriendlyURL.NormalizeObjectName(documentName), LinkConstants.UTF_8_ENCODING);
		Assert.assertEquals("URL constructed does not match expected.", strExpected, strURL);
	}
}
