package com.plumtree.portaluiinfrastructure.test.classtypedescriptors.classtypes;

import junit.framework.*;


import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.IFriendlyURLManager;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockApplicationManager;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockClassTypeDescManager;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.Redirect;
import com.plumtree.uiinfrastructure.application.AppWarmUp;
import com.plumtree.uiinfrastructure.application.varpacks.AppConstants;
import com.plumtree.uiinfrastructure.opener.BaseOpenerAS;
import com.plumtree.uiinfrastructure.web.Application;
import com.plumtree.uiinfrastructure.web.ApplicationManager;
import com.plumtree.uiinfrastructure.web.IApplication;


public class PTMyPagesTest extends TestCase {
	
	protected int communityId = 200;
	protected int pageId = 300;
	protected PTMyPages testObject = null;
	protected AActivitySpace asParent = null;
	protected MockPTSession userSession = null;
	
	/**
	 */
	public PTMyPagesTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		testObject = new PTMyPages();
   		asParent = new BaseOpenerAS();
   		userSession = new MockPTSession();
   		asParent.SetUserSession(userSession);
   		
   		IApplication application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
   		XPHashtable htLookupTable = new XPHashtable();
		htLookupTable.PutElement(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID+"", "mypage");
   		
   		IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
		friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, friendlyURLManager);
   		
		int[] columns = {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME};
		Object[][] data = {{new Integer(200), "another page"},{new Integer(pageId), "Test Page"}};
		// False means the data needs to be flipped.
		MockPTQueryResult.SetStaticData(columns, data, false);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown()  
	{
		testObject = null;
		asParent = null;
		userSession = null;
		MockPTQueryResult.ClearStaticData();
	}
   	
	public void testConstructFriendlyURLWithPageName()
	{
		String pageName = "Test Page";		
		FriendlyURL furl = new FriendlyURL(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID, 500);
		furl.SetObjectName(pageName);
		furl.SetObjectId(pageId);
				
		String urlString = testObject.ConstructFriendlyURL(furl, asParent);
		
		assertEquals(urlString, "/mypage/test_page/"+pageId);
		// object ids disabled
		//assertEquals(urlString, "/mypage/test_page");
		
	}
	
	public void testConstructFriendlyURLWithOutPageName()
	{	
		FriendlyURL furl = new FriendlyURL(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID, 500);
		furl.SetObjectId(pageId);
				
		String urlString = testObject.ConstructFriendlyURL(furl, asParent);

		assertEquals(urlString, "/mypage/test_page/"+pageId);
		// object ids disabled
		//assertEquals(urlString, "/mypage/test_page");
		
	}
	
	public void testConstructFriendlyURLDefaultPageId()
	{	
		FriendlyURL furl = new FriendlyURL(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID, 500);
		furl.SetObjectId(0);
				
		String urlString = testObject.ConstructFriendlyURL(furl, asParent);
		
		assertEquals(urlString, "/mypage/another_page/"+0);
		// object ids disabled
		//assertEquals(urlString, "/mypage/another_page");
		
	}
	
	public void testGetRedirectViewObject()
	{	
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/test_page/", "/", false);
		IFriendlyURLParser fURLParser = new FriendlyURLParser("mypage", XPConvert.ToString(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID), stURLTokens);
		Redirect redirect = testObject.GetRedirectViewObject(fURLParser, asParent, userSession);
		
		String activityspace = redirect.GetSpaceName();
		Assert.assertTrue("Redirect object has the wrong activity space name.", activityspace.equalsIgnoreCase("mypage"));
		String id = redirect.GetControlArgument(PTMyPages.STR_PAGE_ID);
		Assert.assertTrue("Redirect object has the wrong object Id.", pageId == XPConvert.ToInteger(id));
	}
	
}
