package com.plumtree.portaluiinfrastructure.test.friendlyurl;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.server.*;

import junit.framework.*;

public class CommunityFriendlyURLParserTest extends TestCase {
	
	protected CommunityFriendlyURLParser testObject;
	protected String objectName = "object name";
	protected String objectNameNormalized = "object_name";
	protected int objectId = 200;
	protected int pageid = 400;
	protected String childName = "child name";
	protected String childNameNormalized = "child_name";
	
	protected String specialCharString = "!@#$%^&*<>()-=~?';.,\"";
	protected String deNormalizedSpecialCharString = "!@ $   *  ()-=~ ';.,\"";
	protected String normalizedSpecialCharString = "!@_$___*__()-=~_';.,\"";
	
	
	/**
	 */
	public CommunityFriendlyURLParserTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		testObject = null;
	}

	public void testGetObjectNameAndId() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + objectNameNormalized + "/" + objectId, "/", false);
   		testObject = new CommunityFriendlyURLParser("community", XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
   		
		String name = testObject.GetObjectName(true);
		Assert.assertEquals("Wrong name was returned.", name, objectName);
		int id = testObject.GetObjectId();
		Assert.assertEquals("Wrong id was returned.", id, objectId);
	}
	
	public void testGetObjectNameAndChildName() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + objectNameNormalized + "/" + childNameNormalized, "/", false);
   		testObject = new CommunityFriendlyURLParser("community", XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
   		
		String name = testObject.GetObjectName(true);
		Assert.assertEquals("Wrong name was returned.", name, objectName);
		String childName = testObject.GetChildName(true);
		Assert.assertEquals("Wrong child name was returned.", childName, childName);
	}
	
	public void testGetObjectNameAndIdAndChildName() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/" + objectNameNormalized + "/" + objectId + "/" + childNameNormalized, "/", false);
   		testObject = new CommunityFriendlyURLParser("community", XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
   		
		String name = testObject.GetObjectName(true);
		Assert.assertEquals("Wrong name was returned.", name, objectName);
		int id = testObject.GetObjectId();
		Assert.assertEquals("Wrong id was returned.", id, objectId);
		String childName = testObject.GetChildName(true);
		Assert.assertEquals("Wrong child name was returned.", this.childName, childName);
	}
	
	public void testGetObjectNameAndIdAndChildNameAndId() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer(
				"/" + objectNameNormalized + "/" + objectId + "/" + childNameNormalized+"/"+pageid, "/", false);
   		testObject = new CommunityFriendlyURLParser("community", XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID), stURLTokens);
   		
		String name = testObject.GetObjectName(true);
		Assert.assertEquals("Wrong name was returned.", name, objectName);
		int id = testObject.GetObjectId();
		Assert.assertEquals("Wrong id was returned.", id, objectId);
		String childName = testObject.GetChildName(true);
		Assert.assertEquals("Wrong child name was returned.", this.childName, childName);
		int childId = testObject.GetChildId();
		Assert.assertEquals("Wrong child name was returned.", pageid, childId);
	}
	
}
