package com.plumtree.portaluiinfrastructure.test.friendlyurl;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.server.*;

import junit.framework.*;

public class FriendlyURLParserManagerTest extends TestCase {
	
	protected IFriendlyURLParserManager testObject;
	protected String commKeyword = "community";
	protected String mypageKeyword = "mypages";
	protected String APIKeyword = "api";
	protected String RSSKeyword = "rss";
	
	/**
	 */
	public FriendlyURLParserManagerTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();
   		XPHashtable htKeyToClassIdLookup = new XPHashtable();
   		htKeyToClassIdLookup.PutElement(commKeyword, XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID));
   		htKeyToClassIdLookup.PutElement(mypageKeyword, XPConvert.ToString(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID));
   		htKeyToClassIdLookup.PutElement(APIKeyword, XPConvert.ToString(FriendlyURLConstants.REST_API_ID));
   		htKeyToClassIdLookup.PutElement(RSSKeyword, XPConvert.ToString(FriendlyURLConstants.FRIENDLY_RSS_ID));
   		testObject = FriendlyURLParserManager.getInstance();
   		testObject.SetKeyToClassIdLookupTable(htKeyToClassIdLookup);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		testObject = null;
	}

	public void testGetParserCommunity() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer(commKeyword + "/community_name/", "/", false);
		IFriendlyURLParser fURLParser = testObject.GetParser(stURLTokens);
		Assert.assertEquals("Wrong FriendlyURLParser was returned.", CommunityFriendlyURLParser.class, fURLParser.getClass());
	}

	public void testGetParserMyPages() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer(mypageKeyword + "/community_name/", "/", false);
		IFriendlyURLParser fURLParser = testObject.GetParser(stURLTokens);
		Assert.assertEquals("Wrong FriendlyURLParser was returned.", MyPageFriendlyURLParser.class, fURLParser.getClass());
	}

	public void testGetParserAPI() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer(APIKeyword + "/v1/kd/123", "/", false);
		IFriendlyURLParser fURLParser = testObject.GetParser(stURLTokens);
		Assert.assertEquals("Wrong FriendlyURLParser was returned.", APIFriendlyURLParser.class, fURLParser.getClass());
	}
	
	public void testGetParserRSS() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer(RSSKeyword + "/rss/kd/directory/object_name/200", "/", false);
		IFriendlyURLParser fURLParser = testObject.GetParser(stURLTokens);
		Assert.assertEquals("Wrong FriendlyURLParser was returned.", RSSFriendlyURLParser.class, fURLParser.getClass());
		
		stURLTokens = new XPStringTokenizer(RSSKeyword + "/rss/searchresults/search", "/", false);
		fURLParser = testObject.GetParser(stURLTokens);
		Assert.assertEquals("Wrong FriendlyURLParser was returned.", RSSFriendlyURLParser.class, fURLParser.getClass());
	}
}