package com.plumtree.portaluiinfrastructure.test.friendlyurl;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;

public class RSSFriendlyURLParserTest extends TestCase 
{
	protected RSSFriendlyURLParser testObject;
	protected String objectName = "object name";
	protected String objectNameNormalized = "object_name";
	protected int objectId = 200;
	
	/**
	 * @param name
	 */
	public RSSFriendlyURLParserTest(String name) 
	{
		super(name);
	}

	/* (non-Javadoc)
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() throws Exception 
	{
		super.setUp();
	}

	/* (non-Javadoc)
	 * @see junit.framework.TestCase#tearDown()
	 */
	public void tearDown() throws Exception 
	{
		super.tearDown();
	}
	
	/**
	 * Test parsing of a RSS KD Friendly URL. 
	 */
	public void testGetKDObjectNameAndId() 
	{
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/kd/directory/" + objectNameNormalized + "/" + objectId, "/", false);
   		testObject = new RSSFriendlyURLParser("rss", XPConvert.ToString(FriendlyURLConstants.FRIENDLY_RSS_ID), stURLTokens);
   		
		String name = testObject.GetObjectName(true);
		Assert.assertEquals("Wrong name was returned.", name, objectName);
		int id = testObject.GetObjectId();
		Assert.assertEquals("Wrong id was returned.", id, objectId);
	}
	
	/**
	 * Test parsing of a RSS Search Results Friendly URL.
	 */
	public void testGetSearchResultsObjectNameAndId() 
	{
		// Go through parser with search keyword and object id
		XPStringTokenizer stURLTokens = new XPStringTokenizer("/searchresults/search/" + objectId, "/", false);
   		testObject = new RSSFriendlyURLParser("rss", XPConvert.ToString(FriendlyURLConstants.FRIENDLY_RSS_ID), stURLTokens);
   		
		String name = testObject.GetObjectName(true);
		Assert.assertEquals("Wrong name was returned.", name, "searchresults");
		int id = testObject.GetObjectId();
		Assert.assertEquals("Wrong id was returned.", id, objectId);
		
		// Go through parser again without search object id in the URL
		stURLTokens = new XPStringTokenizer("/searchresults/search", "/", false);
   		testObject = new RSSFriendlyURLParser("rss", XPConvert.ToString(FriendlyURLConstants.FRIENDLY_RSS_ID), stURLTokens);
   		
		name = testObject.GetObjectName(true);
		Assert.assertEquals("Wrong name was returned.", name, "searchresults");
		id = testObject.GetObjectId();
		Assert.assertEquals("Wrong id was returned.", id, 0);
	}
}
