package com.plumtree.portaluiinfrastructure.test.helper;

import junit.framework.TestCase;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.tags.MockEnvironment;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.openfoundation.util.XPArrayList;

public class BannerSearchHelperServiceTest extends TestCase {
	
	protected static int int_default = 0;
	protected static String forIntSetting = "searchPageSize";
	protected static String settingsStrSessionName = "searchObjectTypesOverride";
	protected static int settingsStrSessionDefault = -1;
	protected static String str_default = null;
	protected static String settingName = "searchGroupBy";
	XPArrayList arList = new XPArrayList();
	protected static int[] portalClassIDs = new int[]{18, 17, 1, 512, 43, 514, -1};
	protected static String[] objectQuery = new String[] {"protect", "bob"};
	
	protected MockPTSession ptSession = null;
	protected MockPTSessionInfo ptSessionInfo = null;
	protected AActivitySpace m_space = null;
	

	public void setUp() throws Exception {
		m_space = new MockEnvironment();
		ptSession = (MockPTSession)m_space.GetUserSession();
		ptSessionInfo = (MockPTSessionInfo)ptSession.GetSessionInfo();
			
		
	}

	public void tearDown() throws Exception {
		ptSession = null;
		ptSessionInfo = null;
		m_space = null;
	}

	public void testDefaultValueSetings()
	{
		int BIT_FOLDER = 2;
		XPArrayList searchList = new XPArrayList();
		XPArrayList objTypes = new XPArrayList();
				
		IBannerSearchHelper bannerHelper = BannerSearchHelperService.GetInstance();

		//testing sort order
		String sortOrder = bannerHelper.GetBannerSearchPreferenceSortOrder(m_space);
		assertNotNull("Sort order should not be null.", sortOrder);
		
		//getting search constraints from session preferences
		searchList = bannerHelper.GetSearchConstraints(m_space);
		assertNotNull("Constraints list should not be null.", searchList);
		assertTrue("Constraints list should have at least one item.", (searchList.GetSize() > 0));
		
		//getting portal object types based on bitmask info (preset to BIT_FOLDER)
		objTypes = bannerHelper.GetPortalObjectTypes(ptSessionInfo, BIT_FOLDER);
		assertNotNull("Object types should not be null", objTypes);
		
		int sessionSetValue = bannerHelper.GetIntSessionSetting(ptSessionInfo, settingsStrSessionName , settingsStrSessionDefault);
		assertTrue("Default int session setting should not be -1, if so, value doesn't exist.", (sessionSetValue != 0));

		String settingValue = bannerHelper.GetStringSetting(ptSessionInfo, settingName, str_default);
		assertNull("Default string settings value should be null.", settingValue);

		int settingdbValue = bannerHelper.GetIntSetting(ptSessionInfo, forIntSetting, int_default);
		assertTrue("Default int setting from db should be 0.", (settingdbValue == 0));

		//testing setting collab items
		XPArrayList collabConstraints = bannerHelper.setContentItems(arList);
		int collabSize = collabConstraints.GetSize();
		assertNotNull("Default collab item constraints is null.", collabConstraints);
		assertTrue("Default collab item constraint size should be greater than zero.", (collabSize > 0));
		
		//testing setting content item
		XPArrayList contentConstraints = bannerHelper.setContentItems(arList);
		int contentSize = contentConstraints.GetSize();
		assertNotNull("Default content item constraint is null.", contentConstraints);
		assertTrue("Default content item constraint size should be greater than zero.", (contentSize > 0));
		
		//testing converting classids to pathways string constraints
		String currPathwaysValue = "";
		//we're going to use this to make sure that the value being returned is never empty
		String checkString = "";
		int portalClassSize = portalClassIDs.length;
		
		for (int i=0; i< portalClassSize -1; i++ )
		{
			currPathwaysValue = bannerHelper.GetPathwaysClassIdStringValue(portalClassIDs[i]);
			assertTrue("pathways string value should not be empty.", (!checkString.equals(currPathwaysValue)));
		}
		
		//checking the last value of -1 (which symbolizes no filters), which should return null
		currPathwaysValue = bannerHelper.GetPathwaysClassIdStringValue(portalClassSize+100);
		assertNull("pathways string should be null.", currPathwaysValue);

		//testing the construction of the search history for pathways
		String searchHistory = bannerHelper.SetPathwaysSearchHistory(objectQuery);
		String testHistory = "(" + objectQuery[0] + ") and " + objectQuery[1];
		assertEquals("searchHistory should be equal.", testHistory, searchHistory);
		
		
	}
	
}
