package com.plumtree.portaluiinfrastructure.test.helper;

import junit.framework.TestCase;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.tags.MockEnvironment;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.server.mock.webservice.*;

public class EnsembleHelperServiceTest extends TestCase {
	
	public static final String ENSEMBLE_REMOTE_SERVER_UUID = "{4051EE46-9E4E-5D57-31C3-CD398FF42000}"; 
	public static final String ENSEMBLE_REMOTE_SERVER_NAME = "Ensemble Remote Server ID";
	
	//TODO change this to real number
	public static final int ENSEMBLE_REMOTE_SERVER_ID = 308;
	
	protected MockEnvironment m_environment;
	protected MockPTObjectManager  m_objMgr;
	protected MockPTSession ptSession;

	public void setUp() throws Exception {
		m_environment = new MockEnvironment();
		
		ptSession = (MockPTSession)m_environment.GetUserSession();

		//constructing gadget content servers query result
		int gcsColumns[] = {PT_PROPIDS.PT_PROPID_OBJECTID};
		Object[][] gcsData = {{ENSEMBLE_REMOTE_SERVER_ID}};

		MockPTQueryResult ptqrGCS = new MockPTQueryResult();
		ptqrGCS.SetData(gcsColumns, gcsData, true);
		
		//setting up objects in mock objects		
		m_objMgr = (MockPTObjectManager)ptSession.GetGadgetContentServers();
		m_objMgr.m_bUseStatic = false;
		m_objMgr.m_queryResult = ptqrGCS;
		
	}

	public void tearDown() throws Exception {
		m_environment = null;
		ptSession = null;
		m_objMgr = null;
	}

	public void testLoadEnsembleRemoteServer() {
		IEnsembleHelper ensembleHelper = EnsembleHelperService.getInstance();
		
		int remoteServerID = ensembleHelper.GetRemoteServerID(ptSession);	
		assertEquals("Ensemble web service should exist.", ENSEMBLE_REMOTE_SERVER_ID, remoteServerID);
		
		boolean isInstalled = ensembleHelper.IsEnsembleInstalled(ptSession);
		assertTrue("Ensemble should be installed.", isInstalled);
		Object[][] filter = m_objMgr.m_queryFilterUsed;
		assertNotNull("Query filter used to call object manager should not be null", filter);
		assertEquals("Checking for filter operand, should be UUID value.", PT_PROPIDS.PT_PROPID_UUID, filter[0][0]);
		assertEquals("Checking for filter operator, should be \"=\".", PT_FILTEROPS.PT_FILTEROP_EQ, filter[1][0]);
		
		String gcsUUID = (String)filter[2][0];
		assertNotNull("query filter uuid string value should not be null.", gcsUUID);
		assertEquals("Checking uuid item value should be the same.", ENSEMBLE_REMOTE_SERVER_UUID, gcsUUID);
	}

}
