package com.plumtree.portaluiinfrastructure.test.layout;

import junit.framework.*;

import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.portaluiinfrastructure.test.tags.*;
import com.plumtree.server.*;
import com.plumtree.xpshared.htmlelements.*;

public class LayoutDisplayTest extends TestCase
{
	public static final String TEST_HTML_PREFIX = "<html><head/><body>";
	public static final String TEST_HTML_CONTENT = "This is a test page.";
	public static final String TEST_HTML_SUFFIX = "</body></html>";

	public static final String TEST_TAG = "testtag";
	public static final String TEST_LIBRARY = "testlibrary";
	public static final String TEST_VALUE = "test value";

	public ILayoutDisplay m_layoutDisplay;

	public MockEnvironment m_MockSpace;

	public void setUp()
	{
		m_layoutDisplay = LayoutService.getFactoryInstance().CreateDisplay();
		m_MockSpace = new MockEnvironment();

		MockTagLibManager manager = new MockTagLibManager();
		manager.SetTag(new TestSimpleTag(), TEST_TAG, TEST_LIBRARY);
		TagLibManager.setTestInstance(manager);
	}

	public void testHTML()
	{
		Object[][] fragments = new Object[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS][3];

		int i = 0;

		/**
		 * HTML Fragment for page prefix
		 */
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_PREFIX;
		i++;

		/**
		 * HTML Fragment for html content
		 */
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_CONTENT;
		i++;

		/**
		 * HTML Fragment for page suffix
		 */
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_SUFFIX;
		i++;

		HTMLElement result = m_layoutDisplay.ProcessLayout(fragments, m_MockSpace);

		assertEquals("Checking transformed simple HTML content.",
			TEST_HTML_PREFIX + TEST_HTML_CONTENT + TEST_HTML_SUFFIX,
			result.GetDisplayString());
	}

	public void testTagTransformation()
	{
		Object[][] fragments = new Object[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS][3];

		int i = 0;

		/**
		 * HTML Fragment for page prefix
		 */
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_PREFIX;
		i++;

		/**
		 * logic value singleton Tag
		 */
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML);

		// Can't put this directly as an argument because of jump issues.
		Object[][] valueTagXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE) },
			{ TEST_LIBRARY + "." + TEST_TAG, TestSimpleTag.TESTATTRIBUTE.GetName(), null },
			{ null, TEST_VALUE, null } };

		// Add a singleton tag
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = valueTagXML;
		i++;

		/**
		 * HTML Fragment for page suffix
		 */
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		fragments[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_SUFFIX;
		i++;

		HTMLElement result = m_layoutDisplay.ProcessLayout(fragments, m_MockSpace);

		assertEquals("Checking transformed tag content.",
			TEST_HTML_PREFIX + TEST_VALUE + TEST_HTML_SUFFIX,
			result.GetDisplayString());
	}
}