package com.plumtree.portaluiinfrastructure.test.opener.plugins;

import junit.framework.*;

import com.plumtree.openfoundation.mockobjects.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openfoundation.xml.dom.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.opener.plugins.*;
import com.plumtree.server.mock.core.MockPTSession;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.uiinfrastructure.web.*;

public class FriendlyURLPluginTest extends TestCase { 

	private XPDocument document = null;
	private String URIPattern = "portal/server.pt/";
	private String key = "community";
	private String classId = "512";
	private String m_searchFriendlyURLKey = "search";
	private String m_searchFriendlyURLClassId = "-25";
	private String m_rssFriendlyURLKey = "rss";
	private String m_rssFriendlyURLClassId = "-26";
	private String m_kdFriendlyURLKey = "directory";
	private String m_kdFriendlyURLClassId = "17";
	private RedirectData redirectData = null;
	private BaseOpenerAS asCurrentSpace = null;
	private MockPTSession userSession = null;
	
	/**
	 */
	public FriendlyURLPluginTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
		super.setUp();
		// DCA - set up config document
		document = new XPDocument();
		XPNode textNode = document.CreateTextNode(URIPattern);
		XPNode elemNode = document.CreateElement("DetectionPattern");
		elemNode.AppendChild(textNode);
		XPNode settingsNode = document.CreateElement("FriendlyURLSettings");
		settingsNode.AppendChild(elemNode);
		document.AppendChild(settingsNode);
		
		// DCA - set up mapping
		textNode = document.CreateTextNode(key);
		elemNode = document.CreateElement("key");
		elemNode.AppendChild(textNode);
		XPNode parentNode = document.CreateElement("FriendlyURLMapping");
		parentNode.AppendChild(elemNode);
		textNode = document.CreateTextNode(classId);
		elemNode = document.CreateElement("classId");
		elemNode.AppendChild(textNode);
		parentNode.AppendChild(elemNode);
		settingsNode.AppendChild(parentNode);
		
		// set up search url mapping
		textNode = document.CreateTextNode(m_searchFriendlyURLKey);
		elemNode = document.CreateElement("key");
		elemNode.AppendChild(textNode);
		XPNode parentNode2 = document.CreateElement("FriendlyURLMapping");
		parentNode2.AppendChild(elemNode);
		textNode = document.CreateTextNode(m_searchFriendlyURLClassId);
		elemNode = document.CreateElement("classId");
		elemNode.AppendChild(textNode);
		parentNode2.AppendChild(elemNode);
		settingsNode.AppendChild(parentNode2);
		
		// set up rss url mapping
		textNode = document.CreateTextNode(m_rssFriendlyURLKey);
		elemNode = document.CreateElement("key");
		elemNode.AppendChild(textNode);
		XPNode parentNode3 = document.CreateElement("FriendlyURLMapping");
		parentNode3.AppendChild(elemNode);
		textNode = document.CreateTextNode(m_rssFriendlyURLClassId);
		elemNode = document.CreateElement("classId");
		elemNode.AppendChild(textNode);
		parentNode3.AppendChild(elemNode);
		settingsNode.AppendChild(parentNode3);
		
		// set up rss url mapping
		textNode = document.CreateTextNode(m_kdFriendlyURLKey);
		elemNode = document.CreateElement("key");
		elemNode.AppendChild(textNode);
		XPNode parentNode4 = document.CreateElement("FriendlyURLMapping");
		parentNode4.AppendChild(elemNode);
		textNode = document.CreateTextNode(m_kdFriendlyURLClassId);
		elemNode = document.CreateElement("classId");
		elemNode.AppendChild(textNode);
		parentNode4.AppendChild(elemNode);
		settingsNode.AppendChild(parentNode4);
		
		IApplication application = new Application("","");
		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, new MockClassTypeDescManager());
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown()  
	{
		document = null;
		FriendlyURLPlugin.UnInit();
		redirectData = null;
		asCurrentSpace = null;
		userSession = null;
	}
	
   	public void testSetUpConfiguration() 
   	{
   		FriendlyURLPlugin.SetUpConfiguration(document);
   		FriendlyURLPlugin testObject = new FriendlyURLPlugin();
   		
   		String pattern = testObject.GetURIPattern();
   		Assert.assertEquals("URI pattern does not match what was set in the variable.", pattern, URIPattern);
   	}
   	
   	public void testProcessPlugIn() 
   	{
   		// DCA - need to call this to set up config
   		FriendlyURLPlugin.SetUpConfiguration(document);
   		FriendlyURLPlugin testObject = new FriendlyURLPlugin();
   		
   		redirectData = new RedirectData();
   		asCurrentSpace = new BaseOpenerAS();
   		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
   		asCurrentSpace.SetApplication(application);
	
		ConfigVarPack varPack;
		if (XPSystem.IsRunningInDotNet()) {
			varPack = new MockConfigVarPack(ConfigVarPack.APP_PLATFORM_DOT_NET);
		} else {
			varPack = new MockConfigVarPack(ConfigVarPack.APP_PLATFORM_JAVA);
		}
		asCurrentSpace.GetApplication().GetVarPackManager().AddVariablePackage(varPack);
		userSession = new MockPTSession();
		asCurrentSpace.SetUserSession(userSession);
		
		IXPRequest request = null;
		
		boolean failed = false;
   		try {
   			request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/community/");
   			asCurrentSpace.SetCurrentHTTPRequestResponseObjects(request, null);
   			testObject.ProcessPlugIn(redirectData, asCurrentSpace, userSession);
   		} catch (XPException e) {
   			failed = true;
   		}
   		Assert.assertTrue("Friendly URL w/o a community name should fail.", failed);
   		
   		failed = false;
   		try {
   			request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/fakeKey/my_community");
   			asCurrentSpace.SetCurrentHTTPRequestResponseObjects(request, null);
   			testObject.ProcessPlugIn(redirectData, asCurrentSpace, userSession);
   		} catch (XPException e) {
   			failed = true;
   		}
   		Assert.assertTrue("Friendly URL with a bad key should fail.", failed);
   		
   		request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/community/my_community");
		asCurrentSpace.SetCurrentHTTPRequestResponseObjects(request, null);
		testObject.ProcessPlugIn(redirectData, asCurrentSpace, userSession);

		// Test Search Friendly URL processing
   		failed = false;
   		try {
   			// Case 1: Missing query argument in friendly URL.
   			request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/search");
   			asCurrentSpace.SetCurrentHTTPRequestResponseObjects(request, null);
   			testObject.ProcessPlugIn(redirectData, asCurrentSpace, userSession);
   		} catch (XPException e) {
   			failed = true;
   		}
   		Assert.assertTrue("Search Friendly URL with missing query arg param should fail.", failed);

   		// Case 2: Minimum Friendly Search URL (with query arg) should pass.
   		// This should not throw any exceptions
   		request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/search");
		asCurrentSpace.SetCurrentHTTPRequestResponseObjects(request, null);
		redirectData = new RedirectData();
		redirectData.AddQSArgument("q", "*");
		testObject.ProcessPlugIn(redirectData, asCurrentSpace, userSession);
		
   		// Case 3: Minimum Friendly Search URL (with tagquery arg) should pass.
		// This should not throw any exceptions
   		request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/search");
		asCurrentSpace.SetCurrentHTTPRequestResponseObjects(request, null);
		redirectData = new RedirectData();
		redirectData.AddQSArgument("tag", "*");
		testObject.ProcessPlugIn(redirectData, asCurrentSpace, userSession);
   	}

   	public void testDirRESTAPIRedirect()
   	{
   		// DCA - need to call this to set up config
   		FriendlyURLPlugin.SetUpConfiguration(document);
   		FriendlyURLPlugin testObject = new FriendlyURLPlugin();

   		APIFriendlyURLParser parser = new APIFriendlyURLParser("api", FriendlyURLConstants.REST_API_ID_STRING,
   			new XPStringTokenizer("v1/kd/123", "/"));
   		RedirectData data = new RedirectData();
   		boolean bResult = testObject.HandleNonObjectFriendlyURLs(parser, data, new MockEnvironment());

   		Assert.assertTrue("Dir REST API URl should be handled.", bResult);

		Redirect result = data.GetRedirect();
		Assert.assertEquals("Dir REST API redirected to wrong space.", "Dir", result.GetSpaceName());
		Assert.assertEquals("Dir REST API redirected to wrong control.", "DirREST", result.GetControl());
		Assert.assertEquals("Dir REST API included wrong folder ID.", "123", result.GetControlArgument("folderID"));
   	}

   	public void testUserRESTAPIRedirect()
   	{
   		// DCA - need to call this to set up config
   		FriendlyURLPlugin.SetUpConfiguration(document);
   		FriendlyURLPlugin testObject = new FriendlyURLPlugin();

   		APIFriendlyURLParser parser = new APIFriendlyURLParser("api", FriendlyURLConstants.REST_API_ID_STRING,
   			new XPStringTokenizer("v1/user/current", "/"));
   		RedirectData data = new RedirectData();
   		boolean bResult = testObject.HandleNonObjectFriendlyURLs(parser, data, new MockEnvironment());

   		Assert.assertTrue("User REST API URl should be handled.", bResult);

		Redirect result = data.GetRedirect();
		Assert.assertEquals("User REST API redirected to wrong space.", "UserREST", result.GetSpaceName());
		Assert.assertEquals("User REST API redirected to wrong control.", "UserREST", result.GetControl());
		Assert.assertEquals("User REST API included wrong user ID.", "current", result.GetControlArgument("user"));
   	}
   	
   	// Test to check validity of Search Redirects after Search Friendly URL processing.
   	public void testSearchRedirect()
   	{
   		// DCA - need to call this to set up config
   		FriendlyURLPlugin.SetUpConfiguration(document);
   		FriendlyURLPlugin testObject = new FriendlyURLPlugin();
   		String strSearchBannerStartControl = "bannerstart";
   		String strSearchResultsSpaceName = "SearchResult";
   		String strQueryControlArgument = "in_tx_query";

   		// This is needed so that we have a parser to use when we can call HandleNonObjectFriendlyURLs to do the friendly 
   		// URL processing and test that the Search Redirects are good.
   		SearchFriendlyURLParser parser = new SearchFriendlyURLParser(m_searchFriendlyURLKey, m_searchFriendlyURLClassId, null);
   		RedirectData data = new RedirectData();

   		// Process a search query with friendly URL and validate redirect.
   		data.AddQSArgument("q", "*");
   		boolean bResult = testObject.HandleNonObjectFriendlyURLs(parser, data, new MockEnvironment());

   		Assert.assertTrue("Search URL should be handled.", bResult);

		Redirect result = data.GetRedirect();
		Assert.assertEquals("Search URL redirected to wrong control.", strSearchBannerStartControl, result.GetControl());
		Assert.assertEquals("Search URL redirected to wrong space.", strSearchResultsSpaceName, result.GetSpaceName());
		Assert.assertEquals("Search URL included wrong query term.", "*", result.GetControlArgument(strQueryControlArgument));	
   		
		// Test to see if a tag query type search redirects correctly.
   		data = new RedirectData();
   		data.AddQSArgument("tag", "*");
   		data.AddQSArgument("filter", "18");
   		bResult = testObject.HandleNonObjectFriendlyURLs(parser, data, new MockEnvironment());

   		Assert.assertTrue("Search URL should be handled.", bResult);

		result = data.GetRedirect();
		Assert.assertEquals("Search URL redirected to wrong control.", strSearchBannerStartControl, result.GetControl());
		Assert.assertEquals("Search URL redirected to wrong space.", strSearchResultsSpaceName, result.GetSpaceName());
		Assert.assertEquals("Search URL included wrong query term.", "tag:*", result.GetControlArgument(strQueryControlArgument));
   	}
   	
   	// Test to check validity of RSS KD/Search Redirects after RSS Friendly URL processing.
   	public void testRSSRedirect()
   	{
   		// DCA - need to call this to set up config
   		FriendlyURLPlugin.SetUpConfiguration(document);
   		FriendlyURLPlugin testObject = new FriendlyURLPlugin();

   		String strSearchBannerStartControl = "bannerstart";
   		String strSearchResultsSpaceName = "SearchResult";
   		String strQueryControlArgument = "in_tx_query";

   		// This is needed so that we have a parser to use when we can call HandleNonObjectFriendlyURLs to do the friendly 
   		// URL processing and test that the Search Redirects are good.
   		RSSFriendlyURLParser parser = new RSSFriendlyURLParser(m_rssFriendlyURLKey, m_rssFriendlyURLClassId,
   				new XPStringTokenizer("searchresults/search", "/"));
   		RedirectData data = new RedirectData();

   		// Process a search query with friendly URL and validate redirect.
   		data.AddQSArgument("q", "*");
   		boolean bResult = testObject.HandleNonObjectFriendlyURLs(parser, data, new MockEnvironment());

   		Assert.assertTrue("Search URL should be handled.", bResult);

		Redirect result = data.GetRedirect();
		Assert.assertEquals("Search URL redirected to wrong control.", strSearchBannerStartControl, result.GetControl());
		Assert.assertEquals("Search URL redirected to wrong space.", strSearchResultsSpaceName, result.GetSpaceName());
		Assert.assertEquals("Search URL included wrong query term.", "*", result.GetControlArgument(strQueryControlArgument));	
   		
		// Process a KD browse with friendly URL and validate redirect.
		parser = new RSSFriendlyURLParser(m_rssFriendlyURLKey, m_rssFriendlyURLClassId,
   				new XPStringTokenizer("kd/directory/object_name/200", "/"));
   		data = new RedirectData();
   		
   		bResult = testObject.HandleNonObjectFriendlyURLs(parser, data, new MockEnvironment());

   		Assert.assertFalse("KD URL shouldn't be handled.", bResult);
   		
   		// TODO: Process a KD browse with non-friendly URL, but due to below we cannot test this case here.
   		// TODO: We can't seem to create an XPRequest with a different URL - the helper
   		// functions blow up.  So we can't do anything other than a localhost url.
   		//
   		// bResult = testObject.HandleNonObjectFriendlyURLs(parser, data, new MockEnvironment());
   		// RedirectData newRedirect = testObject.ProcessPlugIn(new RedirectData(), new MockEnvironment(), new MockPTSession());
   	}
}