/**
 * 
 */
package com.plumtree.portaluiinfrastructure.test.pathways.tagging;

import com.plumtree.openfoundation.util.XPConvert;
import com.plumtree.openfoundation.util.XPHashtable;
import com.plumtree.portaluiinfrastructure.mock.pathways.tagging.MockTaggingModel;
import com.plumtree.portaluiinfrastructure.pathways.tagging.TaggingControl;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysConstants;


import junit.framework.TestCase;

/**
 * @author Ravi Tunuguntla
 *
 */
public class TaggingControlTest extends TestCase {

	/*
	 * Tests Adding the tag and verifying if the Tag is added successfully.
	 */
	public void testAddTag(){
		TaggingControl control = new TaggingControl();
		MockTaggingModel model = new MockTaggingModel();
		control.Init(model, null);
		
		// Adding Tagging Control Args for Processing
		
		XPHashtable controlArgs = new XPHashtable();
		
		controlArgs.PutElement(TaggingControl.QS_ACTION, new String[]{XPConvert.ToString(TaggingControl.ACTION_ADD_TAG)});
		controlArgs.PutElement(TaggingControl.QS_TAG, new String[]{"test tag"});
		controlArgs.PutElement(TaggingControl.QS_OBJECTID, new String[]{"18_999"});
		controlArgs.PutElement(TaggingControl.QS_SOURCE, new String[]{PathwaysConstants.PTSOURCE_PORTAL});
		control.CheckActionSecurityAndExecute(controlArgs);
		
		assertTrue("Adding Tag should be successful", model.m_bTagged);
		

	}
	
	/*
	 * Tests Adding the tag and verifying if the Tag is Removed successfully.
	 */
	public void testRemoveTag(){
		TaggingControl control = new TaggingControl();
		MockTaggingModel model = new MockTaggingModel();
		control.Init(model, null);
		
		// Adding Tagging Control Args for Processing
		
		XPHashtable controlArgs = new XPHashtable();
		
		controlArgs.PutElement(TaggingControl.QS_ACTION, new String[]{XPConvert.ToString(TaggingControl.ACTION_DELETE_TAG)});
		controlArgs.PutElement(TaggingControl.QS_TAG, new String[]{"test tag"});
		controlArgs.PutElement(TaggingControl.QS_OBJECTID, new String[]{"18_999"});
		controlArgs.PutElement(TaggingControl.QS_SOURCE, new String[]{PathwaysConstants.PTSOURCE_PORTAL});
		control.CheckActionSecurityAndExecute(controlArgs);
		
		assertTrue("Removing Tag should be successful", model.m_bUnTagged);
		
	}		

	/*
	 * Tests Renaming the tag and verifying if the old tag has been renamed to the new tag successfully.
	 */
	public void testRenameTag(){
		TaggingControl control = new TaggingControl();
		MockTaggingModel model = new MockTaggingModel();
		control.Init(model, null);
		
		// Adding Tagging Control Args for Processing
		
		XPHashtable controlArgs = new XPHashtable();
		
		controlArgs.PutElement(TaggingControl.QS_ACTION, new String[]{XPConvert.ToString(TaggingControl.ACTION_RENAME_TAG)});
		controlArgs.PutElement(TaggingControl.QS_TAG, new String[]{"originalTag"});
		controlArgs.PutElement(TaggingControl.QS_OBJECTID, new String[]{"18_999"});
		controlArgs.PutElement(TaggingControl.QS_SOURCE, new String[]{PathwaysConstants.PTSOURCE_PORTAL});
		controlArgs.PutElement(TaggingControl.QS_RENAME_TAG, new String[]{"renamedTag"});
		control.CheckActionSecurityAndExecute(controlArgs);
		
		assertTrue("Renaming Tag should be successful", model.m_bTagged);
	}
}
