package com.plumtree.portaluiinfrastructure.test.search;

import junit.framework.TestCase;

import com.plumtree.openfoundation.util.XPHashtable;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockConfigVarPack;
import com.plumtree.portaluiinfrastructure.mock.helper.MockPathwaysHelperService;
import com.plumtree.portaluiinfrastructure.mock.restconsumerframework.pathways.MockPathwaysRestAPIService;
import com.plumtree.portaluiinfrastructure.mock.tags.MockEnvironment;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysRestAPIService;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.search.pathways.PathwaysSearchResponse;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.web.IApplication;

public class SearchResultModelTest extends TestCase {
	
	protected MockPTSession ptSession;
	protected MockPTSessionInfo ptSessionInfo;
	protected AActivitySpace space;
	//protected IApplication application = null;
	protected MockInternalSession internalSession = null;
	protected MockPTServerConfigSettings serverConfigSettings = null;
	protected MockPathwaysHelperService mp_helper = null;
	IPTFilter advancedFilter = null;
	SearchSettingCollection settings = null;

	protected SearchResultModel srModel = null;
	protected String basicFields = null;
	protected MockPathwaysRestAPIService mp_RestService = null;
	int PathwaysWebID = 0;
	boolean isPathwaysInstalled = false;
	protected MockConfigVarPack m_varPack = null;
	
	protected static String searchTermOne = "test";
	protected static String searchTermTwo = "blah";
	public static final String APP_PLATFORM_JAVA = "Java";	
	protected static String configVPID = "ConfigVarPack";
	public static final String FRIENDLY_CONTROL = "control";
	String []setBannerSearch = new String[]{SearchResultModel.BANNER_SEARCH_CONTROL};
	String []setAdvancedSearch = new String[]{SearchResultModel.ADVANCED_SEARCH_CONTROL};
	
	public static final String testURL = "http://LMAH-test.fakenetwork.com/portal/server.pt?open=18&amp;objID=270&amp;mode=2&amp;in_hi_userid=1";
	public static final String USER_NAME = "testuser";
	public static final String RESPONSE_TYPE = "PTPORTLET";
	 
	XPHashtable tempFormData = new XPHashtable();
	PathwaysSearchResponse testResponse = null;

	public void setUp() throws Exception {
		space = new MockEnvironment();		
		ptSession = (MockPTSession)space.GetUserSession();
		ptSessionInfo = (MockPTSessionInfo)ptSession.GetSessionInfo();
		internalSession =  (MockInternalSession)ptSession.GetInternalSession();
   		((MockPTSessionInfo) ptSession.GetSessionInfo()).m_LoginName = USER_NAME;

		srModel = new SearchResultModel();
		srModel.Init(space);
		PathwaysRestAPIService.setTestInstance(new MockPathwaysRestAPIService());
		mp_RestService = (MockPathwaysRestAPIService)PathwaysRestAPIService.GetInstance(space);
		serverConfigSettings = (MockPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, true);
		settings = new SearchSettingCollection();

	}

	public void tearDown() throws Exception {
		ptSession = null;
		ptSessionInfo = null;
		space = null;
	}
	
	//rename
	public void testBannerPathwaysSearchResult()
	{
		/*
		 * Set up of the search settings 
		 */
		int pageSize = 10;
		//setting search collection - taken from BannerStartSearchControl.GetCustomSearchSettings
		settings = new SearchSettingCollection();

		// Banner search always uses BestBets, spellchecking, and thesaurus
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, Boolean.TRUE);
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK, Boolean.TRUE);
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS, Boolean.TRUE);

		// Banner search does not bring back header, footer, or canvas portlets;
		// restricting GADGET_SEARCH_TYPE to "bannersearch" accomplishes this
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE,
			     SearchSettingCollection.GADGET_SEARCH_TYPE_BANNERSEARCH);

		// Set the user's page size.
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, new Integer(pageSize));
		//set the LIMITBYLOCALE setting
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE, new Boolean(false));
		
		//setting up mock search variables to run unit test.  
		//form data contains the search control that the user would have executed in the portal, setting
		//for banner search first.
		tempFormData.PutElement(SearchResultModel.FRIENDLY_CONTROL, setBannerSearch);
		space.SetCurrentFormData(tempFormData);
		
		//setting the mock pathways search data, this is where it initializes the data to be returned in the response
		mp_RestService.SetPathwaysSearchData();
	
		//executing banner search
		srModel.SetPageMode("browse");
		srModel.Search(searchTermOne, basicFields, advancedFilter, settings);
		//testing to make sure pathways search executed
		assertTrue("This search should be a pathways search.", srModel.IsPathwaysSearch());
		assertTrue("This search should be a pathways enabled banner search.", !srModel.isAdvancedSearch());

		//testing to make sure we got search results returned
		testResponse = (PathwaysSearchResponse)srModel.GetSearchResponseForUnitTest();	
		int length1 = testResponse.GetTotalMatches();		
		assertTrue("Pathways search response should have contained a value.", (length1 != 0));
		//verifying that the response data returned is the mock data, testing the url value of the first
		//response to see if it matches a hardcoded url I put here as a constant, it shouldn't.
		String urlToTest = testResponse.GetFieldsAsString(0, PT_INTRINSICS.PT_PROPERTY_DOCUMENTURL);
		assertTrue("Pathways should have received the mock data correctly.", (!testURL.equals(urlToTest)));
		
		//testing for advanced search now
		tempFormData.PutElement(SearchResultModel.FRIENDLY_CONTROL, setAdvancedSearch);
		space.SetCurrentFormData(tempFormData);
		//adding search objects of documents to this list
		int []searchObjTypes = new int[]{17, 43, 36};
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, searchObjTypes);

		//setting search term in advanced filter
		advancedFilter = PortalObjectsFactory.CreateSearchFilter();
		advancedFilter.SetSearchString(searchTermTwo);

		//executing search
		srModel.Search(null, basicFields, advancedFilter, settings);
		assertTrue("This search should be a pathways enabled search.", srModel.IsPathwaysSearch());
		assertTrue("This search should be a pathways enabled advanced search.", srModel.isAdvancedSearch());
		
		//we will use the same test response as it doesn't really matter
		testResponse = (PathwaysSearchResponse)srModel.GetSearchResponseForUnitTest();	
		int advLength = testResponse.GetTotalMatches();		
		assertTrue("Pathways search response should have contained a value.", (advLength != 0));
		
		//This code should be used for testing legacy search, however, none of the legacy search stuff is mocked out
		//and until I decide to do that, I will skip that test and focus on the pathways integrated unit tests for now.
		
/*		//disabling pathways and testing that legacy works too, this is by passing in an invalid pathways search
		settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE, true);
		
		//executing Legacy search
		srModel.Search(null, basicFields, advancedFilter, settings);
		assertTrue("This search should be a legacy search.", !srModel.isPathwaysSearch());
		assertTrue("This search should be an advanced search.", srModel.isAdvancedSearch());
*/	
		
	}

}
