package com.plumtree.portaluiinfrastructure.test.tags;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This abstract tag class provides various helper
 * methods useful for testing.
 */
public abstract class ATestTag extends ATag
{
	protected HTMLElement m_displayHTML = null;
	protected HTMLScriptCollection m_sharedJavascript = null;
	protected boolean m_bSupportAllAccessStyles = false;
	protected TagType m_tagType = TagType.SIMPLE;

	/**
	 * Helper method to set HTML for this tag to display.
	 * @param _displayHTML
	 */
	public void SetDisplayHTML(HTMLElement _displayHTML)
	{
		m_displayHTML = _displayHTML;
	}

	/**
	 * Helper method to set shared javascript for this tag to display.
	 * @param _collection
	 */
	public void SetSharedJavaScript(HTMLScriptCollection _collection)
	{
		m_sharedJavascript = _collection;
	}

	/**
	 * Helper method to set whether or not to support all access styles.
	 * @param _bSupportAll
	 */
	public void SetSupportAllAccessStyles(boolean _bSupportAll)
	{
		m_bSupportAllAccessStyles = _bSupportAll;
	}

	/**
	 * Helper method to set the tag type.
	 * @param __type
	 */
	public void SetTagType(TagType _type)
	{
		m_tagType = _type;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		return m_displayHTML;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()
	 */
	public HTMLScriptCollection DisplaySharedJavascript()
	{
		// Display the specified shared javascript.
		return m_sharedJavascript;
	}

	/** Override ATag implementation. */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		if (m_bSupportAllAccessStyles)
		{
			// This tag supports all styles.
			return true;
		}

		// Support only Standard style.
		return super.SupportsAccessStyle(_style);
	}

	/** Override ATag method. */
	public TagType GetTagType()
	{
		return m_tagType;
	}

	abstract public ATag Create();
}