package com.plumtree.portaluiinfrastructure.test.tags.displaytree;

import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.server.*;

import junit.framework.*;

/**
 * Test for the display tree classes.
 * 
 * @author donh
 */
public class DisplayTreeTest extends TestCase
{
	/**
	 * Constructor.
	 */
	public DisplayTreeTest(String name)
	{
		super(name);
	}

	/**
	 * This tests building the display tree from
	 * Markup data.
	 */
	public static void testBuildDisplayTree()
	{
		// Can't put this directly as an argument because of jump issues.
		Object[][] objArrMarkup = new Object[2][6];

		/**
		 * HTML Fragment
		 */
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][0] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0] = "<span>";

		/**
		 * Singleton PT Tag
		 */
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][1] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML);

		// Can't put this directly as an argument because of jump issues.
		Object[][] singletonTagObjXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE) },
			{ "testtagname", "testintattr", null },
			{ null, "57", null} };

		// Add a singleton tag
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][1] = singletonTagObjXML;

		/**
		 * HTML Fragment
		 */
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][2] = new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][2] = "</span>";

		/**
		 * Nested Open PT Tag
		 */
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][3] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML);

		// Can't put this directly as an argument because of jump issues.
		Object[][] nestedOpenTagObjXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT) },
			{ "testnestedtagname", "testintattr" },
			{ null, "57"} };

		// Add a nested open tag
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][3] = nestedOpenTagObjXML;

		/**
		 * HTML Fragment
		 */
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][4] = new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][4] = "nested test data";

		/**
		 * Nested Close PT Tag
		 */
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][5] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML);

		// Can't put this directly as an argument because of jump issues.
		Object[][] nestedCloseTagObjXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE) },
			{ "testnestedtagname" },
			{ null } };

		// Add a nested close tag
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][5] = nestedCloseTagObjXML;

		/**
		 * Parse the XML into a tree
		 */
		IDisplayElement tree = DisplayTree.BuildDisplayTree(objArrMarkup);

		assertNotNull("Parsing Markup array into tag display tree.", tree);

		/**
		 * Introduce an error
		 */
		// TODO: This is a bad error that doesn't prove anything.  Should we
		// even be testing for errors if they're not part of an API?
		// We should probably put in bad data and test that it still doesn't fail.
		// Null out the objXML for a tag
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][5] = null;

		boolean bFailed = false;

		/**
		 * Parse the XML into a tree
		 */
		try
		{
			// Parse the bad XML into a tree
			tree = DisplayTree.BuildDisplayTree(objArrMarkup);
		} catch (Exception e)
		{
			// Expected exception
			bFailed = true;
		}

		assertTrue("Parsing invalid markup array should fail.", bFailed);
	}
}
