package com.plumtree.portaluiinfrastructure.test.tags.features;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.portaluiinfrastructure.test.tags.*;
import com.plumtree.server.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Test for the Attribute Value Replacement feature.
 * 
 * I.E.  $var and $data.var in tag attributes.
 * 
 * This uses the TagHelper and TagState, so it is in a
 * separate class from both.
 * 
 * @author DonH
 */

public class AttributeValueReplacementTest extends TestCase
{
	public static final String XHTML_ATTRIBUTE = "testxhtmlattr";
	public static final String STRING_VALUE = "test value";
	public static final int INT_VALUE = 456;

	protected TestTag m_TestTag;

	/**
	 * Constructor.
	 */
	public AttributeValueReplacementTest(String name)
	{
		super(name);

		// Initialize the meta data for the test tags.
		// This is normally done by the TagLibManager.

		m_TestTag = new TestTag();
		TagMetaDataHelper testMetaDataHelper = new TagMetaDataHelper();
		testMetaDataHelper.Init(m_TestTag,
			new TagLibraryMetaData("Test Tag Library",
			"testtaglibrary", "Test tag library description", 1.0));
		m_TestTag.SetTagMetaDataHelper(testMetaDataHelper);
	}

	/**
	 * This tests attribute value replacement (I.E. converting
	 * $var and $data.var in attributes to their respective
	 * variable values).
	 */
	public void testTagAttributeValueReplacement()
	{
		// Can't put this directly as an argument because of jump issues.
		Object[][] objXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_XHTML_ATT) },
			{ TestTag.TESTATTRIBUTE.GetName(), TestTag.TESTINTATTRIBUTE.GetName(), XHTML_ATTRIBUTE },
			{ "$var", "$data.var" , "$var"} };

		ATag tag = GetNewTestTagInstance();

		TagHelper helper = new TagHelper(objXML, null, tag);

		TagState state = new TagState(null, null, null, new XPHashtable());

		TagVisitor visitor = new TagVisitor(state, null, new HTMLElementCollection());

		helper.SetTagVisitor(visitor);

		state.EnterTag(tag);

		// Set variables on state
		// We have to make sure to set our variables in tag
		// or portlet request scope (non-shared), otherwise
		// Tag State will throw a null pointer exception when
		// it searches for the variables in the session, which
		// we did not provide.

		state.SetVariable("var", STRING_VALUE, Scope.PORTLET_REQUEST);

		String strTest;

		// Test $var replacement in a PT attribute (pt:attr)
		strTest = helper.GetAttributeAsString(TestTag.TESTATTRIBUTE);
		Assert.assertEquals("Getting replaced value for test pt attribute $var.", STRING_VALUE, strTest);

		// Test $var replacement in an XHTML attribute (attr)
		strTest = helper.GetXMLAttribute(XHTML_ATTRIBUTE);
		Assert.assertEquals("Getting replaced value for test xhtml attribute $var.", STRING_VALUE, strTest);

		// Set up the data object
		HashtableDataObject dataSet = new HashtableDataObject();

		XPHashtable dataSetHashtable = dataSet.GetHashTable();
		dataSetHashtable.PutElement("var", XPConvert.ToString(INT_VALUE));

		// Store the data collection
		state.SetVariable("data", dataSet, Scope.PORTLET_REQUEST);

		int nTest;

		// Test $data.var replacement
		nTest = helper.GetAttributeAsInt(TestTag.TESTINTATTRIBUTE);
		Assert.assertEquals("Getting replaced value for test attribute $data.var.", INT_VALUE, nTest);

		state.ExitTag();

		helper.ReleaseTagVisitor();
	}

	/**
	 * This helper method creates and initializes a new TestTag instance.
	 * This would normally be handled by the TagLibManager.
	 * 
	 * @return  A new TestTag instance.
	 */
	public TestTag GetNewTestTagInstance()
	{
		TestTag result = new TestTag();
		result.SetTagMetaDataHelper(m_TestTag.GetTagMetaDataHelper());

		return result;
	}
}
