package com.plumtree.portaluiinfrastructure.test.tags.features;

import junit.framework.*;

import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.portaluiinfrastructure.test.tags.*;
import com.plumtree.server.*;

/**
 * Tests the Tag Context Validation framework.
 * 
 * @author donh
 */
public class TagContextValidationTest extends TestCase
{
	protected TestTag m_TestTag;

	/**
	 * Constructor.
	 */
	public TagContextValidationTest(String name)
	{
		super(name);

		// Initialize the meta data for the test tags.
		// This is normally done by the TagLibManager.

		m_TestTag = new TestTag();
		TagMetaDataHelper testMetaDataHelper = new TagMetaDataHelper();
		testMetaDataHelper.Init(m_TestTag,
			new TagLibraryMetaData("Test Tag Library",
			"testtaglibrary", "Test tag library description", 1.0));
		m_TestTag.SetTagMetaDataHelper(testMetaDataHelper);
	}

	/**
	 * This tests required attribute validation failure.
	 */
	public void testRequiredAttributeValidationFailure()
	{
		// Can't put this directly as an argument because of jump issues.
		Object[][] missingObjXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT) },
			{ "testintattr", "testbadintattr" },
			{ "1" , "garbageint" } };

		TagHelper helper = new TagHelper(missingObjXML,
			null, GetNewTestTagInstance());

		Assert.assertNotNull("Context validation for TestTag missing a required attribute should fail.", helper.ValidateRequiredAttributes());

		// Can't put this directly as an argument because of jump issues.
		Object[][] badObjXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT) },
			{ "testreqintattr", "testattr", "testbadintattr" },
			{ "fail", "1" , "garbageint" } };

		helper = new TagHelper(badObjXML,
			null, GetNewTestTagInstance());

		Assert.assertNotNull("Context validation for TestTag with an invalid required attribute should fail.", helper.ValidateRequiredAttributes());
	}

	/**
	 * This tests required attribute validation success.
	 */
	public void testRequiredAttributeValidationSuccess()
	{
		// Can't put this directly as an argument because of jump issues.
		Object[][] objXML = {
			{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT) },
			{ "testattr", "testreqintattr", "testbadintattr" },
			{ "test", "1" , "garbageint" } };

		TagHelper helper = new TagHelper(objXML,
			null, GetNewTestTagInstance());

		Assert.assertNull("Context validation for TestTag should succeed.", helper.ValidateRequiredAttributes());
	}

	/**
	 * This helper method creates and initializes a new TestTag instance.
	 * This would normally be handled by the TagLibManager.
	 * 
	 * @return  A new TestTag instance.
	 */
	protected TestTag GetNewTestTagInstance()
	{
		TestTag result = new TestTag();
		result.SetTagMetaDataHelper(m_TestTag.GetTagMetaDataHelper());

		return result;
	}
}
