package com.plumtree.portaluiinfrastructure.test.tags.helper;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.portaluiinfrastructure.test.tags.*;

import junit.framework.*;

/**
 * Test for the TagMetaDataHelper class.
 * 
 * @author DonH
 */
public class TagMetaDataHelperTest extends TestCase
{
	/**
	 * Constructor.
	 */
	public TagMetaDataHelperTest(String name)
	{
		super(name);
	}

	/**
	 * This tests the error handling for invalid meta data.
	 */
	public static void testTagMetaDataErrorHandling()
	{
		// Test a tag with missing meta data
		ATag testBadTag = new BadMetaDataTag();
		TagMetaDataHelper testMetaDataHelper = new TagMetaDataHelper();

		Assert.assertFalse("Initializing BadMetaDataTag with invalid meta data.",
			testMetaDataHelper.Init(testBadTag, new TagLibraryMetaData("testlib", "Test Library", "Test library description.", 1.0)));
	}

	/**
	 * This tests that the correct meta data is loaded.
	 */
	public static void testValidTagMetaData()
	{
		// Test a tag with functional meta data
		ATag testTag = new TestTag();
		TagMetaDataHelper testTagHelper = new TagMetaDataHelper();

		Assert.assertTrue("Initializing TestTag meta data.",
		testTagHelper.Init(testTag, new TagLibraryMetaData("testlib", "Test Library", "Test library description.", 1.0)));

		// Check Tag meta data
		Assert.assertEquals("Getting Tag meta data for TestTag.",
			TestTag.TAG, testTagHelper.GetTagMetaData());

		// Check RequiredTagAttributes
		RequiredTagAttribute[] testRequiredTagAttributes = testTagHelper.GetRequiredTagAttributes();

		Object[] actualRequiredTagAttributes = new Object[] { TestTag.TESTATTRIBUTE, TestTag.TESTREQINTATTRIBUTE };

		Assert.assertEquals("Checking number of RequiredTagAttributes.",
			actualRequiredTagAttributes.length, testRequiredTagAttributes.length);

		Assert.assertEquals("Checking for number of maches between calculated RequiredTagAttributes and actual RequiredTagAttributes.",
			actualRequiredTagAttributes.length, GetNumberOfMatches(testRequiredTagAttributes, actualRequiredTagAttributes));

		// Check OptionalTagAttributes
		OptionalTagAttribute[] testOptionalTagAttributes = testTagHelper.GetOptionalTagAttributes();

		Object[] actualOptionalTagAttributes = new Object[] { TestTag.TEST2ATTRIBUTE,
			TestTag.TESTBADINTATTRIBUTE, TestTag.TESTINT2ATTRIBUTE, TestTag.TESTINTATTRIBUTE };

		Assert.assertEquals("Checking number of OptionalTagAttributes.",
			actualOptionalTagAttributes.length, testOptionalTagAttributes.length);

		Assert.assertEquals("Checking for number of maches between calculated OptionalTagAttributes and actual OptionalTagAttributes.",
			actualOptionalTagAttributes.length, GetNumberOfMatches(testOptionalTagAttributes, actualOptionalTagAttributes));

		// Check RequiredParentTag -- pointing to itself currently
		Assert.assertEquals("Getting number of RequiredParentTags for TestTag.",
			2, testTagHelper.GetRequiredParentTags().length);
		Assert.assertEquals("Getting first RequiredParentTag meta data for TestTag.",
			TestTag.TAG, testTagHelper.GetRequiredParentTags()[0]);
		Assert.assertEquals("Getting second RequiredParentTag meta data for TestTag.",
			TestTag.TAG, testTagHelper.GetRequiredParentTags()[0]);

		// CheckRequiredChildTags
		ITagMetaData[] testRequiredTagChildren = testTagHelper.GetRequiredChildTags();

		Object[] actualRequiredTagChildren = new Object[]
			{ TestTag.REQUIRED_CHILDREN_FOR_TEST[0], TestTag.REQUIRED_CHILDREN_FOR_TEST[1] };

		Assert.assertEquals("Checking number of RequiredChildTags.",
			actualRequiredTagChildren.length, testRequiredTagChildren.length);

		Assert.assertEquals("Checking for number of maches between calculated RequiredChildTags and actual RequiredChildTags.",
			actualRequiredTagChildren.length, GetNumberOfMatches(testRequiredTagChildren, actualRequiredTagChildren));
	}

	/**
	 * This helper method calculates the number of object == matches between two arrays.
	 * 
	 * @param _firstArray The first array.
	 * @param _secondArray The second array.
	 * @return int The number of matches.
	 */
	protected static int GetNumberOfMatches(Object[] _firstArray, Object[] _secondArray)
	{
		int nMatches = 0;

		for (int i = 0; i < _firstArray.length; i++)
		{
			for (int j = 0; j < _secondArray.length; j++)
			{
				if (_firstArray[i] == _secondArray[j])
				{
					nMatches++;
					break;
				}
			}
		}

		return nMatches;
	}
}
