/**
 * 
 */
package com.plumtree.portaluiinfrastructure.utils;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.utils.*;

/**
 * This unit test tests uiinfrastructure class but it is put in portaluiinfrastructure since
 * uiinfrastructure project doesn't contain any test infrastructure.
 * 
 * @author rozhang
 *
 */
public class JavascriptParserTest extends TestCase
{
	
	/**
	 * Tests the different member variable types
	 * 
	 */
	public void testObjectMemberValueTypes()
	{
		String strDocumentJSON = "{strval: \"value1\" , intval: 5555, boolval :false }";

		JavascriptParser parser = new JavascriptParser();
		parser.ParseJSString(strDocumentJSON);
		
		XPHashtable obj = (XPHashtable)parser.GetRootObject();;
		assertEquals("Parsed string object member value was incorrect.", "value1", (String)obj.GetElement("strval"));
		assertEquals("Parsed numeric object value was incorrect.", new Integer(5555), (Integer)obj.GetElement("intval"));
		assertEquals("Parsed boolean object value was incorrect.", new Boolean(false), (Boolean)obj.GetElement("boolval"));
		
	}
	
	/**
	 * Tests nested objects
	 * 
	 */
	public void testNestedObjects()
	{
		String strDocumentJSON = "{objval1: { nestedvalue1: 'aa', nestedvalue2: 'bb'} ,objval2: { nestedobjval: '' }}";

		JavascriptParser parser = new JavascriptParser();
		parser.ParseJSString(strDocumentJSON);
		
		XPHashtable obj = (XPHashtable)parser.GetRootObject();
		
		assertNotNull("No root object found in parsed Javascript.", obj);
		
		XPHashtable objval1 = (XPHashtable)obj.GetElement("objval1");
		XPHashtable objval2 = (XPHashtable)obj.GetElement("objval2");
		
		assertNotNull("Parsed objval1 Object was not found.", objval1);
		assertNotNull("Parsed objval2 Object was not found.", objval2);
		
		assertEquals("Parsed string object member value was incorrect.", "aa", (String)objval1.GetElement("nestedvalue1"));
		assertEquals("Parsed string object member value was incorrect.", "bb", (String)objval1.GetElement("nestedvalue2"));
		assertEquals("Parsed string object member value was incorrect.", "", (String)objval2.GetElement("nestedobjval"));
	}
	
	public void testArrays()
	{
		String strDocumentJSON = "{ numarray: [2,33,444,5555], stringarray: ['a', 'b', 'c'], boolarray: [true, false, true] }";
		
		JavascriptParser parser = new JavascriptParser();
		parser.ParseJSString(strDocumentJSON);
		
		XPHashtable obj = (XPHashtable)parser.GetRootObject();
		assertNotNull("No root object found in parsed Javascript.", obj);
		
		XPArrayList numList = (XPArrayList)obj.GetElement("numarray");
		XPArrayList stringList = (XPArrayList)obj.GetElement("stringarray");
		XPArrayList boolList = (XPArrayList)obj.GetElement("boolarray");
		
		assertNotNull("Parsed numList Object was not found.", numList);
		assertNotNull("Parsed stringList Object was not found.", stringList);
		assertNotNull("Parsed boolList Object was not found.", boolList);
		// num array
		assertEquals("Parsed numeric array value value was incorrect.", new Integer(2), numList.GetElement(0));
		assertEquals("Parsed numeric array value value was incorrect.", new Integer(33), numList.GetElement(1));
		assertEquals("Parsed numeric array value value was incorrect.", new Integer(444), numList.GetElement(2));
		assertEquals("Parsed numeric array value value was incorrect.", new Integer(5555), numList.GetElement(3));
		// string array
		assertEquals("Parsed string array value value was incorrect.", "a", stringList.GetElement(0));
		assertEquals("Parsed string array value value was incorrect.", "b", stringList.GetElement(1));
		assertEquals("Parsed string array value value was incorrect.", "c", stringList.GetElement(2));
		// bool array
		assertEquals("Parsed bool array value value was incorrect.", new Boolean(true), boolList.GetElement(0));
		assertEquals("Parsed bool array value value was incorrect.", new Boolean(false), boolList.GetElement(1));
		assertEquals("Parsed bool array value value was incorrect.", new Boolean(true), boolList.GetElement(2));
	}
	
	/**
	 * Tests objects in arrays
	 * 
	 */
	public void testObjectsInArrays()
	{
		String strDocumentJSON = "[{green1: 'green1', green2:'green2'}, {red: 0}, {blue1:true}]";
		
		JavascriptParser parser = new JavascriptParser();
		parser.ParseJSString(strDocumentJSON);
		XPArrayList objList = (XPArrayList)parser.GetRootArray();
		
		assertEquals("Parsed string object member value was incorrect.", "green1", ((XPHashtable)objList.GetElement(0)).GetElement("green1"));
		assertEquals("Parsed numeric object value was incorrect.", new Integer(0), ((XPHashtable)objList.GetElement(1)).GetElement("red"));
		assertEquals("Parsed boolean object value was incorrect.", new Boolean(true), ((XPHashtable)objList.GetElement(2)).GetElement("blue1"));
		
	}
}
