/**
 * 
 */
package com.plumtree.portaluiinfrastructure.utils;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class TagTestHelper
{
	/**
	 * Sets up mock environment for tag unit tests 
	 * @return
	 */
	public static MockEnvironment SetupTagTestEnvironment()
	{
		IApplication mockApp = new Application("","");
		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), mockApp);
		MockConfigHelper mockConfig = new MockConfigHelper();
		ConfigService.setTestInstance(mockConfig);
		MockPTConfigHelper mockPTConfig = new MockPTConfigHelper();
		mockPTConfig.m_bUseAllFriendlyURLs = true;
		PTConfigService.setTestPTInstance(mockPTConfig);
		MockClassTypeDescManager classTypeMgr = new MockClassTypeDescManager();
		mockPTConfig.m_classTypeManager = classTypeMgr;
		
		MockEnvironment env = new MockEnvironment();
		mockPTConfig.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION, PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
		return env;
		
	}
	

	/**
	 * Call this before running a tag to setup a mock tag state instance where tag variables are set
	 * @return
	 */
	public static TagStateTestHelper GetMockTagStateInstance()
	{
		TagStateTestHelper state = new TagStateTestHelper();
		return state;
	}
	
	/**
	 * Registers a single tag for use in unit tests.
	 * NOTE don't call this method repeatedly to create multiple tags in same taglib!
	 * Use the CreateTestTags method to create multiple tags in same taglib
	 *  
	 * @param libName
	 * @param tagName
	 * @param tagInstance
	 */
	public static void CreateTestTag(String libName, String tagName, ATag tagInstance)
	{
		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(tagInstance, tagName, libName);
		TagLibManager.setTestInstance(tagLibs);
	}
	
	/**
	 * Registers multiple tags for use in unit tests.
	 *  
	 * @param libName
	 * @param tagName
	 * @param tagInstance
	 */
	public static void CreateTestTags(String libName, String[] tagName, ATag[] tagInstance)
	{
		MockTagLibManager tagLib = new MockTagLibManager();
		for ( int i = 0; i < tagName.length; i++ ) {
			tagLib.SetTag(tagInstance[i], tagName[i], libName);
			TagLibManager.setTestInstance(tagLib);
		}
	}
	
	/**
	 * Executes a single tag without nested child tags in a portlet request context. Note that multiple calls to this method will run
	 * in separate portlet request contexts
	 * 
	 * @param tagAttribNames   Names of the attributes passed to the tag (index of entries must match up with the tagAttribValues list  
	 * @param tagAttribValues  Values of the attributes passed to the tag (index of entries must match up with the tagAttribNames list
	 * @return
	 */
	public static HTMLElement RunSingleTag(String tagLibName, String tagName, XPArrayList tagAttribNames, XPArrayList tagAttribValues, MockEnvironment env)
	{
		return RunSingleTag(tagLibName, tagName, (String[])tagAttribNames.ToArray(new String[] {}), (String[])tagAttribValues.ToArray(new String[] {}), env);
	}
	
	/**
	 * Executes a single tag without nested child tags in a portlet request context. Note that multiple calls to this method will run
	 * in separate portlet request contexts
	 * 
	 * @param tagAttribNames   Names of the attributes passed to the tag (index of entries must match up with the tagAttribValues list  
	 * @param tagAttribValues  Values of the attributes passed to the tag (index of entries must match up with the tagAttribNames list
	 * @return
	 */
	public static HTMLElement RunSingleTag(String tagLibName, String tagName, String[] tagAttribNames, String[] tagAttribValues, MockEnvironment env)
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(tagLibName, tagName);
		for ( int i = 0; i < tagAttribNames.length; i++ ) {
			helper.AddPTAttribute(tagAttribNames[i], tagAttribValues[i]);
		}
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
   		return result;
	}
	
	/**
	 * Executes a single tag without nested child tags in a portlet request context. Note that multiple calls to this method will run
	 * in separate portlet request contexts
	 * 
	 * @param attributes A map with entries where the key is the name of the attribute and the value is the attribute value as string 
	 * @return
	 */
	public static HTMLElement RunSingleTag(String tagLibName, String tagName, XPHashtable attributes, MockEnvironment env)
	{
		return RunSingleTagWithNestedHTML(tagLibName, tagName, attributes, null, env);
	}
	
	/**
	 * Runs a tag with HTML body
	 * @param tagLibName
	 * @param tagName
	 * @param attributes Map of attribute name/value pairs. Attribute names prefixed with '-' are treated as XML attributes (not prefixed with pt:)
	 * @param nestedHTML
	 * @param env
	 * @return
	 */
	public static HTMLElement RunSingleTagWithNestedHTML(String tagLibName, String tagName, XPHashtable attributes, String nestedHTML, MockEnvironment env)
	{
		XMLFragmentTestHelper helper =  XMLFragmentTestHelper.CreateTag(tagLibName, tagName, attributes);
		if ( nestedHTML != null) {
			helper.AddContent(nestedHTML);
		}
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
   		return result;
		
	}
	
	/**
	 * Runs a tag with a tag body containing nested tag 
	 * @param tagLibName
	 * @param tagName
	 * @param attHashtable A map with entries where the key is the name of the attribute and the value is the attribute value as string 
	 * @param nestedTag
	 * @param env
	 * @return
	 */
	public static HTMLElement RunNestedTags(String tagLibName, String tagName, XPHashtable attributes, XMLFragmentTestHelper nestedTag, MockEnvironment env)
	{
		XMLFragmentTestHelper helper =  XMLFragmentTestHelper.CreateTag(tagLibName, tagName, attributes);
		if ( nestedTag != null ) {
			helper.AddContent(nestedTag);
		}
		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
   		return result;
	}
	
	/**
	 * 
	 * @param tagLibName
	 * @param tagName
	 * @param attributesA map with entries where the key is the name of the attribute and the value is the attribute value as string 
	 * @param nestedTag
	 * @param env
	 * @return
	 */
	public static HTMLElement RunNestedTags(String tagLibName, String tagName, XPHashtable attributes, XMLFragmentTestHelper[] nestedTag, MockEnvironment env)
	{
		XMLFragmentTestHelper helper =  XMLFragmentTestHelper.CreateTag(tagLibName, tagName, attributes);
		if ( nestedTag != null ) {
			for ( int i = 0; i < nestedTag.length; i++ ) {
				helper.AddContent(nestedTag[i]);
			}
		}
		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(env, objArrMarkup);
   		return result;
	}
	
	
	/**
	 * Helper function to create hierarchical data structures
	 * Uses default child key of  
	 * @param children
	 * @return
	 */
	public static HashtableDataObject CreateHierDataHelper(int numChildren)
	{
		XPArrayList children = new XPArrayList(); // root list in the data tag variable
		for ( int i = 0; i < numChildren; i++ ) {
			children.Add(new HashtableDataObject());
		}
		
		HashtableDataObject topEntry = new HashtableDataObject();
		topEntry.SetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY, children);
		return topEntry;
	}
	
	/**
	 * Adds empty child HashtableDataObjects to the provided data object.
	 * Returns the list of created children.   
	 * @param numChildren
	 * @param hierData
	 * @return
	 */
	public static XPArrayList SetHierDataChildren(int numChildren, IHierarchicalDataObject hierData)
	{
		XPArrayList children = new XPArrayList(); // root list in the data tag variable
		for ( int i = 0; i < numChildren; i++ ) {
			children.Add(new HashtableDataObject());
		}
		hierData.SetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY, children);
		return children;
	}
	/**
	 * Returns the immediate child element from the provided hierarchical data at the specified index
	 * 
	 * @param index
	 * @return
	 */
	public static IHierarchicalDataObject GetHierDataChildAtIndex(int index, IHierarchicalDataObject hierData)
	{
		XPArrayList children = hierData.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
		return (IHierarchicalDataObject)children.GetElement(index);
	}
	
	/**
	 * Helper function to return the dataobject in the hierarchy as specified by the indexLst argument
	 * 
	 * @param indexList List of comma separated numbers representing list index at each level of the hierarchy. First number is the top level, next the level below, etc.
	 * @param rootData Data structure to traverse through. List of IHierarchicalDataObject with child elements containing further lists of IHierarchicalDataObject and so forth.
	 * 
	 * @return The IHierarchicalDataObject at specified location in the hierarchy
	 */
	public static IHierarchicalDataObject GetDataObjAtIndex(String indexList, XPArrayList rootData)
	{
		XPStringTokenizer tok = new XPStringTokenizer(indexList, ",");
		IHierarchicalDataObject currData = null;
		XPArrayList currList = rootData;
		for ( int i = 0; tok.HasMoreTokens(); i++ ) 
		{
			currList = (i == 0) ? rootData : (XPArrayList)currData.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
			if ( currList == null) { 
				XPSystem.Out.WriteLine("getDataObjAtIndex - No child data found for data at level: "+i+" in the index list: "+indexList);
				return null; 
			}
			int currIndex = XPConvert.ToInteger( tok.GetNextToken() );
			
			if ( currIndex >= currList.GetSize() ) {
				XPSystem.Out.WriteLine("getDataObjAtIndex - Index: "+currIndex+" at level: "+i+" in the index list: "+indexList+" is greater than the list size");
			}
			currData = (IHierarchicalDataObject)currList.GetElement(currIndex);
			if ( currData == null) {
				XPSystem.Out.WriteLine("getDataObjAtIndex - No element found at index: "+currIndex+" at level: "+i+" in the index list: "+indexList);
				return null; 
			}
		}
		
		return currData;
	}
	
	/************ VERIFICATION HELPERS *****************/
	/**
	 * Verifies that result from data tag is empty. HTML returned from data tag always contains errors  
	 * @param result
	 * @return
	 */
	public static boolean VerifyNoTagContent(HTMLElement result)
	{
		return  result==null||"".equals(result.GetDisplayString());
	}
	
	/**
	 * Checks that generated tag content include the provided string  
	 * @param tagContent
	 * @param expectedContentPart
	 * @return
	 */
	public static boolean VerifyTagReturnedContent(HTMLElement tagContent, String expectedContentPart)
	{
		return !TagTestHelper.VerifyNoTagContent(tagContent) && tagContent.GetDisplayString().indexOf(expectedContentPart) != -1;
	}
	

}
