using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.common
{
  /// <summary>
  /// Tag that displays Application Base Url without trailing question mark
  /// </summary>
  /// <author>rozhang</author>
  public class ApplicationBaseUrlTag : ATag
  {
    public static readonly ITagMetaData TAG;
    static ApplicationBaseUrlTag()
    {
      // The TAG member variable needs to be initialized first since it can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("wcibaseurl", "Outputs the imageserver url for the current page. If the page is in secured mode the secure application base url is returned.",
       EncodeForTagDoc("<pt:common.wcibaseurl/>"));
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      String appUrl = TaskAPIUIPortalConfig.GetApplicationBaseURLForFriendlyURL(space);
      return new HTMLGenericElement(appUrl);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new ApplicationBaseUrlTag();
    }
  }
}