using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.common
{
  /// <summary>
  /// This tag allows JavaScript and Style Sheet include information
  /// to be added to a specific point in the Head element of an HTML
  /// page.
  /// NOTE: This tag name needs to be kept in sync with the DisplayTree.java class.
  /// </summary>
  public class HeadIncludesTag : ATag
  {
    public const String HEAD_INCLUDES_EXAMPLE = "<![CDATA[&lt;head&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;&nbsp;&lt;script type=\"text/javascript\" src=\"http://test.com/main.js\"&gt;&lt;/script&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;&nbsp;&lt;pt:common.headincludes/&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;/head&gt;]]>";
    public const String AUTOMATIC_HEAD_INSERTION = "If no " + "headincludes tag is present, it will be included at the bottom " + "of the Head element, or a Head element will be inserted if there is " + "none.";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    static HeadIncludesTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("headincludes", "This tag allows JavaScript and Style Sheet include information " + "to be added to a specific point in the Head element of an HTML " + "page, as required by the XHTML specification.  If a .js or .css " + "file is marked for inclusion multiple times, it will only be " + "included once in the Head element.  JavaScript generated by tags " + "will also be included here. " + AUTOMATIC_HEAD_INSERTION,
       "<![CDATA[Main page HTML:<br>]]>" + HEAD_INCLUDES_EXAMPLE + "<![CDATA[<br>]]><![CDATA[<br>]]>Pagelet HTML:<![CDATA[<br>]]>" + IncludeInHeadTag.INCLUDE_IN_HEAD_EXAMPLE);
      }
    public override HTMLElement DisplayTag()
    {
      // This method has two HTMLElementCollections.  I believe
      // this is because they used to contain different types of JS,
      // but I think they are now the same and one could be removed.
      // Leaving it here for now, though, to make sure we don't
      // break anything.
      HTMLElement mainIncludes = new HTMLElementCollection();
      // Add shared JS
      HTMLElement jsIncludes = new HTMLElementCollection();
      // Add this to the main includes element
      mainIncludes.AddInnerHTMLElement(jsIncludes);
      // Add the shared JS & tag JS to the head.
      // TagState.GetSharedJavascriptCollection() returns both
      // the tag includes and the shared js includes.
      jsIncludes.AddInnerHTMLElement(TagState.GetSharedJavascriptCollection((AActivitySpace) GetEnvironment()));
      return mainIncludes;
    }
    public override ATag Create()
    {
      return new HeadIncludesTag();
    }
  }
}