using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.common
{
  /// <summary>
  /// This tag works in conjunction with the automated CSAPI Include tag
  /// to allow precise placement of the JS Transform Includes.
  /// </summary>
  public class JSTransformTag : ATag
  {
    public const String TAG_NAME = "jstransform";
    public static readonly String JS_TRANSFORM_EXAMPLE = "<![CDATA[&lt;head&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;pt:common." + TAG_NAME + "/&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;/head&gt;]]><![CDATA[<br>]]>";
    
    /// <summary>
    /// The cached javascript from an auto-generated tag. A shared variable. 
    /// </summary>
    private const String JAVASCRIPT_STATE_VARIABLE = "cachedJS";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    static JSTransformTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      // jstransform
      TAG = new TagMetaData(TAG_NAME, "This tag is used to specify the desired location of the " + "CSAPI constructors in the head of the main page. " + "This tag cannot be used in non-main pages (i.e. portlets), " + "and is optional.",
       JS_TRANSFORM_EXAMPLE);
    }
    public override HTMLElement DisplayTag()
    {
      // Since this tag was added by the web developer, make sure we clear out
      // any automated output.
      XPArrayList cachedJavaScript = GetCachedJavaScript();
      if (cachedJavaScript != null)
      {
        // Copy over the old elements to a new element.
        IXPEnumerator elements = cachedJavaScript.GetEnumerator();
        HTMLElementCollection result = new HTMLElementCollection();
        while (elements.MoveNext())
        {
          HTMLElement current = (HTMLElement) elements.GetCurrent();
          // false means non-recursive.  We only want the immediate children.
          IXPEnumerator innerElements = current.GetInnerHTMLElements(false);
          while (innerElements.MoveNext())
          {
            result.AddInnerHTMLElement((HTMLElement) innerElements.GetCurrent());
            }
          // Since this tag was added by the web developer, make
          // sure we clear out any automated output.
          current.ClearInnerHTMLElements();
        }
        ClearCachedJavaScript();
        // Display the javascript directly
        return result;
      }
      // If there was no cached javascript, then another instance of this tag
      // must have already re-displayed it.  Ignore this instance.
      return null;
    }
    
    /// <summary>
    /// Clear the cached javascript.
    /// </summary>
    /// <param name="_javaScript"></param>
    public virtual void ClearCachedJavaScript()
    {
      SetStateSharedVariable(JAVASCRIPT_STATE_VARIABLE, null, Scope.HTTP_REQUEST,
       false);
    }
    
    /// <returns>the cached javascript from the HEAD element.</returns>
    public virtual XPArrayList GetCachedJavaScript()
    {
      return (XPArrayList) GetStateSharedVariable(JAVASCRIPT_STATE_VARIABLE,
       Scope.HTTP_REQUEST);
    }
    public override ATag Create()
    {
      return new JSTransformTag();
    }
  }
}