using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.server;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.common
{
  public class UserInfoTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     typeof(UserInfoTag));
    public const String USER_INFO_EXAMPLE = "<![CDATA[&lt;pt:common.userinfo pt:info=\"e-mail\"/&gt;]]>";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute INFO;
    static UserInfoTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("userinfo", "This tag retrieves the specified user info data and displays it.",
       USER_INFO_EXAMPLE);
      INFO = new RequiredTagAttribute("info", "The name of the user info data to be retrieved.");
      }
    public override HTMLElement DisplayTag()
    {
      IPTUserInfo userInfo = ((IPTSession) GetEnvironment().GetUserSession()).GetUserInfo();
      // Display user info
      String strUserInfoData = userInfo.GetSetting(GetTagAttributeAsString(INFO));
      //log.Debug("Tag userinfo displaying User Info data: '{0}' with the value '{1}'", GetTagAttributeAsString(INFO), strUserInfoData);
      return new HTMLGenericElement(strUserInfoData);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    public override ATag Create()
    {
      return new UserInfoTag();
    }
  }
}