using System;
using xpunit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.taglib.common;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portaluiinfrastructure.test.tags.commontaglib
{
  public class TestHeadFilterUtil : XpTestCase
  {
    public const String JS_INCLUDE_SINGLETON_URL = "http://acme.com/test.js";
    public static readonly String JS_INCLUDE_SINGLETON = "<script type=\"text/javascript\" src=\"" + JS_INCLUDE_SINGLETON_URL + "\"/>";
    public static readonly String JS_INCLUDE_SINGLETON_SINGLE_QUOTES = "<script type=\'text/javascript\' src=\'" + JS_INCLUDE_SINGLETON_URL + "\'/>";
    public const String JS_INCLUDE_NON_XML_URL = "http://acme.com/test.js";
    public static readonly String JS_INCLUDE_NON_XML = "<script type=\"text/javascript\" src=\"" + JS_INCLUDE_NON_XML_URL + "\">";
    public const String JS_INCLUDE_PAIRED_URL = "http://acme.com/test.js";
    public static readonly String JS_INCLUDE_PAIRED = "<script type=\"text/javascript\" src=\"" + JS_INCLUDE_PAIRED_URL + "\"></script>";
    public const String JS_INCLUDE_PAIRED_WS_URL = "http://acme.com/test.js";
    public static readonly String JS_INCLUDE_PAIRED_WS = "<script type=\"text/javascript\" src=\"" + JS_INCLUDE_PAIRED_URL + "\"> \t </script>";
    public const String CSS_INCLUDE_SINGLETON_URL = "http://acme.com/test.css";
    public static readonly String CSS_INCLUDE_SINGLETON = "<link rel=\"stylesheet\" href=\"" + CSS_INCLUDE_SINGLETON_URL + "\" type=\"text/css\"/>";
    public static readonly String CSS_INCLUDE_SINGLETON_SINGLE_QUOTES = "<link rel=\'stylesheet\' href=\'" + CSS_INCLUDE_SINGLETON_URL + "\' type=\'text/css\'/>";
    public const String CSS_INCLUDE_NON_XML_URL = "http://acme.com/test.css";
    public static readonly String CSS_INCLUDE_NON_XML = "<link rel=\"stylesheet\" href=\"" + CSS_INCLUDE_NON_XML_URL + "\" type=\"text/css\">";
    public const String CSS_INCLUDE_PAIRED_URL = "http://acme.com/test.css";
    public static readonly String CSS_INCLUDE_PAIRED = "<link rel=\"stylesheet\" href=\"" + CSS_INCLUDE_PAIRED_URL + "\" type=\"text/css\"></link>";
    public const String CSS_INCLUDE_PAIRED_WS_URL = "http://acme.com/test.css";
    public static readonly String CSS_INCLUDE_PAIRED_WS = "<link rel=\"stylesheet\" href=\"" + CSS_INCLUDE_PAIRED_WS_URL + "\" type=\"text/css\">\t \t</link>";
    public const String REMAINDER = "<!-- my comment -->" + "<script type=\"text/javascript\">var fake = 1;</script>" + "<!-- another comment -->";
    public const String HTML_1 = "<!-- html 1 comment -->";
    public const String HTML_2 = "<!-- html 2 comment -->";
    public virtual void testFilterSimpleJS()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(JS_INCLUDE_SINGLETON);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, null));
      assertTrue("Checking that no CSS links were found.", util.GetNewCSS().IsEmpty());
      assertEquals("Checking that one JS link was found.", 1, util.GetNewJavaScript().GetSize());
      assertEquals("Checking that link was found correctly.", JS_INCLUDE_SINGLETON_URL,
       util.GetNewJavaScript().GetElement(0));
      assertEquals("Checking that JS include was displayed.", JS_INCLUDE_SINGLETON,
       util.GetDisplayContent().GetDisplayString());
    }
    public virtual void testFilterSimpleJSSingleQuotes()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(JS_INCLUDE_SINGLETON_SINGLE_QUOTES);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, null));
      assertTrue("Checking that no CSS links were found.", util.GetNewCSS().IsEmpty());
      assertEquals("Checking that one JS link was found.", 1, util.GetNewJavaScript().GetSize());
      assertEquals("Checking that link was found correctly.", JS_INCLUDE_SINGLETON_URL,
       util.GetNewJavaScript().GetElement(0));
      assertEquals("Checking that JS include was displayed.", JS_INCLUDE_SINGLETON_SINGLE_QUOTES,
       util.GetDisplayContent().GetDisplayString());
    }
    public virtual void testFilterMultiJS()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(JS_INCLUDE_SINGLETON);
      content.AddInnerHTMLString(JS_INCLUDE_NON_XML);
      content.AddInnerHTMLString(JS_INCLUDE_PAIRED);
      content.AddInnerHTMLString(JS_INCLUDE_PAIRED_WS);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, null));
      assertTrue("Checking that no CSS links were found.", util.GetNewCSS().IsEmpty());
      assertEquals("Checking that correct number of JS links were found.",
       4, util.GetNewJavaScript().GetSize());
      assertEquals("Checking that singleton link was found correctly.", JS_INCLUDE_SINGLETON_URL,
       util.GetNewJavaScript().GetElement(0));
      assertEquals("Checking that non-xml link was found correctly.", JS_INCLUDE_NON_XML_URL,
       util.GetNewJavaScript().GetElement(1));
      assertEquals("Checking that paired link was found correctly.", JS_INCLUDE_PAIRED_URL,
       util.GetNewJavaScript().GetElement(2));
      assertEquals("Checking that paired whitespace link was found correctly.",
       JS_INCLUDE_PAIRED_WS_URL, util.GetNewJavaScript().GetElement(3));
      assertEquals("Checking that JS includes were displayed.", JS_INCLUDE_SINGLETON + JS_INCLUDE_NON_XML + JS_INCLUDE_PAIRED + JS_INCLUDE_PAIRED_WS,
       util.GetDisplayContent().GetDisplayString());
    }
    public virtual void testFilterOutMultiJS()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(JS_INCLUDE_SINGLETON);
      content.AddInnerHTMLString(JS_INCLUDE_NON_XML);
      content.AddInnerHTMLString(JS_INCLUDE_PAIRED);
      content.AddInnerHTMLString(JS_INCLUDE_PAIRED_WS);
      XPArrayList removalJavaScript = new XPArrayList();
      removalJavaScript.Add(JS_INCLUDE_SINGLETON_URL);
      removalJavaScript.Add(JS_INCLUDE_NON_XML_URL);
      removalJavaScript.Add(JS_INCLUDE_PAIRED_URL);
      removalJavaScript.Add(JS_INCLUDE_PAIRED_WS_URL);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       removalJavaScript, null));
      assertTrue("Checking that no JS links were found.", util.GetNewJavaScript().IsEmpty());
      assertTrue("Checking that no CSS links were found.", util.GetNewCSS().IsEmpty());
      assertEquals("Checking that JS includes were not displayed.", "", util.GetDisplayContent().GetDisplayString());
      }
    public virtual void testFilterSimpleCSS()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(CSS_INCLUDE_SINGLETON);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, null));
      assertTrue("Checking that no JS links were found.", util.GetNewJavaScript().IsEmpty());
      assertEquals("Checking that one CSS link was found.", 1, util.GetNewCSS().GetSize());
      assertEquals("Checking that link was found correctly.", CSS_INCLUDE_SINGLETON_URL,
       util.GetNewCSS().GetElement(0));
      assertEquals("Checking that CSS include was displayed.", CSS_INCLUDE_SINGLETON,
       util.GetDisplayContent().GetDisplayString());
    }
    public virtual void testFilterSimpleCSSSingleQuotes()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(CSS_INCLUDE_SINGLETON_SINGLE_QUOTES);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, null));
      assertTrue("Checking that no JS links were found.", util.GetNewJavaScript().IsEmpty());
      assertEquals("Checking that one CSS link was found.", 1, util.GetNewCSS().GetSize());
      assertEquals("Checking that link was found correctly.", CSS_INCLUDE_SINGLETON_URL,
       util.GetNewCSS().GetElement(0));
      assertEquals("Checking that CSS include was displayed.", CSS_INCLUDE_SINGLETON_SINGLE_QUOTES,
       util.GetDisplayContent().GetDisplayString());
    }
    public virtual void testFilterMultiCSS()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(CSS_INCLUDE_SINGLETON);
      content.AddInnerHTMLString(CSS_INCLUDE_NON_XML);
      content.AddInnerHTMLString(CSS_INCLUDE_PAIRED);
      content.AddInnerHTMLString(CSS_INCLUDE_PAIRED_WS);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, null));
      assertTrue("Checking that no JS links were found.", util.GetNewJavaScript().IsEmpty());
      assertEquals("Checking that correct number of CSS links were found.",
       4, util.GetNewCSS().GetSize());
      assertEquals("Checking that link was found correctly.", CSS_INCLUDE_SINGLETON_URL,
       util.GetNewCSS().GetElement(0));
      assertEquals("Checking that link was found correctly.", CSS_INCLUDE_NON_XML_URL,
       util.GetNewCSS().GetElement(1));
      assertEquals("Checking that link was found correctly.", CSS_INCLUDE_PAIRED_URL,
       util.GetNewCSS().GetElement(2));
      assertEquals("Checking that link was found correctly.", CSS_INCLUDE_PAIRED_WS_URL,
       util.GetNewCSS().GetElement(3));
      assertEquals("Checking that CSS include was displayed.", CSS_INCLUDE_SINGLETON + CSS_INCLUDE_NON_XML + CSS_INCLUDE_PAIRED + CSS_INCLUDE_PAIRED_WS,
       util.GetDisplayContent().GetDisplayString());
    }
    public virtual void testFilterOutMultiCSS()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(CSS_INCLUDE_SINGLETON);
      content.AddInnerHTMLString(CSS_INCLUDE_NON_XML);
      content.AddInnerHTMLString(CSS_INCLUDE_PAIRED);
      content.AddInnerHTMLString(CSS_INCLUDE_PAIRED_WS);
      XPArrayList removalCSS = new XPArrayList();
      removalCSS.Add(CSS_INCLUDE_SINGLETON_URL);
      removalCSS.Add(CSS_INCLUDE_NON_XML_URL);
      removalCSS.Add(CSS_INCLUDE_PAIRED_URL);
      removalCSS.Add(CSS_INCLUDE_PAIRED_WS_URL);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, removalCSS));
      assertTrue("Checking that no JS links were found.", util.GetNewJavaScript().IsEmpty());
      assertTrue("Checking that no CSS links were found.", util.GetNewCSS().IsEmpty());
      assertEquals("Checking that CSS includes were not displayed.", "", util.GetDisplayContent().GetDisplayString());
      }
    public virtual void testFilterRemainder()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(REMAINDER);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       null, null));
      assertTrue("Checking that no JS links were found.", util.GetNewJavaScript().IsEmpty());
      assertTrue("Checking that no CSS links were found.", util.GetNewCSS().IsEmpty());
      assertEquals("Checking that remainder HTML was found correctly.", REMAINDER,
       util.GetDisplayContent().GetDisplayString());
    }
    public virtual void testFilterContent()
    {
      HeadFilterUtil util = new HeadFilterUtil();
      HTMLElementCollection content = new HTMLElementCollection();
      content.AddInnerHTMLString(HTML_1);
      content.AddInnerHTMLString(JS_INCLUDE_SINGLETON);
      content.AddInnerHTMLString(REMAINDER);
      content.AddInnerHTMLString(CSS_INCLUDE_SINGLETON);
      content.AddInnerHTMLString(HTML_2);
      XPArrayList removalJavaScript = new XPArrayList();
      removalJavaScript.Add(JS_INCLUDE_SINGLETON_URL);
      XPArrayList removalCSS = new XPArrayList();
      removalCSS.Add(CSS_INCLUDE_SINGLETON_URL);
      assertTrue("Checking that filtering succeeds.", util.Filter(content,
       removalJavaScript, removalCSS));
      assertTrue("Checking that no new JS links were found.", util.GetNewJavaScript().IsEmpty());
      assertTrue("Checking that no new CSS links were found.", util.GetNewCSS().IsEmpty());
      assertEquals("Checking that remainder HTML was found correctly.", HTML_1 + REMAINDER + HTML_2,
       util.GetDisplayContent().GetDisplayString());
    }
  }
}