/**
 * 
 */
package com.plumtree.taglib.common;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tag that displays Application Base Url without trailing question mark
 * 
 * @author rozhang
 */
public class ApplicationBaseUrlTag extends ATag
{
	public static final ITagMetaData TAG;
	
	static
	{
		// The TAG member variable needs to be initialized first since it can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("wcibaseurl", 
				"Outputs the imageserver url for the current page. If the page is in secured mode the secure application base url is returned.",
				EncodeForTagDoc("<pt:common.wcibaseurl/>"));  	
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		AActivitySpace space = (AActivitySpace)GetEnvironment();
		String appUrl = TaskAPIUIPortalConfig.GetApplicationBaseURLForFriendlyURL(space);
		
		return new HTMLGenericElement(appUrl);
	}
	

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new ApplicationBaseUrlTag();
	}

}
