/**
 * 
 */
package com.plumtree.taglib.common;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tag that displays current imageserver url
 * 
 * @author rozhang
 */
public class ImageServerUrlTag extends ATag
{
	public static final ITagMetaData TAG;
	
	static
	{
		// The TAG member variable needs to be initialized first since it can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("imageserverurl", 
				"Outputs the imageserver url for the current page. If the page is in secured mode the secure imageserver url is returned.",
				EncodeForTagDoc("<pt:common.imageserverurl/>"));  	
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		AActivitySpace space = (AActivitySpace)GetEnvironment();
		String imgsvrUrl = TaskAPIUIPortalConfig.GetImageServerBaseURL(space);
		
		return new HTMLGenericElement(imgsvrUrl);
	}
	

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new ImageServerUrlTag();
	}
	
}
