package com.plumtree.taglib.common;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag works in conjunction with the automated CSAPI Include tag
 * to allow precise placement of the JS Transform Includes.
 */
public class JSTransformTag extends ATag
{
	public static final String TAG_NAME = "jstransform";

	public static final String JS_TRANSFORM_EXAMPLE =
		"<![CDATA[&lt;head&gt;]]><![CDATA[<br>]]>" +
		"<![CDATA[&lt;pt:common." + TAG_NAME + "/&gt;]]><![CDATA[<br>]]>" +
		"<![CDATA[&lt;/head&gt;]]><![CDATA[<br>]]>";

	/** The cached javascript from an auto-generated tag. A shared variable. */
	private static final String JAVASCRIPT_STATE_VARIABLE = "cachedJS";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.

		// jstransform
		TAG = new TagMetaData(TAG_NAME,
			"This tag is used to specify the desired location of the " +
			"CSAPI constructors in the head of the main page. " +
			"This tag cannot be used in non-main pages (i.e. portlets), " +
			"and is optional.", JS_TRANSFORM_EXAMPLE);
	}

	public HTMLElement DisplayTag()
	{
		// Since this tag was added by the web developer, make sure we clear out
		// any automated output.
		XPArrayList cachedJavaScript = GetCachedJavaScript();

		if (cachedJavaScript != null)
		{
			// Copy over the old elements to a new element.

			IXPEnumerator elements = cachedJavaScript.GetEnumerator();
			HTMLElementCollection result = new HTMLElementCollection();
			while (elements.MoveNext())
			{
				HTMLElement current = (HTMLElement)elements.GetCurrent();

				// false means non-recursive.  We only want the immediate children.
				IXPEnumerator innerElements = current.GetInnerHTMLElements(false);
				while (innerElements.MoveNext())
				{
					result.AddInnerHTMLElement((HTMLElement)innerElements.GetCurrent());
				}

				// Since this tag was added by the web developer, make
				// sure we clear out any automated output.
				current.ClearInnerHTMLElements();
			}

			ClearCachedJavaScript();

			// Display the javascript directly
			return result;				
		}

		// If there was no cached javascript, then another instance of this tag
		// must have already re-displayed it.  Ignore this instance.
		return null;
	}

	/**
	 * Clear the cached javascript.
	 * @param _javaScript
	 */
	public void ClearCachedJavaScript()
	{
		SetStateSharedVariable(JAVASCRIPT_STATE_VARIABLE, null, Scope.HTTP_REQUEST, false);
	}

	/**
	 * @return the cached javascript from the HEAD element.
	 */
	public XPArrayList GetCachedJavaScript()
	{
		return (XPArrayList) GetStateSharedVariable(JAVASCRIPT_STATE_VARIABLE, Scope.HTTP_REQUEST);
	}

	public ATag Create()
	{
		return new JSTransformTag();
	}
}