package com.plumtree.taglib.common;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.xpshared.htmlelements.*;

public class UserInfoTag extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		UserInfoTag.class);

	public static final String USER_INFO_EXAMPLE =
		"<![CDATA[&lt;pt:common.userinfo pt:info=\"e-mail\"/&gt;]]>";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute INFO;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("userinfo",
			"This tag retrieves the specified user info data and displays it.",
			USER_INFO_EXAMPLE);

		INFO = new RequiredTagAttribute("info",
			"The name of the user info data to be retrieved.");
	}

	public HTMLElement DisplayTag()
	{
		IPTUserInfo userInfo = ((IPTSession)GetEnvironment().GetUserSession()).GetUserInfo();

		// Display user info
		
		String strUserInfoData = userInfo.GetSetting(GetTagAttributeAsString(INFO));
		//log.Debug("Tag userinfo displaying User Info data: '{0}' with the value '{1}'", GetTagAttributeAsString(INFO), strUserInfoData);
		return new HTMLGenericElement(strUserInfoData);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	public ATag Create() {
		return new UserInfoTag();
	}
}