using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.tags.tasks;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.core
{
  /// <summary>
  /// This tag turns tag debug mode on and off.
  /// </summary>
  public class DebugModeTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute MODE;
    static DebugModeTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("debugmode", "This tag turns tag debug mode on and off.  When debug mode is on, tags " + "will display HTML comments before and after they are executed to aid in " + "debugging.  Tags may also have custom behavior in debug mode.  This tag " + "uses an editable shared variable for debug mode (see " + "com.plumtree.portaluiinfrastructure.tags.tasks.TagStateTasks.GetIsDebugMode " + "for more details).");
      MODE = new OptionalTagAttribute("mode", "Turns debug mode on and off.",
       AttributeType.BOOLEAN, "true");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      bool bPreviousDebugMode = TagStateTasks.GetIsDebugMode(GetState());
      bool bNewDebugMode = GetTagAttributeAsBoolean(MODE);
      // Set debug mode to the value of the MODE tag attribute.
      TagStateTasks.SetIsDebugMode(bNewDebugMode, GetState());
      // Do not add comment if debug mode was off and we kept it turned off.
      if (bPreviousDebugMode || bNewDebugMode)
      {
        if (bNewDebugMode)
        {
          return new HTMLComment("Turning Debug Mode On.");
        } else
        {
          return new HTMLComment("Turning Debug Mode Off.");
        }
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any content, and therefore supports
      // all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new DebugModeTag();
    }
  }
}