using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.core
{
  /// <summary>
  /// This tag will display the localized version of the string with the given
  /// string Id and string file. It will also replace the tokens, {0},{1},..., if a 
  /// replacement is given via the optional string replace variables.
  /// </summary>
  public class LocalizeTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ID;
    public static readonly RequiredTagAttribute FILE;
    public static readonly OptionalTagAttribute REPLACE_0;
    public static readonly OptionalTagAttribute REPLACE_1;
    public static readonly OptionalTagAttribute REPLACE_2;
    public static readonly OptionalTagAttribute REPLACE_3;
    static LocalizeTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("localize", "This tag will display the localized version of the string with the given string ID and string file. " + "It will also replace the tokens, {0},{1},..., if a  replacement is given via the optional string replacement variables.");
      ID = new RequiredTagAttribute("id", "The ID of the localized string to be displayed. The ID must be an integer.",
       AttributeType.INT);
      FILE = new RequiredTagAttribute("file", "The name of the file that contains the string to be displayed.");
      REPLACE_0 = new OptionalTagAttribute("replace0", "The string that will be used to replace the token: {0}.",
       AttributeType.STRING, "");
      REPLACE_1 = new OptionalTagAttribute("replace1", "The string that will used to replace the token: {1}.",
       AttributeType.STRING, "");
      REPLACE_2 = new OptionalTagAttribute("replace2", "The string that will used to replace the token: {2}.",
       AttributeType.STRING, "");
      REPLACE_3 = new OptionalTagAttribute("replace3", "The string that will used to replace the token: {3}.",
       AttributeType.STRING, "");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      int nId = GetTagAttributeAsInt(ID);
      String strFile = GetTagAttributeAsString(FILE);
      String strReplace0 = GetTagAttributeAsString(REPLACE_0);
      String strReplace1 = GetTagAttributeAsString(REPLACE_1);
      String strReplace2 = GetTagAttributeAsString(REPLACE_2);
      String strReplace3 = GetTagAttributeAsString(REPLACE_3);
      AActivitySpace asEnvironment = (AActivitySpace) GetEnvironment();
      String strLocalizedString = asEnvironment.GetString(nId, strFile);
      String strFormattedString = XPResourceManager.FormatMessage(strLocalizedString,
       strReplace0, strReplace1, strReplace2, strReplace3);
      HTMLGenericElement result = new HTMLGenericElement(strFormattedString);
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript by itself, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LocalizeTag();
    }
  }
}