using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.core
{
  /// <author>rozhang</author>
  public class TagDefArgumentTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.taglib.core.TagDefArgumentTag");
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag TAGDEFCREATE;
    public static readonly RequiredTagAttribute ATTRIB_NAME;
    public static readonly RequiredTagAttribute ATTRIB_DESC;
    //public static final RequiredTagAttribute ATTRIB_TYPE;
    public static readonly OptionalTagAttribute ATTRIB_DEFAULTVALUE;
    static TagDefArgumentTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("tagdefarg", "Defines an argument value this Tag definition expects. Argument values are passed to Tag definitions by declaring XML attributes on the " + "includetagdef tag. " + "",
       EncodeForTagDoc("<pt:core.newtagdef pt:defid=\"newtagdef\" /><br/>" + "  <pt:core.tagdefarg pt:name=\"arg1\" pt:desc=\"this is a required argument\"/><br/>" + "  <pt:core.tagdefarg pt:name=\"arg2\" pt:defaultval=\"0\" pt:desc=\"this is an optional argument\"/><br/>" + "  <pt:logic.value=\"$arg1\"><br/> " + "  <pt:logic.value=\"$arg2\"><br/> " + "</pt:core.tagdef><br/>" + "...<br/>" + "<pt:core.includetagdef pt:defid=\"newtagdef\" arg1=\"value1\" arg2=\"value2\"><br/>"));
      TAGDEFCREATE = new RequiredParentTag(TagDefCreateTag.TAG);
      ATTRIB_NAME = new RequiredTagAttribute("name", "Name of the Tag definition argument (name of tag variable).",
       AttributeType.STRING);
      ATTRIB_DESC = new RequiredTagAttribute("desc", "Description of this tag def argument.");
      // maybe in the future add a type argument for type checking 
      //ATTRIB_TYPE = new RequiredTagAttribute("type", "Type of the tag def argument value (string, int, tagvar, collection, list).", AttributeType.BOOLEAN);
      ATTRIB_DEFAULTVALUE = new OptionalTagAttribute("defaultvalue", "The Tag variable will use this value if no value was provided for this argument.",
       AttributeType.STRING, null);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      ITagState state = GetState();
      String defaultVal = GetTagAttributeAsString(ATTRIB_DEFAULTVALUE);
      String argName = GetTagAttributeAsString(ATTRIB_NAME);
      Object argValue = state.GetSharedVariable(argName, Scope.TAG);
      if (argValue == null)
      {
        // if defaultValue is null then this is a required tag def argument, we should raise an error
        if (defaultVal == null)
        {
          // set a tag var to signal to TagDefIncludeTag that there was an error in the tag def
          state.SetVariable(TagDefIncludeTag.TAGDEF_MISSINGREQARG_TAGVAR,
           argName, Scope.PORTLET_REQUEST);
        } else
        {
          // argument not passed in, set a tag var with the default value
          // set the tag var in parent tag scope (tagdefinclude) and not the tag scope of this tag
          state.StoreInParentTagScope(true);
          state.SetSharedVariable(argName, defaultVal, Scope.TAG, true);
        }
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new TagDefArgumentTag();
    }
  }
}