using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.tags.tagdef;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.core
{
  /// <summary>
  /// This tag is used to declare Tag Output Definition. 
  /// Use TagDefIncludeTag to use the Tag Definitions. 
  /// </summary>
  /// <author>rozhang</author>
  public class TagDefCreateTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.taglib.core.TagDefCreateTag");
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_DEFID;
    public static readonly OptionalTagAttribute ATTRIB_READONLY;
    static TagDefCreateTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("tagdef", "This tag allows you to define a block of arbitrary HTML and/or Adaptive Tags to display in multiple locations. " + "Use the pt:logic.includetagdef to display the content defined by this tag. " + "Create a Tag Definition by placing the block of HTML and Adaptive Tags in the body of this tag and assign an id with the defid attribute. " + "Tag definitions are declared in the Tag definition file, by default located on the WCI imageserver. This file is automatically processed when " + "the pt:logic.includetagdef tag is used. It is also possible to declare Tag definitions in Portlets or Adaptive Layout files, but the Tag Definition " + "is only available on that page. " + "Adaptive Tags in a Tag Definition are not executed until displayed with the pt:logic.includetagdef",
       EncodeForTagDoc("<pt:core.tagdef pt:defid=\"tagdef\" /><br/>" + " ...<br/>" + "</pt:core.tagdef><br/>"));
      ATTRIB_DEFID = new RequiredTagAttribute("defid", "Unique id for the definition. Two Tag Definitions with the same id will overwrite the first one.",
       AttributeType.STRING);
      ATTRIB_READONLY = new OptionalTagAttribute("readonly", "Pass in true to protect this Tag Definition from getting overwritten.",
       AttributeType.BOOLEAN, "false");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      TagOutputDefinitionManager mgr = TagOutputDefinitionManager.GetInstance();
      // tag the output is defined for 
      String defId = GetTagAttributeAsString(ATTRIB_DEFID);
      bool readOnly = GetTagAttributeAsBoolean(ATTRIB_READONLY);
      bool result = mgr.StoreTagOutputDefinition(defId, "", readOnly, GetTagHelper());
      // failed	
      if (!result)
      {
        String errorStr = " Unable to store Tag Definition with id: " + defId + ". A read-only Tag Definition with same id already exists. ";
        log.Warn(errorStr);
        return new HTMLComment(errorStr);
      } else
      {
        // tag def stored, dont need to return anything
        return null;
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new TagDefCreateTag();
    }
  }
}