using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.core
{
  /// <summary>
  /// Tag for declaring blocks of content to only display once per Tag definition id
  /// </summary>
  /// <author>rozhang</author>
  public class TagDefSharedContentTag : ATag
  {
    
    /// <summary>
    /// Tag variable set by TAgDefArgumentTag if a required tag def argument is missing, value of the tag var is the name of the argument*
    /// </summary>
    public const String SHAREDCONTENT_PREFIX = "$$SHAREDCONTENT_";
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute BLOCKID;
    static TagDefSharedContentTag()
    {
      // The TAG member variable needs to be initialized first since it can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("tagdefshared", "Defines a block of content that is only displayed once every page for each Tag definition. Use this tag " + "for Javascript, CSS or HTML shared between multiple Tag definitions. " + "If more than one block of content is needed, use the id attribute to assign a unique id to each shared block.",
       EncodeForTagDoc("<pt:core.tagdefshared /><br/>" + "...first common block of content..." + "</pt:core.tagdefshared><br/>" + "<pt:core.tagdefshared pt:id=\"secondblock\"/><br/>" + "...second common block of content..." + "</pt:core.tagdefshared><br/>"));
      BLOCKID = new OptionalTagAttribute("id", "Only needed when more than one shared blocks is used within a Tag definition. " + "Each additional shared block requires a unique id. ",
       AttributeType.STRING, "");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      String blockId = GetTagAttributeAsString(BLOCKID);
      String id = ConstructUniqueTagDefId(blockId);
      ITagState state = GetState();
      HTMLElement result = null;
      // should use tag scope but doesnt work for some reason
      Object value = state.GetVariable(id, Scope.HTTP_REQUEST);
      // first time we running the tag def, execute the body and set the flag
      if (value == null)
      {
        result = ProcessTagBody();
        //state.StoreInParentTagScope(true); // set in parent tag tag scope
        // should use tag scope but doesnt work for some reason
        // set the variable afterwards in case ProcessTagBody throws exception 
        state.SetVariable(id, true, Scope.HTTP_REQUEST);
      }
      // already exists, means the body has been executed, don't do anything	
      return result;
    }
    
    /// <summary>
    /// Constructs an id 
    /// </summary>
    /// <returns></returns>
    protected virtual String ConstructUniqueTagDefId(String blockId)
    {
      String tagdefId = (String) GetState().GetSharedVariable(TagDefIncludeTag.TAGDEF_DEFID_TAGVAR,
       Scope.TAG);
      if (tagdefId == null)
      {
        throw new XPIllegalStateException("Tag variable " + TagDefIncludeTag.TAGDEF_DEFID_TAGVAR + " not found. tagdefshared tag can only be used inside of Tag definition tags.");
        }
      return SHAREDCONTENT_PREFIX + tagdefId + blockId;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new TagDefSharedContentTag();
    }
  }
}