using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.tagdef;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.core;
using com.plumtree.taglib.logic;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.core.test
{
  /// <summary>
  /// Tests the TagDefCreate tag
  /// </summary>
  /// <author>rozhang</author>
  public class TagDefCreateTagTest : TestCase
  {
    internal static readonly String LOGIC_LIBNAME = CoreTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_DEF_NAME = TagDefCreateTag.TAG.GetName();
    internal static readonly String TAG_DEF_ATTRIB_DEFID = TagDefCreateTag.ATTRIB_DEFID.GetName();
    //static final String TAG_DEF_ATTRIB_VERSION  = TagDefCreateTag.ATTRIB_VERSION.GetName();
    internal static readonly String TAG_DEF_ATTRIB_READONLY = TagDefCreateTag.ATTRIB_READONLY.GetName();
    internal static readonly String TAG_INCLUDE_NAME = TagDefIncludeTag.TAG.GetName();
    internal static readonly String TAG_INCLUDE_ATTRIB_DEFID = TagDefIncludeTag.ATTRIB_DEFID.GetName();
    //static final String TAG_INCLUDE_ATTRIB_VERSION  = TagDefIncludeTag.ATTRIB_VERSION.GetName();
    internal MockEnvironment m_mockEnv = null;
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTags(LOGIC_LIBNAME, new String[]{TAG_DEF_NAME,
       TAG_INCLUDE_NAME, VariableTag.TAG.GetName()}, new ATag[]{new TagDefCreateTag(),
       new TagDefIncludeTag(), new VariableTag()});
      TagOutputDefinitionManager.SetTestInstance(new MockTagOutputDefinitionManager());
      }
    
    /// <summary>
    /// Tests that read only tag defs cannot be clobbered
    /// </summary>
    public virtual void testReadOnlyDef()
    {
      String defId = "testdefinitionid";
      String version = "testversion";
      String oldHTML = "<div><p>Definition Test Output</p></div>";
      String newHTML = "<div><p>UPDATED UPDATED</p></div>";
      // first define the output as read only 
      XPHashtable attribs = new XPHashtable();
      attribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
      //attribs.PutElement(TAG_DEF_ATTRIB_VERSION, version);
      // read only
      attribs.PutElement(TAG_DEF_ATTRIB_READONLY, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(LOGIC_LIBNAME,
       TAG_DEF_NAME, attribs, oldHTML, m_mockEnv);
      assertTrue("Output definition Tag returned HTML: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // now define another tag output with same defid
      result = TagTestHelper.RunSingleTagWithNestedHTML(LOGIC_LIBNAME, TAG_DEF_NAME,
       attribs, newHTML, m_mockEnv);
      // make sure we get an error message
      assertFalse("No error message displayed by tag when over-riding read-only tag definition",
       TagTestHelper.VerifyNoTagContent(result));
      // verify that the tag def is the old one
      XPHashtable incArgs = new XPHashtable();
      incArgs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
      //incArgs.PutElement(TAG_INCLUDE_ATTRIB_VERSION, version);
      // run include tag
      HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME,
       incArgs, m_mockEnv);
      // verify the original tag definition didn't change
      assertEquals("HTML content retrieved and displayed by Tag Definition include tag does not match the original defined HTML.",
       oldHTML, result2.GetDisplayString());
    }
    
    /// <summary>
    /// Tests the TagOutputDefinitionTag to define Tag HTML output and TagDefIncludeTag to display the output 
    /// </summary>
    public virtual void testNoReadOnlyDef()
    {
      String defId = "testdefinitionid";
      String version = "testversion";
      String defHTML = "<div><p>Definition Test Output</p></div>";
      String newHTML = "<div><p>UPDATED UPDATED</p></div>";
      // first define the output as read only 
      XPHashtable attribs = new XPHashtable();
      attribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
      //attribs.PutElement(TAG_DEF_ATTRIB_VERSION, version);
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(LOGIC_LIBNAME,
       TAG_DEF_NAME, attribs, defHTML, m_mockEnv);
      assertTrue("Output definition Tag returned HTML: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // now define another tag output with same defid
      result = TagTestHelper.RunSingleTagWithNestedHTML(LOGIC_LIBNAME, TAG_DEF_NAME,
       attribs, newHTML, m_mockEnv);
      // verify no output
      assertTrue("Output definition Tag returned HTML: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // verify that the tag def is the new one
      XPHashtable incArgs = new XPHashtable();
      incArgs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
      //incArgs.PutElement(TAG_INCLUDE_ATTRIB_VERSION, version);
      // run include tag
      HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME,
       incArgs, m_mockEnv);
      // verify the tag output is the updated one
      assertEquals("HTML content retrieved and displayed by Tag Definition include tag does not match the original defined HTML.",
       newHTML, result2.GetDisplayString());
    }
  }
}