using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.tagdef;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.core;
using com.plumtree.taglib.logic;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.core.test
{
  /// <summary>
  /// Tests the TagDef and  TagDefInclude tags 
  /// </summary>
  /// <author>rozhang</author>
  public class TagDefIncludeTagTest : TestCase
  {
    internal static readonly String LOGIC_LIBNAME = CoreTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_DEF_NAME = TagDefCreateTag.TAG.GetName();
    internal static readonly String TAG_DEF_ATTRIB_DEFID = TagDefCreateTag.ATTRIB_DEFID.GetName();
    //static final String TAG_DEF_ATTRIB_VERSION  = TagDefCreateTag.ATTRIB_VERSION.GetName();
    internal static readonly String TAG_INCLUDE_NAME = TagDefIncludeTag.TAG.GetName();
    internal static readonly String TAG_INCLUDE_ATTRIB_DEFID = TagDefIncludeTag.ATTRIB_DEFID.GetName();
    //static final String TAG_INCLUDE_ATTRIB_VERSION  = TagDefIncludeTag.ATTRIB_VERSION.GetName();
    internal MockEnvironment m_mockEnv = null;
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTags(LOGIC_LIBNAME, new String[]{TAG_DEF_NAME,
       TAG_INCLUDE_NAME, VariableTag.TAG.GetName(), ValueTag.TAG.GetName()},
       new ATag[]{new TagDefCreateTag(), new TagDefIncludeTag(), new VariableTag(),
       new ValueTag()});
      TagOutputDefinitionManager.SetTestInstance(new MockTagOutputDefinitionManager());
      }
    
    /// <summary>
    /// Tests the TagOutputDefinitionTag to define Tag HTML output and TagDefIncludeTag to display the output 
    /// </summary>
    public virtual void testTagDefHTMLStoreRetrieval()
    {
      String defId = "testdefinitionid";
      String version = "testversion";
      String defHTML = "<div><p>Definition Test Output</p></div>";
      XPHashtable attribs = new XPHashtable();
      attribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
      //attribs.PutElement(TAG_DEF_ATTRIB_VERSION, version);
      // first define the output 
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(LOGIC_LIBNAME,
       TAG_DEF_NAME, attribs, defHTML, m_mockEnv);
      assertTrue("Output definition Tag returned HTML: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // now retrieve it
      XPHashtable incArgs = new XPHashtable();
      incArgs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
      //incArgs.PutElement(TAG_INCLUDE_ATTRIB_VERSION, version);
      // run include tag
      HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME,
       incArgs, m_mockEnv);
      // verify the output is the same
      assertEquals("HTML content retrieved and displayed by Tag Definition include tag does not match the original defined HTML.",
       defHTML, result2.GetDisplayString());
    }
    
    /// <summary>
    /// Test that Adaptive Tags in Tag definition isn't executed in definition tag and
    /// test that it is executed when included by the Tag Def include tag.
    /// Set tag def to be a variable tag that updates a tag variable with an initial value.
    /// We know the variable tag was not executed as long as the tag variable contains the 
    /// initial value.   
    /// </summary>
    public virtual void testTagDefTagContentStoreRetrieval()
    {
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      // tag variable with the test value
      String tagVarName = "testVar";
      // tag def id 
      String defId = "testdefinitionid";
      // tag def version
      String version = "testversion";
      // initial value of the test tag variable
      String initialValue = "INITIAL VALUE";
      // updated value of the test tag variable
      String updatedValue = "NEW VALUE";
      // set the initial value of our test variable
      // set the initial tag variable value
      mockState.SetTagHTTPRequestVar(null, tagVarName, initialValue, m_mockEnv);
      // tag def attributes
      XPHashtable defAttribs = new XPHashtable();
      defAttribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
      //defAttribs.PutElement(TAG_DEF_ATTRIB_VERSION, version);
      // variable tag attributes
      XPHashtable varAttribs = new XPHashtable();
      varAttribs.PutElement(VariableTag.KEY.GetName(), tagVarName);
      varAttribs.PutElement(VariableTag.VALUE.GetName(), updatedValue);
      // set on http request scope
      varAttribs.PutElement(VariableTag.SCOPE.GetName(), Scope.HTTP_REQUEST.ToString());
      // create variable tag 
      XMLFragmentTestHelper variableTag = XMLFragmentTestHelper.CreateTag(LOGIC_LIBNAME,
       VariableTag.TAG.GetName(), varAttribs);
      // run test tag with variable tag
      HTMLElement result = TagTestHelper.RunNestedTags(LOGIC_LIBNAME, TAG_DEF_NAME,
       defAttribs, variableTag, m_mockEnv);
      assertTrue("Output definition Tag returned HTML: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // get tag variable value
      Object defTestValue = mockState.GetTagHTTPRequestVar(tagVarName, m_mockEnv);
      // verify that tag variable still contains initial value
      assertTrue("Test Tag variable value does not contain initial value! Tag Def content was executed.",
       initialValue.Equals(defTestValue));
      // now retrieve it
      XPHashtable incAttribs = new XPHashtable();
      incAttribs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
      //incAttribs.PutElement(TAG_INCLUDE_ATTRIB_VERSION, version);
      HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME,
       incAttribs, m_mockEnv);
      // since the tag def only conained a variable tag, no content to display 
      assertTrue("Output definition Tag returned HTML: " + result2.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // verify that test tag variable contains updated value now that it should have been executed by the include tag
      Object newTestValue = mockState.GetTagHTTPRequestVar(tagVarName, m_mockEnv);
      assertEquals("Test Tag variable value does not contain updated value! Tag Def content was not executed by include tag.",
       updatedValue, newTestValue);
    }
    
    /// <summary>
    /// Test that XML attribute name/values are set as tag scope tag variables 
    /// </summary>
    public virtual void testXMLAttributes()
    {
      // tag def id 
      String defId = "testdefinitionid";
      String var1Name = "Name1";
      String var2Name = "Name2";
      String var1Value = "Value1";
      String var2Value = "Value2";
      // Tags in Tag Definition
      // value tag attributes
      XPHashtable varAttribs = new XPHashtable();
      // use attribute replacement to get value of tag variable
      varAttribs.PutElement(ValueTag.VALUE.GetName(), "$" + var1Name);
      // create variable tag
      XMLFragmentTestHelper valueTag = XMLFragmentTestHelper.CreateTag(LOGIC_LIBNAME,
       ValueTag.TAG.GetName(), varAttribs);
      // value tag attributes
      varAttribs = new XPHashtable();
      // use attribute replacement to get value of tag variable
      varAttribs.PutElement(ValueTag.VALUE.GetName(), "$" + var2Name);
      // create variable tag
      XMLFragmentTestHelper valueTag2 = XMLFragmentTestHelper.CreateTag(LOGIC_LIBNAME,
       ValueTag.TAG.GetName(), varAttribs);
      // tag def attributes
      XPHashtable defAttribs = new XPHashtable();
      defAttribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
      // create the tag definition
      HTMLElement result = TagTestHelper.RunNestedTags(LOGIC_LIBNAME, TAG_DEF_NAME,
       defAttribs, new XMLFragmentTestHelper[]{valueTag, valueTag2}, m_mockEnv);
      assertTrue("Output definition Tag returned HTML: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      XPHashtable incAttribs = new XPHashtable();
      incAttribs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
      // the '-' prefix makes this an XML attribute
      incAttribs.PutElement("-" + var1Name, var1Value);
      // the '-' prefix makes this an XML attribute
      incAttribs.PutElement("-" + var2Name, var2Value);
      HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME,
       incAttribs, m_mockEnv);
      // should display the values of the variables passed in with the xml attributes
      assertEquals("Output from tagdefinclude tag did not match excepted result. ",
       var1Value + var2Value, result2.GetDisplayString());
    }
  }
}