package com.plumtree.taglib.core;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Comment tag that allows you to add comments to source HTML
 * but not have it get sent to the browser.
 */
public class CommentTag extends ATag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("comment",
			"This tag is used to display comments in the untransformed source HTML. " +
			"When this tag is transformed, the contents of this tag will not be displayed " +
			"in the HTML sent to the browser.",
			"<![CDATA[&lt;pt:core.comment&gt;This comment will not be sent to the browser.&lt;/pt:core.comment&gt;]]>");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		// This tag never displays anything.
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		// This tag does not actually display the content, but it still
		// needs to be of a type that can display the content so that
		// you can use it to suppress the output.
		return TagType.SIMPLE;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript by itself, and therefore
		// supports all access styles.
		return true;
	}

	@Override
	public ATag Create() {
		return new CommentTag();
	}
}