package com.plumtree.taglib.core;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag will display the localized version of the string with the given
 * string Id and string file. It will also replace the tokens, {0},{1},..., if a 
 * replacement is given via the optional string replace variables.
 * 
 */
public class LocalizeTag extends ATag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ID;
	public static final RequiredTagAttribute FILE;
	public static final OptionalTagAttribute REPLACE_0;
	public static final OptionalTagAttribute REPLACE_1;
	public static final OptionalTagAttribute REPLACE_2;
	public static final OptionalTagAttribute REPLACE_3;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("localize",
			"This tag will display the localized version of the string with the given string ID and string file. " +
			"It will also replace the tokens, {0},{1},..., if a  replacement is given via the optional string replacement variables.");

		ID = new RequiredTagAttribute("id", "The ID of the localized string to be displayed. The ID must be an integer.", AttributeType.INT);
		
		FILE = new RequiredTagAttribute("file", "The name of the file that contains the string to be displayed.");
		
		REPLACE_0 = new OptionalTagAttribute("replace0", "The string that will be used to replace the token: {0}.", 
				AttributeType.STRING, "");
		
		REPLACE_1 = new OptionalTagAttribute("replace1", "The string that will used to replace the token: {1}.", 
				AttributeType.STRING, "");
		
		REPLACE_2 = new OptionalTagAttribute("replace2", "The string that will used to replace the token: {2}.", 
				AttributeType.STRING, "");
		
		REPLACE_3 = new OptionalTagAttribute("replace3", "The string that will used to replace the token: {3}.", 
				AttributeType.STRING, "");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		int nId = GetTagAttributeAsInt(ID);
		String strFile = GetTagAttributeAsString(FILE);
		String strReplace0 = GetTagAttributeAsString(REPLACE_0);
		String strReplace1 = GetTagAttributeAsString(REPLACE_1);
		String strReplace2 = GetTagAttributeAsString(REPLACE_2);
		String strReplace3 = GetTagAttributeAsString(REPLACE_3);
		
		AActivitySpace asEnvironment = (AActivitySpace) GetEnvironment();
		String strLocalizedString = asEnvironment.GetString(nId, strFile);
		String strFormattedString = XPResourceManager.FormatMessage(strLocalizedString, strReplace0, strReplace1, strReplace2, strReplace3);

		HTMLGenericElement result = new HTMLGenericElement(strFormattedString);
		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript by itself, and therefore
		// supports all access styles.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new LocalizeTag();
	}
}
