/**
 * 
 */
package com.plumtree.taglib.core;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.portaluiinfrastructure.tags.tagdef.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag is used to declare Tag Output Definition. 
 * Use TagDefIncludeTag to use the Tag Definitions. 
 * 
 * @author rozhang
 */
public class TagDefCreateTag extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		"com.plumtree.taglib.core.TagDefCreateTag");
	
	public static final ITagMetaData TAG;
	
	public static final RequiredTagAttribute ATTRIB_DEFID;
	public static final OptionalTagAttribute ATTRIB_READONLY;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		
		TAG = new TagMetaData("tagdef",
				"This tag allows you to define a block of arbitrary HTML and/or Adaptive Tags to display in multiple locations. "+
				"Use the pt:logic.includetagdef to display the content defined by this tag. "+
				"Create a Tag Definition by placing the block of HTML and Adaptive Tags in the body of this tag and assign an id with the defid attribute. "+
				"Tag definitions are declared in the Tag definition file, by default located on the WCI imageserver. This file is automatically processed when "+
				"the pt:logic.includetagdef tag is used. It is also possible to declare Tag definitions in Portlets or Adaptive Layout files, but the Tag Definition "+
				"is only available on that page. "+
				"Adaptive Tags in a Tag Definition are not executed until displayed with the pt:logic.includetagdef",
				EncodeForTagDoc(
						"<pt:core.tagdef pt:defid=\"tagdef\" /><br/>"+
						" ...<br/>"+
						"</pt:core.tagdef><br/>"
						));  	
		
		ATTRIB_DEFID   = new RequiredTagAttribute("defid", "Unique id for the definition. Two Tag Definitions with the same id will overwrite the first one.", AttributeType.STRING);
		ATTRIB_READONLY = new OptionalTagAttribute("readonly", "Pass in true to protect this Tag Definition from getting overwritten.", AttributeType.BOOLEAN, "false");
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 * 
	 */
	public HTMLElement DisplayTag()
	{
		TagOutputDefinitionManager mgr = TagOutputDefinitionManager.GetInstance();
		// tag the output is defined for 
		String defId 	 = GetTagAttributeAsString(ATTRIB_DEFID);
		boolean readOnly = GetTagAttributeAsBoolean(ATTRIB_READONLY); 
		
		boolean result = mgr.StoreTagOutputDefinition(defId, "", readOnly, GetTagHelper()) ;
		
		if ( !result) { // failed	
			String errorStr = " Unable to store Tag Definition with id: "+defId+". A read-only Tag Definition with same id already exists. ";
			log.Warn(errorStr);
			return new HTMLComment(errorStr);
		} else {
			// tag def stored, dont need to return anything
			return null;
		}
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new TagDefCreateTag();
	}
}
