package com.plumtree.taglib.core;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Displays stored Tag Definitions
 * 
 * @author rozhang
 */
public class TagDefIncludeTag extends ATagDefDisplay
{
	/** Tag variable set by TAgDefArgumentTag if a required tag def argument is missing, value of the tag var is the name of the argument**/
	public static final String TAGDEF_MISSINGREQARG_TAGVAR = "$$TAGDEF_MISSING_REQUIRED_TAGDEFARGUMENT";
	public static final String TAGDEF_DEFID_TAGVAR = "TAGDEF_ID";
	
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_DEFID;
	
	static
	{
		// The TAG member variable needs to be initialized first since it can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("includetagdef", 
				"This tag displays Tag Definitions, which are blocks of HTML and Adaptive Tags created by the pt:logic.tagdef tag. "+
				"Use Tag variables to pass run-time parameters to Tag Definitions. Names and values of XML attributes (Tag attributes without the pt: prefix) are converted to "+ 
				"Tag scope Tag variables. For example, an XML attribute width=500 sets a Tag scope tag variable that is accessible from the Tag definition as a Tag variable with "+
				"the name 'width' with a value of '500'. ",
				EncodeForTagDoc("<pt:core.includetagdef pt:defid=\"newtagdef\" parameter1=\"value1\" parameter2=\"value2\" /><br/>"));  	
		
		ATTRIB_DEFID   = new RequiredTagAttribute("defid", "Identifier of the Tag definition.", AttributeType.STRING);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		 String definitionId = GetTagAttributeAsString(ATTRIB_DEFID);

		 // Get all the XML attributes and for each, set tag scoped tag variables. 
		 // These are values passed in to the include tag to be used by the tag definition
		 IXPEnumerator attribs = GetXMLTagAttributeNames();
		 while (attribs.MoveNext())
		 {
			 String name  = (String)attribs.GetCurrent();
			 String value = GetXMLTagAttribute(name);
			 // needs to shared to be accessible by tags in the tag def
			 GetState().SetSharedVariable(name, value, Scope.TAG, true);
		 }
		 // set the definition id in tag scope for tags such as TagDefSharedContentTag
		 GetState().SetSharedVariable(TAGDEF_DEFID_TAGVAR, definitionId, Scope.TAG, true);
		 
		 // The method below retrieves and puts the Tag Definition in the body of this tag and transforms (executes tags) the tag body
		 HTMLElement result = ProcessStoredTagContent(definitionId, "");
		 Object var = GetState().GetVariable(TAGDEF_MISSINGREQARG_TAGVAR, Scope.TAG);
		 if ( var != null ) {
			 throw new XPIllegalArgumentException("Missing required Tag definition argument: "+var);
		 }
		 
		 if ( result == null ) {
			 throw new XPIllegalStateException("No Tag Definition found with id: "+definitionId+" found.");
		 }
		 return result;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new TagDefIncludeTag();
	}
}
