/**
 * 
 */
package com.plumtree.taglib.core;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tag for declaring blocks of content to only display once per Tag definition id
 * 
 * @author rozhang
 */
public class TagDefSharedContentTag extends ATag
{
	/** Tag variable set by TAgDefArgumentTag if a required tag def argument is missing, value of the tag var is the name of the argument**/
	public static final String SHAREDCONTENT_PREFIX = "$$SHAREDCONTENT_";
	
	public static final ITagMetaData TAG;
	
	public static final OptionalTagAttribute BLOCKID;
	
	static
	{
		// The TAG member variable needs to be initialized first since it can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("tagdefshared", 
				"Defines a block of content that is only displayed once every page for each Tag definition. Use this tag "+
				"for Javascript, CSS or HTML shared between multiple Tag definitions. "+
				"If more than one block of content is needed, use the id attribute to assign a unique id to each shared block.",
				EncodeForTagDoc(
						"<pt:core.tagdefshared /><br/>"+
						"...first common block of content..."+
						"</pt:core.tagdefshared><br/>"+
						"<pt:core.tagdefshared pt:id=\"secondblock\"/><br/>"+
						"...second common block of content..."+
						"</pt:core.tagdefshared><br/>"));  	
		
		BLOCKID = new OptionalTagAttribute("id", "Only needed when more than one shared blocks is used within a Tag definition. "+
				"Each additional shared block requires a unique id. ", AttributeType.STRING, "");
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		String blockId = GetTagAttributeAsString(BLOCKID);
		String id = ConstructUniqueTagDefId(blockId);
		ITagState state = GetState();
		HTMLElement result = null;
		// should use tag scope but doesnt work for some reason
		Object value = state.GetVariable(id, Scope.HTTP_REQUEST); 
		if ( value == null ) { // first time we running the tag def, execute the body and set the flag
			result = ProcessTagBody();
			//state.StoreInParentTagScope(true); // set in parent tag tag scope
			// should use tag scope but doesnt work for some reason
			state.SetVariable(id, new Boolean(true), Scope.HTTP_REQUEST); // set the variable afterwards in case ProcessTagBody throws exception 
		} 
		// already exists, means the body has been executed, don't do anything	
		return result;
	}
	
	/**
	 * Constructs an id 
	 * @return
	 */
	protected String ConstructUniqueTagDefId(String blockId)
	{
		String tagdefId = (String)GetState().GetSharedVariable(TagDefIncludeTag.TAGDEF_DEFID_TAGVAR, Scope.TAG);
		if (tagdefId == null) {
			throw new XPIllegalStateException("Tag variable "+TagDefIncludeTag.TAGDEF_DEFID_TAGVAR+" not found. tagdefshared tag can only be used inside of Tag definition tags.");
		}
		
		return SHAREDCONTENT_PREFIX+tagdefId+blockId;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new TagDefSharedContentTag();
	}
	
}
