/**
 * 
 */
package com.bea.alui.taglib.core.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.tagdef.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.core.*;
import com.plumtree.taglib.logic.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tests the TagDef and  TagDefInclude tags 
 * 
 * @author rozhang
 */
public class TagDefIncludeTagTest extends TestCase
{
	static final String LOGIC_LIBNAME  			= CoreTagLibraryData.LIBRARY.GetName();

	static final String TAG_DEF_NAME     		= TagDefCreateTag.TAG.GetName();
	static final String TAG_DEF_ATTRIB_DEFID	= TagDefCreateTag.ATTRIB_DEFID.GetName();
	//static final String TAG_DEF_ATTRIB_VERSION  = TagDefCreateTag.ATTRIB_VERSION.GetName();
	
	static final String TAG_INCLUDE_NAME     		= TagDefIncludeTag.TAG.GetName();
	static final String TAG_INCLUDE_ATTRIB_DEFID	= TagDefIncludeTag.ATTRIB_DEFID.GetName();
	//static final String TAG_INCLUDE_ATTRIB_VERSION  = TagDefIncludeTag.ATTRIB_VERSION.GetName();
	
	MockEnvironment m_mockEnv = null;
	
	
	
	public void setUp()
	{
		m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTags(LOGIC_LIBNAME, 
									 new String[] {TAG_DEF_NAME, TAG_INCLUDE_NAME, VariableTag.TAG.GetName(), ValueTag.TAG.GetName()},
									 new ATag[] {new TagDefCreateTag(), new TagDefIncludeTag(), new VariableTag(), new ValueTag()});
		TagOutputDefinitionManager.SetTestInstance(new MockTagOutputDefinitionManager());
	}
	
	/**
	 * Tests the TagOutputDefinitionTag to define Tag HTML output and TagDefIncludeTag to display the output 
	 * 
	 */
	public void testTagDefHTMLStoreRetrieval()
	{
		String defId = "testdefinitionid";
		String version = "testversion";
		String defHTML = "<div><p>Definition Test Output</p></div>";
		
		XPHashtable attribs = new XPHashtable();
		attribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
		//attribs.PutElement(TAG_DEF_ATTRIB_VERSION, version);
		
		// first define the output 
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(LOGIC_LIBNAME, TAG_DEF_NAME, attribs, defHTML, m_mockEnv);
		assertTrue("Output definition Tag returned HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		// now retrieve it
		XPHashtable incArgs = new XPHashtable();
		incArgs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
		//incArgs.PutElement(TAG_INCLUDE_ATTRIB_VERSION, version);
		// run include tag
		HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME, incArgs, m_mockEnv);
		// verify the output is the same
		assertEquals("HTML content retrieved and displayed by Tag Definition include tag does not match the original defined HTML.", defHTML, result2.GetDisplayString());
		
		
	}
	
	/**
	 * Test that Adaptive Tags in Tag definition isn't executed in definition tag and
	 * test that it is executed when included by the Tag Def include tag.
	 * 
	 * Set tag def to be a variable tag that updates a tag variable with an initial value.
	 * We know the variable tag was not executed as long as the tag variable contains the 
	 * initial value.   
	 */
	public void testTagDefTagContentStoreRetrieval()
	{
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		String tagVarName = "testVar"; // tag variable with the test value
		
		String defId = "testdefinitionid"; // tag def id 
		String version = "testversion"; // tag def version
		
		String initialValue = "INITIAL VALUE"; // initial value of the test tag variable
		String updatedValue = "NEW VALUE"; // updated value of the test tag variable
		
		// set the initial value of our test variable
		mockState.SetTagHTTPRequestVar(null, tagVarName, initialValue, m_mockEnv); // set the initial tag variable value
		
		XPHashtable defAttribs = new XPHashtable(); // tag def attributes
		defAttribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
		//defAttribs.PutElement(TAG_DEF_ATTRIB_VERSION, version);
		
		XPHashtable varAttribs = new XPHashtable(); // variable tag attributes
		varAttribs.PutElement(VariableTag.KEY.GetName(), tagVarName);
		varAttribs.PutElement(VariableTag.VALUE.GetName(), updatedValue);
		varAttribs.PutElement(VariableTag.SCOPE.GetName(), Scope.HTTP_REQUEST.toString()); // set on http request scope
		XMLFragmentTestHelper variableTag = XMLFragmentTestHelper.CreateTag(LOGIC_LIBNAME, VariableTag.TAG.GetName(), varAttribs); // create variable tag 
		
		// run test tag with variable tag
		HTMLElement result = TagTestHelper.RunNestedTags(LOGIC_LIBNAME, TAG_DEF_NAME, defAttribs, variableTag, m_mockEnv); 
		assertTrue("Output definition Tag returned HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		Object defTestValue = mockState.GetTagHTTPRequestVar(tagVarName, m_mockEnv); // get tag variable value
		assertTrue("Test Tag variable value does not contain initial value! Tag Def content was executed.", initialValue.equals(defTestValue)); // verify that tag variable still contains initial value
		
		// now retrieve it
		XPHashtable incAttribs = new XPHashtable();
		incAttribs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
		//incAttribs.PutElement(TAG_INCLUDE_ATTRIB_VERSION, version);
		HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME, incAttribs, m_mockEnv);
		assertTrue("Output definition Tag returned HTML: "+result2.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) ); // since the tag def only conained a variable tag, no content to display 
		
		// verify that test tag variable contains updated value now that it should have been executed by the include tag
		Object newTestValue = mockState.GetTagHTTPRequestVar(tagVarName, m_mockEnv);
		assertEquals("Test Tag variable value does not contain updated value! Tag Def content was not executed by include tag.", updatedValue, newTestValue); 
	}
	/**
	 * Test that XML attribute name/values are set as tag scope tag variables 
	 */
	public void testXMLAttributes()
	{
		String defId   = "testdefinitionid"; // tag def id 
		
		String var1Name  = "Name1";
		String var2Name  = "Name2";
		String var1Value = "Value1";
		String var2Value = "Value2";
		/** STEP 1: Setup Tag Definition **/
		
		// Tags in Tag Definition
		XPHashtable varAttribs = new XPHashtable(); // value tag attributes
		varAttribs.PutElement(ValueTag.VALUE.GetName(), "$"+var1Name); // use attribute replacement to get value of tag variable
		XMLFragmentTestHelper valueTag = XMLFragmentTestHelper.CreateTag(LOGIC_LIBNAME, ValueTag.TAG.GetName(), varAttribs); // create variable tag
		
		varAttribs = new XPHashtable(); // value tag attributes
		varAttribs.PutElement(ValueTag.VALUE.GetName(), "$"+var2Name); // use attribute replacement to get value of tag variable
		XMLFragmentTestHelper valueTag2 = XMLFragmentTestHelper.CreateTag(LOGIC_LIBNAME, ValueTag.TAG.GetName(), varAttribs); // create variable tag
		
		// tag def attributes
		XPHashtable defAttribs = new XPHashtable(); 
		defAttribs.PutElement(TAG_DEF_ATTRIB_DEFID, defId);
		
		// create the tag definition
		HTMLElement result = TagTestHelper.RunNestedTags(LOGIC_LIBNAME, TAG_DEF_NAME, defAttribs, new XMLFragmentTestHelper[] {valueTag, valueTag2}, m_mockEnv); 
		assertTrue("Output definition Tag returned HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		/** STEP 2: Display Tag Definition **/

		XPHashtable incAttribs = new XPHashtable();
		incAttribs.PutElement(TAG_INCLUDE_ATTRIB_DEFID, defId);
		incAttribs.PutElement("-"+var1Name, var1Value); // the '-' prefix makes this an XML attribute
		incAttribs.PutElement("-"+var2Name, var2Value); // the '-' prefix makes this an XML attribute
		HTMLElement result2 = TagTestHelper.RunSingleTag(LOGIC_LIBNAME, TAG_INCLUDE_NAME, incAttribs, m_mockEnv);
		 // should display the values of the variables passed in with the xml attributes
		assertEquals("Output from tagdefinclude tag did not match excepted result. ", var1Value+var2Value, result2.GetDisplayString() );
		
	}
}
