using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.logic
{
  /// <author>rozhang</author>
  public abstract class AHierIndexDataTag : ATag
  {
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    public static RequiredTagAttribute ATTRIB_INDEX;
    public static readonly OptionalTagAttribute ATTRIB_HIERID;
    static AHierIndexDataTag()
    {
      ATTRIB_ID = new RequiredTagAttribute("target", "Name of the target tag variable.",
       AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute("scope", "Scope of the target tag variable.",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
      ATTRIB_HIERID = new OptionalTagAttribute("childkey", "Hierarchical data key if different from the default \'children\'. For example, used when adding Community Pages children to Communities.",
       AttributeType.STRING, "children");
    }
    internal const String INDEX_ATTRIB_DESC = "The first number specifies index in the top list, and each following number index in lower level lists. 0 represents the first element of a list. " + "A value of \'2,0,12\' inserts data into 3rd entry in the top list, first entry in the second list and 13th entry in the 3rd level list. ";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public abstract override ATag Create();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public abstract override HTMLElement DisplayTag();
    
    /// <param name="topList"></param>
    /// <returns>Hier data object at the specified index or null if the index is an empty string.</returns>
    /// <throws>XPIllegalArgumentException if the index references an invalid location in the hierarchical structure</throws>
    public virtual IHierarchicalDataObject GetObjectFromIndex(XPArrayList topList)
    {
      String strIndices = GetTagAttributeAsString(ATTRIB_INDEX);
      String hierDataId = GetTagAttributeAsString(ATTRIB_HIERID);
      XPStringTokenizer indicesTok = new XPStringTokenizer(strIndices, ",");
      IHierarchicalDataObject currHDO = null;
      XPArrayList children = topList;
      int count = 0;
      for (;indicesTok.HasMoreTokens();count++)
      {
        // the first iteration the list is the top level list, after that we get it from the current hier data entry 
        if (count != 0)
        {
          children = currHDO.GetHierData(hierDataId);
        }
        int currIndex = XPConvert.ToInteger(indicesTok.GetNextToken());
        // error checking
        if (children == null)
        {
          throw new XPIllegalArgumentException("Invalid index: \'" + strIndices + "\'. No children found at level: " + currIndex + " with id: \'" + hierDataId + "\'");
          } else
        if (currIndex > children.GetSize())
        {
          throw new XPIllegalArgumentException("Invalid index: \'" + strIndices + "\'. Index at level: " + currIndex + " is greater than the number of children.");
          }
        // set the entry in the specified index as the current hierarchical data parent and traverse again
        if (currIndex >= children.GetSize())
        {
          throw new XPIllegalArgumentException("Index number " + count + " with value " + currIndex + " at is greater than number of children (" + children.GetSize() + "). Index string: " + strIndices);
          }
        currHDO = (IHierarchicalDataObject) children.GetElement(currIndex);
        }
      return currHDO;
    }
  }
}