using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.logic
{
  /// <summary>
  /// This tag evaluates whether a shared variable exist and stores
  /// the result as a boolean in memory.  It is designed
  /// to work with the logic.if tag.
  /// </summary>
  public class ExistExprTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.taglib.logic.ExistExprTag");
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute DATA;
    public static readonly RequiredTagAttribute KEY;
    public static readonly OptionalTagAttribute SCOPE;
    static ExistExprTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("existexpr", "This tag evaluates whether a shared variable exists and stores " + "the result as a boolean in memory.  It is designed " + "to work with the logic.if tag.",
       "<![CDATA[&lt;pt:logic.collectionlength pt:data=\"testcollection\" pt:key=\"length\"/&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;pt:logic.existexpr pt:data=\"testdata\" pt:key=\"boolvalue\"/&gt;]]><![CDATA[<br>]]>" + IfTag.IF_EXAMPLE_IF);
      DATA = new RequiredTagAttribute("data", "The key used to retrieve the shared variable from memory.");
      KEY = new RequiredTagAttribute("key", "The key used to store the result in memory.");
      SCOPE = new OptionalTagAttribute("scope", "The scope used to store the result in memory.  " + LogicTagLibraryData.SCOPE_REFERENCE,
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    public override HTMLElement DisplayTag()
    {
      // DCA - get data key and check if it exists
      String strDataKey = GetTagAttributeAsString(DATA);
      Object oData = GetAnyStateVariable(strDataKey);
      bool bResult = true;
      if (null == oData)
      {
        bResult = false;
      }
      // DCA - get scope
      Scope scope = Scope.GetScope(GetTagAttributeAsString(SCOPE));
      if (null == scope)
      {
        log.Warn("Unable to convert scope attribute " + GetTagAttributeAsString(SCOPE) + " to a valid scope in Tag " + TAG.GetName() + ".");
        scope = Scope.PORTLET_REQUEST;
      }
      // Store the boolean of whether the variable exists or not using the specified name.
      SetStateSharedVariable(GetTagAttributeAsString(KEY), XPConvert.ToString(bResult),
       scope, false);
      return ProcessTagBody();
    }
    public override bool SupportsAccessStyle(AccessStyles style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    public override ATag Create()
    {
      return new ExistExprTag();
    }
  }
}