using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.logic
{
  /// <summary>
  /// This tag is displayed if the surrounding if tag evaluates to false.
  /// </summary>
  public class IfFalseTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.taglib.logic.IfFalseTag");
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag IF;
    static IfFalseTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("iffalse", "This tag is displayed if the surrounding logic.if tag evaluates " + "to false.",
       IfTag.IF_EXAMPLE_SETUP + IfTag.IF_EXAMPLE_IF);
      IF = new RequiredParentTag(IfTag.TAG);
    }
    public override HTMLElement DisplayTag()
    {
      bool bIfResult;
      Object oIfResult = GetStateVariable(IfTag.IF_RESULT_VARIABLE, Scope.PORTLET_REQUEST);
      if (null != oIfResult)
      {
        try
        {
          bIfResult = XPConvert.ToBoolean(oIfResult);
        }
        catch (XPFormatException xpfe)
        {
          String strError = "Unable to convert " + IfTag.TAG.GetName() + " tag result to a boolean value in " + TAG.GetName() + " : " + oIfResult;
          // This should never happen, so we'll log it.
          log.Error(xpfe, strError);
          return new HTMLComment(strError);
        }
      } else
      {
        String strError = "Missing " + IfTag.TAG.GetName() + " tag result in " + TAG.GetName() + ".";
        // This should never happen, so we'll log it.
        log.Error(strError);
        return new HTMLComment(strError);
      }
      if (!bIfResult)
      {
        return ProcessTagBody();
      }
      return null;
    }
    public override bool SupportsAccessStyle(AccessStyles style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    public override ATag Create()
    {
      return new IfFalseTag();
    }
  }
}