using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.logic
{
  /// <summary>
  /// This tag evaluates a boolean expression and then displays
  /// either the if-true or if-false tag contents.
  /// </summary>
  public class IfTag : ATag
  {
    public const String IF_RESULT_VARIABLE = "bIfResult";
    public const String OPERAND_VARIABLE_PREFIX = "($";
    public const char OPERAND_VARIABLE_SUFFIX = ')';
    public const String IF_EXAMPLE_SETUP = "<![CDATA[&lt;pt:logic.collectionlength pt:data=\"testcollection\" pt:key=\"length\"/&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;pt:logic.intexpr pt:expr=\"($length) > 1\" pt:key=\"boolvalue\"/&gt;]]><![CDATA[<br>]]>";
    public const String IF_EXAMPLE_IF = "<![CDATA[&lt;pt:logic.if pt:expr=\"$boolvalue\"&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;]]><![CDATA[&lt;pt:logic.iftrue&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;&nbsp;]]><![CDATA[This is displayed if expr evaluates to true. ]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;]]><![CDATA[&lt;/pt:logic.iftrue&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;]]><![CDATA[&lt;pt:logic.iffalse&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;&nbsp;]]><![CDATA[ This is displayed if expr evaluates to false. ]]><![CDATA[<br>]]>" + "<![CDATA[&nbsp;]]><![CDATA[&lt;/pt:logic.iffalse&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:logic.if&gt;]]><![CDATA[<br>]]>";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute EXPR;
    public static readonly RelatedChildTag IF_TRUE;
    public static readonly RelatedChildTag IF_FALSE;
    static IfTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("if", "This tag evaluates an expression and then displays either " + "the logic.iftrue or logic.iffalse tag contents.",
       IF_EXAMPLE_SETUP + IF_EXAMPLE_IF);
      EXPR = new RequiredTagAttribute("expr", "A boolean value (i.e. true or false).  " + "This can be input as an tag variable using " + "the $ attribute notation (i.e. pt:expr=\"$myboolean\").",
       AttributeType.BOOLEAN);
      IF_TRUE = new RelatedChildTag(IfTrueTag.TAG);
      IF_FALSE = new RelatedChildTag(IfFalseTag.TAG);
    }
    public override HTMLElement DisplayTag()
    {
      // Cache the previous value so we can restore it later.
      Object oPrevValue = GetStateVariable(IF_RESULT_VARIABLE, Scope.PORTLET_REQUEST);
      SetStateVariable(IF_RESULT_VARIABLE, GetTagAttributeAsBoolean(EXPR),
       Scope.PORTLET_REQUEST);
      HTMLElement result = ProcessTagBody();
      // Restore the previous value
      SetStateVariable(IF_RESULT_VARIABLE, oPrevValue, Scope.PORTLET_REQUEST);
      return result;
    }
    public override bool SupportsAccessStyle(AccessStyles style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    public override ATag Create()
    {
      return new IfTag();
    }
  }
}