using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.logic
{
  /// <summary>
  /// This tag is used to display a separator in between
  /// elements of a foreach loop without displaying an
  /// extra one at the end.
  /// </summary>
  public class SeparatorTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.taglib.logic.SeparatorTag");
    public const String DISPLAY = "bDisplay";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag PARENT;
    static SeparatorTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("separator", "This tag allows you to display a separator in between elements of a foreach loop without " + "displaying an extra one at the end.  Content in this tag will be displayed for every iteration " + "of the loop except the last.",
       ForEachTag.LOOP_EXAMPLE);
      PARENT = new RequiredParentTag(ForEachTag.TAG);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      bool bDisplay = false;
      Object oDisplay = GetStateVariable(DISPLAY, Scope.TAG);
      if (null != oDisplay)
      {
        try
        {
          bDisplay = XPConvert.ToBoolean(oDisplay);
        }
        catch (XPFormatException xpfe)
        {
          log.Warn("Unable to convert display variable from foreach tag.",
           xpfe);
          // Do not display the tag contents if there are any errors.
          bDisplay = false;
        }
      }
      if (bDisplay)
      {
        return ProcessTagBody();
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any content by itself, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new SeparatorTag();
    }
  }
}