using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.logic
{
  public class StringExprTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.plumtree.taglib.logic.StringExprTag");
    public const String STRING_EXAMPLE_SETUP = "<![CDATA[&lt;pt:logic.variable pt:key=\"title\" pt:value=\"Administrator\"/&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;pt:logic.stringexpr pt:expr=\"($title) == Administrator\" pt:key=\"boolvalue\"/&gt;]]><![CDATA[<br>]]>";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute EXPR;
    public static readonly RequiredTagAttribute KEY;
    public static readonly OptionalTagAttribute SCOPE;
    static StringExprTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("stringexpr", "This tag evaluates whether or not two strings are equal and " + "stores the result as a boolean in memory.  Case must match.  " + "It is designed to work with the logic.if tag.",
       STRING_EXAMPLE_SETUP + IfTag.IF_EXAMPLE_IF);
      EXPR = new RequiredTagAttribute("expr", "A tag variable, followed by a space and a string comparator, and then " + "another space and a string value or another tag variable.  The tag " + "variable must be in $ attribute notation surrounded by " + "parentheses.  The following operators are allowed: <![CDATA[\'" + StringOperators.OP_EQUAL + "\' and \'" + StringOperators.OP_NOT_EQUAL + "\']]>.");
      KEY = new RequiredTagAttribute("key", "The key used to store the result in memory.");
      SCOPE = new OptionalTagAttribute("scope", "The scope used to store the result in memory.  " + LogicTagLibraryData.SCOPE_REFERENCE,
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    public override HTMLElement DisplayTag()
    {
      String strExpr = GetTagAttributeAsString(EXPR);
      StringOperators op = FindOperator(strExpr);
      int nIndex = XPStringUtility.IndexOf(strExpr, op.ToString());
      String strFirstOperand = XPStringUtility.Substring(strExpr, 0, nIndex);
      String strSecondOperand = XPStringUtility.Substring(strExpr, nIndex + op.ToString().Length,
       strExpr.Length);
      // Strip whitespace from operands
      strFirstOperand = XPStringUtility.Trim(strFirstOperand);
      // remove leading (but not trailing) whitespace from second operand
      int nWhitespace = 0;
      for (nWhitespace = 0;nWhitespace < strSecondOperand.Length;nWhitespace++)
      {
        if (XPStringUtility.CharAt(strSecondOperand, nWhitespace) != ' ')
        {
          // found first non-whitespace character
          break;
        }
      }
      strSecondOperand = XPStringUtility.Substring(strSecondOperand, nWhitespace,
       strSecondOperand.Length);
      // Get first operand
      if (!XPStringUtility.StartsWith(strFirstOperand, IfTag.OPERAND_VARIABLE_PREFIX) || IfTag.OPERAND_VARIABLE_SUFFIX != XPStringUtility.CharAt(strFirstOperand,
       strFirstOperand.Length - 1))
      {
        return new HTMLComment("Invalid first operand in " + EXPR.GetName() + " attribute in " + TAG.GetName() + " tag.  First operand must be a variable and be " + "enclosed in parentheses and start with a \'$\': " + strFirstOperand);
        }
      String strVariable = XPStringUtility.Substring(strFirstOperand, 2, strFirstOperand.Length - 1);
      String strFirstValue = XPConvert.ToString(GetAnyStateVariable(strVariable));
      if (null == strFirstValue)
      {
        return new HTMLComment("Empty value returned for first operand variable in " + EXPR.GetName() + " attribute in " + TAG.GetName() + " tag.  First operand: " + strFirstOperand);
        }
      // get second operand
      String strSecondValue;
      if (XPStringUtility.StartsWith(strSecondOperand, IfTag.OPERAND_VARIABLE_PREFIX))
      {
        strSecondOperand = XPStringUtility.Trim(strSecondOperand);
        if (IfTag.OPERAND_VARIABLE_SUFFIX != XPStringUtility.CharAt(strSecondOperand,
         strSecondOperand.Length - 1))
        {
          return new HTMLComment("Invalid second operand in " + EXPR.GetName() + " attribute in " + TAG.GetName() + " tag.  Variable operands must be " + "enclosed in parentheses and start with a \'$\': " + strFirstOperand);
          }
        strVariable = XPStringUtility.Substring(strSecondOperand, 2, strSecondOperand.Length - 1);
        strSecondValue = XPConvert.ToString(GetAnyStateVariable(strVariable));
        if (null == strSecondValue)
        {
          return new HTMLComment("Empty value returned for second operand variable in " + EXPR.GetName() + " attribute in " + TAG.GetName() + " tag.  Second operand: " + strSecondOperand);
          }
      } else
      {
        strSecondValue = strSecondOperand;
      }
      bool bResult;
      // Calculate result
      if (op == StringOperators.OP_EQUAL)
      {
        bResult = (XPStringUtility.Compare(strFirstValue, strSecondValue) == 0);
        } else
      if (op == StringOperators.OP_NOT_EQUAL)
      {
        bResult = (XPStringUtility.Compare(strFirstValue, strSecondValue) != 0);
        } else
      {
        return new HTMLComment("Invalid operator in " + EXPR.GetName() + " attribute in " + TAG.GetName() + " tag.  Valid operators include: " + StringOperators.OP_EQUAL + " and " + StringOperators.OP_NOT_EQUAL);
        }
      // Determine the appropriate scope
      Scope scope = Scope.GetScope(GetTagAttributeAsString(SCOPE));
      if (null == scope)
      {
        log.Warn("Unable to convert scope attribute " + GetTagAttributeAsString(SCOPE) + " to a valid scope in Tag " + TAG.GetName() + ".");
        scope = Scope.PORTLET_REQUEST;
      }
      // Store the filled out data collection in its final location.
      SetStateSharedVariable(GetTagAttributeAsString(KEY), XPConvert.ToString(bResult),
       scope, false);
      return ProcessTagBody();
    }
    
    /// <summary>
    /// This helper method finds a string operator in an
    /// expression string.
    /// </summary>
    /// <param name="_strExpr"></param>
    /// <returns></returns>
    public virtual StringOperators FindOperator(String _strExpr)
    {
      int nFirstSpace = XPStringUtility.IndexOf(_strExpr, ' ');
      // first space must be after ($x) 
      if (nFirstSpace < (IfTag.OPERAND_VARIABLE_PREFIX.Length + 2))
      {
        throw new XPFormatException("Invalid expression \'" + _strExpr + "\' in " + EXPR.GetName() + " attribute in " + TAG.GetName() + " tag.  Operator must be surrounded by spaces.");
        }
      String strOperator = XPStringUtility.Substring(_strExpr, nFirstSpace + 1,
       _strExpr.Length);
      strOperator = XPStringUtility.Trim(strOperator);
      int nSecondSpace = XPStringUtility.IndexOf(strOperator, ' ');
      // must have space after the operand
      if (nSecondSpace < 1)
      {
        throw new XPFormatException("Invalid expression \'" + _strExpr + "\' in " + EXPR.GetName() + " attribute in " + TAG.GetName() + " tag.  Operator must be surrounded by spaces.");
        }
      strOperator = XPStringUtility.Substring(strOperator, 0, nSecondSpace);
      StringOperators[] ops = StringOperators.ops;
      for (int i = 0;i < ops.Length;i++)
      {
        if (XPStringUtility.Compare(strOperator, ops[i].ToString()) >= 0)
        {
          return ops[i];
        }
      }
      throw new XPIllegalArgumentException("Unable to locate valid " + "string operator in expression: " + _strExpr);
      }
    public override bool SupportsAccessStyle(AccessStyles style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    public override ATag Create()
    {
      return new StringExprTag();
    }
  }
}