using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.logic
{
  /// <summary>
  /// This tag evaluates an expression and displays the result.
  /// </summary>
  public class ValueTag : AEncodeTag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute VALUE;
    public static readonly OptionalTagAttribute ENCODE;
    static ValueTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("value", "This tag evaluates the attribute as a Transformer Tag attribute " + "and displays the value.",
       "<![CDATA[&lt;pt:logic.value pt:value=\"$var\"/&gt;]]><![CDATA[<br>]]>" + "would display the value stored in var and <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:logic.value pt:value=\"$data.var\"/&gt;]]><![CDATA[<br>]]>" + "would display the value stored in the IDataObject data with the key var.");
      VALUE = new RequiredTagAttribute("value", "The value to be displayed. Any displayed value is HTML encoded unless specified by the encode attribute.");
      ENCODE = new OptionalTagAttribute(ENCODE_ATTR_NAME, ENCODE_ATTR_DESC,
       AttributeType.INT, XPConvert.ToString(ENCODE_HTML));
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLElement result = new HTMLElementCollection();
      String encodedVal = EncodeString(GetTagAttributeAsString(VALUE));
      result.AddInnerHTMLString(encodedVal);
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any content by itself, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new ValueTag();
    }
    
    /// <seealso cref="com.plumtree.taglib.logic.AEncodeTag#GetEncoding()"></seealso>
    protected override int GetEncoding()
    {
      return GetTagAttributeAsInt(ENCODE);
    }
  }
}