using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.logic;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.logic.test
{
  /// <summary>
  /// Tests AppendHierarchicalDataTag tag
  /// </summary>
  /// <author>rozhang</author>
  public class AppendHierarchicalDataTagTest : TestCase
  {
    internal static readonly String TAG_LIBNAME = LogicTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_NAME = AppendHierarchicalDataTag.TAG.GetName();
    internal static readonly String TAG_ATTRIB_ID = AppendHierarchicalDataTag.ATTRIB_ID.GetName();
    internal static readonly String TAG_ATTRIB_SCOPE = AppendHierarchicalDataTag.ATTRIB_SCOPE.GetName();
    internal static readonly String TAG_ATTRIB_DATAID = AppendHierarchicalDataTag.ATTRIB_DATAID.GetName();
    internal static readonly String TAG_ATTRIB_DATASCOPE = AppendHierarchicalDataTag.ATTRIB_DATASCOPE.GetName();
    internal static readonly String TAG_ATTRIB_INDEX = AppendHierarchicalDataTag.ATTRIB_INDEX.GetName();
    internal MockEnvironment m_mockEnv = null;
    
    /// <seealso cref="junit.framework.TestCase#setUp()"></seealso>
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new AppendHierarchicalDataTag());
      }
    
    /// <summary>
    /// Helper function to setup hierarchical data with default child key
    /// Adds the following entries (entries separated with -)
    /// 0 - 1 - 2 - 0,0 - 0,1 - 1,0 - 1,1 
    /// </summary>
    /// <returns></returns>
    public virtual XPArrayList setUpTestHierData()
    {
      // root list in the data tag variable
      XPArrayList tagVar = new XPArrayList();
      // creating 0,0 and 0,1
      HashtableDataObject firstEntry = TagTestHelper.CreateHierDataHelper(2);
      // creating 0,0 and 0,1
      HashtableDataObject midEntry = TagTestHelper.CreateHierDataHelper(2);
      // 0 - 0,0 - 0,1
      tagVar.Add(firstEntry);
      // 1 - 1,0 - 1,1
      tagVar.Add(midEntry);
      // 2
      tagVar.Add(new HashtableDataObject());
      return tagVar;
    }
    
    /// <summary>
    /// Tests creating a new hier data structure and appending to existing top level list. Both use an empty index value
    /// </summary>
    public virtual void testTopLevelAppend()
    {
      // data that is added
      HashtableDataObject addData = new HashtableDataObject();
      // so that we can check that it is the test data
      addData.SetData("test", "test");
      String addDataName = "adddata";
      String destDataName = "destdata";
      // set the initial data tag variables in tag scope
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      // set tag variable with data to add to hier data structure
      mockState.SetTagHTTPRequestVar(null, addDataName, addData, m_mockEnv);
      // set the initial hier data structure
      mockState.SetTagPortletRequestVar(null, destDataName, setUpTestHierData());
      // attributes 
      XPHashtable attribs = new XPHashtable();
      attribs.PutElement(TAG_ATTRIB_ID, destDataName);
      attribs.PutElement(TAG_ATTRIB_DATAID, addDataName);
      attribs.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.ToString());
      // empty index to create a new hier data structure in the tag variable
      attribs.PutElement(TAG_ATTRIB_INDEX, "");
      HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
       attribs, m_mockEnv);
      assertTrue("Data tag return HTML: " + result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
      Object newData = mockState.GetTagPortletRequestVar(destDataName);
      assertTrue("Set data in tag variable is not an XPArrayList: " + newData,
       newData is XPArrayList);
      XPArrayList newListData = (XPArrayList) newData;
      assertTrue("Set data in tag variable is not the data that was added!",
       (newListData).GetElement(newListData.GetSize() - 1).Equals(addData));
      mockState = TagTestHelper.GetMockTagStateInstance();
      result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribs,
       m_mockEnv);
      assertTrue("Data tag return HTML: " + result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
      newData = mockState.GetTagPortletRequestVar(destDataName);
      assertTrue("Set data in tag variable is not an XPArrayList: " + newData,
       newData is XPArrayList);
      assertEquals("Set data in tag variable is not the data that was added!",
       ((XPArrayList) newData).GetElement(0), addData);
    }
    
    /// <summary>
    /// Test append of hierarchical data 
    /// </summary>
    public virtual void testAppendOfHierData()
    {
      // data that is added
      XPArrayList addData = setUpTestHierData();
      String addDataName = "adddata";
      String destDataName = "destdata";
      // set the initial data tag variables in tag scope
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      // set tag variable with data to add to hier data structure
      mockState.SetTagHTTPRequestVar(null, addDataName, addData, m_mockEnv);
      // set the initial hier data structure
      mockState.SetTagPortletRequestVar(null, destDataName, setUpTestHierData());
      // attributes 
      XPHashtable attribs = new XPHashtable();
      attribs.PutElement(TAG_ATTRIB_ID, destDataName);
      attribs.PutElement(TAG_ATTRIB_DATAID, addDataName);
      attribs.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.ToString());
      attribs.PutElement(TAG_ATTRIB_INDEX, "1");
      HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
       attribs, m_mockEnv);
      assertTrue("Data tag return HTML: " + result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
      Object newData = mockState.GetTagPortletRequestVar(destDataName);
      assertTrue("Set data in tag variable is not an XPArrayList: " + newData,
       newData is XPArrayList);
      XPArrayList newListData = (XPArrayList) newData;
      // verify 1,1,1,1 exists
      assertTrue("No data found at the expected index 1,3,1", TagTestHelper.GetDataObjAtIndex("1,3,1",
       newListData) != null);
    }
    
    /// <summary>
    /// Test appending data list
    /// </summary>
    public virtual void testAppendListData()
    {
      // data that is added
      XPArrayList addList = new XPArrayList();
      HashtableDataObject addData = TagTestHelper.CreateHierDataHelper(2);
      // so that we can check that it is the test data
      addData.SetData("test", "test");
      addList.Add(addData);
      addList.Add(addData);
      addList.Add(addData);
      String addDataName = "adddata";
      String destDataName = "destdata";
      // set the initial data tag variables in tag scope
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      XPArrayList destList = setUpTestHierData();
      int origSize = destList.GetSize();
      // set tag variable with data to add to hier data structure
      // create separate instances to avoid funkiness since we are performing appends on appended lists
      mockState.SetTagHTTPRequestVar(null, addDataName + "0", addList.Clone(),
       m_mockEnv);
      mockState.SetTagHTTPRequestVar(null, addDataName + "1", addList.Clone(),
       m_mockEnv);
      mockState.SetTagHTTPRequestVar(null, addDataName + "2", addList.Clone(),
       m_mockEnv);
      mockState.SetTagHTTPRequestVar(null, addDataName + "3", addList.Clone(),
       m_mockEnv);
      // set the initial hier data structure
      mockState.SetTagHTTPRequestVar(null, destDataName, destList, m_mockEnv);
      // attributes 
      XPHashtable attribs = new XPHashtable();
      attribs.PutElement(TAG_ATTRIB_ID, destDataName);
      attribs.PutElement(TAG_ATTRIB_SCOPE, Scope.HTTP_REQUEST.ToString());
      attribs.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.ToString());
      // First add to top level list
      // Then append to the child list in the recently added list
      // Append twice to a child list
      // 
      String[] indexValues = new String[]{"", "4", "1", "1"};
      for (int i = 0;i < indexValues.Length;i++)
      {
        XPSystem.Out.WriteLine("testAppendListData - running: " + i + " with index: " + indexValues[i]);
        attribs.PutElement(TAG_ATTRIB_DATAID, addDataName + i);
        // set the index from the array in the attribute value array to pass in
        attribs.PutElement(TAG_ATTRIB_INDEX, indexValues[i]);
        HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
         attribs, m_mockEnv);
        assertTrue("Data tag return HTML: " + result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
        }
      Object newData = mockState.GetTagHTTPRequestVar(destDataName, m_mockEnv);
      assertTrue("Set data in tag variable is not an XPArrayList: " + newData,
       newData is XPArrayList);
      // test first index
      XPArrayList newListData = (XPArrayList) newData;
      // from adding to top level
      assertEquals("Set list in tag variable is not of the expected size!",
       newListData.GetSize(), origSize + addList.GetSize());
      // test second index
      IHierarchicalDataObject entry = TagTestHelper.GetDataObjAtIndex("4",
       newListData);
      assertEquals("Unexpected number of child entries after append", addData.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY).GetSize(),
       entry.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY).GetSize());
      // test third and fourth index
      // there were 2 children at index "1", should 2 plus twice the number the children in the add data  
      entry = TagTestHelper.GetDataObjAtIndex("1", newListData);
      assertEquals("Unexpected number of child entries after append", (addList.GetSize() * 2) + 2,
       entry.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY).GetSize());
      }
  }
}