using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.logic;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.logic.test
{
  /// <summary>
  /// Unit Tests for the AttachHierarchicalDataTag
  /// </summary>
  /// <author>rozhang</author>
  public class ReplaceHierarchicalDataTagTest : TestCase
  {
    internal static readonly String TAG_LIBNAME = LogicTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_NAME = ReplaceHierarchicalDataTag.TAG.GetName();
    internal static readonly String TAG_ATTRIB_ID = ReplaceHierarchicalDataTag.ATTRIB_ID.GetName();
    internal static readonly String TAG_ATTRIB_SCOPE = ReplaceHierarchicalDataTag.ATTRIB_SCOPE.GetName();
    internal static readonly String TAG_ATTRIB_DATAID = ReplaceHierarchicalDataTag.ATTRIB_DATAID.GetName();
    internal static readonly String TAG_ATTRIB_DATASCOPE = ReplaceHierarchicalDataTag.ATTRIB_DATASCOPE.GetName();
    internal static readonly String TAG_ATTRIB_INDEX = ReplaceHierarchicalDataTag.ATTRIB_INDEX.GetName();
    internal MockEnvironment m_mockEnv = null;
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new ReplaceHierarchicalDataTag());
      }
    
    /// <summary>
    /// Helper function to setup hierarchical data with default child key
    /// Adds the following entries (entries separated with -)
    /// 0 - 1 - 2 - 0,0 - 0,1
    /// </summary>
    /// <returns></returns>
    public virtual XPArrayList setUpTestHierData()
    {
      // root list in the data tag variable
      XPArrayList tagVar = new XPArrayList();
      // creating 0,0 and 0,1
      HashtableDataObject firstEntry = TagTestHelper.CreateHierDataHelper(2);
      // 0
      tagVar.Add(firstEntry);
      // 1
      tagVar.Add(new HashtableDataObject());
      // 2
      tagVar.Add(new HashtableDataObject());
      return tagVar;
    }
    
    /// <summary>
    /// Takes a existing hierarchical data variable and attaches additional data to it
    /// Tests the index attribute to ensure that data are properly attached
    /// </summary>
    public virtual void testAddOneDimensionalData()
    {
      // setup data tag to add, same data instance is added to different locations
      // shouldn't need to add unique data to each position, we are just checking that data is attached 
      XPArrayList dataTagVar = new XPArrayList();
      dataTagVar.Add(new HashtableDataObject());
      dataTagVar.Add(new HashtableDataObject());
      // name of the tag variables to set in tag scope
      String tagDataVarName = "testdata";
      String hierDataVarName = "hierdata";
      // set the initial data tag variables in tag scope
      TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
      // set on http request scope since we are running the execute tag function multiple which creates multiple portlet requests
      // set tag variable with data to add to hier data structure
      tagState.SetTagHTTPRequestVar(null, tagDataVarName, dataTagVar, m_mockEnv);
      // set the initial hier data structure
      tagState.SetTagHTTPRequestVar(null, hierDataVarName, setUpTestHierData(),
       m_mockEnv);
      // the indices to add data to
      String[] indexValues = new String[]{"0,1", "1", "1,1", "0,1,1", "0,0",
       "0,0,0"};
      // attribute list of names and valies
      String[] attribNames = new String[]{TAG_ATTRIB_ID, TAG_ATTRIB_SCOPE,
       TAG_ATTRIB_DATAID, TAG_ATTRIB_DATASCOPE, TAG_ATTRIB_INDEX};
      // last value is a place holder, will get set later
      String[] attribValues = new String[]{hierDataVarName, Scope.HTTP_REQUEST.ToString(),
       tagDataVarName, Scope.HTTP_REQUEST.ToString(), ""};
      // run the attach tag multiple times with all the indices defined in indexValues array to simulate multiple attach tags
      for (int i = 0;i < indexValues.Length;i++)
      {
        //XPSystem.Out.WriteLine("Running: "+i+" with index: "+indexValues[i]);
        // set the index from the array in the attribute value array to pass in
        attribValues[4] = indexValues[i];
        HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
         attribNames, attribValues, m_mockEnv);
        assertTrue("Data tag return HTML: " + result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
        }
      // get the final hierarchical data structure from tag scope
      XPArrayList data = (XPArrayList) tagState.GetTagHTTPRequestVar(hierDataVarName,
       m_mockEnv);
      assertTrue("No hierarchical tag data was found with the variable name: " + hierDataVarName,
       data != null);
      // verify values
      for (int i = 0;i < indexValues.Length;i++)
      {
        assertTrue("No DataObject found at index position: " + indexValues[i],
         TagTestHelper.GetDataObjAtIndex(indexValues[i], data) != null);
      }
    }
    
    /// <summary>
    /// Takes a existing hierarchical data variable and attaches additional hierarchical data to it
    /// Tests the index attribute to ensure that data are properly attached
    /// </summary>
    public virtual void testAddHierarchicalData()
    {
      // setup data tag to add, same value instance is used multiple times
      // Data contains the following indices (- separated): 0 - 1 - 2 - 1,0 - 1,1 - 1,1,0 - 1,1,1 - 1,1,2
      XPArrayList topList = new XPArrayList();
      // create the 1,0 and 1,1 data
      IHierarchicalDataObject middle = TagTestHelper.CreateHierDataHelper(2);
      // 0
      topList.Add(new HashtableDataObject());
      // 1 
      topList.Add(middle);
      // 2
      topList.Add(new HashtableDataObject());
      // get 1,1
      IHierarchicalDataObject child = TagTestHelper.GetHierDataChildAtIndex(1,
       middle);
      // create 1,1,0 - 1,1,1 - 1,1,2
      TagTestHelper.SetHierDataChildren(3, child);
      // name of the tag variables to set in tag scope
      String tagDataVarName = "testdata";
      String hierDataVarName = "hierdata";
      // set the initial data tag variables in tag scope
      TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
      // set tag variable with data to add to hier data structure
      tagState.SetTagHTTPRequestVar(null, tagDataVarName, topList, m_mockEnv);
      // set the initial hier data structure
      tagState.SetTagHTTPRequestVar(null, hierDataVarName, setUpTestHierData(),
       m_mockEnv);
      // the indices to add data to
      String[] indexValues = new String[]{"2", "0,1"};
      // attribute list of names and values
      String[] attribNames = new String[]{TAG_ATTRIB_ID, TAG_ATTRIB_SCOPE,
       TAG_ATTRIB_DATAID, TAG_ATTRIB_DATASCOPE, TAG_ATTRIB_INDEX};
      // last value is a place holder, will get set later
      String[] attribValues = new String[]{hierDataVarName, Scope.HTTP_REQUEST.ToString(),
       tagDataVarName, Scope.HTTP_REQUEST.ToString(), ""};
      // run the attach tag multiple times with all the indices defined in indexValues array to simulate multiple attach tags
      for (int i = 0;i < indexValues.Length;i++)
      {
        XPSystem.Out.WriteLine("testAddHierarchicalData - running: " + i + " with index: " + indexValues[i]);
        // set the index from the array in the attribute value array to pass in
        attribValues[4] = indexValues[i];
        HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
         attribNames, attribValues, m_mockEnv);
        assertTrue("Data tag return HTML: " + result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
        }
      // get the final hierarchical data structure from tag scope
      XPArrayList data = (XPArrayList) tagState.GetTagHTTPRequestVar(hierDataVarName,
       m_mockEnv);
      assertTrue("No hierarchical tag data was found with the variable name: " + hierDataVarName,
       data != null);
      // verify values
      for (int i = 0;i < indexValues.Length;i++)
      {
        assertTrue("No DataObject found at index position: " + indexValues[i],
         TagTestHelper.GetDataObjAtIndex(indexValues[i], data) != null);
      }
    }
    
    /// <summary>
    /// Test with invalid index, expect error message
    /// </summary>
    public virtual void testIndexAttributeErrorCases()
    {
      // setup data tag to add, same data instance is added to different locations
      // shouldn't need to add unique data to each position, we are just checking that data is attached 
      XPArrayList dataTagVar = new XPArrayList();
      dataTagVar.Add(new HashtableDataObject());
      // name of the tag variables to set in tag scope
      String tagDataVarName = "testdata";
      String hierDataVarName = "hierdata";
      // set the initial data tag variables in tag scope
      TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
      // set on http request scope since we are running the execute tag function multiple which creates multiple portlet requests
      // set tag variable with data to add to hier data structure
      tagState.SetTagPortletRequestVar(null, tagDataVarName, dataTagVar);
      // set the initial hier data structure
      tagState.SetTagPortletRequestVar(null, hierDataVarName, setUpTestHierData());
      // attribute list of names and valies
      String[] attribNames = new String[]{TAG_ATTRIB_ID, TAG_ATTRIB_DATAID,
       TAG_ATTRIB_INDEX};
      // invalid index
      String[] attribValues = new String[]{hierDataVarName, tagDataVarName,
       "3"};
      HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
       attribNames, attribValues, m_mockEnv);
      // look for the exception type and one word in the error message
      assertTrue("Data tag return HTML: " + result.GetDisplayString(), XPStringUtility.IndexOf(result.GetDisplayString(),
       "XPIllegalArgumentException") != -1 && XPStringUtility.IndexOf(result.GetDisplayString(),
       "Index") != -1);
    }
  }
}