using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.logic;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.logic.test
{
  /// <author>rozhang</author>
  public class TagDataSessionCacheTagTest : TestCase
  {
    internal static readonly String TAG_LIBNAME = LogicTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_NAME = TagDataSessionCacheTag.TAG.GetName();
    internal static readonly String TAG_ATTRIB_DATAID = TagDataSessionCacheTag.ATTRIB_DATAID.GetName();
    internal static readonly String TAG_ATTRIB_DATASCOPE = TagDataSessionCacheTag.ATTRIB_DATASCOPE.GetName();
    internal static readonly String TAG_ATTRIB_CACHEID = TagDataSessionCacheTag.ATTRIB_CACHEID.GetName();
    internal static readonly String TAG_ATTRIB_CONTEXT = TagDataSessionCacheTag.ATTRIB_CONTEXTID.GetName();
    internal static readonly String TAG_ATTRIB_EXPIRATION = TagDataSessionCacheTag.ATTRIB_EXPIRATION.GetName();
    // hard coding the reference here so we dont have to add reference to data tag l
    internal static readonly String DATATAG_LIBNAME = LogicTagLibraryData.LIBRARY.GetName();
    internal static readonly String DATATAG_NAME = VariableTag.TAG.GetName();
    internal static readonly String DATATAG_KEY = VariableTag.KEY.GetName();
    internal static readonly String DATATAG_KEYSCOPE = VariableTag.SCOPE.GetName();
    internal static readonly String DATATAG_VALUE = VariableTag.VALUE.GetName();
    internal MockEnvironment m_mockEnv = null;
    internal String m_oldDataValue = "old";
    internal String m_newDataValue = "new";
    // this is the value that the cached data tag will use
    internal String m_cacheValueVarId = "cacheValue";
    internal String m_dataKey = "dataVar";
    internal String m_context = "511";
    internal XMLFragmentTestHelper m_dataTag;
    
    /// <seealso cref="junit.framework.TestCase#setUp()"></seealso>
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTags(TAG_LIBNAME, new String[]{TAG_NAME, DATATAG_NAME},
       new ATag[]{new TagDataSessionCacheTag(), new VariableTag()});
      // setup the variable tag to use the data value 
      XPHashtable dataargs = new XPHashtable();
      dataargs.PutElement(DATATAG_KEY, m_dataKey);
      dataargs.PutElement(DATATAG_KEYSCOPE, Scope.HTTP_REQUEST.ToString());
      // reference the data value from the tag variable
      dataargs.PutElement(DATATAG_VALUE, "$" + m_cacheValueVarId);
      m_dataTag = XMLFragmentTestHelper.CreateTag(DATATAG_LIBNAME, DATATAG_NAME,
       dataargs);
    }
    
    /// <summary>
    /// Test caching by using a variable tag inside the cache tag. The value of the variable tag (data tag being cached) is read from another
    /// tag variable.
    /// 1. Run cache tag. The variable tag is executed inside the cache tag and the data cached.
    /// 2. We then change the value of the tag variable the variable tag gets its value from and run the cache tag again. 
    /// 3. Run cache tag again. The idea is that we know the caching works if the cache tag uses the cache value instead of the new value. 
    /// </summary>
    public virtual void testCachingWithContext()
    {
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_oldDataValue,
       m_mockEnv);
      XPHashtable args = new XPHashtable();
      // the name of the data var
      args.PutElement(TAG_ATTRIB_DATAID, m_dataKey);
      // context
      args.PutElement(TAG_ATTRIB_CONTEXT, m_context);
      // scope of the data var
      args.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.ToString());
      // expiration isn't used in this test so this value doesn't matter but it is required by the tag
      args.PutElement(TAG_ATTRIB_EXPIRATION, "2");
      HTMLElement result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME,
       args, m_dataTag, m_mockEnv);
      assertTrue("Cache tag returned unexpected content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // verify that the tag variable contains the expected value
      Object dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
      assertEquals("Tag variable does not contain expected value after running cache tag!",
       m_oldDataValue, dataVar);
      // Now let's change the value of the cacheValue variable and the run the cache tag again
      // if the cached version is used the cache tag sets the dataVar variable with value 'old', otherwise the variable tag is run and the 
      // dataVar variable contains value 'new'
      mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_newDataValue,
       m_mockEnv);
      result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME, args, m_dataTag,
       m_mockEnv);
      assertTrue("Cache tag returned unexpected content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
      assertEquals("Tag variable does not contain expected value after running cache tag!",
       m_oldDataValue, dataVar);
    }
    
    /// <summary>
    /// Same as testCachingWithContext but with custom cache key 
    /// </summary>
    public virtual void testCachingWithCustomCacheKey()
    {
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_oldDataValue,
       m_mockEnv);
      XPHashtable args = new XPHashtable();
      // the name of the data var
      args.PutElement(TAG_ATTRIB_DATAID, m_dataKey);
      // context
      args.PutElement(TAG_ATTRIB_CONTEXT, m_context);
      // custom cache key
      args.PutElement(TAG_ATTRIB_CACHEID, "customkey");
      // scope of the data var
      args.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.ToString());
      // expiration isn't used in this test so this value doesn't matter but it is required by the tag
      args.PutElement(TAG_ATTRIB_EXPIRATION, "2");
      HTMLElement result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME,
       args, m_dataTag, m_mockEnv);
      assertTrue("Cache tag returned unexpected content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // verify that the tag variable contains the expected value
      Object dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
      assertEquals("Tag variable does not contain expected value after running cache tag!",
       m_oldDataValue, dataVar);
      // Now let's change the value of the cacheValue variable and the run the cache tag again
      // if the cached version is used the cache tag sets the dataVar variable with value 'old', otherwise the variable tag is run and the 
      // dataVar variable contains value 'new'
      mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_newDataValue,
       m_mockEnv);
      result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME, args, m_dataTag,
       m_mockEnv);
      assertTrue("Cache tag returned unexpected content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
      assertEquals("Tag variable does not contain expected value after running cache tag!",
       m_oldDataValue, dataVar);
    }
    
    /// <summary>
    /// The test expires the cache entry by changing the cache entry in the cache entry tag variable so that the test
    /// doesnt have to run for x minutes for the entry to actually expire 
    /// </summary>
    public virtual void testCacheExpiration()
    {
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      // set the cache value
      mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_oldDataValue,
       m_mockEnv);
      XPHashtable args = new XPHashtable();
      // the name of the data var
      args.PutElement(TAG_ATTRIB_DATAID, m_dataKey);
      // scope of the data var
      args.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.ToString());
      // we manually expire the cache entry so this value doesn't matter in this test
      args.PutElement(TAG_ATTRIB_EXPIRATION, "2");
      HTMLElement result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME,
       args, m_dataTag, m_mockEnv);
      assertTrue("Cache tag returned unexpected content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // verify that the tag variable contains the expected value
      Object dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
      assertEquals("Tag variable does not contain expected value after running cache tag!",
       m_oldDataValue, dataVar);
      // To simulate cache entry expiration, we change the time in the cache entry.
      // We also change the cache variable value to make sure that the cache tag reruns the variable tag and sets the new value
      // update value to cache
      mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_newDataValue,
       m_mockEnv);
      // get the cache entry by adding the cache entry prefix. The cache id will be the datakey since we explicitly specify a cache id on the cache tag
      XPHashtable cacheMap = (XPHashtable) mockState.GetTagSessionVar(TagState.CACHE_LIB + "." + TagState.CACHE_MAPENTRY_NAME,
       m_mockEnv);
      // the dash is to separate between cache key and cache context, no context is used in this test
      TagCacheEntry cacheEntry = (TagCacheEntry) cacheMap.GetElement("-" + m_dataKey);
      assertTrue("No cache entry found on the session!", cacheEntry != null);
      // expire cache entry
      cacheEntry.ExpireEntry();
      // now run the cache tag again, which should rerun the variable tag and fetch the new value
      result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME, args, m_dataTag,
       m_mockEnv);
      assertTrue("Cache tag returned unexpected content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
      assertEquals("Tag variable does not contain expected value after running cache tag!",
       m_newDataValue, dataVar);
    }
  }
}