using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.taglib.logic;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.logic.test
{
  public class TestForEachTag : TestCase
  {
    public const String DATA_NAME = "myData";
    public const String RESULT_VAR = "myVar";
    public const String NULL_DATA_ERROR = "data collection was null.-->";
    public const String VAR_1 = "my first var";
    public const String VAR_2 = "my second var";
    public MockEnvironment m_environment;
    public override void setUp()
    {
      m_environment = new MockEnvironment();
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new ForEachTag(), ForEachTag.TAG.GetName(), LogicTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new ValueTag(), ValueTag.TAG.GetName(), LogicTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// This method tests computing the length of a null collection.
    /// </summary>
    public virtual void testNullCollection()
    {
      // Initialize null data collection - TagState will use this
      // special hashtable as the portlet request data when it is
      // constructed.
      TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
      SharedStateVariable stateVar = new SharedStateVariable(null);
      // Shared state variables are prefixed with a .
      TagState.TEST_PORTLET_REQUEST_DATA.PutElement("." + DATA_NAME, stateVar);
      // initialize markup
      XMLFragmentTestHelper forEachTagHelper = new XMLFragmentTestHelper(LogicTagLibraryData.LIBRARY.GetName(),
       ForEachTag.TAG.GetName());
      forEachTagHelper.AddPTAttribute(ForEachTag.DATA.GetName(), DATA_NAME);
      forEachTagHelper.AddPTAttribute(ForEachTag.VAR.GetName(), RESULT_VAR);
      forEachTagHelper.AddPTAttribute(ForEachTag.ACCEPTNULLDATA.GetName(),
       "false");
      Object[][] objArrMarkup = forEachTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      int nIndex = XPStringUtility.IndexOf(strResult, NULL_DATA_ERROR);
      Assert.assertTrue("Checking that result HTML contains null data error comment.",
       nIndex > 0);
    }
    
    /// <summary>
    /// This method tests computing the length of a normal collection.
    /// </summary>
    public virtual void testNormalCollection()
    {
      // Initialize normal data collection - TagState will use this
      // special hashtable as the portlet request data when it is
      // constructed.
      XPArrayList collection = new XPArrayList();
      collection.Add(VAR_1);
      collection.Add(VAR_2);
      TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
      SharedStateVariable stateVar = new SharedStateVariable(collection);
      // Shared state variables are prefixed with a .
      TagState.TEST_PORTLET_REQUEST_DATA.PutElement("." + DATA_NAME, stateVar);
      // initialize markup
      XMLFragmentTestHelper valueTagHelper = new XMLFragmentTestHelper(LogicTagLibraryData.LIBRARY.GetName(),
       ValueTag.TAG.GetName());
      valueTagHelper.AddPTAttribute(ValueTag.VALUE.GetName(), "$" + RESULT_VAR);
      XMLFragmentTestHelper forEachTagHelper = new XMLFragmentTestHelper(LogicTagLibraryData.LIBRARY.GetName(),
       ForEachTag.TAG.GetName());
      forEachTagHelper.AddPTAttribute(ForEachTag.DATA.GetName(), DATA_NAME);
      forEachTagHelper.AddPTAttribute(ForEachTag.VAR.GetName(), RESULT_VAR);
      forEachTagHelper.AddContent(valueTagHelper);
      Object[][] objArrMarkup = forEachTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      int nIndex = XPStringUtility.IndexOf(strResult, NULL_DATA_ERROR);
      Assert.assertTrue("Checking that result HTML does not contain null data error comment.",
       nIndex < 0);
      nIndex = XPStringUtility.IndexOf(strResult, VAR_1);
      Assert.assertTrue("Checking that result HTML contains the first list item.",
       nIndex >= 0);
      nIndex = XPStringUtility.IndexOf(strResult, VAR_2);
      Assert.assertTrue("Checking that result HTML contains the second list item.",
       nIndex >= 0);
    }
  }
}