using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server.mock.core;
using com.plumtree.taglib.logic;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.logic.test
{
  /// <summary>
  /// Tests the sort tag with a data tag and a collections tag with different properties
  /// </summary>
  /// <author>lmah</author>
  public class TestSortLogicTag : TestCase
  {
    public MockEnvironment m_environment;
    public MockLayoutManager m_layoutManager;
    public MockPTSession m_session;
    public MockConfigHelper m_configHelper;
    public MockPTConfigHelper m_helper;
    public override void setUp()
    {
      m_configHelper = new MockConfigHelper();
      ConfigService.setTestInstance(m_configHelper);
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      // Enable layouts globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      // CR ROB: Using mocenvironment instead of the mock as in portletpage library so you don't have to depend on that project
      m_environment = new MockEnvironment();
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      m_layoutManager = new MockLayoutManager();
      LayoutService.setManagerTestInstance(m_layoutManager);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new SortTag(), SortTag.TAG.GetName(), LogicTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    public virtual void testSortLogic()
    {
      //variables for the original data tag
      String mypages = "mypages";
      String testcollection = "testcollection";
      //variables for the sorted data tag
      String sortedmypages = "sortedmypages";
      String sortedtestcollection = "sortedtestcollection";
      String mypages1 = "any Page";
      String mypages2 = "BEA Page";
      String mypages3 = "Home Page";
      String mypages4 = "Testing Page";
      HashtableDataObject page1 = new HashtableDataObject();
      page1.SetData("url", "http://portalserver:8080/portal/server.pt/Home Page/200");
      page1.SetData("title", "Home Page");
      HashtableDataObject page2 = new HashtableDataObject();
      page2.SetData("url", "http://portalserver:8080/portal/server.pt/BEA Page/201");
      page2.SetData("title", "BEA Page");
      HashtableDataObject page3 = new HashtableDataObject();
      page3.SetData("url", "http://portalserver:8080/portal/server.pt/Testing Page/202");
      page3.SetData("title", "Testing Page");
      HashtableDataObject page4 = new HashtableDataObject();
      page4.SetData("url", "http://portalserver:8080/portal/server.pt/any Page/203");
      page4.SetData("title", "any Page");
      XPArrayList mypagesList = new XPArrayList();
      mypagesList.Add(page1);
      mypagesList.Add(page2);
      mypagesList.Add(page3);
      mypagesList.Add(page4);
      String url1 = "http://www.bea.com";
      String url2 = "http://www.microsoft.com";
      String url3 = "http://www.myco.com";
      // CR ROB: I would add some additional properties that are not used by the sort too
      //variables for the properties
      String prop1 = "url";
      String prop3 = "title";
      HashtableDataObject mycol1 = new HashtableDataObject();
      mycol1.SetData("url", "http://www.myco.com");
      mycol1.SetData("name", "My Company");
      HashtableDataObject mycol2 = new HashtableDataObject();
      mycol2.SetData("url", "http://www.bea.com");
      mycol2.SetData("name", "Bea Systems");
      HashtableDataObject mycol3 = new HashtableDataObject();
      mycol3.SetData("url", "http://www.microsoft.com");
      mycol3.SetData("name", "Microsoft Corp");
      XPArrayList collectionList = new XPArrayList();
      collectionList.Add(mycol1);
      collectionList.Add(mycol2);
      collectionList.Add(mycol3);
      // CR ROB: Describe what you are doing here
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      SharedStateVariable stateVar = new SharedStateVariable(mypagesList);
      scopeData.PutElement("." + mypages, stateVar);
      SharedStateVariable stateVar2 = new SharedStateVariable(collectionList);
      scopeData.PutElement("." + testcollection, stateVar2);
      // CR ROB: describe the tags you are using and what they are doing
      // initialize markup		
      XMLFragmentTestHelper sortLogicTag1 = new XMLFragmentTestHelper(LogicTagLibraryData.LIBRARY.GetName(),
       SortTag.TAG.GetName());
      sortLogicTag1.AddPTAttribute(SortTag.DATA.GetName(), mypages);
      sortLogicTag1.AddPTAttribute(SortTag.SORTEDDATA.GetName(), sortedmypages);
      sortLogicTag1.AddPTAttribute(SortTag.PROPERTY.GetName(), prop3);
      // set it on the http request so that we can easily access it
      sortLogicTag1.AddPTAttribute(SortTag.SCOPE.GetName(), Scope.HTTP_REQUEST + "");
      sortLogicTag1.AddPTAttribute(SortTag.SORTEDSCOPE.GetName(), Scope.HTTP_REQUEST + "");
      XMLFragmentTestHelper sortLogicTag2 = new XMLFragmentTestHelper(LogicTagLibraryData.LIBRARY.GetName(),
       SortTag.TAG.GetName());
      sortLogicTag2.AddPTAttribute(SortTag.DATA.GetName(), testcollection);
      sortLogicTag2.AddPTAttribute(SortTag.SORTEDDATA.GetName(), sortedtestcollection);
      sortLogicTag2.AddPTAttribute(SortTag.PROPERTY.GetName(), prop1);
      // set it on the http request so that we can easily access it
      sortLogicTag2.AddPTAttribute(SortTag.SCOPE.GetName(), Scope.HTTP_REQUEST + "");
      sortLogicTag2.AddPTAttribute(SortTag.SORTEDSCOPE.GetName(), Scope.HTTP_REQUEST + "");
      XMLFragmentTestHelper sortLogicTags = new XMLFragmentTestHelper(new XMLFragmentTestHelper[]{sortLogicTag1,
       sortLogicTag2});
      Object[][] markup = sortLogicTags.ToArrayEntireFragment();
      HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
      scopeData = TagState.GetHTTPRequestData(m_environment);
      // CR ROB: describe what is happening here
      // for some reason the names are prefixed with a '.'
      Object o1 = scopeData.GetElement("." + sortedmypages);
      Object o2 = scopeData.GetElement("." + sortedtestcollection);
      if (o1 == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + mypages + " set in tag memory");
        }
      if (o2 == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + testcollection + " set in tag memory");
        }
      try
      {
        // CR ROB: describe what you are checking
        XPArrayList datalist1 = (XPArrayList) ((SharedStateVariable) o1).GetValue();
        XPArrayList datalist2 = (XPArrayList) ((SharedStateVariable) o2).GetValue();
        Assert.assertEquals(4, datalist1.GetSize());
        testTagData(mypages1, prop3, (IDataObject) datalist1.GetElement(0));
        testTagData(mypages2, prop3, (IDataObject) datalist1.GetElement(1));
        testTagData(mypages3, prop3, (IDataObject) datalist1.GetElement(2));
        testTagData(mypages4, prop3, (IDataObject) datalist1.GetElement(3));
        Assert.assertEquals(3, datalist2.GetSize());
        // return values are string so make sure to compare with strings
        testTagData(url1, prop1, (IDataObject) datalist2.GetElement(0));
        testTagData(url2, prop1, (IDataObject) datalist2.GetElement(1));
        testTagData(url3, prop1, (IDataObject) datalist2.GetElement(2));
      }
      catch (XPException e)
      {
        fail("Found expected tag variable but it was not of the expected type. See stacktrace below for exact issue.");
        e.PrintStackTrace();
      }
    }
    
    /// <summary>
    /// Helper method to check the content in a portlet data tag variable
    /// </summary>
    /// <param name="name"></param>
    /// <param name="property"></param>
    /// <param name="tagData"></param>
    protected virtual void testTagData(String name, String property, IDataObject tagData)
    {
      try
      {
        Assert.assertEquals(name + "", tagData.GetData(property));
      }
      catch (XPException ex)
      {
        fail("name is:  " + name + " and tagData is:  " + tagData.GetData(property));
        ex.PrintStackTrace();
      }
    }
  }
}