package com.plumtree.taglib.logic;

import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * This tag evaluates an expression and displays the result.
 */
public abstract class AEncodeTag extends ATag
{
	public static final int ENCODE_NONE = 0;
	public static final int ENCODE_HTML = 1;
	public static final int ENCODE_URL = 2;
	public static final int ENCODE_JAVASCRIPT = 3;
	
	/**
	 * DCA - below is the atrribute name and description for the encode attribute that will need to be declared
	 * and instatiated by the extending class. The attribute is not declared here so that the extending class
	 * can shoose their own default encoding for the attribute.
	 */
	protected static final String ENCODE_ATTR_NAME = "encode";
	protected static final String ENCODE_ATTR_DESC = "Specify how to encode the URL title or not. "+
		ENCODE_NONE+": No encoding. Not encoding user entered string is a potential security risk as users could insert "+
		"javascript that gets executed on the page. "+
		ENCODE_HTML+": HTML encoding for titles displayed directly on the page. "+
		ENCODE_URL+":  URL encoding for titles used in URLs. "+
		ENCODE_JAVASCRIPT+": Javascript encoding for titles used in Javascript. ";
	
	abstract protected int GetEncoding();
	
	/**
	 * Encodes the string based on the option set on the tag 
	 * 
	 * @param value
	 */
	protected String EncodeString(String value)
	{
		String encoded = value;
		int optEncoding = GetEncoding();
		if ( value != null )
		{
			switch (optEncoding) {
			case ENCODE_HTML:
				encoded = XPHttpUtility.HtmlEncode(value);
				
				break;
			case ENCODE_URL:
				encoded = XPHttpUtility.UrlEncode(value, "UTF-8");
				break;
			case ENCODE_JAVASCRIPT:
				encoded = JSHelper.escapeJS(value);
				break;
			default:
				// don't need to encode anything
				break;
			}
			
		}
		return encoded;
	}
}
