package com.plumtree.taglib.logic;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public abstract class AHierIndexDataTag extends ATag
{
	public static final RequiredTagAttribute ATTRIB_ID;
	public static final OptionalTagAttribute ATTRIB_SCOPE;
	public static RequiredTagAttribute ATTRIB_INDEX;
	public static final OptionalTagAttribute ATTRIB_HIERID;
	
	static {
	
		ATTRIB_ID = new RequiredTagAttribute("target", "Name of the target tag variable.", AttributeType.STRING);
		ATTRIB_SCOPE = new OptionalTagAttribute("scope", "Scope of the target tag variable.", AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
		ATTRIB_HIERID = new OptionalTagAttribute("childkey", "Hierarchical data key if different from the default 'children'. For example, used when adding Community Pages children to Communities.", AttributeType.STRING, "children");
	}
	
	static final String INDEX_ATTRIB_DESC = 
		"The first number specifies index in the top list, and each following number index in lower level lists. 0 represents the first element of a list. "+
		"A value of '2,0,12' inserts data into 3rd entry in the top list, first entry in the second list and 13th entry in the 3rd level list. ";

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	abstract public ATag Create();

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	abstract public HTMLElement DisplayTag();
	
	/**
	 * 
	 * @param topList
	 * @return Hier data object at the specified index or null if the index is an empty string.
	 * @throws XPIllegalArgumentException if the index references an invalid location in the hierarchical structure
	 */
	public IHierarchicalDataObject GetObjectFromIndex(XPArrayList topList)
	{
		String strIndices = GetTagAttributeAsString(ATTRIB_INDEX);
		String hierDataId = GetTagAttributeAsString(ATTRIB_HIERID);
		
		XPStringTokenizer indicesTok = new XPStringTokenizer(strIndices, ",");
		IHierarchicalDataObject currHDO = null;

		XPArrayList children = topList;
		int count = 0;
		for ( ; indicesTok.HasMoreTokens(); count++ )
		{
			if ( count != 0) children = currHDO.GetHierData(hierDataId); // the first iteration the list is the top level list, after that we get it from the current hier data entry 
			
			int currIndex = XPConvert.ToInteger( indicesTok.GetNextToken() );
			
			// error checking
			if ( children == null ) {
				throw new XPIllegalArgumentException("Invalid index: '"+strIndices+"'. No children found at level: "+currIndex+" with id: '"+hierDataId+"'");
			} else if ( currIndex > children.GetSize() ) {
				throw new XPIllegalArgumentException("Invalid index: '"+strIndices+"'. Index at level: "+currIndex+" is greater than the number of children.");
			}
			// set the entry in the specified index as the current hierarchical data parent and traverse again
			if ( currIndex >= children.GetSize() ) {
				throw new XPIllegalArgumentException("Index number "+count+" with value "+currIndex+" at is greater than number of children ("+children.GetSize()+"). Index string: "+strIndices);
			}
			currHDO =  (IHierarchicalDataObject)children.GetElement(currIndex);
		}
		
		return currHDO;
	}
}
