
package com.plumtree.taglib.logic;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tags concatenates two provided values and stores the result
 * in a memory variable with a specified name.
 * 
 * @author robertz
 */
public class ConcatTag extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		"com.plumtree.taglib.logic.BooleanExprTag");
	
	public static String CONCAT_EXAMPLE = 
		"<![CDATA[&lt;pt:logic.variable pt:key=\"somepageid\" pt:value=\"2000\"/&gt;]]><![CDATA[<br>]]>" +
		"<![CDATA[&lt;pt:logic.concat pt:key=\"target\" pt:value1=\"pageid\" pt:value2=\"$somepageid\" /&gt;]]><![CDATA[<br>]]>" +
		"<![CDATA[&lt;pt:logic.value pt:value=\"$target\"/&gt;]]><![CDATA[<br>]]>";
		
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute VALUE1;
	public static final RequiredTagAttribute VALUE2;
	public static final OptionalTagAttribute VALUE3;
	public static final OptionalTagAttribute VALUE4;
	public static final OptionalTagAttribute VALUE5;
	public static final OptionalTagAttribute VALUE6;
	public static final OptionalTagAttribute VALUE7;
	public static final OptionalTagAttribute VALUE8;
	public static final OptionalTagAttribute VALUE9;
	public static final OptionalTagAttribute VALUE10;
	public static final OptionalTagAttribute SCOPE;
	public static final RequiredTagAttribute KEY;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("concat",
			"This tag concatenates up to ten values into one and sets the new value  " +
			"in a variable with a specified name. The first two values are required in " +
			"order to perform a concatenation.",
			CONCAT_EXAMPLE
			);

		VALUE1 = new RequiredTagAttribute("value1",
			"Value added to the front in the final concatenated value.");
		
		VALUE2 = new RequiredTagAttribute("value2",
			"Value added to the back of value1 in the final concatenated value.");
		
		VALUE3 = new OptionalTagAttribute("value3",
			"Value added to the back of value2 in the final concatenated value.",
			AttributeType.STRING, "");
		
		VALUE4 = new OptionalTagAttribute("value4",
			"Value added to the back of value3 in the final concatenated value.",
			AttributeType.STRING, "");
		
		VALUE5 = new OptionalTagAttribute("value5",
			"Value added to the back of value4 in the final concatenated value.",
			AttributeType.STRING, "");
		
		VALUE6 = new OptionalTagAttribute("value6",
			"Value added to the back of value5 in the final concatenated value.",
			AttributeType.STRING, "");
		
		VALUE7 = new OptionalTagAttribute("value7",
			"Value added to the back of value6 in the final concatenated value.",
			AttributeType.STRING, "");
		
		VALUE8 = new OptionalTagAttribute("value8",
			"Value added to the back of value7 in the final concatenated value.",
			AttributeType.STRING, "");
		
		VALUE9 = new OptionalTagAttribute("value9",
			"Value added to the back of value8 in the final concatenated value.",
			AttributeType.STRING, "");
		
		VALUE10 = new OptionalTagAttribute("value10",
			"Value added to the back of value9 in the final concatenated value.",
			AttributeType.STRING, "");

		KEY = new RequiredTagAttribute("key",
			"Name of the resulting concatenated values.");

		SCOPE = new OptionalTagAttribute("scope",
			"The scope used to store the result in memory.  " + LogicTagLibraryData.SCOPE_REFERENCE,
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
	}
	
	public HTMLElement DisplayTag()
	{
		
		// Get the values to concatenate
		String value1 = GetTagAttributeAsString(VALUE1);
		String value2 = GetTagAttributeAsString(VALUE2);
		String value3 = GetTagAttributeAsString(VALUE3);
		String value4 = GetTagAttributeAsString(VALUE4);
		String value5 = GetTagAttributeAsString(VALUE5);
		String value6 = GetTagAttributeAsString(VALUE6);
		String value7 = GetTagAttributeAsString(VALUE7);
		String value8 = GetTagAttributeAsString(VALUE8);
		String value9 = GetTagAttributeAsString(VALUE9);
		String value10 = GetTagAttributeAsString(VALUE10);
		
		// Perform the concat
		String result = value1 + value2 + value3 + value4 + value5 +
						value6 + value7 + value8 + value9 + value10;
		
		// Get the variable name to store the result string
		String varname = GetTagAttributeAsString(KEY);
		
		// Determine the appropriate scope
		Scope scope = Scope.GetScope(GetTagAttributeAsString(SCOPE));
		if (null == scope)
		{
			log.Warn("Unable to convert scope attribute " +
				GetTagAttributeAsString(SCOPE) + " to a valid scope in Tag " +
				TAG.GetName() + ".");

			scope = Scope.PORTLET_REQUEST;
		}

		// Set the resulting variable 
		SetStateSharedVariable(varname, result, scope, false);
		
		return ProcessTagBody();
	}
	
	public boolean SupportsAccessStyle(AccessStyles style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

	public ATag Create()
	{
		
		return new ConcatTag();
	}

}
