package com.plumtree.taglib.logic;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag evaluates whether a shared variable exist and stores
 * the result as a boolean in memory.  It is designed
 * to work with the logic.if tag.
 */
public class ExistExprTag extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		"com.plumtree.taglib.logic.ExistExprTag");

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute DATA;
	public static final RequiredTagAttribute KEY;
	public static final OptionalTagAttribute SCOPE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("existexpr",
			"This tag evaluates whether a shared variable exists and stores " +
			"the result as a boolean in memory.  It is designed " +
			"to work with the logic.if tag.",
			"<![CDATA[&lt;pt:logic.collectionlength pt:data=\"testcollection\" pt:key=\"length\"/&gt;]]><![CDATA[<br>]]>" +
			"<![CDATA[&lt;pt:logic.existexpr pt:data=\"testdata\" pt:key=\"boolvalue\"/&gt;]]><![CDATA[<br>]]>" +
			IfTag.IF_EXAMPLE_IF);

		DATA = new RequiredTagAttribute("data",
				"The key used to retrieve the shared variable from memory.");

		KEY = new RequiredTagAttribute("key",
			"The key used to store the result in memory.");

		SCOPE = new OptionalTagAttribute("scope",
			"The scope used to store the result in memory.  " + LogicTagLibraryData.SCOPE_REFERENCE,
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
	}

	public HTMLElement DisplayTag()
	{
		// DCA - get data key and check if it exists
		String strDataKey = GetTagAttributeAsString(DATA);

		Object oData = GetAnyStateVariable(strDataKey);
		boolean bResult = true;
		if (null == oData) {
			bResult = false;
		}
		
		// DCA - get scope
		Scope scope = Scope.GetScope(GetTagAttributeAsString(SCOPE));
		if (null == scope)
		{
			log.Warn("Unable to convert scope attribute " +
				GetTagAttributeAsString(SCOPE) + " to a valid scope in Tag " +
				TAG.GetName() + ".");

			scope = Scope.PORTLET_REQUEST;
		}

		// Store the boolean of whether the variable exists or not using the specified name.
		SetStateSharedVariable(GetTagAttributeAsString(KEY), XPConvert.ToString(bResult), scope, false);
		
		return ProcessTagBody();
	}

	public boolean SupportsAccessStyle(AccessStyles style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

	public ATag Create()
	{
		return new ExistExprTag();
	}
}