package com.plumtree.taglib.logic;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag evaluates an expression and displays the result.
 */
public class ValueTag extends AEncodeTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute VALUE;
	public static final OptionalTagAttribute ENCODE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("value",
			"This tag evaluates the attribute as a Transformer Tag attribute " +
			"and displays the value.",   
			"<![CDATA[&lt;pt:logic.value pt:value=\"$var\"/&gt;]]><![CDATA[<br>]]>" +
			"would display the value stored in var and <![CDATA[<br>]]>" +
			"<![CDATA[&lt;pt:logic.value pt:value=\"$data.var\"/&gt;]]><![CDATA[<br>]]>" +
			"would display the value stored in the IDataObject data with the key var.");

		VALUE = new RequiredTagAttribute("value", 
				"The value to be displayed. Any displayed value is HTML encoded unless specified by the encode attribute.");

		ENCODE = new OptionalTagAttribute(ENCODE_ATTR_NAME, ENCODE_ATTR_DESC,
			AttributeType.INT, XPConvert.ToString(ENCODE_HTML));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
	    HTMLElement result = new HTMLElementCollection();
	    String encodedVal = EncodeString(GetTagAttributeAsString(VALUE));
	    
	    result.AddInnerHTMLString( encodedVal );
	    
	    return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any content by itself, and therefore
		// supports all access styles.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new ValueTag();
	}

	/**
	 * @see com.plumtree.taglib.logic.AEncodeTag#GetEncoding()
	 */
	protected int GetEncoding() {
		return GetTagAttributeAsInt(ENCODE);
	}
}
