/**
 * 
 */
package com.bea.alui.taglib.logic.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.logic.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tests AppendHierarchicalDataTag tag
 * 
 * @author rozhang
 */
public class AppendHierarchicalDataTagTest extends TestCase
{
	static final String TAG_LIBNAME  		= LogicTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     		= AppendHierarchicalDataTag.TAG.GetName();
	static final String TAG_ATTRIB_ID 		= AppendHierarchicalDataTag.ATTRIB_ID.GetName();
	static final String TAG_ATTRIB_SCOPE 	= AppendHierarchicalDataTag.ATTRIB_SCOPE.GetName();
	static final String TAG_ATTRIB_DATAID	= AppendHierarchicalDataTag.ATTRIB_DATAID.GetName();
	static final String TAG_ATTRIB_DATASCOPE= AppendHierarchicalDataTag.ATTRIB_DATASCOPE.GetName();
	static final String TAG_ATTRIB_INDEX	= AppendHierarchicalDataTag.ATTRIB_INDEX.GetName();
	
	MockEnvironment m_mockEnv = null;

	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() 
	{
		m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new AppendHierarchicalDataTag());
	}
	
	/**
	 * Helper function to setup hierarchical data with default child key
	 * Adds the following entries (entries separated with -)
	 * 0 - 1 - 2 - 0,0 - 0,1 - 1,0 - 1,1 
	 * @return
	 */
	public XPArrayList setUpTestHierData()
	{
		XPArrayList tagVar = new XPArrayList(); // root list in the data tag variable
		HashtableDataObject firstEntry = TagTestHelper.CreateHierDataHelper(2); // creating 0,0 and 0,1
		HashtableDataObject midEntry = TagTestHelper.CreateHierDataHelper(2); // creating 0,0 and 0,1
		tagVar.Add(firstEntry); // 0 - 0,0 - 0,1
		tagVar.Add(midEntry); // 1 - 1,0 - 1,1
		tagVar.Add(new HashtableDataObject()); // 2
		
		return tagVar;
	}
	
	/**
	 * Tests creating a new hier data structure and appending to existing top level list. Both use an empty index value
	 */
	public void testTopLevelAppend()
	{
		/** CASE 1: Replace existing data **/
		// data that is added
		HashtableDataObject addData = new HashtableDataObject();
		addData.SetData("test", "test"); // so that we can check that it is the test data
		
		String addDataName 	= "adddata";
		String destDataName	= "destdata";
		// set the initial data tag variables in tag scope
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		mockState.SetTagHTTPRequestVar(null, addDataName, addData, m_mockEnv); // set tag variable with data to add to hier data structure
		mockState.SetTagPortletRequestVar(null, destDataName, setUpTestHierData()); // set the initial hier data structure
		
		// attributes 
		XPHashtable attribs = new XPHashtable();
		attribs.PutElement(TAG_ATTRIB_ID, 		destDataName);
		attribs.PutElement(TAG_ATTRIB_DATAID, 	addDataName);
		attribs.PutElement(TAG_ATTRIB_DATASCOPE,Scope.HTTP_REQUEST.toString());
		attribs.PutElement(TAG_ATTRIB_INDEX, 	""); // empty index to create a new hier data structure in the tag variable
		
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribs, m_mockEnv);
		assertTrue("Data tag return HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		Object newData = mockState.GetTagPortletRequestVar(destDataName);
		assertTrue("Set data in tag variable is not an XPArrayList: "+newData, newData instanceof XPArrayList);
		XPArrayList newListData = (XPArrayList)newData;
		assertTrue("Set data in tag variable is not the data that was added!", (newListData).GetElement(newListData.GetSize()-1).equals(addData));
		
		/** CASE 2: Create new data **/
		mockState = TagTestHelper.GetMockTagStateInstance();
		result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribs, m_mockEnv);
		
		assertTrue("Data tag return HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		newData = mockState.GetTagPortletRequestVar(destDataName);
		assertTrue("Set data in tag variable is not an XPArrayList: "+newData, newData instanceof XPArrayList);
		assertEquals("Set data in tag variable is not the data that was added!", ((XPArrayList)newData).GetElement(0), addData);
		
	}
	
	/**
	 * Test append of hierarchical data 
	 */
	public void testAppendOfHierData()
	{
		// data that is added
		XPArrayList addData = setUpTestHierData();
		
		String addDataName 	= "adddata";
		String destDataName	= "destdata";
		// set the initial data tag variables in tag scope
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		mockState.SetTagHTTPRequestVar(null, addDataName, addData, m_mockEnv); // set tag variable with data to add to hier data structure
		mockState.SetTagPortletRequestVar(null, destDataName, setUpTestHierData()); // set the initial hier data structure
		
		// attributes 
		XPHashtable attribs = new XPHashtable();
		attribs.PutElement(TAG_ATTRIB_ID, 		destDataName);
		attribs.PutElement(TAG_ATTRIB_DATAID, 	addDataName);
		attribs.PutElement(TAG_ATTRIB_DATASCOPE,Scope.HTTP_REQUEST.toString());
		attribs.PutElement(TAG_ATTRIB_INDEX, 	"1"); 
		
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribs, m_mockEnv);
		assertTrue("Data tag return HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		Object newData = mockState.GetTagPortletRequestVar(destDataName);
		assertTrue("Set data in tag variable is not an XPArrayList: "+newData, newData instanceof XPArrayList);
		XPArrayList newListData = (XPArrayList)newData;
		
		// verify 1,1,1,1 exists
		assertTrue("No data found at the expected index 1,3,1", TagTestHelper.GetDataObjAtIndex("1,3,1", newListData) != null);
	}
	
	/**
	 * Test appending data list
	 */
	public void testAppendListData()
	{
		// data that is added
		XPArrayList addList = new XPArrayList();
		HashtableDataObject addData = TagTestHelper.CreateHierDataHelper(2);
		addData.SetData("test", "test"); // so that we can check that it is the test data
		addList.Add(addData);
		addList.Add(addData);
		addList.Add(addData);
		
		String addDataName 	= "adddata";
		String destDataName	= "destdata";
		// set the initial data tag variables in tag scope
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		XPArrayList destList = setUpTestHierData();
		int origSize = destList.GetSize();
		// set tag variable with data to add to hier data structure
		// create separate instances to avoid funkiness since we are performing appends on appended lists
		mockState.SetTagHTTPRequestVar(null, addDataName+"0", addList.Clone(), m_mockEnv); 
		mockState.SetTagHTTPRequestVar(null, addDataName+"1", addList.Clone(), m_mockEnv); 
		mockState.SetTagHTTPRequestVar(null, addDataName+"2", addList.Clone(), m_mockEnv); 
		mockState.SetTagHTTPRequestVar(null, addDataName+"3", addList.Clone(), m_mockEnv); 
		mockState.SetTagHTTPRequestVar(null, destDataName, destList, m_mockEnv); // set the initial hier data structure
		
		// attributes 
		XPHashtable attribs = new XPHashtable();
		attribs.PutElement(TAG_ATTRIB_ID, 		destDataName);
		attribs.PutElement(TAG_ATTRIB_SCOPE		,Scope.HTTP_REQUEST.toString());
		attribs.PutElement(TAG_ATTRIB_DATASCOPE ,Scope.HTTP_REQUEST.toString());
	
		// First add to top level list
		// Then append to the child list in the recently added list
		// Append twice to a child list
		// 
		String[] indexValues= new String[] {"", "4", "1", "1" };
		
		for ( int i = 0; i < indexValues.length; i++ ) {
			XPSystem.Out.WriteLine("testAppendListData - running: "+i+" with index: "+indexValues[i]);
			
			attribs.PutElement(TAG_ATTRIB_DATAID, 	addDataName+i);
			attribs.PutElement(TAG_ATTRIB_INDEX, indexValues[i]); // set the index from the array in the attribute value array to pass in
			HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribs, m_mockEnv);
			assertTrue("Data tag return HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		}
		
		Object newData = mockState.GetTagHTTPRequestVar(destDataName, m_mockEnv);
		assertTrue("Set data in tag variable is not an XPArrayList: "+newData, newData instanceof XPArrayList);
		// test first index
		XPArrayList newListData = (XPArrayList)newData;
		assertEquals("Set list in tag variable is not of the expected size!", newListData.GetSize(), origSize+addList.GetSize()); // from adding to top level
		// test second index
		IHierarchicalDataObject entry = TagTestHelper.GetDataObjAtIndex("4", newListData);
		assertEquals("Unexpected number of child entries after append", addData.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY).GetSize(), entry.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY).GetSize());
		// test third and fourth index
		entry = TagTestHelper.GetDataObjAtIndex("1", newListData); // there were 2 children at index "1", should 2 plus twice the number the children in the add data  
		assertEquals("Unexpected number of child entries after append", (addList.GetSize()*2)+2, entry.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY).GetSize());
	}
	
	
}
