/**
 * 
 */
package com.bea.alui.taglib.logic.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.logic.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Unit Tests for the AttachHierarchicalDataTag
 * @author rozhang
 *
 */
public class ReplaceHierarchicalDataTagTest extends TestCase
{
	static final String TAG_LIBNAME  		= LogicTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     		= ReplaceHierarchicalDataTag.TAG.GetName();
	static final String TAG_ATTRIB_ID 		= ReplaceHierarchicalDataTag.ATTRIB_ID.GetName();
	static final String TAG_ATTRIB_SCOPE 	= ReplaceHierarchicalDataTag.ATTRIB_SCOPE.GetName();
	static final String TAG_ATTRIB_DATAID	= ReplaceHierarchicalDataTag.ATTRIB_DATAID.GetName();
	static final String TAG_ATTRIB_DATASCOPE= ReplaceHierarchicalDataTag.ATTRIB_DATASCOPE.GetName();
	static final String TAG_ATTRIB_INDEX	= ReplaceHierarchicalDataTag.ATTRIB_INDEX.GetName();
	
	MockEnvironment m_mockEnv = null;
	
	public void setUp()
	{
		m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new ReplaceHierarchicalDataTag());
	}
	
	/**
	 * Helper function to setup hierarchical data with default child key
	 * Adds the following entries (entries separated with -)
	 * 0 - 1 - 2 - 0,0 - 0,1
	 * @return
	 */
	public XPArrayList setUpTestHierData()
	{
		XPArrayList tagVar = new XPArrayList(); // root list in the data tag variable
		HashtableDataObject firstEntry = TagTestHelper.CreateHierDataHelper(2); // creating 0,0 and 0,1
		tagVar.Add(firstEntry); // 0
		tagVar.Add(new HashtableDataObject()); // 1
		tagVar.Add(new HashtableDataObject()); // 2
		
		return tagVar;
	}
	
	
	
	/**
	 * Takes a existing hierarchical data variable and attaches additional data to it
	 * Tests the index attribute to ensure that data are properly attached
	 */
	public void testAddOneDimensionalData()
	{
		// setup data tag to add, same data instance is added to different locations
		// shouldn't need to add unique data to each position, we are just checking that data is attached 
		XPArrayList dataTagVar = new XPArrayList();
		dataTagVar.Add(new HashtableDataObject());
		dataTagVar.Add(new HashtableDataObject());
		// name of the tag variables to set in tag scope
		String tagDataVarName 	= "testdata";
		String hierDataVarName	=  "hierdata";
		// set the initial data tag variables in tag scope
		TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
		// set on http request scope since we are running the execute tag function multiple which creates multiple portlet requests
		tagState.SetTagHTTPRequestVar(null, tagDataVarName, dataTagVar, m_mockEnv); // set tag variable with data to add to hier data structure
		tagState.SetTagHTTPRequestVar(null, hierDataVarName, setUpTestHierData(), m_mockEnv); // set the initial hier data structure
		
		// the indices to add data to
		String[] indexValues= new String[] {"0,1", "1", "1,1", "0,1,1", "0,0", "0,0,0"};
		// attribute list of names and valies
		String[] attribNames = new String[] {TAG_ATTRIB_ID, TAG_ATTRIB_SCOPE, TAG_ATTRIB_DATAID, TAG_ATTRIB_DATASCOPE, TAG_ATTRIB_INDEX};
		String[] attribValues = new String[] {hierDataVarName, Scope.HTTP_REQUEST.toString(), tagDataVarName, Scope.HTTP_REQUEST.toString(), ""}; // last value is a place holder, will get set later
		// run the attach tag multiple times with all the indices defined in indexValues array to simulate multiple attach tags
		for ( int i = 0; i < indexValues.length; i++ ) {
			//XPSystem.Out.WriteLine("Running: "+i+" with index: "+indexValues[i]);
			attribValues[4] = indexValues[i]; // set the index from the array in the attribute value array to pass in
			HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribNames, attribValues, m_mockEnv);
			assertTrue("Data tag return HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		}
		// get the final hierarchical data structure from tag scope
		XPArrayList data = (XPArrayList)tagState.GetTagHTTPRequestVar(hierDataVarName, m_mockEnv);
		assertTrue("No hierarchical tag data was found with the variable name: "+hierDataVarName, data != null);
		// verify values
		for ( int i = 0; i < indexValues.length; i++ ) {
			assertTrue("No DataObject found at index position: "+indexValues[i], TagTestHelper.GetDataObjAtIndex(indexValues[i], data) != null);
		}
	}
	
	/**
	 * Takes a existing hierarchical data variable and attaches additional hierarchical data to it
	 * Tests the index attribute to ensure that data are properly attached
	 */
	public void testAddHierarchicalData()
	{
		// setup data tag to add, same value instance is used multiple times
		// Data contains the following indices (- separated): 0 - 1 - 2 - 1,0 - 1,1 - 1,1,0 - 1,1,1 - 1,1,2
		XPArrayList topList = new XPArrayList();
		IHierarchicalDataObject middle = TagTestHelper.CreateHierDataHelper(2); // create the 1,0 and 1,1 data
		topList.Add(new HashtableDataObject()); // 0
		topList.Add(middle);  // 1 
		topList.Add(new HashtableDataObject()); // 2
		IHierarchicalDataObject child = TagTestHelper.GetHierDataChildAtIndex(1, middle); // get 1,1
		TagTestHelper.SetHierDataChildren(3, child); // create 1,1,0 - 1,1,1 - 1,1,2
		
		// name of the tag variables to set in tag scope
		String tagDataVarName 	= "testdata";
		String hierDataVarName	=  "hierdata";
		// set the initial data tag variables in tag scope
		TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
		
		tagState.SetTagHTTPRequestVar(null, tagDataVarName, topList, m_mockEnv); // set tag variable with data to add to hier data structure
		tagState.SetTagHTTPRequestVar(null, hierDataVarName, setUpTestHierData(), m_mockEnv); // set the initial hier data structure
		
		// the indices to add data to
		String[] indexValues= new String[] {"2", "0,1"};
		// attribute list of names and values
		String[] attribNames = new String[] {TAG_ATTRIB_ID, TAG_ATTRIB_SCOPE, TAG_ATTRIB_DATAID, TAG_ATTRIB_DATASCOPE, TAG_ATTRIB_INDEX};
		String[] attribValues = new String[] {hierDataVarName, Scope.HTTP_REQUEST.toString(), tagDataVarName, Scope.HTTP_REQUEST.toString(), ""}; // last value is a place holder, will get set later
		// run the attach tag multiple times with all the indices defined in indexValues array to simulate multiple attach tags
		for ( int i = 0; i < indexValues.length; i++ ) {
			XPSystem.Out.WriteLine("testAddHierarchicalData - running: "+i+" with index: "+indexValues[i]);
			attribValues[4] = indexValues[i]; // set the index from the array in the attribute value array to pass in
			HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribNames, attribValues, m_mockEnv);
			assertTrue("Data tag return HTML: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		}
		// get the final hierarchical data structure from tag scope
		XPArrayList data = (XPArrayList)tagState.GetTagHTTPRequestVar(hierDataVarName, m_mockEnv);
		assertTrue("No hierarchical tag data was found with the variable name: "+hierDataVarName, data != null);
		// verify values
		for ( int i = 0; i < indexValues.length; i++ ) {
			assertTrue("No DataObject found at index position: "+indexValues[i], TagTestHelper.GetDataObjAtIndex(indexValues[i], data) != null);
		}
	}
	
	/**
	 * Test with invalid index, expect error message
	 */
	public void testIndexAttributeErrorCases()
	{
		// setup data tag to add, same data instance is added to different locations
		// shouldn't need to add unique data to each position, we are just checking that data is attached 
		XPArrayList dataTagVar = new XPArrayList();
		dataTagVar.Add(new HashtableDataObject());
		// name of the tag variables to set in tag scope
		String tagDataVarName 	= "testdata";
		String hierDataVarName	=  "hierdata";
		// set the initial data tag variables in tag scope
		TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
		// set on http request scope since we are running the execute tag function multiple which creates multiple portlet requests
		tagState.SetTagPortletRequestVar(null, tagDataVarName, dataTagVar); // set tag variable with data to add to hier data structure
		tagState.SetTagPortletRequestVar(null, hierDataVarName, setUpTestHierData()); // set the initial hier data structure
		
		// attribute list of names and valies
		String[] attribNames = new String[] {TAG_ATTRIB_ID, TAG_ATTRIB_DATAID, TAG_ATTRIB_INDEX};
		String[] attribValues = new String[] {hierDataVarName, tagDataVarName, "3"}; // invalid index
		
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, attribNames, attribValues, m_mockEnv);
		// look for the exception type and one word in the error message
		assertTrue("Data tag return HTML: "+result.GetDisplayString(), result.GetDisplayString().indexOf("XPIllegalArgumentException") != -1 && result.GetDisplayString().indexOf("Index") != -1 );
	}
	
	
}
