/**
 * 
 */
package com.bea.alui.taglib.logic.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.logic.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class TagDataApplicationCacheTagTest extends TestCase
{
	static final String TAG_LIBNAME  			= LogicTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     			= TagDataApplicationCacheTag.TAG.GetName();
	static final String TAG_ATTRIB_DATAID 		= TagDataApplicationCacheTag.ATTRIB_DATAID.GetName();
	static final String TAG_ATTRIB_DATASCOPE 	= TagDataApplicationCacheTag.ATTRIB_DATASCOPE.GetName();
	static final String TAG_ATTRIB_CACHEID		= TagDataApplicationCacheTag.ATTRIB_CONTEXTID.GetName();
	static final String TAG_ATTRIB_CACHESCOPE	= TagDataApplicationCacheTag.ATTRIB_CACHEID.GetName();
	static final String TAG_ATTRIB_EXPIRATION	= TagDataApplicationCacheTag.ATTRIB_EXPIRATION.GetName();
	
	static final String DATATAG_LIBNAME  		= LogicTagLibraryData.LIBRARY.GetName(); // hard coding the reference here so we dont have to add reference to data tag l
	static final String DATATAG_NAME     		= VariableTag.TAG.GetName();
	static final String DATATAG_KEY     		= VariableTag.KEY.GetName();
	static final String DATATAG_KEYSCOPE 		= VariableTag.SCOPE.GetName();
	static final String DATATAG_VALUE     		= VariableTag.VALUE.GetName();
	
	
	MockEnvironment m_mockEnv = null;
	String m_oldDataValue = "old";
	String m_newDataValue = "new";
	// this is the value that the cached data tag will use
	String m_cacheValueVarId = "cacheValue";
	String m_dataKey = "dataVar";
	XMLFragmentTestHelper m_dataTag;
	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() 
	{
		m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTags(TAG_LIBNAME, new String[] {TAG_NAME, DATATAG_NAME}, new ATag[] {new TagDataApplicationCacheTag(), new VariableTag()});
		
		
		// setup the variable tag to use the data value 
		
		XPHashtable dataargs = new XPHashtable();
		dataargs.PutElement(DATATAG_KEY, m_dataKey);
		dataargs.PutElement(DATATAG_KEYSCOPE, Scope.HTTP_REQUEST.toString());
		dataargs.PutElement(DATATAG_VALUE, "$"+m_cacheValueVarId); // reference the data value from the tag variable
		m_dataTag = XMLFragmentTestHelper.CreateTag(DATATAG_LIBNAME, DATATAG_NAME, dataargs);
		
		
	}
	
	/**
	 * Test caching by using a variable tag inside the cache tag. The value of the variable tag (data tag being cached) is read from another
	 * tag variable.
	 * 1. Run cache tag. The variable tag is executed inside the cache tag and the data cached.
	 * 2. We then change the value of the tag variable the variable tag gets its value from and run the cache tag again. 
	 * 3. Run cache tag again. The idea is that we know the caching works if the cache tag uses the cache value instead of the new value. 
     *
	 */
	public void testCaching()
	{
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_oldDataValue, m_mockEnv);
		
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_DATAID, m_dataKey); // the name of the data var
		args.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.toString()); // scope of the data var
		args.PutElement(TAG_ATTRIB_EXPIRATION, "2"); // expiration isn't used in this test so this value doesn't matter but it is required by the tag
		HTMLElement result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME, args, m_dataTag, m_mockEnv);
		
		assertTrue("Cache tag returned unexpected content: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		// verify that the tag variable contains the expected value
		Object dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
		assertEquals("Tag variable does not contain expected value after running cache tag!", m_oldDataValue, dataVar);
		
		// Now let's change the value of the cacheValue variable and the run the cache tag again
		// if the cached version is used the cache tag sets the dataVar variable with value 'old', otherwise the variable tag is run and the 
		// dataVar variable contains value 'new'
		mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_newDataValue, m_mockEnv);
		result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME, args, m_dataTag, m_mockEnv);
		
		assertTrue("Cache tag returned unexpected content: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
		assertEquals("Tag variable does not contain expected value after running cache tag!", m_oldDataValue, dataVar);
	}
	
	/**
	 * The test expires the cache entry by changing the cache entry in the cache entry tag variable so that the test
	 * doesnt have to run for x minutes for the entry to actually expire 
	 */
	public void testCacheExpiration()
	{
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_oldDataValue, m_mockEnv); // set the cache value
		
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_DATAID, m_dataKey); // the name of the data var
		args.PutElement(TAG_ATTRIB_DATASCOPE, Scope.HTTP_REQUEST.toString()); // scope of the data var
		args.PutElement(TAG_ATTRIB_EXPIRATION, "2"); // we manually expire the cache entry so this value doesn't matter in this test
		HTMLElement result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME, args, m_dataTag, m_mockEnv);
		
		assertTrue("Cache tag returned unexpected content: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		
		// verify that the tag variable contains the expected value
		Object dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
		assertEquals("Tag variable does not contain expected value after running cache tag!", m_oldDataValue, dataVar);
		
		// To simulate cache entry expiration, we change the time in the cache entry.
		// We also change the cache variable value to make sure that the cache tag reruns the variable tag and sets the new value
		mockState.SetTagHTTPRequestVar("", m_cacheValueVarId, m_newDataValue, m_mockEnv); // update value to cache
		
		// get the cache entry by adding the cache entry prefix. The cache id will be the datakey since we explicitly specify a cache id on the cache tag
		XPHashtable cacheMap = (XPHashtable)mockState.GetTagApplicationVar(TagState.CACHE_LIB+"."+TagState.CACHE_MAPENTRY_NAME, m_mockEnv);
		TagCacheEntry cacheEntry = (TagCacheEntry)cacheMap.GetElement("-"+m_dataKey); // the dash is to separate cache key from cache context
		assertTrue("No cache entry found on the Application!", cacheEntry != null);
		cacheEntry.ExpireEntry(); // expire cache entry
		// now run the cache tag again, which should rerun the variable tag and fetch the new value
		result = TagTestHelper.RunNestedTags(TAG_LIBNAME, TAG_NAME, args, m_dataTag, m_mockEnv);
		
		
		assertTrue("Cache tag returned unexpected content: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result) );
		dataVar = mockState.GetTagHTTPRequestVar(m_dataKey, m_mockEnv);
		assertEquals("Tag variable does not contain expected value after running cache tag!", m_newDataValue, dataVar);
	}
}
