package com.bea.alui.taglib.logic.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.taglib.logic.*;
import com.plumtree.xpshared.htmlelements.*;

public class TestCollectionLengthTag extends TestCase
{
	public static final String DATA_NAME = "myData";
	public static final String RESULT_KEY = "myLength";
	public static final String NULL_DATA_ERROR = "data collection was null.-->";

	public MockEnvironment m_environment;

	public void setUp()
	{
		m_environment = new MockEnvironment();

		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new CollectionLengthTag(), CollectionLengthTag.TAG.GetName(), LogicTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * This method tests computing the length of a null collection.
	 */
	public void testNullCollection()
	{
		// Initialize null data collection - TagState will use this
		// special hashtable as the portlet request data when it is
		// constructed.
		TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
		SharedStateVariable stateVar = new SharedStateVariable(null);
		// Shared state variables are prefixed with a .
		TagState.TEST_PORTLET_REQUEST_DATA.PutElement("." + DATA_NAME, stateVar);		

		// initialize markup
		XMLFragmentTestHelper collectionLengthTagHelper = new XMLFragmentTestHelper(
			LogicTagLibraryData.LIBRARY.GetName(), 
			CollectionLengthTag.TAG.GetName());
		collectionLengthTagHelper.AddPTAttribute(CollectionLengthTag.DATA.GetName(), DATA_NAME);
		collectionLengthTagHelper.AddPTAttribute(CollectionLengthTag.KEY.GetName(), RESULT_KEY);
		collectionLengthTagHelper.AddPTAttribute(CollectionLengthTag.SCOPE.GetName(), Scope.HTTP_REQUEST.toString());

   		Object[][] objArrMarkup = collectionLengthTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		int nIndex = XPStringUtility.IndexOf(strResult, NULL_DATA_ERROR);
   		Assert.assertTrue("Checking that result HTML contains null data error comment.", nIndex > 0);

		XPHashtable httpData = TagState.GetHTTPRequestData(m_environment);

		// Get length result
		// for some reason the names are prefixed with a '.'
		Object oLength = httpData.GetElement("." + RESULT_KEY);
		Assert.assertNotNull("Checking that length variable is not null.", oLength);

		String strLength = (String) ((SharedStateVariable)oLength).GetValue();

		Assert.assertEquals("Checking that null lists have length of 0.", "0", strLength);
	}

	/**
	 * This method tests computing the length of a normal collection.
	 */
	public void testNormalCollection()
	{
		// Initialize normal data collection - TagState will use this
		// special hashtable as the portlet request data when it is
		// constructed.
		XPArrayList collection = new XPArrayList();
		collection.Add(new Object());
		collection.Add(new Object());
		int nCollectionLength = 2;
		TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
		SharedStateVariable stateVar = new SharedStateVariable(collection);
		// Shared state variables are prefixed with a .
		TagState.TEST_PORTLET_REQUEST_DATA.PutElement("." + DATA_NAME, stateVar);		

		// initialize markup
		XMLFragmentTestHelper collectionLengthTagHelper = new XMLFragmentTestHelper(
			LogicTagLibraryData.LIBRARY.GetName(), 
			CollectionLengthTag.TAG.GetName());
		collectionLengthTagHelper.AddPTAttribute(CollectionLengthTag.DATA.GetName(), DATA_NAME);
		collectionLengthTagHelper.AddPTAttribute(CollectionLengthTag.KEY.GetName(), RESULT_KEY);
		collectionLengthTagHelper.AddPTAttribute(CollectionLengthTag.SCOPE.GetName(), Scope.HTTP_REQUEST.toString());

   		Object[][] objArrMarkup = collectionLengthTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		int nIndex = XPStringUtility.IndexOf(strResult, NULL_DATA_ERROR);
   		Assert.assertTrue("Checking that result HTML does not contain null data error comment.", nIndex < 0);

		XPHashtable httpData = TagState.GetHTTPRequestData(m_environment);

		// Get length result
		// for some reason the names are prefixed with a '.'
		Object oLength = httpData.GetElement("." + RESULT_KEY);
		Assert.assertNotNull("Checking that length variable is not null.", oLength);

		String strLength = (String) ((SharedStateVariable)oLength).GetValue();

		Assert.assertEquals("Checking that list length is correct.",
			XPConvert.ToString(nCollectionLength), strLength);
	}
}