package com.bea.alui.taglib.logic.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.taglib.logic.*;
import com.plumtree.xpshared.htmlelements.*;

public class TestForEachTag extends TestCase
{
	public static final String DATA_NAME = "myData";
	public static final String RESULT_VAR = "myVar";
	public static final String NULL_DATA_ERROR = "data collection was null.-->";
	public static final String VAR_1 = "my first var";
	public static final String VAR_2 = "my second var";

	public MockEnvironment m_environment;

	public void setUp()
	{
		m_environment = new MockEnvironment();

		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new ForEachTag(), ForEachTag.TAG.GetName(), LogicTagLibraryData.LIBRARY.GetName());
		tagLibs.SetTag(new ValueTag(), ValueTag.TAG.GetName(), LogicTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * This method tests computing the length of a null collection.
	 */
	public void testNullCollection()
	{
		// Initialize null data collection - TagState will use this
		// special hashtable as the portlet request data when it is
		// constructed.
		TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
		SharedStateVariable stateVar = new SharedStateVariable(null);
		// Shared state variables are prefixed with a .
		TagState.TEST_PORTLET_REQUEST_DATA.PutElement("." + DATA_NAME, stateVar);		

		// initialize markup
		XMLFragmentTestHelper forEachTagHelper = new XMLFragmentTestHelper(
			LogicTagLibraryData.LIBRARY.GetName(), 
			ForEachTag.TAG.GetName());
		forEachTagHelper.AddPTAttribute(ForEachTag.DATA.GetName(), DATA_NAME);
		forEachTagHelper.AddPTAttribute(ForEachTag.VAR.GetName(), RESULT_VAR);
		forEachTagHelper.AddPTAttribute(ForEachTag.ACCEPTNULLDATA.GetName(), "false");

   		Object[][] objArrMarkup = forEachTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		int nIndex = XPStringUtility.IndexOf(strResult, NULL_DATA_ERROR);
   		Assert.assertTrue("Checking that result HTML contains null data error comment.", nIndex > 0);
	}

	/**
	 * This method tests computing the length of a normal collection.
	 */
	public void testNormalCollection()
	{
		// Initialize normal data collection - TagState will use this
		// special hashtable as the portlet request data when it is
		// constructed.
		XPArrayList collection = new XPArrayList();
		collection.Add(VAR_1);
		collection.Add(VAR_2);
		TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
		SharedStateVariable stateVar = new SharedStateVariable(collection);
		// Shared state variables are prefixed with a .
		TagState.TEST_PORTLET_REQUEST_DATA.PutElement("." + DATA_NAME, stateVar);		

		// initialize markup
		XMLFragmentTestHelper valueTagHelper = new XMLFragmentTestHelper(
			LogicTagLibraryData.LIBRARY.GetName(), 
			ValueTag.TAG.GetName());
		valueTagHelper.AddPTAttribute(ValueTag.VALUE.GetName(), "$" + RESULT_VAR);

		XMLFragmentTestHelper forEachTagHelper = new XMLFragmentTestHelper(
			LogicTagLibraryData.LIBRARY.GetName(), 
			ForEachTag.TAG.GetName());
		forEachTagHelper.AddPTAttribute(ForEachTag.DATA.GetName(), DATA_NAME);
		forEachTagHelper.AddPTAttribute(ForEachTag.VAR.GetName(), RESULT_VAR);
		forEachTagHelper.AddContent(valueTagHelper);

   		Object[][] objArrMarkup = forEachTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		int nIndex = XPStringUtility.IndexOf(strResult, NULL_DATA_ERROR);
   		Assert.assertTrue("Checking that result HTML does not contain null data error comment.", nIndex < 0);

   		nIndex = XPStringUtility.IndexOf(strResult, VAR_1);
   		Assert.assertTrue("Checking that result HTML contains the first list item.", nIndex >= 0);

   		nIndex = XPStringUtility.IndexOf(strResult, VAR_2);
   		Assert.assertTrue("Checking that result HTML contains the second list item.", nIndex >= 0);
	}
}