using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptconditionals
{
  /// <author>rozhang</author>
  public class IsCurrentPageTag : ATag
  {
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute ATTRIB_PAGEID;
    public static readonly OptionalTagAttribute ATTRIB_PAGENAME;
    public static readonly OptionalTagAttribute ATTRIB_PAGEIDDATA;
    public static readonly OptionalTagAttribute ATTRIB_DATASCOPE;
    static IsCurrentPageTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("iscurrcommpage", "This is a conditional tag used to output HTML and Adaptive Tags when on a specified Community Page. " + "This tag does not do anything when not on a Community page. " + "Specify  a page by passing in the page Id or name. The page Id is specified either by directly passing the id value in the " + "\'id\' attribute or passing in the name of a tag variable with a list of ids. " + "Comparison against Page name will check if the current Page name contains the passed in value. Exact match is done by using the begin of line and end of line markers." + "In the case when both ids and name is specified the tag body is displayed if one (or more) of the checks pass. " + "Nest two or more tags to perform checks where both id and name need to match.",
       EncodeForTagDoc("<pt:ptcond.iscurrcommpage pt:id=\"350\"><br/>You are on a Page with id 350<br/></pt:ptcond.iscurrcommpage><br/>" + "<pt:ptcond.iscurrcommpage pt:name=\"^Comm Page^\"><br/>You are on a Community Page with the exact name \'Comm Page\'<br/></pt:ptcond.iscurrcommpage><br/>" + "<pt:ptcond.iscurrcommpage pt:name=\"^Comm Page\"><br/>You are on Community Page with a name starting with \'Comm Page\'<br/></pt:ptcond.iscurrcommpage><br/>" + 
      // nested tag 
      "<pt:ptcond.iscurrcommpage pt:name=\"^Comm Page\"><br/>" + "&nbsp;<pt:ptcond.iscurrcommpage pt:id=\"350\"><br/>You are on a Community Page with id 350 and name starting with \'Comm Page\'</pt:ptcond.iscurrcommpage><br/>" + "</pt:ptcond.iscurrpage><br/>"));
      ATTRIB_PAGEID = new OptionalTagAttribute("id", "Community Page id to display the tag body in.",
       AttributeType.INT, "-1");
      ATTRIB_PAGENAME = new OptionalTagAttribute("name", "Page name. The \'^\' character is used as begin of string marker when placed in the beginning of the string and end of string at the end.",
       AttributeType.STRING, null);
      ATTRIB_PAGEIDDATA = new OptionalTagAttribute("iddata", "Id of data tag variable with a list of Page ids to display the tag body in.",
       AttributeType.STRING, null);
      ATTRIB_DATASCOPE = new OptionalTagAttribute("datascope", "The tag scope of the iddata tag variable if it is not in the portlet request scope.",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      int inputPageid = GetTagAttributeAsInt(ATTRIB_PAGEID);
      String inputPageName = GetTagAttributeAsString(ATTRIB_PAGENAME);
      String tagVarName = GetTagAttributeAsString(ATTRIB_PAGEIDDATA);
      if (inputPageid == -1 && inputPageName == null && tagVarName == null)
      {
        throw new XPIllegalArgumentException("None of the required attributes were defined. This tag requires at least one of the id, name or iddata.");
        }
      AActivitySpace env = (AActivitySpace) GetEnvironment();
      // are we on a mypage or community page or neither?
      int currId;
      String currName;
      ITaskAPIUICommunity commAPI = TaskAPIUICommunityService.GetInstance();
      // is this a community portlet page?
      if (commAPI.IsCurrentPageCommunityPage(env) && commAPI.IsCurrentPageMyPortalPage(env))
      {
        currId = commAPI.GetCurrentCommunityPageID(env);
        currName = commAPI.GetCurrentCommunityPageName(env);
      } else
      //		 removed support for mypages in the tag
      //		else if ( TaskAPIUIMyPages.IsCurrentPageMyPage(env) ) { // is this a mypage portlet page?
      //			currId = TaskAPIUIMyPages.GetCurrentMyPageID(env);
      //			currName = TaskAPIUIMyPages.GetCurrentMyPageName(env);
      {
        // not on community nor mypage, no need to go further
        return null;
      }
      bool idMatch = false;
      bool nameMatch = false;
      bool idTagVarMatch = false;
      // current page id match?
      if (inputPageid > 0)
      {
        if (currId == inputPageid)
        {
          idMatch = true;
        }
      }
      // current page name match?
      if (inputPageName != null && !"".Equals(inputPageName))
      {
        nameMatch = GeneralHelpers.CompareStringWithWildCard(inputPageName,
         currName);
      }
      // current page id match with values in the tag variable?
      if (tagVarName != null)
      {
        Object inputIdVar = GetTagAttributeAsTagVariable(ATTRIB_PAGEIDDATA,
         GetTagAttributeAsScope(ATTRIB_DATASCOPE));
        // compare tag var with list value
        if (inputIdVar is IXPList)
        {
          IXPList idList = (IXPList) inputIdVar;
          idTagVarMatch = idList.Contains(currId + "");
        } else
        // compare tag var with string value
        if (inputIdVar is String)
        {
          idTagVarMatch = (currId + "").Equals(inputIdVar);
        } else
        {
          throw new XPIllegalArgumentException("Unexpected type for tag variable with name: \'" + GetTagAttributeAsString(ATTRIB_PAGEIDDATA) + "\'. Expected string or IXPList, was: " + inputIdVar);
          }
      }
      // process tag body if one of the checks pass
      if (idMatch || nameMatch || idTagVarMatch)
      {
        return ProcessTagBody();
      } else
      {
        return null;
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new IsCurrentPageTag();
    }
  }
}