using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptconditionals
{
  /// <author>rozhang</author>
  public class IsInCommunityTag : ATag
  {
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute ATTRIB_CHECKPROFILE;
    static IsInCommunityTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("isincommunity", "This is a conditional tag used to output HTML and Adaptive Tags when on a Community page. Nothing is displayed if not in a Community. " + "Use the isnotincommunity tag to check when the current page is not a Community page. ",
       EncodeForTagDoc("<pt:ptcond.isincommunity><br/>&nbsp;You are in Community <pt:logic.value pt:value=\"$communityName\"/><br/></pt:ptcond.isincommunity>"));
      ATTRIB_CHECKPROFILE = new OptionalTagAttribute("userprofilecomm", "Pass in true (default value) to count the User Profile Page as a Community page. Pass in false not to. " + "Default behavior is to display tag body when on the User Profile Page. Pass in false to disable this.",
       AttributeType.BOOLEAN, "true");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      ITaskAPIUICommunity commAPI = TaskAPIUICommunityService.GetInstance();
      bool result = commAPI.IsCurrentPageCommunityPage((AActivitySpace) GetEnvironment());
      bool isUserProfile = commAPI.IsCurrentCommunityUserProfileCommunity((AActivitySpace) GetEnvironment());
      bool countUserProfile = GetTagAttributeAsBoolean(ATTRIB_CHECKPROFILE);
      // if checkuserprofile is false, then we don't want to run body if this is the user profile community
      if (result)
      {
        if (isUserProfile)
        {
          if (countUserProfile)
          {
            return ProcessTagBody();
          } else
          {
            // user profile page not counted as community so don't execute body
            return null;
          }
        }
        return ProcessTagBody();
      } else
      {
        // not a community, don't do anything
        return null;
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new IsInCommunityTag();
    }
  }
}