using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptconditionals
{
  /// <author>rozhang</author>
  public class IsNotInCommunityTag : ATag
  {
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute ATTRIB_CHECKPROFILE;
    static IsNotInCommunityTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("isnotincommunity", "This is a conditional tag used to output HTML and Adaptive Tags when NOT on a Community page. Nothing is displayed if in a Community. " + "This tag has the opposite behavior of isincommunity tag. ",
       EncodeForTagDoc("<pt:ptcond.isnotincommunity/><br/>You are NOT in a Community<br/></pt:ptcond.isnotincommunity>"));
      ATTRIB_CHECKPROFILE = new OptionalTagAttribute("userprofilecomm", "Pass in \"true\" to count User Profile Page as community (default) or false not to. " + "Default behavior is not to run tag body when on the User Profile Page. Pass in false to run when on the User Profile Page.",
       AttributeType.BOOLEAN, "true");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      ITaskAPIUICommunity commAPI = TaskAPIUICommunityService.GetInstance();
      bool result = commAPI.IsCurrentPageCommunityPage((AActivitySpace) GetEnvironment());
      bool isUserProfile = commAPI.IsCurrentCommunityUserProfileCommunity((AActivitySpace) GetEnvironment());
      bool countUserProfile = GetTagAttributeAsBoolean(ATTRIB_CHECKPROFILE);
      if (result)
      {
        if (isUserProfile)
        {
          if (countUserProfile)
          {
            // if we are on the user profile community and it counts as a community then don't run tag body
            return null;
          } else
          {
            // user profile page doesn't count as community
            return ProcessTagBody();
          }
        }
        return null;
      } else
      {
        // run tag body when not in a community
        return ProcessTagBody();
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new IsNotInCommunityTag();
    }
  }
}