using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.ptconditionals;
using com.plumtree.taskapi.portalui;
using com.plumtree.taskapi.test.portalui.mock;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.ptconditionals.test
{
  /// <author>rozhang</author>
  public class IsCurrentPageTagTest : TestCase
  {
    internal static readonly String TAG_LIBNAME = PTConditionalsTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_NAME = IsCurrentPageTag.TAG.GetName();
    internal static readonly String TAG_ATTRIB_ID = IsCurrentPageTag.ATTRIB_PAGEID.GetName();
    internal static readonly String TAG_ATTRIB_NAME = IsCurrentPageTag.ATTRIB_PAGENAME.GetName();
    internal static readonly String TAG_ATTRIB_DATA = IsCurrentPageTag.ATTRIB_PAGEIDDATA.GetName();
    internal const String TESTHTML = "<p>HTML in Tag body</p>";
    internal MockEnvironment m_mockEnv = null;
    internal MockTaskAPIUICommunityService m_mockCommAPI = null;
    //int m_currMyPageId = 500;
    internal int m_currCommPageId = 600;
    //String m_currMyPageName = "Unit Test MyPage";
    internal String m_currCommPageName = "Unit Test CommunityPage";
    
    /// <seealso cref="junit.framework.TestCase#setUp()"></seealso>
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new IsCurrentPageTag());
      m_mockCommAPI = new MockTaskAPIUICommunityService();
      TaskAPIUICommunityService.SetMockInstanceForDebug(m_mockCommAPI);
      //m_mockCommAPI.MockAddPage(m_currMyPageId, m_currMyPageName, MockTaskAPIUICommunityService.PageEntry.PAGETYPE_MYPAGE);
      m_mockCommAPI.MockAddPage(m_currCommPageId, m_currCommPageName, MockTaskAPIUICommunityService.PageEntry.PAGETYPE_COMMUNITY);
      // set a current community so that all pages are treated as community pages
      // we want to test with all community pages since there is no mock taskapi interface for taskapiuimypages
      // logic is basically the same for mypages and community pages so testing with comm pages only is sufficient
      // we can test with mypages in selenium tests
      m_mockCommAPI.m_currCommId = 300;
    }
    
    /// <summary>
    /// Test that tag does not return any content when not in a community
    /// </summary>
    public virtual void testNotInPage()
    {
      // simulate not in a page
      m_mockCommAPI.m_currPageId = -1;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_ID, "300");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // not in a page so tag should not return anything 
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    
    /// <summary>
    /// Test Error case when no attributes are passed to the tag
    /// </summary>
    public virtual void testInvalidArguments()
    {
      m_mockCommAPI.m_currPageId = -1;
      XPHashtable args = new XPHashtable();
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Expected tag return content was not found, instead this was output: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, "XPIllegalArgumentException"));
      }
    
    /// <summary>
    /// Tests page id attribute with values that DOES NOT match that of the current page
    /// </summary>
    public virtual void testIdAttributeNotInCurrentPage()
    {
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_ID, "200");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // we didn't pass in current page id id so the content inside the tag body should display 
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    
    /// <summary>
    /// Test page id attribute with values that DOES match that of the current page
    /// </summary>
    public virtual void testIdAttributeInCurrentPage()
    {
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_ID, m_currCommPageId + "");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // we passed in current page id so the content inside the tag body should display 
      assertTrue("Expected tag return content was not found, instead this was output: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    
    /// <summary>
    /// Test page name attribute with values that DOES NOT match that of the current page
    /// </summary>
    public virtual void testNameAttributeNotInCurrentPage()
    {
      String[] testNames = new String[]{"Different Name", "^Test Page", "Unit Test^",
       "^Page", "2 Unit", "Test Page 4"};
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      for (int i = 0;i < testNames.Length;i++)
      {
        XPHashtable args = new XPHashtable();
        args.PutElement(TAG_ATTRIB_NAME, testNames[i]);
        HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
         TAG_NAME, args, TESTHTML, m_mockEnv);
        // we didn't pass in current page name so the content inside the tag body should NOT display 
        assertTrue("Found tag content when none was expected for name: " + testNames[i] + ". Return content: " + result.GetDisplayString(),
         TagTestHelper.VerifyNoTagContent(result));
      }
    }
    
    /// <summary>
    /// Test page name attribute with value that DOES match that of the current page
    /// </summary>
    public virtual void testNameAttributeInCurrentPage()
    {
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      String[] testNames = new String[]{"Unit Test", "Test Community", "Test CommunityPage^",
       "^Unit Test", "^Unit Test CommunityPage^", "Unit Test CommunityPage^",
       "^Unit Test CommunityPage", "Test", "Commu"};
      for (int i = 0;i < testNames.Length;i++)
      {
        XPHashtable args = new XPHashtable();
        args.PutElement(TAG_ATTRIB_NAME, testNames[i]);
        HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
         TAG_NAME, args, TESTHTML, m_mockEnv);
        // expect the test html back
        assertTrue("Expected tag return content was not found for name: " + testNames[i] + ". This was output: " + result.GetDisplayString(),
         TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
      }
    }
    
    /// <summary>
    /// Test tag var data attribute with values that DOES NOT match that of the current page
    /// </summary>
    public virtual void testDataAttributeNotInCurrentPage()
    {
      // Test Case 1: Tag var with string value
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      String tagVarName = "testTagVar";
      // not current comm id
      mockState.SetTagPortletRequestVar(null, tagVarName, "200");
      // setup tag attributes
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_DATA, tagVarName);
      // run tag 
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Found tag content when none was expected for tag variable: " + tagVarName + ". Return content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // Test Case 2: Tag var with a list of ids
      mockState = TagTestHelper.GetMockTagStateInstance();
      tagVarName = "testTagVar2";
      // none of these community ids are valid
      XPArrayList idList = new XPArrayList();
      idList.Add("200");
      idList.Add("201");
      idList.Add("202");
      idList.Add("203");
      // set tag variable
      mockState.SetTagPortletRequestVar(null, tagVarName, idList);
      // setup attributes
      args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_DATA, tagVarName);
      // run tag
      result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME,
       args, TESTHTML, m_mockEnv);
      assertTrue("Found tag content when none was expected for tag variable: " + tagVarName + ". Return content: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    
    /// <summary>
    /// Test tag var data attribute with values that DOES match that of the current page
    /// </summary>
    public virtual void testDataAttributeInCurrentPage()
    {
      // Test Case 1: Tag var with string value
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      // tag variable name
      String tagVarName = "testTagVar";
      // set tag variable
      mockState.SetTagPortletRequestVar(null, tagVarName, m_currCommPageId + "");
      // setup attributes
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_DATA, tagVarName);
      // run tag
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Expected tag return content was not found, instead this was output: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
      // Test Case 2: Tag var with a list of ids
      mockState = TagTestHelper.GetMockTagStateInstance();
      tagVarName = "testTagVar2";
      XPArrayList idList = new XPArrayList();
      idList.Add("200");
      idList.Add("201");
      // current id
      idList.Add(m_currCommPageId + "");
      idList.Add("203");
      // set tag variable
      mockState.SetTagPortletRequestVar(null, tagVarName, idList);
      // setup tag attributes
      args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_DATA, tagVarName);
      // run tag
      result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME,
       args, TESTHTML, m_mockEnv);
      assertTrue("Expected tag return content was not found, instead this was output: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    
    /// <summary>
    /// Test with multiple attributes together with values that DOES match that of the current community
    /// </summary>
    public virtual void testMultipleAttributesInCurrentCommunity()
    {
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      // Test 1: With id and name attributes
      XPHashtable args = new XPHashtable();
      // current page id
      args.PutElement(TAG_ATTRIB_ID, m_currCommPageId + "");
      // not current page name
      args.PutElement(TAG_ATTRIB_NAME, "Not current Page Name");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect test html back
      assertTrue("Expected tag return content was not found for Community id: " + m_currCommPageId,
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
      // Test 2: With all 3 attributes
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      String tagVarName = "testTagVar";
      // set tag var with not current page id
      mockState.SetTagPortletRequestVar(null, tagVarName, "100");
      args = new XPHashtable();
      // not current page id
      args.PutElement(TAG_ATTRIB_ID, "600");
      // tag var with not current id
      args.PutElement(TAG_ATTRIB_DATA, tagVarName);
      // current name
      args.PutElement(TAG_ATTRIB_NAME, m_currCommPageName);
      result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME,
       args, TESTHTML, m_mockEnv);
      // expect test html back
      assertTrue("Expected tag return content was not found for Community with name: " + m_currCommPageName + ", this was output: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    
    /// <summary>
    /// Test with multiple attributes together with values that DOESN'T match that of the current page
    /// </summary>
    public virtual void testMultipleAttributesNotInCurrentPage()
    {
      m_mockCommAPI.m_currPageId = m_currCommPageId;
      // Test 1: With id and name attributes
      // tag variable
      XPHashtable args = new XPHashtable();
      // not current page id
      args.PutElement(TAG_ATTRIB_ID, "200");
      // not current page name
      args.PutElement(TAG_ATTRIB_NAME, "Not current Page Name");
      // run tag
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // we didn't pass in current page id so the content inside the tag body should display 
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // Test 2: With all 3 attributes
      TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
      String tagVarName = "testTagVar";
      // set tag variable with not current page id
      mockState.SetTagPortletRequestVar(null, tagVarName, "200");
      // tag attributes
      args = new XPHashtable();
      // not current page id
      args.PutElement(TAG_ATTRIB_ID, "200");
      // tag variable with not current page name
      args.PutElement(TAG_ATTRIB_DATA, tagVarName);
      // not current page name
      args.PutElement(TAG_ATTRIB_NAME, "Not current Page Name");
      // run tag
      result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME,
       args, TESTHTML, m_mockEnv);
      // we didn't pass in current comm id so the content inside the tag body should display 
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
  }
}