using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.adminfolder;
using com.plumtree.portalpages.admin.objsearch;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.directory.browse;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.ptconditionals;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.ptconditionals.test
{
  /// <author>rozhang</author>
  public class IsCurrentURLTagTest : TestCase
  {
    internal static readonly String TAG_LIBNAME = PTConditionalsTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_NAME = IsCurrentURLTag.TAG.GetName();
    //static final String TAG_ATTRIB_ASNAME 	= IsCurrentURLTag.ATTRIB_ASNAME.GetName();
    internal static readonly String TAG_ATTRIB_URL1 = IsCurrentURLTag.ATTRIB_URLMATCH1.GetName();
    internal static readonly String TAG_ATTRIB_URL2 = IsCurrentURLTag.ATTRIB_URLMATCH2.GetName();
    internal static readonly String TAG_ATTRIB_URL3 = IsCurrentURLTag.ATTRIB_URLMATCH3.GetName();
    internal static readonly String TAG_ATTRIB_URL4 = IsCurrentURLTag.ATTRIB_URLMATCH4.GetName();
    internal static readonly String TAG_ATTRIB_URL5 = IsCurrentURLTag.ATTRIB_URLMATCH5.GetName();
    internal static readonly String TAG_ATTRIB_KDAS = IsCurrentURLTag.ATTRIB_CHECK_KDAS.GetName();
    internal static readonly String TAG_ATTRIB_LOGINAS = IsCurrentURLTag.ATTRIB_CHECK_LOGINAS.GetName();
    internal static readonly String tAG_ATTRIB_SEARCHAS = IsCurrentURLTag.ATTRIB_CHECK_SEARCHRESAS.GetName();
    internal const String TESTHTML = "<p>HTML in Tag body</p>";
    internal MockEnvironment m_mockEnv = null;
    
    /// <seealso cref="junit.framework.TestCase#setUp()"></seealso>
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new IsCurrentURLTag());
      // create a generic DP in the activityspace to avoid null pointer exception in the tag
      m_mockEnv.SetCurrentPage(new AdminSearchDP());
    }
    public virtual void testInvalidArguments()
    {
      XPHashtable args = new XPHashtable();
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, "XPIllegalArgumentException"));
      }
    public virtual void testURLMatchSuccess()
    {
      m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
      // all of these string should match the url
      String[] matches = new String[]{"server.pt/mypage", "param1=value",
       "param1=value1", "param3=value3", "param2=value2&"};
      // test that each of the url match attributes work
      String[] attribs = new String[]{TAG_ATTRIB_URL1, TAG_ATTRIB_URL2, TAG_ATTRIB_URL3,
       TAG_ATTRIB_URL4, TAG_ATTRIB_URL5};
      for (int attrib = 0;attrib < attribs.Length;attrib++)
      {
        for (int match = 0;match < matches.Length;match++)
        {
          XPHashtable args = new XPHashtable();
          args.PutElement(attribs[attrib], matches[match]);
          HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
           TAG_NAME, args, TESTHTML, m_mockEnv);
          assertTrue("Expected tag return content was not found for attribute: " + attribs[attrib] + " and string: " + matches[match] + ". " + "Output: " + result.GetDisplayString(),
           TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
        }
      }
    }
    public virtual void testURLMatchFail()
    {
      m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
      // none of these string should match the url
      String[] matches = new String[]{"server.pt/comms", "param1=value2",
       "param2=value3", "param1=val&", ".pt/mypage/208"};
      // test that each of the url match attributes work
      String[] attribs = new String[]{TAG_ATTRIB_URL1, TAG_ATTRIB_URL2, TAG_ATTRIB_URL3,
       TAG_ATTRIB_URL4, TAG_ATTRIB_URL5};
      for (int attrib = 0;attrib < attribs.Length;attrib++)
      {
        for (int i = 0;i < matches.Length;i++)
        {
          XPHashtable args = new XPHashtable();
          args.PutElement(attribs[attrib], matches[i]);
          HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
           TAG_NAME, args, TESTHTML, m_mockEnv);
          assertTrue("Unexpected content was returned for attribute: " + attribs[attrib] + " and string: " + matches[i] + ". Output: " + result.GetDisplayString(),
           TagTestHelper.VerifyNoTagContent(result));
        }
      }
    }
    public virtual void testCheckLoginSuccess()
    {
      // matching current as
      m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_LOGINAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect body to run
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    public virtual void testCheckLoginFailure()
    {
      // non matchign current as
      m_mockEnv.m_asName = MyPageAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_LOGINAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    public virtual void testCheckSearchResultSuccess()
    {
      // matching current as
      m_mockEnv.m_asName = SearchResultAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(tAG_ATTRIB_SEARCHAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect body to run
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    public virtual void testCheckSearchResultFailure()
    {
      m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(tAG_ATTRIB_SEARCHAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    public virtual void testCheckKDSuccess()
    {
      // matching as name
      m_mockEnv.m_asName = DirAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_KDAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect body to run
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    public virtual void testCheckKDFailure()
    {
      // non-matching as name
      m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_KDAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    public virtual void testMultipleASArgumentsSuccess()
    {
      m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_URL1, "server.pt/mypage");
      args.PutElement(TAG_ATTRIB_URL2, "param1=val");
      args.PutElement(TAG_ATTRIB_URL3, "param2=value2");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect body to run
      assertTrue("Expected tag return content was not found. Output: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    public virtual void testMultipleASArgumentsFail()
    {
      m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
      XPHashtable args = new XPHashtable();
      // no match
      args.PutElement(TAG_ATTRIB_URL1, "server.pt/comms");
      // no match
      args.PutElement(TAG_ATTRIB_URL2, "param1=value3");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    public virtual void testMultipleHelperASArgsSuccess()
    {
      // matching as name
      m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_KDAS, "true");
      // the matching as name
      args.PutElement(TAG_ATTRIB_LOGINAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect body to run
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    public virtual void testMultipleHelperASFail()
    {
      // matching as name
      m_mockEnv.m_asName = SearchResultAS.STR_MVC_CLASS_NAME;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_KDAS, "true");
      // the matching as name
      args.PutElement(TAG_ATTRIB_LOGINAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    public virtual void testBothArgTypesSuccess()
    {
      // TEST 1: Success with pre-def AS checks
      m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME;
      m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
      XPHashtable args = new XPHashtable();
      // non-match
      args.PutElement(TAG_ATTRIB_URL1, "server.pt/kdfolder");
      // non-match
      args.PutElement(TAG_ATTRIB_KDAS, "true");
      // the matching as name
      args.PutElement(TAG_ATTRIB_LOGINAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect body to run
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
      // TEST 2: Success with string comparison success
      m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
      args = new XPHashtable();
      // matching url
      args.PutElement(TAG_ATTRIB_URL1, "server.pt/mypage");
      // non-match
      args.PutElement(TAG_ATTRIB_KDAS, "true");
      // non-match
      args.PutElement(tAG_ATTRIB_SEARCHAS, "true");
      result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME,
       args, TESTHTML, m_mockEnv);
      // expect body to run
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    public virtual void testBothArgTypesFail()
    {
      m_mockEnv.m_asName = AdminFolderEditorAS.STR_MVC_CLASS_NAME;
      m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
      DirBrowseDP dp = new DirBrowseDP();
      XPHashtable args = new XPHashtable();
      // non-match
      args.PutElement(TAG_ATTRIB_URL1, "param2=value3");
      // non-match
      args.PutElement(TAG_ATTRIB_URL2, "param3=value4");
      // non-match
      args.PutElement(TAG_ATTRIB_KDAS, "true");
      // non-match
      args.PutElement(TAG_ATTRIB_LOGINAS, "true");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
  }
}