using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.server;
using com.plumtree.taglib.ptconditionals;
using com.plumtree.taskapi.portalui;
using com.plumtree.taskapi.test.portalui.mock;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.ptconditionals.test
{
  /// <author>rozhang</author>
  public class IsInCommunityTagTest : TestCase
  {
    internal static readonly String TAG_LIBNAME = PTConditionalsTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_NAME = IsInCommunityTag.TAG.GetName();
    internal static readonly String TAG_ATTRIB_CHECKPROFILE = IsInCommunityTag.ATTRIB_CHECKPROFILE.GetName();
    internal const String TESTHTML = "<p>HTML in Tag body</p>";
    internal MockEnvironment m_mockEnv = null;
    internal MockTaskAPIUICommunityService m_mockCommAPI = null;
    internal int m_currCommId = 500;
    internal String m_currCommName = "Unit Test Community";
    
    /// <seealso cref="junit.framework.TestCase#setUp()"></seealso>
    public override void setUp()
    {
      m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new IsInCommunityTag());
      m_mockCommAPI = new MockTaskAPIUICommunityService();
      TaskAPIUICommunityService.SetMockInstanceForDebug(m_mockCommAPI);
      m_mockCommAPI.m_currCommId = m_currCommId;
      m_mockCommAPI.MockAddCommunity(m_currCommId, m_currCommName, null, null);
      }
    
    /// <summary>
    /// Test when in community
    /// </summary>
    public virtual void testInCommunity()
    {
      XPHashtable args = new XPHashtable();
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect the tag to return content
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    
    /// <summary>
    /// Test when in community
    /// </summary>
    public virtual void testNotInCommunity()
    {
      // simulate not in a community
      m_mockCommAPI.m_currCommId = -1;
      XPHashtable args = new XPHashtable();
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // not in a community so tag should not return anything 
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
    
    /// <summary>
    /// Test when in community
    /// </summary>
    public virtual void testInUserProfileCommunity()
    {
      // simulate in user profile community
      m_mockCommAPI.m_currCommId = PT_INTRINSICS.PT_PROFILE_COMMUNITY;
      XPHashtable args = new XPHashtable();
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // expect the tag to return content
      assertTrue("Expected tag return content was not found: " + result.GetDisplayString(),
       TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
    }
    
    /// <summary>
    /// Test when in community
    /// </summary>
    public virtual void testInUserProfileCommunityNoCheck()
    {
      // simulate in user profile community
      m_mockCommAPI.m_currCommId = PT_INTRINSICS.PT_PROFILE_COMMUNITY;
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIB_CHECKPROFILE, "false");
      HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME,
       TAG_NAME, args, TESTHTML, m_mockEnv);
      // not in a community so tag should not return anything 
      assertTrue("Unexpected content was returned: " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
    }
  }
}