/**
 * 
 */
package com.plumtree.taglib.ptconditionals;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.login.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The logic of this tag is tricky, read the tag description for information on how this tag behaves.
 * 
 * @author rozhang
 */
public class IsCurrentURLTag extends ATag
{
	public static final ITagMetaData TAG;
	// First set, values to check against the url
	public static final OptionalTagAttribute ATTRIB_URLMATCH1;
	public static final OptionalTagAttribute ATTRIB_URLMATCH2;
	public static final OptionalTagAttribute ATTRIB_URLMATCH3;
	public static final OptionalTagAttribute ATTRIB_URLMATCH4;
	public static final OptionalTagAttribute ATTRIB_URLMATCH5;
	// Second set, pre-defined checks for common specific AS
	public static final OptionalTagAttribute ATTRIB_CHECK_SEARCHRESAS;
	public static final OptionalTagAttribute ATTRIB_CHECK_LOGINAS;
	public static final OptionalTagAttribute ATTRIB_CHECK_KDAS;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("iscurrenturl", 
				"This is a conditional tag used to output HTML and Adaptive Tags when on a specific WCI page by comparing against the page URL. "+
				"The output content is placed inside the tag body and is displayed if the page URL satisfies parameters passed in through tag attributes. Nothing is displayed "+
				"when not on the specified page. There are two types of URL comparisons.The first way is to check if the URL contains supplied strings through the contains1-5 attributes. "+
				"These attributes are used to check for query string parameters or existence friendly URL keywords. "+
				"Multiple contains attributes are ORed, meaning the tag body is displayed when either one of the attributes are true. "+
				"ANDing multiple string comparisons is done by nesting two or more tags."+
				"The second way is to use attributes checking for specific WCI pages. For example using the 'loginpage' attribute will run the tag body when on the Login page. "+
				"With these attributes the tag performs the URL check internally. "+
				"It is also possible to combine both attribute types. When doing this, the tag body runs when either URL matches or on one of the specified pages. " +
				"NOTE: Be aware that Urls could change depending on Friendly Urls being enabled or disabled. You might want to include checks for both friendly and non-friendly Urls. ",
				EncodeForTagDoc(
					"<pt:ptcond.iscurrenturl pt:contains1=\"userid=1\"/><br/>Page URL contains Query string parameter userid with value 1<br/></pt:ptcond.iscurrenturl><br/>"+
					"<pt:ptcond.iscurrenturl pt:loginpage=\"true\"/><br/>You are on the Login Page<br/></pt:ptcond.iscurrenturl><br/>"+
					"<pt:ptcond.iscurrenturl pt:contains1=\"server.pt/mypage\" pt:contains2=\"server.pt/directory\"/><br/>You are either on a MyPage or Directory Page<br/></pt:ptcond.iscurrenturl><br/>"+
					"<pt:ptcond.iscurrenturl pt:contains1=\"space=MyPage\"/><br/>"+
					"&nbsp;&nbsp;<pt:ptcond.iscurrenturl pt:contains1=\"userid=1\"/><br/>&nbsp;&nbsp;You are on a MyPage and your User Id is 1<br/>"+
					"&nbsp;</pt:ptcond.iscurrenturl><br/></pt:ptcond.iscurrenturl><br/>")); 
		
		String containsAttribDesc = "Checks if the page URL contains the value. Tag body is displayed if at least one of the contains attribute values are found in the URL.";
		ATTRIB_URLMATCH1 	= new OptionalTagAttribute("contains1", containsAttribDesc, AttributeType.STRING, null);
		ATTRIB_URLMATCH2 	= new OptionalTagAttribute("contains2", containsAttribDesc, AttributeType.STRING, null);
		ATTRIB_URLMATCH3 	= new OptionalTagAttribute("contains3", containsAttribDesc, AttributeType.STRING, null);
		ATTRIB_URLMATCH4 	= new OptionalTagAttribute("contains4", containsAttribDesc, AttributeType.STRING, null);
		ATTRIB_URLMATCH5 	= new OptionalTagAttribute("contains5", containsAttribDesc, AttributeType.STRING, null);
		
		ATTRIB_CHECK_LOGINAS  	 = new OptionalTagAttribute("loginpage", 	   "Set to 'true' to display tag body if current page is a Login page.", AttributeType.BOOLEAN, "false");
		ATTRIB_CHECK_SEARCHRESAS = new OptionalTagAttribute("searchresultpage","Set to 'true' to display tag body if current page is a Search Result page.", AttributeType.BOOLEAN, "false");
		ATTRIB_CHECK_KDAS     	 = new OptionalTagAttribute("knowledgedirpage","Set to 'true' to display tag body if current page is a Knowledge Directory page.", AttributeType.BOOLEAN, "false");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		// check if no attributes were set on the tag
		if ( GetTagAttributeAsString(ATTRIB_URLMATCH1) == null && GetTagAttributeAsString(ATTRIB_URLMATCH2) == null && 
			 GetTagAttributeAsString(ATTRIB_URLMATCH3) == null && GetTagAttributeAsString(ATTRIB_URLMATCH4) == null &&
			 GetTagAttributeAsString(ATTRIB_URLMATCH5) == null && GetTagAttributeAsBoolean(ATTRIB_CHECK_SEARCHRESAS) == false && 
			 GetTagAttributeAsBoolean(ATTRIB_CHECK_LOGINAS) == false && GetTagAttributeAsBoolean(ATTRIB_CHECK_KDAS) == false ) 
		{
			throw new XPIllegalArgumentException("No attribute were declared on the tag. At least one attribute is required.");
		}
		// ** First check the contains attribute values
		// get the values for the contains attributes
		String match1Input   = GetTagAttributeAsString(ATTRIB_URLMATCH1);
		String match2Input   = GetTagAttributeAsString(ATTRIB_URLMATCH2);
		String match3Input   = GetTagAttributeAsString(ATTRIB_URLMATCH3);
		String match4Input   = GetTagAttributeAsString(ATTRIB_URLMATCH4);
		String match5Input   = GetTagAttributeAsString(ATTRIB_URLMATCH5);
			
		// get current AS name and URL
		AActivitySpace env  = (AActivitySpace)GetEnvironment();
		String currASName 	= env.GetName(); // get current as name
		String currURL		= env.GetCurrentRequestURL(); 
		
		boolean currUrlMatch = false; // used to store if the contains attributes set passed the test  
		// was any of these attributes used?
		boolean noUrlCompareArgs = (match1Input==null && match2Input==null && match3Input==null&& match4Input==null && match5Input==null);
		// don't bother comparing strings if no attribute values were passed in
		if ( !noUrlCompareArgs ) { 
			String[] containsInputs = new String[] {match1Input, match2Input, match3Input, match4Input, match5Input};
			// check the value for each attribute, only perform comparisons on attributes with values 
			for ( int i = 0; i < containsInputs.length; i++ ) {
				if ( containsInputs[i] != null) {
					currUrlMatch = currUrlMatch || GeneralHelpers.CompareStringWithWildCard(containsInputs[i], currURL); // result ORed
				}
			}
		} else {
			currUrlMatch = true; // set to true so the tag won't fail if no contains attributes were used
		}

		// ** Secondly check the pre-defined page attribute values
		// all tests should pass if no pre-def activityspace check attributes were set
		boolean noPreDefASCheckArgs = true;
		boolean predefASMatch 		= false; 
		
		// if attributes aren't passed in the flags remain true and checks will pass
		// if they are, the asname checks determine value of flags  
		if ( GetTagAttributeAsBoolean(ATTRIB_CHECK_SEARCHRESAS) ) {
			noPreDefASCheckArgs = false;
			predefASMatch = predefASMatch || SearchResultAS.STR_MVC_CLASS_NAME.equals(currASName); 
		}
		if ( GetTagAttributeAsBoolean(ATTRIB_CHECK_LOGINAS) ) {
			noPreDefASCheckArgs = false;
			predefASMatch = predefASMatch || LoginAS.STR_MVC_CLASS_NAME.equals(currASName);
		}
		if ( GetTagAttributeAsBoolean(ATTRIB_CHECK_KDAS) ) {
			noPreDefASCheckArgs = false;
			predefASMatch = predefASMatch || DirAS.STR_MVC_CLASS_NAME.equals(currASName);
		}
		
		// ** Finally determine if the tag should run the tag body or not 
		if ( noUrlCompareArgs ) { // if we don't have any of these attributes then don't bother checking the value of currUrlMatch
			if ( noPreDefASCheckArgs ) { // shouldn't get here since we checked for this at the beginnig but defensive coding never hurts
				throw new XPIllegalArgumentException("No attribute were declared on the tag. At least one attribute is required."); 
			}
			// only need to check the pre-defined page check result
			return  (predefASMatch) ? ProcessTagBody() : null; // 
		} else { // so we need to check currUrlMatch value
			if ( noPreDefASCheckArgs ) { // do we need to check predefAsMatch value?
				return  (currUrlMatch) ? ProcessTagBody() : null; // no we don't just use currUrlMatch
			} else { // we need to check both, so OR them
				return (currUrlMatch || predefASMatch) ? ProcessTagBody() : null;
			}
		}
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new IsCurrentURLTag();
	}

}
