/**
 * 
 */
package com.plumtree.taglib.ptconditionals;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class IsNotInCommunityTag extends ATag
{
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute ATTRIB_CHECKPROFILE;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("isnotincommunity", 
				"This is a conditional tag used to output HTML and Adaptive Tags when NOT on a Community page. Nothing is displayed if in a Community. "+
				"This tag has the opposite behavior of isincommunity tag. ",
				EncodeForTagDoc("<pt:ptcond.isnotincommunity/><br/>You are NOT in a Community<br/></pt:ptcond.isnotincommunity>")); 
		
		ATTRIB_CHECKPROFILE = new OptionalTagAttribute("userprofilecomm", "Pass in \"true\" to count User Profile Page as community (default) or false not to. "+
				"Default behavior is not to run tag body when on the User Profile Page. Pass in false to run when on the User Profile Page.", AttributeType.BOOLEAN, "true");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		ITaskAPIUICommunity commAPI = TaskAPIUICommunityService.GetInstance();
		
		boolean result 			= commAPI.IsCurrentPageCommunityPage((AActivitySpace)GetEnvironment());
		boolean isUserProfile 	= commAPI.IsCurrentCommunityUserProfileCommunity((AActivitySpace)GetEnvironment());
		boolean countUserProfile = GetTagAttributeAsBoolean(ATTRIB_CHECKPROFILE);
		
		if ( result ) {
			if ( isUserProfile ) {
				if ( countUserProfile ) { 
					// if we are on the user profile community and it counts as a community then don't run tag body
					return null;
				} else {
					// user profile page doesn't count as community
					return ProcessTagBody();
				}
			}
			return null;
		} else {
			// run tag body when not in a community
			return ProcessTagBody();
		}
	}
	
	
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new IsNotInCommunityTag();
	}
}
