/**
 * 
 */
package com.bea.alui.taglib.ptconditionals.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.ptconditionals.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.taskapi.test.portalui.mock.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class IsCurrentPageTagTest extends TestCase
{
	static final String TAG_LIBNAME  		= PTConditionalsTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     		= IsCurrentPageTag.TAG.GetName();
	static final String TAG_ATTRIB_ID 		= IsCurrentPageTag.ATTRIB_PAGEID.GetName();
	static final String TAG_ATTRIB_NAME 	= IsCurrentPageTag.ATTRIB_PAGENAME.GetName();
	static final String TAG_ATTRIB_DATA 	= IsCurrentPageTag.ATTRIB_PAGEIDDATA.GetName();
	
	static final String TESTHTML = "<p>HTML in Tag body</p>";
	MockEnvironment m_mockEnv = null;
	MockTaskAPIUICommunityService m_mockCommAPI = null;
	
	//int m_currMyPageId = 500;
	int m_currCommPageId = 600;
	//String m_currMyPageName = "Unit Test MyPage";
	String m_currCommPageName = "Unit Test CommunityPage";
	
	
	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() 
	{
		m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new IsCurrentPageTag());
		m_mockCommAPI = new MockTaskAPIUICommunityService();
		TaskAPIUICommunityService.SetMockInstanceForDebug(m_mockCommAPI);
		
		//m_mockCommAPI.MockAddPage(m_currMyPageId, m_currMyPageName, MockTaskAPIUICommunityService.PageEntry.PAGETYPE_MYPAGE);
		m_mockCommAPI.MockAddPage(m_currCommPageId, m_currCommPageName, MockTaskAPIUICommunityService.PageEntry.PAGETYPE_COMMUNITY);
		// set a current community so that all pages are treated as community pages
		// we want to test with all community pages since there is no mock taskapi interface for taskapiuimypages
		// logic is basically the same for mypages and community pages so testing with comm pages only is sufficient
		// we can test with mypages in selenium tests
		m_mockCommAPI.m_currCommId = 300; 
	}
	
	/**
	 * Test that tag does not return any content when not in a community
	 */
	public void testNotInPage()
	{
		m_mockCommAPI.m_currPageId = -1; // simulate not in a page
		
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_ID, "300");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// not in a page so tag should not return anything 
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
	/**
	 * Test Error case when no attributes are passed to the tag
	 */
	public void testInvalidArguments()
	{
		m_mockCommAPI.m_currPageId = -1;
		
		XPHashtable args = new XPHashtable();
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Expected tag return content was not found, instead this was output: "+result.GetDisplayString(), TagTestHelper.VerifyTagReturnedContent(result, "XPIllegalArgumentException") );
	}
	
	/**
	 * Tests page id attribute with values that DOES NOT match that of the current page
	 */
	public void testIdAttributeNotInCurrentPage()
	{
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_ID, "200");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// we didn't pass in current page id id so the content inside the tag body should display 
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
	/**
	 * Test page id attribute with values that DOES match that of the current page
	 */
	public void testIdAttributeInCurrentPage()
	{
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_ID, m_currCommPageId+"");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// we passed in current page id so the content inside the tag body should display 
		assertTrue("Expected tag return content was not found, instead this was output: "+result.GetDisplayString(), TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
	}
	
	/**
	 * Test page name attribute with values that DOES NOT match that of the current page
	 */
	public void testNameAttributeNotInCurrentPage()
	{
		String[] testNames = new String[] {"Different Name", "^Test Page", "Unit Test^", "^Page", "2 Unit", "Test Page 4"};
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		for ( int i = 0; i < testNames.length; i++ )
		{
			XPHashtable args = new XPHashtable();
			args.PutElement(TAG_ATTRIB_NAME, testNames[i]);
			HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
			
			// we didn't pass in current page name so the content inside the tag body should NOT display 
			assertTrue("Found tag content when none was expected for name: "+testNames[i]+". Return content: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
		}
	}
	
	/**
	 * Test page name attribute with value that DOES match that of the current page
	 */
	public void testNameAttributeInCurrentPage()
	{
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		
		String[] testNames = new String[] {"Unit Test", "Test Community", "Test CommunityPage^", "^Unit Test", "^Unit Test CommunityPage^", "Unit Test CommunityPage^", "^Unit Test CommunityPage", "Test", "Commu"};
		
		for ( int i = 0; i < testNames.length; i++ )
		{
			XPHashtable args = new XPHashtable();
			args.PutElement(TAG_ATTRIB_NAME, testNames[i]);
			HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
			
			// expect the test html back
			assertTrue("Expected tag return content was not found for name: "+testNames[i]+". This was output: "+result.GetDisplayString(), TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
		}
		
	}
	
	/**
	 * Test tag var data attribute with values that DOES NOT match that of the current page
	 */
	public void testDataAttributeNotInCurrentPage()
	{
		// Test Case 1: Tag var with string value
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		String tagVarName = "testTagVar";
		mockState.SetTagPortletRequestVar(null, tagVarName, "200"); // not current comm id
		
		XPHashtable args = new XPHashtable(); // setup tag attributes
		args.PutElement(TAG_ATTRIB_DATA, tagVarName);
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv); // run tag 
		
		assertTrue("Found tag content when none was expected for tag variable: "+tagVarName+". Return content: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
		
		// Test Case 2: Tag var with a list of ids
		mockState = TagTestHelper.GetMockTagStateInstance();
		
		tagVarName = "testTagVar2";
		XPArrayList idList = new XPArrayList(); // none of these community ids are valid
		idList.Add("200");
		idList.Add("201");
		idList.Add("202");
		idList.Add("203");
		mockState.SetTagPortletRequestVar(null, tagVarName, idList); // set tag variable
		args = new XPHashtable(); // setup attributes
		args.PutElement(TAG_ATTRIB_DATA, tagVarName);
		result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv); // run tag
		
		assertTrue("Found tag content when none was expected for tag variable: "+tagVarName+". Return content: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
		
		
	}
	
	/**
	 * Test tag var data attribute with values that DOES match that of the current page
	 */
	public void testDataAttributeInCurrentPage()
	{
		// Test Case 1: Tag var with string value
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		String tagVarName = "testTagVar"; // tag variable name
		mockState.SetTagPortletRequestVar(null, tagVarName, m_currCommPageId+""); // set tag variable
		
		XPHashtable args = new XPHashtable(); // setup attributes
		args.PutElement(TAG_ATTRIB_DATA, tagVarName);
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv); // run tag
		
		assertTrue("Expected tag return content was not found, instead this was output: "+result.GetDisplayString(), TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
		
		// Test Case 2: Tag var with a list of ids
		mockState = TagTestHelper.GetMockTagStateInstance();
		
		tagVarName = "testTagVar2";
		XPArrayList idList = new XPArrayList(); 
		idList.Add("200");
		idList.Add("201");
		idList.Add(m_currCommPageId+""); // current id
		idList.Add("203");
		mockState.SetTagPortletRequestVar(null, tagVarName, idList); // set tag variable
		
		args = new XPHashtable(); // setup tag attributes
		args.PutElement(TAG_ATTRIB_DATA, tagVarName);
		result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv); // run tag
		
		assertTrue("Expected tag return content was not found, instead this was output: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
	}
	
	/**
	 * Test with multiple attributes together with values that DOES match that of the current community
	 */
	public void testMultipleAttributesInCurrentCommunity()
	{
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		// Test 1: With id and name attributes
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_ID, m_currCommPageId+""); // current page id
		args.PutElement(TAG_ATTRIB_NAME, "Not current Page Name"); // not current page name
		
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect test html back
		assertTrue("Expected tag return content was not found for Community id: "+m_currCommPageId,  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
		
		// Test 2: With all 3 attributes
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		String tagVarName = "testTagVar";
		mockState.SetTagPortletRequestVar(null, tagVarName, "100"); // set tag var with not current page id
		
		args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_ID, "600"); // not current page id
		args.PutElement(TAG_ATTRIB_DATA, tagVarName); // tag var with not current id
		args.PutElement(TAG_ATTRIB_NAME, m_currCommPageName); // current name
		
		result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect test html back
		assertTrue("Expected tag return content was not found for Community with name: "+m_currCommPageName+", this was output: "+result.GetDisplayString(), TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
	}
	
	/**
	 * Test with multiple attributes together with values that DOESN'T match that of the current page
	 */
	public void testMultipleAttributesNotInCurrentPage()
	{
		m_mockCommAPI.m_currPageId = m_currCommPageId;
		// Test 1: With id and name attributes
		XPHashtable args = new XPHashtable(); // tag variable
		args.PutElement(TAG_ATTRIB_ID, "200"); // not current page id
		args.PutElement(TAG_ATTRIB_NAME, "Not current Page Name"); // not current page name
		
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv); // run tag
		
		// we didn't pass in current page id so the content inside the tag body should display 
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
		
		// Test 2: With all 3 attributes
		TagStateTestHelper mockState = TagTestHelper.GetMockTagStateInstance();
		
		String tagVarName = "testTagVar";
		mockState.SetTagPortletRequestVar(null, tagVarName, "200"); // set tag variable with not current page id
		
		args = new XPHashtable(); // tag attributes
		args.PutElement(TAG_ATTRIB_ID, "200"); // not current page id
		args.PutElement(TAG_ATTRIB_DATA, tagVarName); // tag variable with not current page name
		args.PutElement(TAG_ATTRIB_NAME, "Not current Page Name"); // not current page name
		
		result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv); // run tag
		
		// we didn't pass in current comm id so the content inside the tag body should display 
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
}
