/**
 * 
 */
package com.bea.alui.taglib.ptconditionals.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.adminfolder.*;
import com.plumtree.portalpages.admin.objsearch.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.directory.browse.*;
import com.plumtree.portalpages.browsing.login.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.ptconditionals.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class IsCurrentURLTagTest extends TestCase
{
	static final String TAG_LIBNAME  		= PTConditionalsTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     		= IsCurrentURLTag.TAG.GetName();
	//static final String TAG_ATTRIB_ASNAME 	= IsCurrentURLTag.ATTRIB_ASNAME.GetName();
	static final String TAG_ATTRIB_URL1		= IsCurrentURLTag.ATTRIB_URLMATCH1.GetName();
	static final String TAG_ATTRIB_URL2		= IsCurrentURLTag.ATTRIB_URLMATCH2.GetName();
	static final String TAG_ATTRIB_URL3		= IsCurrentURLTag.ATTRIB_URLMATCH3.GetName();
	static final String TAG_ATTRIB_URL4		= IsCurrentURLTag.ATTRIB_URLMATCH4.GetName();
	static final String TAG_ATTRIB_URL5		= IsCurrentURLTag.ATTRIB_URLMATCH5.GetName();
	
	static final String TAG_ATTRIB_KDAS 	= IsCurrentURLTag.ATTRIB_CHECK_KDAS.GetName();
	static final String TAG_ATTRIB_LOGINAS	= IsCurrentURLTag.ATTRIB_CHECK_LOGINAS.GetName();
	static final String tAG_ATTRIB_SEARCHAS	= IsCurrentURLTag.ATTRIB_CHECK_SEARCHRESAS.GetName();
	
	
	static final String TESTHTML = "<p>HTML in Tag body</p>";
	MockEnvironment m_mockEnv = null;
	
	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() 
	{
		m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new IsCurrentURLTag());
		m_mockEnv.SetCurrentPage(new AdminSearchDP()); // create a generic DP in the activityspace to avoid null pointer exception in the tag
	}
	
	public void testInvalidArguments()
	{
		XPHashtable args = new XPHashtable();
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, "XPIllegalArgumentException") );
	}

	
	public void testURLMatchSuccess()
	{
		m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
		
		// all of these string should match the url
		String[] matches = new String[] {"server.pt/mypage", "param1=value", "param1=value1", "param3=value3", "param2=value2&"};
		
		// test that each of the url match attributes work
		String[] attribs = new String[] {TAG_ATTRIB_URL1, TAG_ATTRIB_URL2, TAG_ATTRIB_URL3, TAG_ATTRIB_URL4, TAG_ATTRIB_URL5};
		
		for ( int attrib = 0; attrib < attribs.length; attrib++ )
		{
			for ( int match = 0; match < matches.length; match++ )
			{
				XPHashtable args = new XPHashtable();
				args.PutElement(attribs[attrib], matches[match]); 
				HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
				
				assertTrue("Expected tag return content was not found for attribute: "+attribs[attrib]+" and string: "+matches[match]+". "+
						"Output: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
			}
		}
	}
	
	public void testURLMatchFail()
	{
		m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
		
		// none of these string should match the url
		String[] matches = new String[] {"server.pt/comms", "param1=value2", "param2=value3", "param1=val&", ".pt/mypage/208"};
		
		// test that each of the url match attributes work
		String[] attribs = new String[] {TAG_ATTRIB_URL1, TAG_ATTRIB_URL2, TAG_ATTRIB_URL3, TAG_ATTRIB_URL4, TAG_ATTRIB_URL5};
		
		for ( int attrib = 0; attrib < attribs.length; attrib++ )
		{
			for ( int i = 0; i < matches.length; i++ )
			{
				XPHashtable args = new XPHashtable();
				args.PutElement(attribs[attrib], matches[i]); 
				HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
				
				assertTrue("Unexpected content was returned for attribute: "+attribs[attrib]+" and string: "+matches[i]+". Output: "+
						result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
			}
		}
		
	}
	
	public void testCheckLoginSuccess()
	{
		m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME; // matching current as
			
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_LOGINAS, "true");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect body to run
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
	}
	
	public void testCheckLoginFailure()
	{
		m_mockEnv.m_asName = MyPageAS.STR_MVC_CLASS_NAME; // non matchign current as
			
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_LOGINAS, "true");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
		
	}
	
	public void testCheckSearchResultSuccess()
	{
		m_mockEnv.m_asName = SearchResultAS.STR_MVC_CLASS_NAME; // matching current as
			
		XPHashtable args = new XPHashtable();
		args.PutElement(tAG_ATTRIB_SEARCHAS, "true");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect body to run
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
		
	}
	
	public void testCheckSearchResultFailure()
	{
		m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME;
			
		XPHashtable args = new XPHashtable();
		args.PutElement(tAG_ATTRIB_SEARCHAS, "true");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
		
	}
	
	public void testCheckKDSuccess()
	{
		m_mockEnv.m_asName = DirAS.STR_MVC_CLASS_NAME; // matching as name
			
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_KDAS, "true");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect body to run
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
		
	}
	
	public void testCheckKDFailure()
	{
		m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME; // non-matching as name
			
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_KDAS, "true");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
	public void testMultipleASArgumentsSuccess()
	{
		m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_URL1, "server.pt/mypage");
		args.PutElement(TAG_ATTRIB_URL2, "param1=val");
		args.PutElement(TAG_ATTRIB_URL3, "param2=value2");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect body to run
		assertTrue("Expected tag return content was not found. Output: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
	}
	
	public void testMultipleASArgumentsFail()
	{
		m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_URL1, "server.pt/comms"); // no match
		args.PutElement(TAG_ATTRIB_URL2, "param1=value3"); // no match
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
	public void testMultipleHelperASArgsSuccess()
	{
		m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME; // matching as name
			
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_KDAS, "true");
		args.PutElement(TAG_ATTRIB_LOGINAS, "true"); // the matching as name
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect body to run
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
	}
	
	public void testMultipleHelperASFail()
	{
		m_mockEnv.m_asName = SearchResultAS.STR_MVC_CLASS_NAME; // matching as name
			
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_KDAS, "true");
		args.PutElement(TAG_ATTRIB_LOGINAS, "true"); // the matching as name
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
	public void testBothArgTypesSuccess()
	{
		// TEST 1: Success with pre-def AS checks
		m_mockEnv.m_asName = LoginAS.STR_MVC_CLASS_NAME; 
		m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_URL1, "server.pt/kdfolder"); // non-match
		args.PutElement(TAG_ATTRIB_KDAS, "true"); // non-match
		args.PutElement(TAG_ATTRIB_LOGINAS, "true"); // the matching as name
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect body to run
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
		
		// TEST 2: Success with string comparison success
		m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
		args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_URL1, "server.pt/mypage"); // matching url
		args.PutElement(TAG_ATTRIB_KDAS, "true"); // non-match
		args.PutElement(tAG_ATTRIB_SEARCHAS, "true"); // non-match
		result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect body to run
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML) );
		
	}
	
	public void testBothArgTypesFail()
	{
		m_mockEnv.m_asName = AdminFolderEditorAS.STR_MVC_CLASS_NAME; 
		m_mockEnv.SetCurrentRequestURL("http://somehost:8080/portal/server.pt/mypage/205?param1=value1&param2=value2&param3=value3");
		DirBrowseDP dp = new DirBrowseDP();	
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_URL1, "param2=value3"); // non-match
		args.PutElement(TAG_ATTRIB_URL2, "param3=value4"); // non-match
		args.PutElement(TAG_ATTRIB_KDAS, "true"); // non-match
		args.PutElement(TAG_ATTRIB_LOGINAS, "true"); // non-match
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
}
