/**
 * 
 */
package com.bea.alui.taglib.ptconditionals.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.server.*;
import com.plumtree.taglib.ptconditionals.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.taskapi.test.portalui.mock.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class IsNotInCommunityTagTest extends TestCase
{
	static final String TAG_LIBNAME  		= PTConditionalsTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     		= IsNotInCommunityTag.TAG.GetName();
	static final String TAG_ATTRIB_CHECKPROFILE	= IsNotInCommunityTag.ATTRIB_CHECKPROFILE.GetName();
	
	static final String TESTHTML = "<p>HTML in Tag body</p>";
	MockEnvironment m_mockEnv = null;
	MockTaskAPIUICommunityService m_mockCommAPI = null;
	
	int m_currCommId = 500;
	String m_currCommName = "Unit Test Community";
	
	
	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp() 
	{
		m_mockEnv = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new IsNotInCommunityTag());
		m_mockCommAPI = new MockTaskAPIUICommunityService();
		TaskAPIUICommunityService.SetMockInstanceForDebug(m_mockCommAPI);
		
		m_mockCommAPI.m_currCommId = m_currCommId;
		m_mockCommAPI.MockAddCommunity(m_currCommId, m_currCommName, null, null);
		
	}
	
	/**
	 * Test when in community
	 */
	public void testInCommunity()
	{
		XPHashtable args = new XPHashtable();
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// not in a community so tag should not return anything 
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
	/**
	 * Test when in community
	 */
	public void testNotInCommunity()
	{
		m_mockCommAPI.m_currCommId = -1; // not in a community
		
		XPHashtable args = new XPHashtable();
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect the tag to return content
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
	}
	
	/**
	 * Test when in user profile page with count user profile attribute set to true
	 */
	public void testInUserProfilePage()
	{
		m_mockCommAPI.m_currCommId = PT_INTRINSICS.PT_PROFILE_COMMUNITY; // simulate in user profile community
		
		XPHashtable args = new XPHashtable();
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// not in a community so tag should not return anything 
		assertTrue("Unexpected content was returned: "+result.GetDisplayString(), TagTestHelper.VerifyNoTagContent(result));
	}
	
	/**
	 * Test when in user profile page with count user profile attribute set to false
	 */
	public void testInUserProfilePageNoCheck()
	{
		m_mockCommAPI.m_currCommId = PT_INTRINSICS.PT_PROFILE_COMMUNITY; // simulate in user profile community
		
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIB_CHECKPROFILE, "false");
		HTMLElement result = TagTestHelper.RunSingleTagWithNestedHTML(TAG_LIBNAME, TAG_NAME, args, TESTHTML, m_mockEnv);
		
		// expect the tag to return content
		assertTrue("Expected tag return content was not found: "+result.GetDisplayString(),  TagTestHelper.VerifyTagReturnedContent(result, TESTHTML));
	}
}
