using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptdata
{
  /// <summary>
  /// Implementation of the CommunityPages PTURL DO Data Tag
  /// </summary>
  public class CommunityPagesDataTag : APTURLDODataTag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_COMMUNITYID;
    static CommunityPagesDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("communitypagesdata", COMMON_PRETAGMETADATA_LIST_DESC + " containing the link information for Community Pages in the specified Community. " + COMMON_TAGVAR_DESC + "Only the Pages the user has access to are included. " + COMMON_COLLECTION_DESC + COMMON_PROPLIST_HEADER + COMMON_PAGE_DESC + COMMON_COMMS_DESC + COMMON_POSTTAGMETADATA_DESC + COMMON_CURRENTMARKER_DESC,
       EncodeForTagDoc("<pt:ptdata.communitypagesdata pt:id=\"commpages\" pt:commid=\"500\" /><br/>" + "<pt:logic.foreach pt:data=\"commpages\" pt:var=\"curr\" /> //display values for each community page <br/>" + "&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.pageid\"/>   // Page Id<br/>" + "&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.pagename\"/> // Page Name<br/>" + "&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commid\"/>   // Community Id<br/>" + "&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commname\"/> // Community Name<br/>" + "&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.url\"/> \t // URL to the page<br/>" + "</pt:logic.foreach>" + ""));
      ATTRIB_COMMUNITYID = new RequiredTagAttribute("commid", "The Object ID of the Community to list pages from.",
       AttributeType.INT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      IEnvironment env = GetEnvironment();
      int nCommunityID = GetTagAttributeAsInt(ATTRIB_COMMUNITYID);
      XPArrayList urls = TaskAPIUICommunity.GetCommunityPagesAsURLs(TaskAPIUICommon.GetEnvTypeObject(env),
       nCommunityID);
      SetPTURLDataCollection(urls);
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new CommunityPagesDataTag();
    }
  }
}