using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptdata
{
  /// <summary>
  /// Implementation of the CreateCommPageOneClickAction PTURL DO Data Tag
  /// </summary>
  public class CreateCommPageOneClickActionDataTag : APTURLDODataTag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute TAG_INHERIT_TEMPLATE;
    public static readonly OptionalTagAttribute TAG_PAGE_TEMPLATE;
    static CreateCommPageOneClickActionDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("createcommpageoneclickdata", COMMON_PRETAGMETADATA_SINGLE_DESC + "with the link information for the One-click Create New Community Page " + "(Link that creates a new Community without an editor). " + COMMON_TAGVAR_DESC + "Template and page inheritance rule can be overriden with the optional pagetemplate and inherittemplate attributes. " + "The URL is only returned for users who has access to create new Community pages. " + COMMON_COLLECTION_DESC + COMMON_PROPLIST_HEADER + COMMON_POSTTAGMETADATA_DESC);
      TAG_INHERIT_TEMPLATE = new OptionalTagAttribute("inherittemplate", "Indicates whether new page should inherit page template",
       AttributeType.BOOLEAN, XPConvert.ToString(false));
      // Inherit Template Defaults to False, Since by default Community Pages are created 
      // using blank page templates and also if the page is inherited from a template then
      // Remove button on portlets is not displayed, and only Templates can be edited to add portlets.
      TAG_PAGE_TEMPLATE = new OptionalTagAttribute("pagetemplate", "Page template to use for new page",
       AttributeType.INT, XPConvert.ToString(-1));
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      IEnvironment env = GetEnvironment();
      bool bInheritTemplate = GetTagAttributeAsBoolean(TAG_INHERIT_TEMPLATE);
      int nPageTemplate = GetTagAttributeAsInt(TAG_PAGE_TEMPLATE);
      IPTURL url = TaskAPIUICommunity.GetURLForCreateCommunityPageOneClick(TaskAPIUICommon.GetEnvTypeObject(env),
       bInheritTemplate, nPageTemplate);
      SetPTURLDataEntry(url);
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new CreateCommPageOneClickActionDataTag();
    }
  }
}