/*
 * Created on Nov 30, 2007
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptdata
{
  /// <summary>
  /// Implementation of the CurrentCommunityDataTag Data Tag
  /// </summary>
  public class CurrentCommunityDataTag : APTURLDODataTag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     typeof(CurrentCommunityDataTag));
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    static CurrentCommunityDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("currcommunitydata", COMMON_PRETAGMETADATA_SINGLE_DESC + "containing the link information about the current Community, including the name, object id and URL to the Community home page. " + COMMON_TAGVAR_DESC + "Nothing is set in the Tag variable if the current page is not a Community page or if the current user does not have sufficient access to the current Community. " + COMMON_COLLECTION_DESC + COMMON_PROPLIST_HEADER + COMMON_COMMS_DESC + COMMON_POSTTAGMETADATA_DESC + COMMON_USERPROFILE_DESC,
       EncodeForTagDoc("<pt:ptdata.currcommunitydata pt:id=\"currcomm\" pt:noarray=\"true\" /><br/>" + "<pt:logic.value pt:value=\"$currcomm.commid\"/>   // get Community Id<br/>" + "<pt:logic.value pt:value=\"$currcomm.commname\"/> // get Community Name<br/>" + ""));
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      IEnvironment env = GetEnvironment();
      AActivitySpace owner = TaskAPIUICommon.GetEnvTypeObject(env);
      if (!TaskAPIUICommunity.IsCurrentPageCommunityPage(owner))
      {
        log.Info("Tag currcommunitydata used on a non-Community page. No data to set to datavar: \'{0}\' in scope \'{1}\'",
         GetTagAttributeAsString(ATTRIB_ID), GetTagAttributeAsString(ATTRIB_SCOPE));
        return null;
      }
      // current community URL
      XPArrayList urls = TaskAPIUICommunity.GetURLForCurrentCommunity(TaskAPIUICommon.GetEnvTypeObject(env));
      if (urls.GetSize() == 1)
      {
        SetPTURLDataEntry((IPTURL) urls.GetElement(0));
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new CurrentCommunityDataTag();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(com.plumtree.uiinfrastructure.constants.AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
  }
}