using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.utils;
using com.plumtree.taglib.ptdata;
using com.plumtree.taskapi.portalui;
using com.plumtree.taskapi.test.portalui.mock;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptdata.test
{
  /// <summary>
  /// Tag for creating a data structure with Communities, Subcommunities and Community Pages
  /// </summary>
  /// <author>rozhang</author>
  public class CommunityHierarchyDataTagTest : TestCase
  {
    internal static readonly String TAG_LIBNAME = PTDataTagLibraryData.LIBRARY.GetName();
    internal static readonly String TAG_NAME = CommunityHierarchyDataTag.TAG.GetName();
    internal static readonly String TAG_ATTRIBID = CommunityHierarchyDataTag.ATTRIB_ID.GetName();
    internal static readonly String TAG_ATTRIBCOMMID = CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName();
    internal static readonly String TAG_ATTRIBCOMMDATAID = CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName();
    internal static readonly String TAG_ATTRIBINCPAGE = CommunityHierarchyDataTag.ATTRIB_INCLUDEPAGES.GetName();
    public MockEnvironment m_environment;
    protected int[] m_topCommIds;
    protected int[] m_subCommsIds1s;
    protected int[] m_subCommsIds2s;
    protected int[] m_subCommsIds3s;
    protected int[] m_subCommsIds4s;
    protected int[] m_subCommsIds5s;
    internal readonly int[] m_commPages = new int[]{10000, 20000, 30000};
    public override void setUp()
    {
      m_environment = TagTestHelper.SetupTagTestEnvironment();
      TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new CommunityHierarchyDataTag());
      }
    
    /// <summary>
    /// Helper method to create unique page ids for each community. 
    /// Adds an array of generic page id and community id together to form a unique page id.
    /// This works as long as there is always a magnitude difference between page and community ids
    /// Ex. Community Ids in the thousands while page ids are in the ten thousands  
    /// </summary>
    public virtual int[] getPageIds(int[] pageTemplateIds, int commId)
    {
      int[] pageIds = new int[pageTemplateIds.Length];
      for (int i = 0;i < pageIds.Length;i++)
      {
        pageIds[i] = pageTemplateIds[i] + commId;
      }
      return pageIds;
    }
    
    /// <summary>
    /// Setup community structure
    /// </summary>
    /// <param name="commAPI"></param>
    public virtual void setupCommunityStructure(MockTaskAPIUICommunityService commAPI)
    {
      m_topCommIds = new int[]{1000, 2000, 3000, 4000, 5000};
      m_subCommsIds1s = new int[]{1100, 1200, 1300, 1400};
      m_subCommsIds2s = new int[]{2100, 2200, 2300, 2400};
      m_subCommsIds3s = new int[]{3100, 3200, 3300, 3400};
      m_subCommsIds4s = new int[]{4100, 4200, 4300, 4400};
      m_subCommsIds5s = new int[]{};
      int[][] topSubCommIds = new int[][]{m_subCommsIds1s, m_subCommsIds2s,
       m_subCommsIds3s, m_subCommsIds4s, m_subCommsIds5s};
      int[] subCommsIds11 = new int[]{1110, 1120, 1130};
      int[] subCommsIds21 = new int[]{2110};
      int[] subCommsIds22 = new int[]{2210, 2120};
      int[] subCommsIds211 = new int[]{2111, 2112};
      // dont want to create individual pages for each community
      // so create unique page ids by adding the page ids to the community ids
      // the pages ids are in the 10k and community ids are in the 1k so there should be no overlap
      for (int i = 0;i < m_topCommIds.Length;i++)
      {
        // add top level communities
        int[] subCommIds = topSubCommIds[i];
        commAPI.MockAddCommunity(m_topCommIds[i], "Test Community " + i, subCommIds,
         getPageIds(m_commPages, m_topCommIds[i]));
        for (int j = 0;j < subCommIds.Length;j++)
        {
          // add 1st level sub communities
          commAPI.MockAddCommunity(subCommIds[j], "Test Community " + i + j,
           null, getPageIds(m_commPages, subCommIds[j]));
        }
      }
      for (int i = 0;i < subCommsIds11.Length;i++)
      {
        commAPI.MockAddCommunity(subCommsIds11[i], "Test Community 11" + i,
         null, null);
      }
      for (int i = 0;i < subCommsIds21.Length;i++)
      {
        commAPI.MockAddCommunity(subCommsIds21[i], "Test Community 21" + i,
         null, null);
      }
      for (int i = 0;i < subCommsIds22.Length;i++)
      {
        commAPI.MockAddCommunity(subCommsIds22[i], "Test Community 22" + i,
         null, null);
      }
      for (int i = 0;i < subCommsIds211.Length;i++)
      {
        commAPI.MockAddCommunity(subCommsIds211[i], "Test Community 211" + i,
         null, null);
      }
      commAPI.MockAddSubCommunities(m_subCommsIds1s[0], subCommsIds11);
      commAPI.MockAddSubCommunities(m_subCommsIds2s[0], subCommsIds21);
      commAPI.MockAddSubCommunities(m_subCommsIds2s[1], subCommsIds22);
      commAPI.MockAddSubCommunities(subCommsIds21[0], subCommsIds211);
    }
    
    /// <summary>
    /// Tests the tag with various ways to pass in comunity ids and verify that the data structure
    /// matches the community structure 
    /// </summary>
    public virtual void testTag()
    {
      MockTaskAPIUICommunityService commAPI = new MockTaskAPIUICommunityService();
      TaskAPIUICommunityService.SetMockInstanceForDebug(commAPI);
      setupCommunityStructure(commAPI);
      String dataVarId = "testdata";
      int currCommId = m_topCommIds[4];
      String[] argNames = new String[]{TAG_ATTRIBID, TAG_ATTRIBCOMMID};
      String[] argValues = new String[]{dataVarId, currCommId + ""};
      TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
      HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
       argNames, argValues, m_environment);
      assertTrue("Data tag returned the following error HTML:\n " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      // verify data
      XPArrayList commUrls = (XPArrayList) tagState.GetTagPortletRequestVar(dataVarId);
      XPHashtable testCommStructure = BuildCommStructureMap(commUrls);
      int testResult = commAPI.VerifySubCommunityStructure(currCommId, 3,
       testCommStructure);
      assertTrue("Hierarchichal Community data tag failed with single comm id value of: " + testResult,
       testResult == 0);
      int[] currCommIds = m_topCommIds;
      String idsArgValue = "";
      for (int i = 0;i < currCommIds.Length;i++)
      {
        idsArgValue+=(i == 0 ? "" : ",") + currCommIds[i];
      }
      argNames = new String[]{TAG_ATTRIBID, TAG_ATTRIBCOMMID};
      argValues = new String[]{dataVarId, idsArgValue};
      tagState = TagTestHelper.GetMockTagStateInstance();
      result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, argNames,
       argValues, m_environment);
      assertTrue("Data tag returned the following error HTML:\n " + result.GetDisplayString(),
       result == null || "".Equals(result.GetDisplayString()));
      // verify data
      commUrls = (XPArrayList) tagState.GetTagPortletRequestVar(dataVarId);
      testCommStructure = BuildCommStructureMap(commUrls);
      for (int i = 0;i < currCommIds.Length;i++)
      {
        testResult = commAPI.VerifySubCommunityStructure(currCommIds[i], 3,
         testCommStructure);
        assertTrue("Hierarchichal Community data tag failed with single comm id value of: " + testResult,
         testResult == 0);
      }
      currCommId = m_topCommIds[0];
      String commIdTagVar = "commId";
      String commId = currCommId + "";
      argNames = new String[]{TAG_ATTRIBID, TAG_ATTRIBCOMMDATAID};
      argValues = new String[]{dataVarId, commIdTagVar};
      tagState = TagTestHelper.GetMockTagStateInstance();
      tagState.SetTagPortletRequestVar(null, commIdTagVar, commId);
      result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, argNames,
       argValues, m_environment);
      assertTrue("Data tag returned the following error HTML:\n " + result.GetDisplayString(),
       result == null || "".Equals(result.GetDisplayString()));
      // verify data
      commUrls = (XPArrayList) tagState.GetTagPortletRequestVar(dataVarId);
      testCommStructure = BuildCommStructureMap(commUrls);
      testResult = commAPI.VerifySubCommunityStructure(currCommId, 3, testCommStructure);
      assertTrue("Hierarchichal Community data tag failed with single comm id value of: " + testResult,
       testResult == 0);
      commIdTagVar = "commIdList";
      XPArrayList tagVarValue = new XPArrayList();
      for (int i = 0;i < m_topCommIds.Length;i++)
      {
        tagVarValue.Add(m_topCommIds[i]);
      }
      argNames = new String[]{TAG_ATTRIBID, TAG_ATTRIBCOMMDATAID};
      argValues = new String[]{dataVarId, commIdTagVar};
      tagState = TagTestHelper.GetMockTagStateInstance();
      tagState.SetTagPortletRequestVar(null, commIdTagVar, tagVarValue);
      result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, argNames,
       argValues, m_environment);
      assertTrue("Data tag returned the following error HTML:\n " + result.GetDisplayString(),
       result == null || "".Equals(result.GetDisplayString()));
      // verify data
      commUrls = (XPArrayList) tagState.GetTagPortletRequestVar(dataVarId);
      testCommStructure = BuildCommStructureMap(commUrls);
      for (int i = 0;i < currCommIds.Length;i++)
      {
        testResult = commAPI.VerifySubCommunityStructure(currCommIds[i], 3,
         testCommStructure);
        assertTrue("Hierarchichal Community data tag failed with single comm id value of: " + testResult,
         testResult == 0);
      }
    }
    
    /// <summary>
    /// Tests that community pages exists in the data 
    /// Tests pages in top community and subcommunities (but not nested subcommunities)
    /// </summary>
    public virtual void testCommPages()
    {
      MockTaskAPIUICommunityService commAPI = new MockTaskAPIUICommunityService();
      TaskAPIUICommunityService.SetMockInstanceForDebug(commAPI);
      setupCommunityStructure(commAPI);
      String dataVarId = "testdata";
      int currCommId = m_topCommIds[0];
      XPHashtable args = new XPHashtable();
      args.PutElement(TAG_ATTRIBID, dataVarId);
      args.PutElement(TAG_ATTRIBCOMMID, currCommId + "");
      args.PutElement(TAG_ATTRIBINCPAGE, "true");
      TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
      HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME,
       args, m_environment);
      assertTrue("Data tag returned the following error HTML:\n " + result.GetDisplayString(),
       TagTestHelper.VerifyNoTagContent(result));
      Object tagVarData = tagState.GetTagPortletRequestVar(dataVarId);
      assertNotNull("No tag variable with Community data found!", tagVarData);
      XPArrayList commData = (XPArrayList) tagVarData;
      // we specified a single community id so there should be only one
      IHierarchicalDataObject comm = (IHierarchicalDataObject) commData.GetElement(0);
      // each community is created with 3 pages, verify they are in there
      // verify top level community
      verifyCommunityPages(comm);
      XPArrayList subComms = (XPArrayList) comm.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
      // check pages in every subcommunity
      for (int i = 0;i < subComms.GetSize();i++)
      {
        IHierarchicalDataObject subcomm = (IHierarchicalDataObject) subComms.GetElement(i);
        // verify
        verifyCommunityPages(subcomm);
      }
    }
    
    /// <param name="comm"></param>
    /// <param name="pages"></param>
    protected virtual void verifyCommunityPages(IHierarchicalDataObject comm)
    {
      // get pages
      XPArrayList pages = comm.GetHierData(CommunityHierarchyDataTag.HIERDATA_PAGESKEY);
      String commId = (String) comm.GetData(CommonOpenerFriendlyURL.KEY_FRIENDLYURL_OBJECTID);
      int[] pageIds = getPageIds(m_commPages, XPConvert.ToInteger(commId));
      // compare the ids with expected ids
      for (int pageindex = 0;pageindex < pages.GetSize();pageindex++)
      {
        int currpageid = XPConvert.ToInteger(pages.GetElement(pageindex));
        assertEquals("Community Page in Community with id: " + commId + " do not match expected value!",
         currpageid, pageIds[pageindex]);
      }
    }
    
    /// <summary>
    /// Tests error handling with invalid attribute values
    /// </summary>
    public virtual void testCommIdAttributesErrorCases()
    {
      // CASE 1: Both comm id types are specified
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       CommunityHierarchyDataTag.TAG.GetName());
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(),
       "testdata");
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName(),
       "200");
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(),
       "commidtagvar");
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertTrue("No error message generated when passing values in both community id value and reference attributes!",
       result != null);
      String output = result.GetDisplayString();
      Assert.assertTrue("Expected error message when passing values in both community id value and reference attributes not found!",
       XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_BOTHCOMMIDTYPES) > 0 && XPStringUtility.IndexOf(output,
       "XPIllegalArgumentException") > 0);
      // CASE 2: No comm id specified
      helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       CommunityHierarchyDataTag.TAG.GetName());
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(),
       "testdata");
      objArrMarkup = helper.ToArrayEntireFragment();
      result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertTrue("No error message generated when not specifying any community ids!",
       result != null);
      output = result.GetDisplayString();
      Assert.assertTrue("Expected error message when not specifying any community ids!",
       XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_NOCOMMIDS) > 0 && XPStringUtility.IndexOf(output,
       "XPIllegalArgumentException") > 0);
      // CASE 3: Invalid single comm id value
      helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       CommunityHierarchyDataTag.TAG.GetName());
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(),
       "testdata");
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName(),
       "aa");
      objArrMarkup = helper.ToArrayEntireFragment();
      result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertTrue("No error message generated specifying invalid community id value!",
       result != null);
      output = result.GetDisplayString();
      Assert.assertTrue("Expected error message when specifying invalid community id value!",
       XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_NONNUMERICCOMMID) > 0 && XPStringUtility.IndexOf(output,
       "XPIllegalArgumentException") > 0);
      // CASE 4: Invalid comm id in list
      helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       CommunityHierarchyDataTag.TAG.GetName());
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(),
       "testdata");
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName(),
       "300, 302, 403, aaa");
      objArrMarkup = helper.ToArrayEntireFragment();
      result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertTrue("No error message generated specifying invalid community id value in a list!",
       result != null);
      output = result.GetDisplayString();
      Assert.assertTrue("Expected error message when specifying invalid community id value in a list!",
       XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDCOMMID_INLIST) > 0 && XPStringUtility.IndexOf(output,
       "XPIllegalArgumentException") > 0);
      String tagVarName = "mocktagvar";
      Object tagVarSingleValue = null;
      XPArrayList tagVarListValue = null;
      SharedStateVariable tagVar = null;
      // CASE 5: Invalid tag variable type
      helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       CommunityHierarchyDataTag.TAG.GetName());
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(),
       "testVar");
      helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(),
       tagVarName);
      tagVarSingleValue = new XPHashtable();
      TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
      TagState.TEST_PORTLET_REQUEST_DATA.PutElement("ptdata." + tagVarName,
       tagVarSingleValue);
      objArrMarkup = helper.ToArrayEntireFragment();
      result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertTrue("No error message generated specifying invalid community id value in a list!",
       result != null);
      output = result.GetDisplayString();
      Assert.assertTrue("Expected error message when specifying invalid community id value in a list!",
       XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDTAGVARTYPE) > 0 && XPStringUtility.IndexOf(output,
       "XPIllegalArgumentException") > 0);
      // CASE 6: Invalid single comm id in tag variable
      // invalid community id value
      tagVarSingleValue = "aaaa";
      TagStateTestHelper state = TagTestHelper.GetMockTagStateInstance();
      state.SetTagPortletRequestVar("", tagVarName, tagVarSingleValue);
      XPHashtable args = new XPHashtable();
      args.PutElement(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testVar");
      args.PutElement(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(),
       tagVarName);
      result = TagTestHelper.RunSingleTag(PTDataTagLibraryData.LIBRARY.GetName(),
       CommunityHierarchyDataTag.TAG.GetName(), args, m_environment);
      Assert.assertTrue("No error message generated specifying invalid community id value in tag variable!",
       !TagTestHelper.VerifyNoTagContent(result));
      output = result.GetDisplayString();
      Assert.assertTrue("Expected error message when specifying invalid community id value in tag variable!",
       XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDTAGVAR_COMMID) > 0 && XPStringUtility.IndexOf(output,
       "XPIllegalArgumentException") > 0);
      // CASE 7: Invalid comm id in tag variable list
      // tag variable list
      tagVarListValue = new XPArrayList();
      tagVarListValue.Add("200");
      tagVarListValue.Add("300");
      tagVarListValue.Add("bbbb");
      tagVarListValue.Add("400");
      state = TagTestHelper.GetMockTagStateInstance();
      state.SetTagPortletRequestVar("", tagVarName, tagVarListValue);
      // setup and run tag
      args = new XPHashtable();
      args.PutElement(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testVar");
      args.PutElement(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(),
       tagVarName);
      result = TagTestHelper.RunSingleTag(PTDataTagLibraryData.LIBRARY.GetName(),
       CommunityHierarchyDataTag.TAG.GetName(), args, m_environment);
      // verify results
      Assert.assertTrue("No error message generated specifying invalid community id in tag variable list!",
       result != null);
      output = result.GetDisplayString();
      Assert.assertTrue("Expected error message when specifying invalid community id value in tag variable list!",
       XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDTAGVARLISTENTRYTYPE) > 0 && XPStringUtility.IndexOf(output,
       "XPIllegalArgumentException") > 0);
    }
    
    /// <param name="commList"></param>
    /// <returns></returns>
    public virtual XPHashtable BuildCommStructureMap(IXPList hierCommDataList)
    {
      XPHashtable retMap = new XPHashtable();
      for (int i = 0;i < hierCommDataList.GetSize();i++)
      {
        // for each community in the list: 
        // - add comm id to map as key and a list of subcomm ids as value
        // - find sub comms for the sub comm by calling this function recursively
        IPTURL curr = (IPTURL) hierCommDataList.GetElement(i);
        // get the id
        int commId = XPConvert.ToInteger(curr.GetData(ACommonOpenerURL.KEY_OBJECTID));
        IXPList subComms = curr.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
        IXPList subCommIds = new XPArrayList();
        if (subComms != null && !subComms.IsEmpty())
        {
          // get subcomm ids and populate map with subcomms in the subcomm
          subCommIds = RecursiveBuildCommStructureMap(subComms, retMap);
        }
        retMap.PutElement(commId, subCommIds);
      }
      return retMap;
    }
    
    /// <summary>
    /// Helper 
    /// </summary>
    /// <param name="hierCommDataList"></param>
    /// <param name="returnMap"></param>
    /// <returns></returns>
    private IXPList RecursiveBuildCommStructureMap(IXPList hierCommDataList,
     XPHashtable returnMap)
    {
      XPArrayList subCommIds = new XPArrayList();
      // for each community
      // - convert ipturl to id and add ot subcommid list that we return
      // - find all sub communities of the community
      for (int i = 0;i < hierCommDataList.GetSize();i++)
      {
        IPTURL curr = (IPTURL) hierCommDataList.GetElement(i);
        // get the id
        int commId = XPConvert.ToInteger(curr.GetData(ACommonOpenerURL.KEY_OBJECTID));
        // add comm id to list that we return
        subCommIds.Add(XPConvert.ToInteger(curr.GetData(ACommonOpenerURL.KEY_OBJECTID)));
        IXPList subComms = curr.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
        IXPList subsubCommIds = new XPArrayList();
        if (subComms != null && !subComms.IsEmpty())
        {
          // get subsubcomm ids and populate map with depper subcomms
          subsubCommIds = RecursiveBuildCommStructureMap(subComms, returnMap);
          }
        returnMap.PutElement(commId, subsubCommIds);
      }
      return subCommIds;
    }
  }
}
//out.PutElement(commId, subCommIds);
