using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.taglib.ptdata;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptdata.test
{
  /// <summary>
  /// Tests for the page link tag.
  /// </summary>
  public class PageLinkTagTest : TestCase
  {
    public const String REQUEST_URL = "http://www.test.com:90/portal/server.pt?space=test";
    public const String PAGELINK_HOST_NAME = "mock.base.com";
    public const String PAGELINK_BASE_URL = "http://mock.base.com/myportal/test.pt";
    public const String PAGELINK_HTTP_ENTRY_POINT = "/myportal/test.pt";
    public const String PAGELINK_FILE_PATH_NAME = "";
    public const String PAGELINK_QUERY_STRING = null;
    public MockEnvironment m_environment;
    
    /// <summary>
    /// mock base URL without the trailing ?
    /// </summary>
    public String BASE_URL = XPStringUtility.Substring(MockEnvironment.MOCK_BASE_URL,
     0, MockEnvironment.MOCK_BASE_URL.Length - 1);
    public override void setUp()
    {
      ConfigService.setTestInstance(new MockConfigHelper());
      m_environment = new MockEnvironment();
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PageLinkTag(), PageLinkTag.TAG.GetName(), PTDataTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// This method tests storing the base URL.
    /// </summary>
    public virtual void testBaseURL()
    {
      // initialize markup
      XMLFragmentTestHelper portletBrowseModeTagHelper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       PageLinkTag.TAG.GetName());
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.USE_BASE_URL.GetName(),
       "true");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletBrowseModeTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      assertEquals("The output should be empty.", "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + PageLinkTag.KEY.GetDefaultValue());
      Assert.assertNotNull("Checking URL data is present.", ssVariable);
      String strURL = (String) ssVariable.GetValue();
      Assert.assertEquals("Checking URL data.", BASE_URL, strURL);
    }
    
    /// <summary>
    /// This method tests storing the base URL with a modified entry point.
    /// </summary>
    public virtual void testBaseURLWithNewEntryPoint()
    {
      // initialize markup
      XMLFragmentTestHelper portletBrowseModeTagHelper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       PageLinkTag.TAG.GetName());
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.ENTRY_POINT.GetName(),
       "/myportal/test.pt");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.USE_BASE_URL.GetName(),
       "true");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletBrowseModeTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      assertEquals("The output should be empty.", "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + PageLinkTag.KEY.GetDefaultValue());
      Assert.assertNotNull("Checking URL data is present.", ssVariable);
      String strNewURL = GeneralHelpers.Replace(BASE_URL, "/portal/server.pt",
       "/myportal/test.pt");
      String strURL = (String) ssVariable.GetValue();
      Assert.assertEquals("Checking URL data with new http entry point.",
       strNewURL, strURL);
    }
    
    /// <summary>
    /// This method tests storing the current page URL.
    /// </summary>
    public virtual void testPageURL()
    {
      // initialize markup
      XMLFragmentTestHelper portletBrowseModeTagHelper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       PageLinkTag.TAG.GetName());
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletBrowseModeTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      assertEquals("The output should be empty.", "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + PageLinkTag.KEY.GetDefaultValue());
      Assert.assertNotNull("Checking URL data is present.", ssVariable);
      String strURL = (String) ssVariable.GetValue();
      Assert.assertEquals("Checking URL data.", m_environment.GetCurrentRequestURL(),
       strURL);
    }
    
    /// <summary>
    /// This method tests parsing of the base URL and storing it in a data collection.
    /// TODO: We can't seem to create an XPRequest with a different URL - the helper
    /// functions blow up.  So we can't do anything other than a localhost url.
    /// The test will include the USE_BASE_URL attribute so that it uses the Mock Base URL
    /// when parsing instead of trying to parse http://localhost that we get from the call
    /// to GetEnvironment().GetCurrentRequestURL.
    /// </summary>
    public virtual void testParseURL()
    {
      // initialize markup
      XMLFragmentTestHelper portletBrowseModeTagHelper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       PageLinkTag.TAG.GetName());
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.USE_BASE_URL.GetName(),
       "true");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.PARSE_URL.GetName(),
       "true");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletBrowseModeTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      assertEquals("The output should be empty.", "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + PageLinkTag.KEY.GetDefaultValue());
      Assert.assertNotNull("Checking URL data is present.", ssVariable);
      // Since we're using the parseurl attribute, this should return a HashtableDataObject
      IDataObject doPageLink = (IDataObject) ssVariable.GetValue();
      String hostname = doPageLink.GetData(PageLinkTag.HOST_NAME);
      Assert.assertEquals("Checking for hostname in URL.", "mock.base.com",
       hostname);
      // Expecting null since we can't create an XPRequest with a different URL
      String port = doPageLink.GetData(PageLinkTag.PORT_NUMBER);
      Assert.assertEquals("Checking for port number in URL.", null, port);
      String baseUrl = doPageLink.GetData(PageLinkTag.BASE_URL);
      Assert.assertEquals("Checking for base URL.", "http://mock.base.com/portal/server.pt",
       baseUrl);
      String entryPoint = doPageLink.GetData(PageLinkTag.HTTP_ENTRY_POINT);
      Assert.assertEquals("Checking for entry point in URL.", "server.pt",
       entryPoint);
      // Expecting empty string since we can't create an XPRequest with a different URL
      String filePathname = doPageLink.GetData(PageLinkTag.FILE_PATH_NAME);
      Assert.assertEquals("Checking for query string in URL.", "", filePathname);
      // Expecting null since we can't create an XPRequest with a different URL
      String queryString = doPageLink.GetData(PageLinkTag.QUERY_STRING);
      Assert.assertEquals("Checking for query string in URL.", null, queryString);
      }
    
    /// <summary>
    /// This method tests parsing of the base URL with a modified entry point and storing it in 
    /// a data collection.
    /// TODO: We can't seem to create an XPRequest with a different URL - the helper
    /// functions blow up.  So we can't do anything other than a localhost url.
    /// The test will include the USE_BASE_URL attribute so that it uses the Mock Base URL
    /// when parsing instead of trying to parse http://localhost that we get from the call
    /// to GetEnvironment().GetCurrentRequestURL.
    /// </summary>
    public virtual void testParseURLWithNewEntryPoint()
    {
      // initialize markup
      XMLFragmentTestHelper portletBrowseModeTagHelper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       PageLinkTag.TAG.GetName());
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.ENTRY_POINT.GetName(),
       "/myportal/test.pt");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.USE_BASE_URL.GetName(),
       "true");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.PARSE_URL.GetName(),
       "true");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletBrowseModeTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      assertEquals("The output should be empty.", "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + PageLinkTag.KEY.GetDefaultValue());
      Assert.assertNotNull("Checking URL data is present.", ssVariable);
      // Since we're using the parseurl attribute, this should return a HashtableDataObject
      IDataObject doPageLink = (IDataObject) ssVariable.GetValue();
      String hostname = doPageLink.GetData(PageLinkTag.HOST_NAME);
      Assert.assertEquals("Checking for hostname in URL.", PAGELINK_HOST_NAME,
       hostname);
      // Expecting null since we can't create an XPRequest with a different URL
      String port = doPageLink.GetData(PageLinkTag.PORT_NUMBER);
      Assert.assertEquals("Checking for port number in URL.", null, port);
      String baseUrl = doPageLink.GetData(PageLinkTag.BASE_URL);
      Assert.assertEquals("Checking for base URL.", "http://mock.base.com/myportal/test.pt",
       baseUrl);
      String entryPoint = doPageLink.GetData(PageLinkTag.HTTP_ENTRY_POINT);
      Assert.assertEquals("Checking for entry point in URL.", "/myportal/test.pt",
       entryPoint);
      // Expecting empty string since we can't create an XPRequest with a different URL
      String filePathname = doPageLink.GetData(PageLinkTag.FILE_PATH_NAME);
      Assert.assertEquals("Checking for query string in URL.", "", filePathname);
      // Expecting null since we can't create an XPRequest with a different URL
      String queryString = doPageLink.GetData(PageLinkTag.QUERY_STRING);
      Assert.assertEquals("Checking for query string in URL.", null, queryString);
      }
    
    /// <summary>
    /// This method tests storing the page URL with a modified entry point.
    /// </summary>
    public virtual void xxxtestPageURLWithNewEntryPoint()
    {
      // TODO: We can't seem to create an XPRequest with a different URL - the helper
      // functions blow up.  So we can't do anything other than a localhost url.
      // initialize markup
      XMLFragmentTestHelper portletBrowseModeTagHelper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(),
       PageLinkTag.TAG.GetName());
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.ENTRY_POINT.GetName(),
       "/myportal/test.pt");
      portletBrowseModeTagHelper.AddPTAttribute(PageLinkTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletBrowseModeTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      assertEquals("The output should be empty.", "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + PageLinkTag.KEY.GetDefaultValue());
      Assert.assertNotNull("Checking URL data is present.", ssVariable);
      String strNewURL = GeneralHelpers.Replace("http://localhost", "/portal/server.pt",
       "/myportal/test.pt");
      String strURL = (String) ssVariable.GetValue();
      Assert.assertEquals("Checking URL data with new http entry point.",
       strNewURL, strURL);
    }
  }
}