/*
 * Created on Jun 8, 2005
 */
package com.plumtree.taglib.ptdata;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;

/**
 * Shared data and definitions for PTURL DO Data tags
 * 
 */
public abstract class APTURLDODataTag extends ATag
{
	public static final String COMMON_TAGVAR_DESC = 
		"<![CDATA[<p>]]>"+
		"The data collection is set in the specified Tag variable. By default, data tags store data collections in a list, even for a single collection. " +
		"Data tags do not replace data in a Tag variable if something is stored there already but they append their new data to the existing data instead." +
		" Assembling a list of data from multiple data tags is done by specifying the data tags to use the same Tag variable. " +
		"The downside with data collections stored in lists is that a single data collection is not " +
		"directly referenceable using the '$' syntax. Instead of using a foreach tag to iterate over the list for a single data collection, use the 'noarray' "+
		"attribute. See description for this Tag library for example. "+
		"<![CDATA[</p>]]>";
	
	public static final String COMMON_PRETAGMETADATA_LIST_DESC = 
		"Creates a list of data collections ";
	
	public static final String COMMON_PRETAGMETADATA_SINGLE_DESC = 
		"Creates a single data collection ";
	
	//Sets PTURL DO data on the PORTLET REQUEST scope with
	public static final String COMMON_POSTTAGMETADATA_DESC =
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_TITLE+"<![CDATA[</code>]]>: "+"URL display string, usually the name of target the Page or Community "+"<![CDATA[<br>]]>"+
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_FULLURL+"<![CDATA[</code>]]>: "+"Full URL to the target page "+"<![CDATA[<br>]]>"+
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_URI+"<![CDATA[</code>]]>: "+"URI (part of URL after the server name) to the target page"+"<![CDATA[<br>]]>"+
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_ICONIMG+"<![CDATA[</code>]]>: "+"URL to the Icon associated with the target page "+"<![CDATA[<br>]]>"+
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_ICONIMGHEIGHT+"<![CDATA[</code>]]>: "+"Height of the icon in pixels "+"<![CDATA[<br>]]>"+
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_ICONIMGWIDTH+"<![CDATA[</code>]]>: "+"Width of the icon in pixels "+"<![CDATA[<br>]]>"+
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_PARAMS+"<![CDATA[</code>]]>: "+"Query string of the target URL"+" <![CDATA[<br>]]>";
	
	public static final String COMMON_CURRENTMARKER_DESC =
		"<![CDATA[<code>]]>"+PTURLConstants.KEY_CURRENTMARKER+"<![CDATA[</code>]]>: " +
		"This property is only set on the data collection item containing information about the current page or community. "+
		"Check for this property to locale the currently active Page or Community in a list of Pages or Communities. This allows" +
		"you to for example bold the name of the currently active Page or Community. <![CDATA[<br/>]]>";
	
	public static final String COMMON_PAGE_DESC = 
		"<![CDATA[<code>]]>pageid<![CDATA[</code>]]>: Page Id <![CDATA[<br/>]]>" +
		"<![CDATA[<code>]]>pagename<![CDATA[</code>]]>: Page name<![CDATA[<br/>]]>";
	
	public static final String COMMON_COMMS_DESC = 
		"<![CDATA[<code>]]>commid<![CDATA[</code>]]>: Community id <![CDATA[<br/>]]>" +
		"<![CDATA[<code>]]>commname<![CDATA[</code>]]>: Community name <![CDATA[<br/>]]> ";
	
	public static final String COMMON_PROPLIST_HEADER =
		"<![CDATA[<p>]]><![CDATA[<b>]]>Data properties<![CDATA[</b>]]><![CDATA[<br/>]]>"+
		"This data collection contains the following data properties: <![CDATA[<br/>]]><![CDATA[<br/>]]>";
	
	public static final String COMMON_COLLECTION_DESC =
		"<![CDATA[<p>]]>"+
		"A data collection is a bag of \"properties\": name/value pairs where values are typically Strings. " +
		"When assigned in tag variables, data collections and their properties are accessible in tag attributes through a special syntax: " +
		"<![CDATA[<code>]]>${tag variable name}.{property name}<![CDATA[</code>]]><![CDATA[</p>]]> " +
		"<![CDATA[<p>]]><![CDATA[<b>]]>Example:<![CDATA[</b/>]]> <![CDATA[&nbsp;]]> <![CDATA[<code>]]> <![CDATA[&lt;]]>pt:logic.value pt:value=\"$mytag.nameproperty\" /<![CDATA[&gt;]]> <![CDATA[</code>]]> <![CDATA[</p>]]>"+
		"<![CDATA[<p>]]>When the tag framework executes the tags, the expression is replaced with the property value in the data collection." +
		" See description of ptdata tag library for more information and examples of tag collections. <![CDATA[</p>]]>"
		;
	
	public static final String COMMON_USERPROFILE_DESC = 
		"<![CDATA[<br/>]]><![CDATA[<br/>]]>If used on a User Profile Page: <![CDATA[<br/>]]>" +
		"<![CDATA[<code>]]>classid<![CDATA[</code>]]>: Contains the value \"1\" <![CDATA[<br/>]]>" +
		"<![CDATA[<code>]]>commid<![CDATA[</code>]]>: User id of the displayed User Profile <![CDATA[<br/>]]>" +
		"<![CDATA[<code>]]>commname<![CDATA[</code>]]>: Name of the user <![CDATA[<br/>]]>" +
		"<![CDATA[<code>]]>pageid<![CDATA[</code>]]>: User Profile Page Id <![CDATA[<br/>]]>" +
		"<![CDATA[<code>]]>pagename<![CDATA[</code>]]>: Name of the User Profile Page <![CDATA[<br/>]]>";
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final RequiredTagAttribute ATTRIB_ID;
	public static final OptionalTagAttribute ATTRIB_SCOPE;
	public static final OptionalTagAttribute ATTRIB_IMG;
	public static final OptionalTagAttribute ATTRIB_NOARRAY;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.

		ATTRIB_ID = new RequiredTagAttribute("id",
			"Name of the variable in memory where the PTURL DO data created by this tag is stored. "+
			"Specify this ID in the data attribute (most commonly the DATAVAR attribute) for any display tag consuming PTURL DO data. "+
			"Multiple data tags can share the same ID, in which case they are added to a list in the order they were processed. ",	
			AttributeType.STRING);

		ATTRIB_SCOPE = new OptionalTagAttribute("scope",
			"The scope used to store the data. See Tagdoc for the logic tag library for a list of all available scopes. ",
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
		
		ATTRIB_NOARRAY = new OptionalTagAttribute("noarray",
				"Set this attribute to true to store the data tag variable as a single collection instead of a list of collection. The default behavior, setting this data as a list "+
				"allows you to assemble multiple data into a list but prevents the data from being used directly in attribute replacement. The work around is to reference the data in "+
				"a foreach tag. With noarray set to true, this data is usable in attribute replacement but cannot be added to lists of other data tags. "+
				"This attribute only applies to data tags which set a single data entry, such as "+CurrentCommunityDataTag.TAG.GetName()+" or "+CurrentProfileDataTag.TAG.GetName()+". "+
				"It has no effects for tags which return a list of data entries, such as "+CommunityPagesDataTag.TAG.GetName()+" or "+CommunityMembershipDataTag.TAG.GetName()+".",
				AttributeType.BOOLEAN, "false");
		
		ATTRIB_IMG = new OptionalTagAttribute("img", "Takes an image URL used to override the default icon assigned to a data collection." +
				"This attribute only overrides icons for data tags returning a single data collection, such as, "+
				CommunityPagesDataTag.TAG.GetName()+" or "+CommunityMembershipDataTag.TAG.GetName(), AttributeType.STRING, null);
		
	}

	/** PTURL Setter Helper class **/
	TagDataSetterPTURLDOData m_URLSetter = new TagDataSetterPTURLDOData();
	
	/**
	 * 
	 * @param xpList
	 */
	public void SetPTURLDataCollection(IXPList xpList)
	{
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		
		m_URLSetter.SetScope(tagScope);
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		
		m_URLSetter.SetDataCollectionOnTagScope(GetState(), strDataReference, xpList);
		
	}
	
	/**
	 * 
	 * @param urlEntry
	 */
	public void SetPTURLDataEntry(IPTURL urlEntry)
	{
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		String strImg = GetTagAttributeAsString(ATTRIB_IMG);
		if(null != strImg && urlEntry != null)
		{
			urlEntry.SetURLData(PTURLConstants.KEY_ICONIMG, strImg);
		}
		
		if ( GetTagAttributeAsBoolean(ATTRIB_NOARRAY) ) {
			GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_ID), urlEntry, tagScope, false);
		} else {
		
			m_URLSetter.SetScope(tagScope);
			String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
			
			m_URLSetter.SetDataEntryOnTagScope(GetState(), strDataReference, urlEntry);
		}
		
	}
	
	
	/**
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(com.plumtree.uiinfrastructure.constants.AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	
	}

}
