/*
 * Created on Jan 31, 2005
 */
package  com.plumtree.taglib.ptdata;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the CurrentCommunityPages PTURL DO Data Tag
 * 
 */
public class CurrentCommunityPagesDataTag extends APTURLDODataTag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		CurrentCommunityPagesDataTag.class);

	
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("currcommunitypagesdata",
			COMMON_PRETAGMETADATA_LIST_DESC+"with the link information for Community pages in the current Community. " +
			COMMON_TAGVAR_DESC+
			"Nothing is set in the Tag variable if the current user is not in a Community or does not have sufficient access to the current Community." +
			COMMON_COLLECTION_DESC+
			COMMON_PROPLIST_HEADER+
			"<![CDATA[<code>]]>pageid<![CDATA[</code>]]>: Community Page Id <![CDATA[<br/>]]>" +
			"<![CDATA[<code>]]>pagename<![CDATA[</code>]]>: Community Page name <![CDATA[<br/>]]>" +
			"<![CDATA[<code>]]>commid<![CDATA[</code>]]>: Community id <![CDATA[<br/>]]>" +
			"<![CDATA[<code>]]>commname<![CDATA[</code>]]>: Community name <![CDATA[<br/>]]>"+
			COMMON_POSTTAGMETADATA_DESC+
			COMMON_CURRENTMARKER_DESC+
			COMMON_USERPROFILE_DESC,
			EncodeForTagDoc(
				"<pt:ptdata.currcommunitypagesdata pt:id=\"currcommpages\" /><br/>"+
				"<pt:logic.foreach pt:data=\"currcommpages\" pt:var=\"curr\" /> //display values for each community page <br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.pageid\"/>   // Page Id<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.pagename\"/> // Page Name<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commid\"/>   // Community Id<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commname\"/> // Community Name<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.url\"/> 	 // URL to the page<br/>"+
				"</pt:logic.foreach>"+
				"")
		);
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IEnvironment env = GetEnvironment();
		
		XPArrayList urls = TaskAPIUICommunity.GetCurrentCommunityPagesAsURLs(TaskAPIUICommon.GetEnvTypeObject(env));
		if ( urls == null ) {
			log.Info("Tag currcommunitypagesdata did not find any pages in current Community. No data to set to datavar: '{0}' in scope '{1}'",
					GetTagAttributeAsString(ATTRIB_ID), GetTagAttributeAsString(ATTRIB_SCOPE));
			urls = new XPArrayList();
		}
		SetPTURLDataCollection(urls);
		
		return null;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new CurrentCommunityPagesDataTag();
	}

}
