/*
 * Created on Dec 5, 2007
 */
package  com.plumtree.taglib.ptdata;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the CurrentProfileIDDataTag Data Tag
 * 
 */
public class CurrentProfileDataTag  extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		CurrentProfileDataTag.class);
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute KEY;
	public static final OptionalTagAttribute ATTRIB_SCOPE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("currprofiledata",
			APTURLDODataTag.COMMON_PRETAGMETADATA_SINGLE_DESC+ "with information about the current User Profile. "+
			APTURLDODataTag.COMMON_TAGVAR_DESC+
			"Nothing is set in the Tag variable if this tag is not used on a User Profile page.<![CDATA[<br/>]]> " +
			"Note, this tag displays information about the user who's profile is being viewed; not the logged-in user."+
			APTURLDODataTag.COMMON_COLLECTION_DESC+
			APTURLDODataTag.COMMON_PROPLIST_HEADER+
			"<![CDATA[<code>]]>fullname, email, imuser, phone, employeeid, department, title, zipcode, manager, _profileuserid, _profileusername, " +
			"_profiledescription, _profileloginname, _profileuniquename, _profileauthname, accessingfromintranet, hostpagequerystring<![CDATA[</code>]]><![CDATA[<br/>]]>"+
			"Note that not all UserInfo properties are set for every user.<![CDATA[</p>]]>"
			);
		
		KEY = new RequiredTagAttribute("key",
			"The name of the tag variable the profile data collection is stored.");

		ATTRIB_SCOPE = new OptionalTagAttribute("scope",
			"The scope used to store the data. See Tagdoc for the logic tag library for a list of all available scopes. ",
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		IEnvironment env = GetEnvironment();
		AActivitySpace owner = TaskAPIUICommon.GetEnvTypeObject(env);
		int profileID=-1;
	    
		// make sure tag is being used on the profile community only
		if (TaskAPIUICommunity.IsCurrentCommunityUserProfileCommunity(owner) && (owner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME)))
		{
			// get profile id
			MyPortalModel model= (MyPortalModel) owner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
			profileID = model.GetProfileID();
			IPTProfileManager m_ptProfileManager = null;

			try
			{
				// open the profile manager
				m_ptProfileManager = (IPTProfileManager) ((IPTSession)owner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER, false);
				IPTUserInfo userInfo = m_ptProfileManager.GetUserInfo(profileID);
				IXPList profileData = new XPArrayList();

				// load the properties into a dataObject
				HashtableDataObject profileDO = new HashtableDataObject();
				String[] emptyArray = null;
				Object property[][] = userInfo.LookupUserInfoSettings(emptyArray);
				if (null != property) {
					int numProperties = property[0].length;
					for (int i=0; i<numProperties; i++)
					{
						profileDO.SetData(XPStringUtility.ToLowerCase((String) property[0][i]), safeString((String)property[1][i]));					
					}
				}
				profileDO.SetData("id", "" + profileID);

				// add the dataObject to the arrayList
				profileData.Add(profileDO);
				SetStateSharedVariable(GetTagAttributeAsString(KEY), profileDO, tagScope, false);
				
			}
			catch (Exception e)
			{
				log.Info(e, "Tag currprofiledata was unable to retrieve User Profile data from the current page. "+
						"No data was set to datavar: '{0}' in scope: '{1}'", GetTagAttributeAsString(KEY), tagScope);
				return null;
			}			
		}
		log.Info("Tag currprofiledata was not used on a User Profile Page. "+
						"No data was set to datavar: '{0}' in scope: '{1}'", GetTagAttributeAsString(KEY), tagScope);
		
		return null;
	}
	
	// avoid setting null values
	private String safeString(String in_text)
	{
		return (in_text == null)?"":in_text;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new CurrentProfileDataTag();
	}
	
	/**
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(com.plumtree.uiinfrastructure.constants.AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}
	
}
