/*
 */
package  com.plumtree.taglib.ptdata;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the CurrentSubCommunities PTURL DO Data Tag
 * 
 */
public class CurrentSubCommunitiesDataTag extends APTURLDODataTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("currsubcommunitiesdata",
			COMMON_PRETAGMETADATA_LIST_DESC+"with the link information for the Subcommunity " +
					"(Communities inside another Community in the Admin hierarchy) of the current Community. " +
			COMMON_TAGVAR_DESC+
			"Nothing is set in the Tag variable if this tag is not used in a Community. "+ 
			COMMON_COLLECTION_DESC+
			COMMON_PROPLIST_HEADER+
			COMMON_COMMS_DESC+
			COMMON_POSTTAGMETADATA_DESC+
			COMMON_CURRENTMARKER_DESC,
			EncodeForTagDoc(
				"<pt:ptdata.currsubcommunitiesdata pt:id=\"subcomms\" /><br/>"+
				"<pt:logic.foreach pt:data=\"subcomms\" pt:var=\"curr\" /> //display values for each community page <br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commid\"/>   // Community Id<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commname\"/> // Community Name<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.url\"/> 	 // URL to the page<br/>"+
				"</pt:logic.foreach>"+
				""));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IEnvironment env = GetEnvironment();
		
		XPArrayList urls = TaskAPIUICommunity.GetCurrentSubCommunitiesAsURLs(TaskAPIUICommon.GetEnvTypeObject(env));
		
		SetPTURLDataCollection(urls);
		
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new CurrentSubCommunitiesDataTag();
	}
}
