package  com.plumtree.taglib.ptdata;

import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the GenericURL PTURL DO Data Tag
 * 
 */
public class GenericURLDataTag extends APTURLDODataTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_URL;
	public static final RequiredTagAttribute ATTRIB_TEXT;
	public static final OptionalTagAttribute ATTRIB_IMAGE;
	public static final OptionalTagAttribute ATTRIB_IMAGEWIDTH;
	public static final OptionalTagAttribute ATTRIB_IMAGEHEIGHT;
	public static final OptionalTagAttribute ATTRIB_PTIMAGE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.

		// TODOCR DONH: If this url has a custom image, how can it add the image size
		// to the URL (see COMMON_POSTTAGMETADATA_DESC).
		TAG = new TagMetaData("genericurl",
			COMMON_PRETAGMETADATA_SINGLE_DESC +"with configurable link information. Specify link data through the attributes." +
			COMMON_TAGVAR_DESC+
			COMMON_COLLECTION_DESC+
			COMMON_PROPLIST_HEADER+
			COMMON_POSTTAGMETADATA_DESC+
			"<![CDATA[<br/>]]>The <![CDATA[<code>]]>"+PTURLConstants.KEY_ICONIMG+"<![CDATA[</code>]]>"+
			"property is only set if an image is specified."
			);

		ATTRIB_URL = new RequiredTagAttribute("url",
			"Full URL (For example, http://www.plumtree.com) ",	
			AttributeType.STRING);

		ATTRIB_TEXT = new RequiredTagAttribute("text",
			"URL Title",	
			AttributeType.STRING);

		ATTRIB_IMAGE = new OptionalTagAttribute("image",
			"Full URL to an icon (For example, http://www.plumtree.com/image.gif. This image will be set if both this and the ptimage attribute is set) ",	
			AttributeType.STRING, 
			null);

		ATTRIB_PTIMAGE = new OptionalTagAttribute("ptimage",
			"File name of image on the plumtree imageserver in the \\plumtree\\portal\\public\\img\\ directory (For example, icon_community.gif) ",	
			AttributeType.STRING, 
			null);
		
		ATTRIB_IMAGEWIDTH = new OptionalTagAttribute("imagewidth",
			"Pixel width of the specified image. No image width is used if no value is specified.",	
			AttributeType.INT, 
			"-1");
		
		ATTRIB_IMAGEHEIGHT = new OptionalTagAttribute("imageheight",
			"Pixel height of the specified image. No image height is used if no value is specified.",	
			AttributeType.INT, 
			"-1");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		// IEnvironment env = GetEnvironment();
		
		String strTitle = GetTagAttributeAsString(ATTRIB_TEXT);
		String strURL = GetTagAttributeAsString(ATTRIB_URL);
		String strImg	= GetTagAttributeAsString(ATTRIB_IMAGE);
		String strPTImg	= GetTagAttributeAsString(ATTRIB_PTIMAGE);
		
		String strImgSvrURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()));
		
		FullURL url = new FullURL(strTitle, strURL);
		
		if ( strImg == null ) {
			if ( strPTImg != null )
			url.SetURLData(PTURLConstants.KEY_ICONIMG, strImgSvrURL+"/portal/public/img/"+strPTImg);
		} else {
			url.SetURLData(PTURLConstants.KEY_ICONIMG, strImg);
		}
		
		int imgWidth = GetTagAttributeAsInt(ATTRIB_IMAGEWIDTH);
		int imgHeight = GetTagAttributeAsInt(ATTRIB_IMAGEHEIGHT);
		if ( GetTagAttributeAsInt(ATTRIB_IMAGEWIDTH) != -1) {
			url.SetURLData(PTURLConstants.KEY_ICONIMGWIDTH, imgWidth+"");
		}
		if ( GetTagAttributeAsInt(ATTRIB_IMAGEHEIGHT) != -1) {
			url.SetURLData(PTURLConstants.KEY_ICONIMGHEIGHT, imgHeight+"");
		}
		
		
		SetPTURLDataEntry(url);
		
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new GenericURLDataTag();
	}
}
