/*
 * Created on Jan 31, 2005
 */
package  com.plumtree.taglib.ptdata;

import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the HelpPage PTURL DO Data Tag
 * 
 */
public class HelpPageDataTag extends APTURLDODataTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("helppagedata",
			COMMON_PRETAGMETADATA_SINGLE_DESC + "with the link information for the Online Help Page (Opens the online help for the current page). " +
			COMMON_TAGVAR_DESC+
			COMMON_COLLECTION_DESC+
			COMMON_PROPLIST_HEADER+
			COMMON_POSTTAGMETADATA_DESC+
			"<![CDATA[<code>]]>"+PTURLConstants.KEY_FULLURL+"<![CDATA[</code>]]>: Returns # in standard display mode,"+
			"since help is opened in a popup window. Use the <![CDATA[<code>]]>"+PTURLConstants.KEY_JAVASCRIPT_ACTION+"<![CDATA[</code>]]> property" +
			"to get the javascript that opens the help popup. In Accessibility and low-bandwidth mode this property contains a URL to the help page.",
			EncodeForTagDoc(
					"<pt:ptdata.helppagedata pt:id=\"pageurl\"/> <br/> "+
					"<pt:core.html pt:tag=\"a\" href=\"#\" onclick=\"$pageurl.jsaction\"> \\ standard mode help link<br/> "+
					"&nbsp;<pt:logic.value pt:value=\"$pageurl.title\"><br/>"+
					"</pt:core.html><br/>"+
					"<br/>"+
					"<pt:core.html pt:tag=\"a\" href=\"$pageurl.url\"> \\ in accessibility and low-bandwidth mode<br/>"+
					"&nbsp;<pt:logic.value pt:value=\"$pageurl.title\"><br/>"+
					"</pt:core.html><br/>"
			));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IEnvironment env = GetEnvironment();
		
		IPTURL url = TaskAPIUIPortalConfig.GetURLForCurrentPageHelp(TaskAPIUICommon.GetEnvTypeObject(env));
		
		SetPTURLDataEntry(url);
		
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new HelpPageDataTag();
	}
}
