/**
 * 
 */
package com.plumtree.taglib.ptdata;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author rozhang
 *
 */
public class JSArrayDataFormatterTag extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		"com.plumtree.taglib.logic.JSArrayDataFormatter");
	
	public static final ITagMetaData TAG;
	
	public static final RequiredTagAttribute ATTRIB_DATA;
	public static final OptionalTagAttribute ATTRIB_SCOPE;
	public static final OptionalTagAttribute ATTRIB_CHILDKEY;
	
	public static final RequiredTagAttribute ATTRIB_PROPERTIES;
	
	/** Counter for each object, to generate unique id for each entry, used by dojo **/
	protected int m_index = 0;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		
		TAG = new TagMetaData("jsarraydataformat",
				"This tag is different from other data tag in that it does not set data in a Tag variable. "+
				"Instead it is used to generate and output a JSON (Javascript object notation) representation of a single- or list of data collections. "+
				"Data collection properties are represented as javascript object properties, data collection as javascript objects and lists as javascript arrays. "+ 
				"Nested lists and collections are supported for use with hierarchical data tags. <br/><br/>"+
				"Used for:<br/>"+
				"1. With menu and tree tag definitions"+
				"2. Debugging property values in a data collection. Put this tag in an HTML comment or javascript block and pass in the data collection " +
				"with the properties to inspect. View the values by looking at the HTML source for the page. ",
				EncodeForTagDoc(
						"<script><br/>"+
						"&nbsp;var jsdata = <pt:ptdata.jsarraydataformat pt:data=\"hierdatavar\" pt:props=\"title,url,currpage,img\" />;<br/>"+
						"</script><br/>"+
						"Output:<br/>"+
						"var jsdata = {<br/>"+
						"&nbsp;title:'Page 1', url:'http://server/portal/server.pt/community/Community_1', img:'http://imgsrv/img.gif'<br/>"+
						"&nbsp;children:[ { title:'Page 1', url:'http://server/portal/server.pt/community/Community_2/page_1', img:'http://imgsrv/img.gif' } ]<br/>"+
						"&nbsp;{title:'Page 2', url:'http://server/portal/server.pt/community/Community_2/page_2', img:'http://imgsrv/img.gif'} "
						));  	
		
		ATTRIB_DATA   	= new RequiredTagAttribute("data", "Reference to tag variable with data to be converted", AttributeType.STRING);
		ATTRIB_SCOPE 	= new OptionalTagAttribute("scope", "The scope of the tag variable referenced in the data attribute.  ", AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
		ATTRIB_CHILDKEY = new OptionalTagAttribute("childkey", "Hierarchical child key if different from default. ", AttributeType.STRING, null);
		ATTRIB_PROPERTIES   = new RequiredTagAttribute("props", "A comma separated string with data properties to include in the javascript array. ", AttributeType.STRING);
	}
	
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		m_index = 0;
		// This tag is used in javascript so we don't want to directly output java exception
		// If we get an exception, output an empty array with error in js comment.
		try {
			Scope scope 	= GetTagAttributeAsScope(ATTRIB_SCOPE);
			String tagVarId = GetTagAttributeAsString(ATTRIB_DATA);
			Object val 		= GetTagAttributeAsTagVariable(ATTRIB_DATA, scope);
			if ( val == null ) {
				throw new XPIllegalArgumentException("Specified tag variable: "+tagVarId+" in scope: "+scope.toString()+" did not contain a data object.");
			}
			if ( !(val instanceof XPArrayList) ) {
				throw new XPIllegalArgumentException("Specified tag variable: "+tagVarId+" in scope: "+scope.toString()+" did not contain a valid data object of type XPArrayList It was: "+val);
			} 
			
			XPStringBuilder buf = new XPStringBuilder(400);
			XPArrayList parentData = (XPArrayList)val;
			
			boolean isMultiLine = (parentData.GetSize() > 1) ; // if the constructed array has a carriage return, ie has children or array contains more than one element
			
			buf.Append("["); // start of main array
			for (int i = 0; i < parentData.GetSize(); i++ ) {
				Object currParent = parentData.GetElement(i);
				// add comma after each child object, except for the last one
				if ( i != 0 ) { buf.Append(",\n"); }
				
				if ( currParent instanceof IDataObject ) {
					isMultiLine = true;
					GenerateJSArray(buf, (IDataObject)currParent, 1, (i==0));
				} else {
					log.Warn("Invalid child data in tag variable: "+tagVarId+" in scope: "+scope.toString()+". Type: "+currParent);
				}
			}
			buf.Append("]"); // end of main array
			if ( isMultiLine ) {
				buf.Insert(0, "\n");
			}
			return new HTMLGenericElement(buf.ToString());
			
		} catch (XPException e) {
			XPStringBuilder buf = new XPStringBuilder(200); // output buffer
			buf.Append("[]"); // first add the empty array
			buf.Append("/** Exception in pt:ptdata.jsarraydataformat tag: "+e.GetMessage()+" **/"); // then add exception in javascript comment
			log.Error(e, "Exception in pt:ptdata.jsarraydataformat tag!\n");
			return new HTMLGenericElement(buf.ToString());
		}
		
	}
	
	protected void GenerateJSArray(XPStringBuilder buf, IDataObject data, int depth, boolean isfirst)
	{
		/* Generate JSArray for properties in this data */
		String[] propNames  = GetProperties();
		// get property values from the data entry
		String[] propValues = new String[propNames.length];
		for ( int i = 0; i < propNames.length; i++ ) {
			propValues[i] = data.GetData(propNames[i]);
		}
		int curIndex = m_index;
		// padding for nested objects, add tabs plus space (for the /*0*/) to align under first nested object in the same level:" 
		String padding = (isfirst) ? "" : GetPadding(depth)+"    ";
		// start js object for data object, add comment with index 
		buf.Append( padding +"{/*"+curIndex+"*/ ");
		// display each property 
		for ( int i = 0; i < propNames.length; i++ ) {
			if ( i != 0 ) { buf.Append(", "); }
			// name and value
			buf.Append(propNames[i]+": \""+propValues[i]+"\"");
		}
		buf.Append(", id:"+(m_index++)+""); // add unique id for each entry
		
		
		/* if data object has children, generate sub arrays for the children */
		if ( data instanceof IHierarchicalDataObject ) 
		{
			XPArrayList childKeys = new XPArrayList();
			childKeys.Add("children");

			String custChildKey = GetTagAttributeAsString(ATTRIB_CHILDKEY);
			if ( custChildKey != null ) {
				childKeys.Add(custChildKey);
			}
			
			XPArrayList children = new XPArrayList();
			for ( int k = 0; k < childKeys.GetSize(); k++ ) 
			{
				XPArrayList cl = ((IHierarchicalDataObject)data).GetHierData((String)childKeys.GetElement(k));
				if ( cl != null ) 
					children.AddRange(cl);
			}
				
				if ( children != null || children.GetSize() != 0 ) 
				{
					buf.Append( ",\n"+GetPadding(depth+1) + "children: [ " );
					// generate javascript object for each child data
					for (int i = 0; i < children.GetSize(); i++ ) { 
						Object child = children.GetElement(i);
						if ( child instanceof IDataObject ) {
							// generate array for child data
							GenerateJSArray(buf, (IDataObject)child, depth+2, (i==0));
							// add comma after each child object
							if ( i < children.GetSize()-1 ) {
								buf.Append(",\n"); 
							}
						} else {
							Scope scope 	= GetTagAttributeAsScope(ATTRIB_SCOPE);
							String tagVarId = GetTagAttributeAsString(ATTRIB_DATA);
							log.Warn("Invalid child data in tag variable: "+tagVarId+" in scope: "+scope.toString()+". Type: "+child);
						}
					}
					buf.Append("]");
				}
			
			
		}
		
		// end js object for data object, add comment with index  
		buf.Append( " }/*end:"+curIndex+"*/");
	}
	
	protected String GetPadding(int depth)
	{
		String padd;
		switch(depth)
		{
			case 0: padd=""; break;
			case 1: padd="\t"; break;
			case 2: padd="\t\t"; break; 
			case 3: padd="\t\t\t"; break;
			case 4: padd="\t\t\t\t"; break;
			case 5: padd="\t\t\t\t\t"; break;
			case 6: padd="\t\t\t\t\t\t"; break;
			case 7: padd="\t\t\t\t\t\t\t"; break;
			case 8: padd="\t\t\t\t\t\t\t\t"; break;
			default: padd="\t\t\t\t\t\t\t\t\t\t"; break;
		}
		return padd;
	}
	
	/**
	 * Gets the list of properties to generate
	 * @return
	 */
	protected String[] GetProperties()
	{
		String propList = GetTagAttributeAsString(ATTRIB_PROPERTIES);
		
		XPStringTokenizer propsTok = new XPStringTokenizer(propList, ",");
		XPArrayList props = new XPArrayList();
		while( propsTok.HasMoreTokens() )
		{
			String curProp = propsTok.GetNextToken();
			props.Add(curProp);
		}
		String[] propArray = new String[props.GetSize()]; 
		for ( int i = 0; i < props.GetSize(); i++ ) {
			propArray[i] = (String)props.GetElement(i);
		}
		
		return propArray;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new JSArrayDataFormatterTag();
	}

}
