/*
 * Created on Feb 2, 2005
 */
package  com.plumtree.taglib.ptdata;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.taskapi.server.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of Subportal Mandatory Links Folder Name String data tag
 * 
 */
public class MandatoryLinksFolderNameDataTag extends ATag
{

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute KEY;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("mandatorylinknamedata",
			"Sets Subportal Mandatory Links Folder Name (Mandatory links are configured in Experience Definitions. " +
			"The folder name is the string that is displayed as the header for these links. For example as the title of a tab" +
			"that opens mandatory links in a dropdown menu) in specified Tag variable."
			);

		KEY = new RequiredTagAttribute("key",
			"The reference to the String data stored on the Tag PORTLET REQUEST Scope.");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IPTSession ptSession = TaskAPIUICommon.GetPTSession(TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()));
		
		String strFolderName = TaskAPIServerSubPortal.GetSubPortalMyMandatoryLinksFolderName(ptSession);
		
		if ( null == strFolderName )
		{
			strFolderName = "";
		}
		
		SetStateSharedVariable(GetTagAttributeAsString(KEY), strFolderName, Scope.PORTLET_REQUEST, false);
		
		return null;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new MandatoryLinksFolderNameDataTag();
	}
	
	/**
	 * 
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(com.plumtree.uiinfrastructure.constants.AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	
	}

}
