package com.plumtree.taglib.ptdata;

import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the ParentCommunity PTURL DO Data Tag
 * 
 */
public class ParentCommunityDataTag extends APTURLDODataTag
{

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_COMMUNITYID;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("parentcommunitydata",
			COMMON_PRETAGMETADATA_SINGLE_DESC +"with the link information for the Parent Community of a specified Community " +
					"(The Community above the specified Community in the Admin hierarchy)."+
			COMMON_TAGVAR_DESC+
			"Nothing is set in the tag variable if the specified Community does not have a parent Community or if the specified Community cannot be found. "+
			COMMON_COLLECTION_DESC+
			COMMON_PROPLIST_HEADER+
			COMMON_COMMS_DESC+
			COMMON_POSTTAGMETADATA_DESC+
			COMMON_CURRENTMARKER_DESC,
			EncodeForTagDoc(
				"<pt:ptdata.parentcommunitydata pt:id=\"parent\" pt:commid=\"500\" pt:noarray=\"true\"/><br/>"+
				"<pt:logic.value pt:value=\"parent.commid\"/>   // Community Id<br/>"+
				"<pt:logic.value pt:value=\"parent.commname\"/> // Community Name<br/>"+
				"<pt:logic.value pt:value=\"parent.url\"/> 	 // URL to Community home page<br/>"+
				""));

		ATTRIB_COMMUNITYID = new RequiredTagAttribute("commid",
			"The Object ID of the Community to retrieve the Parent Communities from.",	
			AttributeType.INT);
	}

	 TagDataSetterPTURLDOData m_URLSetter = new TagDataSetterPTURLDOData();
	
	public HTMLElement DisplayTag()
	{
		IEnvironment env = GetEnvironment();
	
		int nCommunityID = GetTagAttributeAsInt(ATTRIB_COMMUNITYID);
		
		IPTURL url = TaskAPIUICommunity.GetParentCommunityAsURL(TaskAPIUICommon.GetEnvTypeObject(env), nCommunityID);
		
		SetPTURLDataEntry(url);
		
		return null;
	}

	public ATag Create()
	{
		return new ParentCommunityDataTag();
	}

}
