/*
 * Created on Jan 20, 2005
 */
package  com.plumtree.taglib.ptdata;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the RelatedCommunities PTURL DO Data Tag
 * 
 */
public class RelatedCommunitiesDataTag extends APTURLDODataTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_COMMUNITYID;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("relatedcommunitiesdata",
			COMMON_PRETAGMETADATA_LIST_DESC +
			"with the link information for Related Communities (Communities in the same level of the Admin hierarchy) of the specified Community. "+
			COMMON_TAGVAR_DESC+
			"Nothing is set in the tag variable if the specified Community does not have related Communities or if the specified Community cannot be found. "+
			COMMON_COLLECTION_DESC+
			COMMON_PROPLIST_HEADER+
			COMMON_COMMS_DESC+
			COMMON_POSTTAGMETADATA_DESC+
			COMMON_CURRENTMARKER_DESC,
			EncodeForTagDoc(
				"<pt:ptdata.relatedcommunitiesdata pt:id=\"relcomms\" pt:commid=\"500\" /><br/>"+
				"<pt:logic.foreach pt:data=\"relcomms\" pt:var=\"curr\" /> //display values for each community page <br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commid\"/>   // Community Id<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.commname\"/> // Community Name<br/>"+
				"&nbsp; &nbsp; <pt:logic.value pt:value=\"$curr.url\"/> 	 // URL to the page<br/>"+
				"</pt:logic.foreach>"+
				""));

		ATTRIB_COMMUNITYID = new RequiredTagAttribute("commid",
			"The Object ID of the Community to retrieve Related Communities from.",	
			AttributeType.INT);
	}

	 TagDataSetterPTURLDOData m_URLSetter = new TagDataSetterPTURLDOData();
	 
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IEnvironment env = GetEnvironment();
	
		int nCommunityID = GetTagAttributeAsInt(ATTRIB_COMMUNITYID);
		
		XPArrayList urls = TaskAPIUICommunity.GetRelatedCommununitiesAsURLs(TaskAPIUICommon.GetEnvTypeObject(env), nCommunityID);
		
		SetPTURLDataCollection(urls);
		
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new RelatedCommunitiesDataTag();
	}
}
