/**
 * 
 */
package com.plumtree.taglib.ptdata.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.ptdata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.taskapi.test.portalui.mock.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tag for creating a data structure with Communities, Subcommunities and Community Pages
 * 
 * @author rozhang
 */
public class CommunityHierarchyDataTagTest extends TestCase
{
	static final String TAG_LIBNAME  	= PTDataTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     	= CommunityHierarchyDataTag.TAG.GetName();
	static final String TAG_ATTRIBID 	= CommunityHierarchyDataTag.ATTRIB_ID.GetName();
	static final String TAG_ATTRIBCOMMID= CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName();
	static final String TAG_ATTRIBCOMMDATAID= CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName();
	static final String TAG_ATTRIBINCPAGE= CommunityHierarchyDataTag.ATTRIB_INCLUDEPAGES.GetName();
	
	public MockEnvironment m_environment;
	protected int[] m_topCommIds;
	protected int[] m_subCommsIds1s;
	protected int[] m_subCommsIds2s;
	protected int[] m_subCommsIds3s;
	protected int[] m_subCommsIds4s;
	protected int[] m_subCommsIds5s;
	
	final int[] m_commPages = new int[] {10000, 20000, 30000};

	public void setUp()
	{

		m_environment = TagTestHelper.SetupTagTestEnvironment();
		
		TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new CommunityHierarchyDataTag());

	}
	
	/**
	 * Helper method to create unique page ids for each community. 
	 * Adds an array of generic page id and community id together to form a unique page id.
	 * This works as long as there is always a magnitude difference between page and community ids
	 * Ex. Community Ids in the thousands while page ids are in the ten thousands  
	 */
	public int[] getPageIds(int[] pageTemplateIds, int commId)
	{
		int pageIds[] = new int[pageTemplateIds.length];
		for (int i = 0; i < pageIds.length; i++ ) {
			pageIds[i] = pageTemplateIds[i] + commId;
		}
		return pageIds;
	}

	/**
	 * Setup community structure
	 * 
	 * @param commAPI
	 */
	public void setupCommunityStructure(MockTaskAPIUICommunityService commAPI) 
	{
		m_topCommIds = new int[] {1000, 2000, 3000, 4000, 5000};
		m_subCommsIds1s = new int[] {1100, 1200, 1300, 1400};
		m_subCommsIds2s = new int[] {2100, 2200, 2300, 2400};
		m_subCommsIds3s	= new int[] {3100, 3200, 3300, 3400};
		m_subCommsIds4s	= new int[] {4100, 4200, 4300, 4400};
		m_subCommsIds5s	= new int[] {};
		int[][] topSubCommIds = new int[][] { m_subCommsIds1s, m_subCommsIds2s, m_subCommsIds3s, m_subCommsIds4s, m_subCommsIds5s}; 
		
		int[] subCommsIds11	= new int[] {1110, 1120, 1130};
		int[] subCommsIds21	= new int[] {2110};
		int[] subCommsIds22	= new int[] {2210, 2120};
		int[] subCommsIds211= new int[] {2111, 2112};
		
		// dont want to create individual pages for each community
		// so create unique page ids by adding the page ids to the community ids
		// the pages ids are in the 10k and community ids are in the 1k so there should be no overlap
		  
		
		for  ( int i = 0; i < m_topCommIds.length; i++ ) {
			// add top level communities
			int[] subCommIds = topSubCommIds[i];
			commAPI.MockAddCommunity(m_topCommIds[i], "Test Community "+i, subCommIds, getPageIds(m_commPages, m_topCommIds[i])); 
			for ( int j = 0; j < subCommIds.length; j++) {
				// add 1st level sub communities
				commAPI.MockAddCommunity(subCommIds[j], "Test Community "+i+j, null, getPageIds(m_commPages, subCommIds[j])); 
			}
		}
		
		for  ( int i = 0; i < subCommsIds11.length; i++ ) {
			commAPI.MockAddCommunity(subCommsIds11[i], "Test Community 11"+i, null, null);
		}
		for  ( int i = 0; i < subCommsIds21.length; i++ ) {
			commAPI.MockAddCommunity(subCommsIds21[i], "Test Community 21"+i, null, null);
		}
		for  ( int i = 0; i < subCommsIds22.length; i++ ) {
			commAPI.MockAddCommunity(subCommsIds22[i], "Test Community 22"+i, null, null);
		}
		for  ( int i = 0; i < subCommsIds211.length; i++ ) {
			commAPI.MockAddCommunity(subCommsIds211[i], "Test Community 211"+i, null, null);
		}
		
		commAPI.MockAddSubCommunities(m_subCommsIds1s[0], subCommsIds11);
		commAPI.MockAddSubCommunities(m_subCommsIds2s[0], subCommsIds21);
		commAPI.MockAddSubCommunities(m_subCommsIds2s[1], subCommsIds22);
		commAPI.MockAddSubCommunities(subCommsIds21[0], subCommsIds211);
	}
	
	/**
	 * Tests the tag with various ways to pass in comunity ids and verify that the data structure
	 * matches the community structure 
	 */
	public void testTag()
	{
		MockTaskAPIUICommunityService commAPI = new MockTaskAPIUICommunityService();
		TaskAPIUICommunityService.SetMockInstanceForDebug(commAPI);
		
		setupCommunityStructure(commAPI);
		
		/** TEST 1: Single comm id value **/
		String dataVarId = "testdata";
		int currCommId = m_topCommIds[4];
		
		String[] argNames = new String[] {TAG_ATTRIBID, TAG_ATTRIBCOMMID};
		String[] argValues = new String[] {dataVarId, currCommId+""};
		TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, argNames, argValues, m_environment);
		
		assertTrue("Data tag returned the following error HTML:\n "+result.GetDisplayString(),TagTestHelper.VerifyNoTagContent(result));

		// verify data
   		XPArrayList commUrls = (XPArrayList)tagState.GetTagPortletRequestVar(dataVarId);
   		XPHashtable testCommStructure = BuildCommStructureMap(commUrls);
   		int testResult = commAPI.VerifySubCommunityStructure(currCommId, 3, testCommStructure);
   		assertTrue("Hierarchichal Community data tag failed with single comm id value of: "+testResult, testResult == 0 );
		
   		
   		/** TEST 2: Comm ids list value **/
		int[] currCommIds = m_topCommIds;
		String idsArgValue = "";
		for ( int i = 0; i < currCommIds.length; i++ ) {
			idsArgValue += (i==0?"":",") + currCommIds[i];
		}
		
		argNames = new String[] {TAG_ATTRIBID, TAG_ATTRIBCOMMID};
		argValues = new String[] {dataVarId, idsArgValue};
		
		tagState = TagTestHelper.GetMockTagStateInstance();
		result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, argNames, argValues, m_environment);
		
		assertTrue("Data tag returned the following error HTML:\n "+result.GetDisplayString(), result==null||"".equals(result.GetDisplayString()));

		// verify data
   		commUrls = (XPArrayList)tagState.GetTagPortletRequestVar(dataVarId);
   		testCommStructure = BuildCommStructureMap(commUrls);
   		for ( int i = 0; i < currCommIds.length; i++ ) {
   			testResult = commAPI.VerifySubCommunityStructure(currCommIds[i], 3, testCommStructure);
   			assertTrue("Hierarchichal Community data tag failed with single comm id value of: "+testResult, testResult == 0 );
   		}
   		
   		
   		/** TEST 3: Comm id from tag var **/
		currCommId = m_topCommIds[0];
		String commIdTagVar = "commId";
		String commId = currCommId+"";
		argNames = new String[] {TAG_ATTRIBID, TAG_ATTRIBCOMMDATAID};
		argValues = new String[] {dataVarId, commIdTagVar};
		
		tagState = TagTestHelper.GetMockTagStateInstance();
		tagState.SetTagPortletRequestVar(null, commIdTagVar, commId );
		result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, argNames, argValues, m_environment);
		
		assertTrue("Data tag returned the following error HTML:\n "+result.GetDisplayString(), result==null||"".equals(result.GetDisplayString()));

		// verify data
   		commUrls = (XPArrayList)tagState.GetTagPortletRequestVar(dataVarId);
   		testCommStructure = BuildCommStructureMap(commUrls);
   		testResult = commAPI.VerifySubCommunityStructure(currCommId, 3, testCommStructure);
   		assertTrue("Hierarchichal Community data tag failed with single comm id value of: "+testResult, testResult == 0 );
   		
   		/** TEST 3: Comm id from tag var **/
		commIdTagVar = "commIdList";
		XPArrayList tagVarValue = new XPArrayList();
		for ( int i = 0; i < m_topCommIds.length; i++ ) { tagVarValue.Add(m_topCommIds[i]); } 
		
		argNames = new String[] {TAG_ATTRIBID, TAG_ATTRIBCOMMDATAID};
		argValues = new String[] {dataVarId, commIdTagVar};
		
		tagState = TagTestHelper.GetMockTagStateInstance();
		tagState.SetTagPortletRequestVar(null, commIdTagVar, tagVarValue );
		result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, argNames, argValues, m_environment);
		
		assertTrue("Data tag returned the following error HTML:\n "+result.GetDisplayString(), result==null||"".equals(result.GetDisplayString()));

		// verify data
   		commUrls = (XPArrayList)tagState.GetTagPortletRequestVar(dataVarId);
   		testCommStructure = BuildCommStructureMap(commUrls);
   		for ( int i = 0; i < currCommIds.length; i++ ) {
   			testResult = commAPI.VerifySubCommunityStructure(currCommIds[i], 3, testCommStructure);
   			assertTrue("Hierarchichal Community data tag failed with single comm id value of: "+testResult, testResult == 0 );
   		}
	}
	
	/**
	 * Tests that community pages exists in the data 
	 * Tests pages in top community and subcommunities (but not nested subcommunities)
	 */
	public void testCommPages()
	{
		MockTaskAPIUICommunityService commAPI = new MockTaskAPIUICommunityService();
		TaskAPIUICommunityService.SetMockInstanceForDebug(commAPI);
		
		setupCommunityStructure(commAPI);
		
		String dataVarId = "testdata";
		int currCommId = m_topCommIds[0]; 
		
		XPHashtable args = new XPHashtable();
		args.PutElement(TAG_ATTRIBID, dataVarId);
		args.PutElement(TAG_ATTRIBCOMMID, currCommId+"");
		args.PutElement(TAG_ATTRIBINCPAGE, "true");
		TagStateTestHelper tagState = TagTestHelper.GetMockTagStateInstance();
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, args, m_environment);
		assertTrue("Data tag returned the following error HTML:\n "+result.GetDisplayString(),TagTestHelper.VerifyNoTagContent(result));
		
		Object tagVarData = tagState.GetTagPortletRequestVar(dataVarId);
		assertNotNull("No tag variable with Community data found!", tagVarData);
		XPArrayList commData = (XPArrayList)tagVarData;
		
		IHierarchicalDataObject comm = (IHierarchicalDataObject)commData.GetElement(0); // we specified a single community id so there should be only one
		// each community is created with 3 pages, verify they are in there
		verifyCommunityPages(comm); // verify top level community
		XPArrayList subComms = (XPArrayList)comm.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
		
		for ( int i = 0; i < subComms.GetSize(); i++ ) { // check pages in every subcommunity
			IHierarchicalDataObject subcomm = (IHierarchicalDataObject)subComms.GetElement(i);
			verifyCommunityPages(subcomm); // verify
		}
	}

	/**
	 * @param comm
	 * @param pages
	 */
	protected void verifyCommunityPages(IHierarchicalDataObject comm)
	{
		XPArrayList pages = comm.GetHierData(CommunityHierarchyDataTag.HIERDATA_PAGESKEY); // get pages
		String commId = (String)comm.GetData(CommonOpenerFriendlyURL.KEY_FRIENDLYURL_OBJECTID);
		int[] pageIds = getPageIds(m_commPages, XPConvert.ToInteger(commId));
		
		// compare the ids with expected ids
		for ( int pageindex = 0; pageindex < pages.GetSize(); pageindex++ ) {
			int currpageid = XPConvert.ToInteger( pages.GetElement(pageindex) );
			assertEquals("Community Page in Community with id: "+commId+" do not match expected value!", currpageid, pageIds[pageindex]);
		}
	}
	
	
	/**
	 * Tests error handling with invalid attribute values
	 */
	public void testCommIdAttributesErrorCases()
	{
		// CASE 1: Both comm id types are specified
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(), CommunityHierarchyDataTag.TAG.GetName());
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testdata");
   		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName(), "200");
   		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(), "commidtagvar");
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		Assert.assertTrue("No error message generated when passing values in both community id value and reference attributes!", result != null);
   		String output = result.GetDisplayString();
   		Assert.assertTrue("Expected error message when passing values in both community id value and reference attributes not found!", 
   				XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_BOTHCOMMIDTYPES) > 0 && 
   				XPStringUtility.IndexOf(output, "XPIllegalArgumentException") > 0);
   		
   		// CASE 2: No comm id specified
   		helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(), CommunityHierarchyDataTag.TAG.GetName());
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testdata");
   		
   		objArrMarkup = helper.ToArrayEntireFragment();
   		result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		Assert.assertTrue("No error message generated when not specifying any community ids!", result != null);
   		output = result.GetDisplayString();
   		Assert.assertTrue("Expected error message when not specifying any community ids!", 
   				XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_NOCOMMIDS) > 0 && 
   				XPStringUtility.IndexOf(output, "XPIllegalArgumentException") > 0);
   		
   		// CASE 3: Invalid single comm id value
   		helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(), CommunityHierarchyDataTag.TAG.GetName());
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testdata");
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName(), "aa");
   		
   		objArrMarkup = helper.ToArrayEntireFragment();
   		result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		Assert.assertTrue("No error message generated specifying invalid community id value!", result != null);
   		output = result.GetDisplayString();
   		Assert.assertTrue("Expected error message when specifying invalid community id value!", 
   				XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_NONNUMERICCOMMID) > 0 && 
   				XPStringUtility.IndexOf(output, "XPIllegalArgumentException") > 0);
   		
   		// CASE 4: Invalid comm id in list
   		helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(), CommunityHierarchyDataTag.TAG.GetName());
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testdata");
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYID.GetName(), "300, 302, 403, aaa");
   		
   		objArrMarkup = helper.ToArrayEntireFragment();
   		result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		Assert.assertTrue("No error message generated specifying invalid community id value in a list!", result != null);
   		output = result.GetDisplayString();
   		Assert.assertTrue("Expected error message when specifying invalid community id value in a list!", 
   				XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDCOMMID_INLIST) > 0 && 
   				XPStringUtility.IndexOf(output, "XPIllegalArgumentException") > 0);
   		
   		/** TAG VAR TESTING **/
   		String tagVarName = "mocktagvar";
   		Object tagVarSingleValue = null;
   		XPArrayList tagVarListValue = null;
   		SharedStateVariable tagVar = null;
   		
   		// CASE 5: Invalid tag variable type
   		helper = new XMLFragmentTestHelper(PTDataTagLibraryData.LIBRARY.GetName(), CommunityHierarchyDataTag.TAG.GetName());
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testVar");
		helper.AddPTAttribute(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(), tagVarName);
		
		tagVarSingleValue = new XPHashtable();
		TagState.TEST_PORTLET_REQUEST_DATA = new XPHashtable();
		TagState.TEST_PORTLET_REQUEST_DATA.PutElement("ptdata." + tagVarName, tagVarSingleValue);	
   		
   		objArrMarkup = helper.ToArrayEntireFragment();
   		result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		Assert.assertTrue("No error message generated specifying invalid community id value in a list!", result != null);
   		output = result.GetDisplayString();
   		Assert.assertTrue("Expected error message when specifying invalid community id value in a list!", 
   				XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDTAGVARTYPE) > 0 && 
   				XPStringUtility.IndexOf(output, "XPIllegalArgumentException") > 0);
   		
   		// CASE 6: Invalid single comm id in tag variable
   		
   		tagVarSingleValue = "aaaa"; // invalid community id value
   		
   		TagStateTestHelper state = TagTestHelper.GetMockTagStateInstance();
   		state.SetTagPortletRequestVar("", tagVarName, tagVarSingleValue);
   		
   		XPHashtable args = new XPHashtable();
   		args.PutElement(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testVar");
   		args.PutElement(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(), tagVarName);
		result = TagTestHelper.RunSingleTag(PTDataTagLibraryData.LIBRARY.GetName(), CommunityHierarchyDataTag.TAG.GetName(), args, m_environment);
   		
   		Assert.assertTrue("No error message generated specifying invalid community id value in tag variable!", !TagTestHelper.VerifyNoTagContent(result));
   		output = result.GetDisplayString();
   		Assert.assertTrue("Expected error message when specifying invalid community id value in tag variable!", 
   				XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDTAGVAR_COMMID ) > 0 && 
   				XPStringUtility.IndexOf(output, "XPIllegalArgumentException") > 0);
   		
   		// CASE 7: Invalid comm id in tag variable list
   		// tag variable list
		tagVarListValue = new XPArrayList();
		tagVarListValue.Add("200");
		tagVarListValue.Add("300");
		tagVarListValue.Add("bbbb");
		tagVarListValue.Add("400");
		state = TagTestHelper.GetMockTagStateInstance();
   		state.SetTagPortletRequestVar("", tagVarName, tagVarListValue);
   		// setup and run tag
		args = new XPHashtable();
   		args.PutElement(CommunityHierarchyDataTag.ATTRIB_ID.GetName(), "testVar");
   		args.PutElement(CommunityHierarchyDataTag.ATTRIB_COMMUNITYDATAID.GetName(), tagVarName);
   		result = TagTestHelper.RunSingleTag(PTDataTagLibraryData.LIBRARY.GetName(), CommunityHierarchyDataTag.TAG.GetName(), args, m_environment);
   		// verify results
   		Assert.assertTrue("No error message generated specifying invalid community id in tag variable list!", result != null);
   		output = result.GetDisplayString();
   		Assert.assertTrue("Expected error message when specifying invalid community id value in tag variable list!", 
   				XPStringUtility.IndexOf(output, CommunityHierarchyDataTag.ERRORMSG_INVALIDTAGVARLISTENTRYTYPE) > 0 && 
   				XPStringUtility.IndexOf(output, "XPIllegalArgumentException") > 0);
   		
	}
	
	/**
	 * 
	 * @param commList
	 * @return
	 */
	public XPHashtable BuildCommStructureMap(IXPList hierCommDataList)
	{
		XPHashtable retMap = new XPHashtable();
		
		for ( int i = 0; i < hierCommDataList.GetSize(); i++) 
		{
			// for each community in the list: 
			// - add comm id to map as key and a list of subcomm ids as value
			// - find sub comms for the sub comm by calling this function recursively
			IPTURL curr = (IPTURL)hierCommDataList.GetElement(i);
			int commId = XPConvert.ToInteger( curr.GetData(ACommonOpenerURL.KEY_OBJECTID) ); // get the id
			IXPList subComms = curr.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
			IXPList subCommIds = new XPArrayList();
			if ( subComms != null && !subComms.IsEmpty()) {
				subCommIds = RecursiveBuildCommStructureMap(subComms, retMap); // get subcomm ids and populate map with subcomms in the subcomm
			}
			retMap.PutElement(commId, subCommIds);
		}
		return retMap;
	}
	
	/**
	 * Helper 
	 * @param hierCommDataList
	 * @param returnMap
	 * @return
	 */
	private IXPList RecursiveBuildCommStructureMap(IXPList hierCommDataList, XPHashtable returnMap)
	{
		XPArrayList subCommIds = new XPArrayList();
		// for each community
		// - convert ipturl to id and add ot subcommid list that we return
		// - find all sub communities of the community
		for ( int i = 0; i < hierCommDataList.GetSize(); i++) {
			IPTURL curr = (IPTURL)hierCommDataList.GetElement(i);
			int commId = XPConvert.ToInteger( curr.GetData(ACommonOpenerURL.KEY_OBJECTID) ); // get the id
			
			subCommIds.Add( XPConvert.ToInteger( curr.GetData(ACommonOpenerURL.KEY_OBJECTID)) ); // add comm id to list that we return

			IXPList subComms = curr.GetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY);
			IXPList subsubCommIds = new XPArrayList();
			if ( subComms != null && !subComms.IsEmpty()) {
				subsubCommIds = RecursiveBuildCommStructureMap(subComms, returnMap); // get subsubcomm ids and populate map with depper subcomms
			}
			returnMap.PutElement(commId, subsubCommIds);
		}
		return subCommIds;
		//out.PutElement(commId, subCommIds);
	}
	
	
	
}
