/**
 * 
 */
package com.plumtree.taglib.ptdata.test;

import junit.framework.*;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.utils.*;
import com.plumtree.taglib.ptdata.*;
import com.plumtree.uiinfrastructure.utils.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tests the JSArrayDataFormatterTag by validating its output from constructed
 * data structures
 */
public class JSArrayDataFormatterTagTest extends TestCase
{
	static final String TAG_LIBNAME  	= PTDataTagLibraryData.LIBRARY.GetName();
	static final String TAG_NAME     	= JSArrayDataFormatterTag.TAG.GetName();
	static final String ATTR_DATA 		= JSArrayDataFormatterTag.ATTRIB_DATA.GetName();
	static final String ATTR_PROP	 	= JSArrayDataFormatterTag.ATTRIB_PROPERTIES.GetName();
	static final String ATTR_CHILDKEY	= JSArrayDataFormatterTag.ATTRIB_CHILDKEY.GetName();
	
	MockEnvironment m_env;
	
	public void setUp()
	{
		m_env = TagTestHelper.SetupTagTestEnvironment();
		TagTestHelper.CreateTestTag(TAG_LIBNAME, TAG_NAME, new JSArrayDataFormatterTag());
	}
	
	/**
	 * Tests generated javascript array from a list of 3 tag data entries
	 */
	public void testFlatData()
	{
		String dataTagVarName = "testtagvar";  
		int entries = 3;
		
		TagStateTestHelper scope = TagTestHelper.GetMockTagStateInstance();
		// create data with 3 entries
		scope.SetTagPortletRequestVar("", dataTagVarName, CreateTestFlatDataStructure(entries));
		
		XPHashtable args = new XPHashtable();
		// pass in the name to the tag variable with the data
		args.PutElement(ATTR_DATA, dataTagVarName);
		// This tag arg specifies which properties to use, the test data is created with 5 properties. We just get 3 of them
		args.PutElement(ATTR_PROP, TESTDATA_NAMEPREFIX+"1,"+TESTDATA_NAMEPREFIX+"2,"+TESTDATA_NAMEPREFIX+"4");
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, args, m_env);
		assertTrue("Tag did not display HTML!", !TagTestHelper.VerifyNoTagContent(result) );

		//XPSystem.Out.Write(result.GetDisplayString());

		// get the result and parse it
		String js = result.GetDisplayString();
		JavascriptParser parser = new JavascriptParser();
		parser.ParseJSString(js);
		
		XPArrayList jsArray = parser.GetRootArray();
		assertNotNull("Parsing of generated Javascript array failed.", jsArray);
		
		assertEquals("Generated Javascript array did not contain number of expected entries.", entries, jsArray.GetSize());
		XPHashtable data1 = (XPHashtable)jsArray.GetElement(0);
		XPHashtable data2 = (XPHashtable)jsArray.GetElement(1);
		XPHashtable data3 = (XPHashtable)jsArray.GetElement(2);
		
		assertNotNull("No data entry was generated!", data1);
		assertNotNull("No data entry was generated!", data2);
		assertNotNull("No data entry was generated!", data3);
		
		XPHashtable[] dataArr = new XPHashtable[] {data1, data2, data3};
		for ( int i = 0; i < entries; i++ ) 
		{
			assertEquals("Generated JS did not contain expected value!", GetTestDataValue(1), dataArr[i].GetElement(TESTDATA_NAMEPREFIX+"1"));
			assertEquals("Generated JS did not contain expected value!", GetTestDataValue(2), dataArr[i].GetElement(TESTDATA_NAMEPREFIX+"2"));
			assertEquals("Generated JS did not contain expected value!", GetTestDataValue(4), dataArr[i].GetElement(TESTDATA_NAMEPREFIX+"4"));
			// this should be null since this property name was not passed into the tag 
			assertNull("Unexpected property was included in generated Javascript", dataArr[i].GetElement(TESTDATA_NAMEPREFIX+"3"));
		}
	}
	
	/*
	 * Should get just empty array [] with empty list
	 */
	public void testEmptyList()
	{
		String dataTagVarName = "testtagvar";  
		
		TagStateTestHelper scope = TagTestHelper.GetMockTagStateInstance();
		// create data with 3 entries
		XPArrayList testList = new XPArrayList();
		
		scope.SetTagPortletRequestVar("", dataTagVarName, testList);
		
		XPHashtable args = new XPHashtable();
		// pass in the name to the tag variable with the data
		args.PutElement(ATTR_DATA, dataTagVarName);
		// This tag arg specifies which properties to use, the test data is created with 5 properties. We just get 3 of them
		args.PutElement(ATTR_PROP, TESTDATA_NAMEPREFIX+"1,"+TESTDATA_NAMEPREFIX+"2,"+TESTDATA_NAMEPREFIX+"4");
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, args, m_env);
		assertTrue("Tag did not display HTML!", !TagTestHelper.VerifyNoTagContent(result) );

		XPSystem.Out.Write(result.GetDisplayString());

		assertEquals("Expected empty array.", "[]", result.GetDisplayString());
	}
	
	/*
	 * Should get just empty array [] with empty list
	 */
	public void testInvalidDataList()
	{
		String dataTagVarName = "testtagvar";  
		
		TagStateTestHelper scope = TagTestHelper.GetMockTagStateInstance();
		// create data with 3 entries
		
		scope.SetTagPortletRequestVar("", dataTagVarName, new XPHashtable());
		
		XPHashtable args = new XPHashtable();
		// pass in the name to the tag variable with the data
		args.PutElement(ATTR_DATA, dataTagVarName);
		// This tag arg specifies which properties to use, the test data is created with 5 properties. We just get 3 of them
		args.PutElement(ATTR_PROP, TESTDATA_NAMEPREFIX+"1,"+TESTDATA_NAMEPREFIX+"2,"+TESTDATA_NAMEPREFIX+"4");
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, args, m_env);
		assertTrue("Tag did not display HTML!", !TagTestHelper.VerifyNoTagContent(result) );

		XPSystem.Out.Write(result.GetDisplayString());

		assertEquals("Expected empty array.", "[]", result.GetDisplayString().substring(0, 2));
	}
	
	
	/**
	 * Test generated javascript array with nested data
	 */
	public void testNestedData()
	{
		String dataTagVarName = "testtagvar";  
		
		TagStateTestHelper scope = TagTestHelper.GetMockTagStateInstance();
		// setup data structure with 3 top level data, each data entries with 2 child data, and each child data have another 2 child data
		scope.SetTagPortletRequestVar("", dataTagVarName, CreateTestNestedDataStructure(3, 3, 3));
		
		XPHashtable args = new XPHashtable();
		args.PutElement(ATTR_DATA, dataTagVarName);
		// the test data is created with 5 of these properties. We just use 2
		args.PutElement(ATTR_PROP, TESTDATA_NAMEPREFIX+"2,"+TESTDATA_NAMEPREFIX+"3");
		HTMLElement result = TagTestHelper.RunSingleTag(TAG_LIBNAME, TAG_NAME, args, m_env);
		assertTrue("Tag did not display HTML!", !TagTestHelper.VerifyNoTagContent(result) );
		
		//XPSystem.Out.Write(result.GetDisplayString());
		// get the result and parse it
		String js = result.GetDisplayString();
		JavascriptParser parser = new JavascriptParser();
		parser.ParseJSString(js);
		
		XPArrayList jsArray = parser.GetRootArray();
		
		assertEquals("Generated Javascript array did not contain number of expected entries.", 3, jsArray.GetSize());
		XPHashtable data1 = (XPHashtable)jsArray.GetElement(0);
		XPHashtable data2 = (XPHashtable)jsArray.GetElement(1);
		
		XPHashtable data3 = (XPHashtable)jsArray.GetElement(2);
		
		assertNotNull("No data entry was generated!", data1);
		assertNotNull("No data entry was generated!", data2);
		assertNotNull("No data entry was generated!", data3);
		
		// just test one child from each parent
		XPArrayList childdata1 = (XPArrayList)data1.GetElement("children");
		XPArrayList childdata2 = (XPArrayList)data1.GetElement("children");
		XPArrayList childdata3 = (XPArrayList)data1.GetElement("children");
		
		assertNotNull("Unable to find child data list in generated Javascript array!", childdata1);
		assertNotNull("Unable to find child data list in generated Javascript array!", childdata2);
		assertNotNull("Unable to find child data list in generated Javascript array!", childdata3);
		
		XPHashtable childentry1 = (XPHashtable)childdata1.GetElement(0);
		assertNotNull("Unable to find child data entry in generated Javascript array!", childentry1);
		
		XPHashtable childentry2 = (XPHashtable)childdata2.GetElement(1);
		assertNotNull("Unable to find child data entry in generated Javascript array!", childentry2);
		
		XPHashtable childentry3 = (XPHashtable)childdata3.GetElement(2);
		assertNotNull("Unable to find child data entry in generated Javascript array!", childentry3);
		
		// check data property on child, just check that the value exists
		assertNotNull("Property value in child data not found in generated Javascript array", childentry1.GetElement(TESTDATA_NAMEPREFIX+"2"));
		assertNotNull("Property value in child data not found in generated Javascript array", childentry2.GetElement(TESTDATA_NAMEPREFIX+"3"));
		assertNotNull("Property value in child data not found in generated Javascript array", childentry3.GetElement(TESTDATA_NAMEPREFIX+"3"));
		
		// get the grand child data (one in each child
		XPArrayList grandchilddata1 = (XPArrayList)childentry1.GetElement("children");
		XPArrayList grandchilddata2 = (XPArrayList)childentry2.GetElement("children");
		XPArrayList grandchilddata3 = (XPArrayList)childentry3.GetElement("children");
		
		assertNotNull("Unable to find child data list in generated Javascript array!", grandchilddata1);
		assertNotNull("Unable to find child data list in generated Javascript array!", grandchilddata2);
		assertNotNull("Unable to find child data list in generated Javascript array!", grandchilddata3);
		
		XPHashtable grandchildentry1 = (XPHashtable)grandchilddata1.GetElement(0);
		assertNotNull("Unable to find grand child data entry in generated Javascript array!", grandchildentry1);
		
		XPHashtable grandchildentry2 = (XPHashtable)grandchilddata1.GetElement(1);
		assertNotNull("Unable to find grand child data entry in generated Javascript array!", grandchildentry2);
		
		XPHashtable grandchildentry3 = (XPHashtable)grandchilddata1.GetElement(2);
		assertNotNull("Unable to find grand child data entry in generated Javascript array!", grandchildentry3);
		
		// check the property value in grand child data
		assertNotNull("Property value of grand child data not found in generated Javascript array", grandchildentry1.GetElement(TESTDATA_NAMEPREFIX+"2"));
		assertNotNull("Property value of grand child data not found in generated Javascript array", grandchildentry2.GetElement(TESTDATA_NAMEPREFIX+"3"));
		assertNotNull("Property value of grand child data not found in generated Javascript array", grandchildentry3.GetElement(TESTDATA_NAMEPREFIX+"3"));
		
	}
	
	protected final static String TESTDATA_NAMEPREFIX  = "TestName";
	protected final static String TESTDATA_VALUEPREFIX = "TestValue";
	
	/**
	 * TEST HELPER
	 * Returns a list of tag Data Entries. 
	 * Data entries contain 5 properties name/values using the provided prefix.
	 * Name and values are in the following format:
	 * TestName<x> = TestValue-<x> where <x> is the nth property
	 * 
	 * @param entries Number of data entries in the array
	 * @param preFix String prefixed to data property name and values
	 * @return
	 */
	protected XPArrayList CreateTestFlatDataStructure(int entries)
	{
		XPArrayList list = new XPArrayList(entries);
		for ( int i = 0; i < entries; i++ ) {
			HashtableDataObject entry = new HashtableDataObject();
			
			// create five values in the data
			for ( int j = 0; j < 5; j++ ) {
				entry.SetData(TESTDATA_NAMEPREFIX+j, GetTestDataValue(j));
			}
			list.Add(entry);
		}
		return list;
	}
	
	protected String GetTestDataValue(int index)
	{
		return TESTDATA_VALUEPREFIX+index;
	}
	
	/**
	 * Test helper to create a structure for data entries.
	 * Creates a list of data entries and child data in each top level data entry.
	 * Levels of child data and number of child data objects is specified by the depth and numChildren arguments.
	 * Each level of data entries is created with CreateTestFlatDataStructure  
	 * 
	 * @param parentEntries
	 * @param depth
	 * @param numChildren
	 * @return
	 */
	protected XPArrayList CreateTestNestedDataStructure(int parentEntries, int depth, int numChildren)
	{
		XPArrayList nextParent = new XPArrayList();
		XPArrayList retList = CreateTestFlatDataStructure(parentEntries);
		XPArrayList parents = retList;
		
		for ( int d = 1; d < depth; d++ )
		{
			// create child data for all the parent entries
			for (int i = 0; i < parents.GetSize(); i++ ) {
				// identical child data instance for each parent entry
				XPArrayList children = CreateTestFlatDataStructure(numChildren);
				// attach the child node
				IHierarchicalDataObject parent = (IHierarchicalDataObject)parents.GetElement(i);
				parent.SetHierData(HashtableDataObject.HIERDATA_DEFAULTKEY, children);
				
				// now we want to add all the current child data as parent data for next depth level 
				nextParent.AddRange(children);
			}
			parents = nextParent;
			nextParent = new XPArrayList();
		}	
		return retList;
	}
	
}
