using System;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag provides common behavior for all Plumtree UI links.
  /// </summary>
  public abstract class APTLinkTag : APTUITag
  {
    private const String LINK_BEHAVIOR_DESCRIPTION_START = "If this tag is used as a singleton tag (I.E. <![CDATA[&lt;pt:";
    private const String LINK_BEHAVIOR_DESCRIPTION_END = "/&gt;]]>), rather than as a tag requiring both opening and closing tags, " + "then the link string text will be placed within the generated " + "Anchor tag, otherwise the HTML inside the tag will be used.";
    
    /// <summary>
    /// This method returns the link behavior description string with
    /// the proper tag name inserted.
    /// </summary>
    /// <param name="_strName">The name of the tag.</param>
    /// <returns>The link behavior description string.</returns>
    protected static String GetLinkBehaviorDescription(String _strName)
    {
      // Note that we cannot use the metadata GetName() method
      // yet because we are in the process of defining the metadata
      // when this method is called.
      return LINK_BEHAVIOR_DESCRIPTION_START + PTUITagLibraryData.LIBRARY.GetName() + "." + _strName + LINK_BEHAVIOR_DESCRIPTION_END;
      }
    
    /// <summary>
    /// This method adds either the inner HTML, or the default text to the
    /// anchor.  It also sets the title on the anchor.
    /// This should be called before AddSpanToFinalOutput().
    /// Note: This calls ProcessTagBody.
    /// </summary>
    /// <param name="_anchor"></param>
    /// <param name="_strDefaultText"></param>
    protected virtual void AddContentToLink(HTMLElement _anchor, String _strDefaultText)
    {
      AddContentToLink(_anchor, _strDefaultText, _strDefaultText);
    }
    
    /// <summary>
    /// This method adds either the inner HTML, or the default text to the
    /// anchor.  It also sets the title on the anchor.
    /// This should be called before AddSpanToFinalOutput().
    /// Note: This calls ProcessTagBody.
    /// </summary>
    /// <param name="_anchor"></param>
    /// <param name="_strDefaultText"></param>
    /// <param name="_strLinkTitle"></param>
    protected virtual void AddContentToLink(HTMLElement _anchor, String _strDefaultText,
     String _strLinkTitle)
    {
      // TODO: this should also have a way to add xml attributes to the anchor tag.
      _anchor.SetTitle(_strLinkTitle);
      HTMLElement body = ProcessTagBody();
      if (null == body)
      {
        if (null != _strDefaultText)
        {
          // If there is nothing inside the anchor, add the default string.
          _anchor.AddInnerHTMLString(_strDefaultText);
        }
      } else
      {
        _anchor.AddInnerHTMLElement(body);
      }
    }
  }
}