using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This base class provides common functionality for all
  /// Plumtree UI tags.  Tags that extend this class must
  /// add the USE_SPAN attribute as follows:
  /// public static final OptionalTagAttribute USE_SPAN = new OptionalTagAttribute(
  /// USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of myStyleID " +
  /// COMMON_POST_USE_SPAN_DESC, USE_SPAN_TYPE, USE_SPAN_DEFAULT);
  /// </summary>
  public abstract class APTUITag : ATag
  {
    public const String USE_SPAN_NAME = "usespan";
    public const String COMMON_PRE_USE_SPAN_DESC = "This attribute controls whether or not this tag wraps " + "the output in a span with an ID ";
    public const String COMMON_POST_USE_SPAN_DESC = "for use in DHTML manipulation, or just displays the text.";
    public static readonly AttributeType USE_SPAN_TYPE = AttributeType.BOOLEAN;
    public const String USE_SPAN_DEFAULT = "true";
    
    /// <summary>
    /// This method is used to access the USE_SPAN attribute in
    /// the base APTUITag class.
    /// </summary>
    /// <returns>OptionalTagAttribute The USE_SPAN attribute.</returns>
    public abstract OptionalTagAttribute GetUseSpanAttribute();
    
    /// <summary>
    /// This helper method checks to see if the tag output needs to be wrapped
    /// in a Span and returns the final output.
    /// </summary>
    /// <param name="_tagOutput">The preliminary output from the tag.</param>
    /// <param name="_strStyleID">The style ID to use in the Span, if necessary.  This may be null.</param>
    /// <returns>HTMLElement The final output of the tag (possibly wrapped in a Span).</returns>
    protected virtual HTMLElement AddSpanToFinalOutput(HTMLElement _tagOutput,
     String _strStyleID)
    {
      return AddSpanToFinalOutput(_tagOutput, _strStyleID, null);
    }
    
    /// <summary>
    /// This helper method checks to see if the tag output needs to be wrapped
    /// in a Span and returns the final output.
    /// </summary>
    /// <param name="_tagOutput">The preliminary output from the tag.</param>
    /// <param name="_strStyleID">The style ID to use in the Span, if necessary.  This may be null.</param>
    /// <param name="_styleClass">The style class to use in the Span, if necessary.  This may be null.</param>
    /// <returns>HTMLElement The final output of the tag (possibly wrapped in a Span).</returns>
    protected virtual HTMLElement AddSpanToFinalOutput(HTMLElement _tagOutput,
     String _strStyleID, StyleClass _styleClass)
    {
      HTMLElement result;
      if (GetTagAttributeAsBoolean(GetUseSpanAttribute()))
      {
        result = new HTMLSpan();
        if (null != _strStyleID)
        {
          result.SetID(_strStyleID);
        }
        if (null != _styleClass)
        {
          result.SetStyleClass(_styleClass);
        }
        result.AddInnerHTMLElement(_tagOutput);
      } else
      {
        result = _tagOutput;
      }
      return result;
    }
  }
}