using System;
using com.plumtree.portalpages.browsing.login.createaccount;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using PTLoginHelper=com.plumtree.portaluiinfrastructure.login.PTLoginHelper;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays a create account link.
  /// </summary>
  public class CreateAccountTag : APTLinkTag
  {
    private const String TAG_NAME = "createaccount";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute USE_SPAN;
    private AActivitySpace asOwner;
    static CreateAccountTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays a Create Account link. " + APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));
      USE_SPAN = new OptionalTagAttribute(USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " + PTStyleID.PT_LOGIN_CREATE_ACCOUNT + " " + COMMON_POST_USE_SPAN_DESC,
       USE_SPAN_TYPE, USE_SPAN_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      asOwner = (AActivitySpace) GetEnvironment();
      HTMLElement myCreateLink = null;
      // Verifying Account Creation is allowed, We show link only if it is allowed.
      if (PTLoginHelper.GetAllowUserCreation(asOwner, asOwner.GetApplication()))
      {
        ASURL myHRef = new ASURL(TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()));
        myHRef.SetLinkGetSpaceIfCached(CreateAccountAS.STR_MVC_CLASS_NAME,
         TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()));
        myHRef.SetControl(CreateAccountControl.STR_MVC_CLASS_NAME);
        // Create an account
        myHRef.AddInnerHTMLString(GetEnvironment().GetString(637, "ptmsgs_portalbrowsingmsgs"));
        // Create an account
        ((HTMLAnchor) myHRef.GetURLAsHTMLElement()).SetTitle(GetEnvironment().GetString(1459,
         "ptmsgs_portalbrowsingmsgs"));
        myCreateLink = myHRef.GetURLAsHTMLElement();
      }
      return AddSpanToFinalOutput(myCreateLink, PTStyleID.PT_LOGIN_CREATE_ACCOUNT);
      }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()"></seealso>
    public override OptionalTagAttribute GetUseSpanAttribute()
    {
      return USE_SPAN;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new CreateAccountTag();
    }
  }
}