using System;
using IXPEnumerator=com.plumtree.openfoundation.util.IXPEnumerator;
using ATag=com.plumtree.portaluiinfrastructure.tags.ATag;
using TagType=com.plumtree.portaluiinfrastructure.tags.TagType;
using ITagMetaData=com.plumtree.portaluiinfrastructure.tags.metadata.ITagMetaData;
using TagMetaData=com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using AccessStyles=com.plumtree.uiinfrastructure.constants.AccessStyles;
using ErrorDisplayHelper=com.plumtree.uiinfrastructure.errordisplay.ErrorDisplayHelper;
using UIErrorHandler=com.plumtree.uiinfrastructure.errordisplay.UIErrorHandler;
using HTMLElement=com.plumtree.xpshared.htmlelements.HTMLElement;
using HTMLElementCollection=com.plumtree.xpshared.htmlelements.HTMLElementCollection;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays the current extended error text on the page so that
  /// it can be placed and formatted as desired. Only the first error
  /// message's extened text will be displayed.  Other errors, as well as exception
  /// stack traces will be ignored.
  /// </summary>
  /// <author>Ravi Tunuguntla</author>
  public class ErrorExtendedMessageTag : ATag
  {
    //	All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    static ErrorExtendedMessageTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("errorextendedmessage", "This tag displays the extended error text on the page so that " + "it can be placed and formatted as desired. Only the first error " + "message\'s extended text will be displayed.  Other errors," + " as well as exception stack traces will be ignored.  If " + "this tag is displayed on a page, errors will no longer be " + "displayed in the normal error location.",
       ErrorTag.ERROR_EXAMPLE);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace currentAS = (AActivitySpace) GetEnvironment();
      // Get errors associated with this activity space
      IXPEnumerator eErrors = UIErrorHandler.GetErrors(currentAS.GetSubSession(),
       currentAS.GetApplication(), currentAS, true, UIErrorHandler.GetDisplayAdminErrors(currentAS));
      ErrorDisplayHelper helper = new ErrorDisplayHelper(currentAS, eErrors);
      HTMLElement result = new HTMLElementCollection();
      //	This is extended error message from helper.
      String strExtendedErrorText = helper.GetFirstErrorExtendedText();
      result.AddInnerHTMLEncodedString(strExtendedErrorText);
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any content by itself, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new ErrorTextTag();
    }
  }
}