using System;
using com.plumtree.portalpages.browsing.search.network;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays the federated search button.
  /// </summary>
  public class FederatedSearchButtonTag : APTButtonTag
  {
    private const String TAG_NAME = "federatedsearchbutton";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute USE_SPAN;
    static FederatedSearchButtonTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays the federated search button. " + APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));
      USE_SPAN = new OptionalTagAttribute(USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " + PTStyleID.PT_FEDERATED_SEARCH_BUTTON + " " + COMMON_POST_USE_SPAN_DESC,
       USE_SPAN_TYPE, USE_SPAN_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      String strNetworkSearch = GetEnvironment().GetString(340, "ptmsgs_portalcommonmsgs");
      ASURL netsearch = new ASURL((AActivitySpace) GetEnvironment());
      netsearch.SetLinkCreateNewSpace(NetworkSearchAS.STR_MVC_CLASS_NAME,
       (AActivitySpace) GetEnvironment());
      netsearch.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
      HTMLElement anchor = netsearch.GetURLAsHTMLElement();
      // No text inside the link.
      AddContentToLink(anchor, null, strNetworkSearch);
      return AddSpanToFinalOutput(anchor, PTStyleID.PT_FEDERATED_SEARCH_BUTTON,
       null);
    }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTButtonTag#GetButtonImage(java.lang.String)"></seealso>
    public override HTMLElement GetButtonImage(String _strAltText)
    {
      HTMLImg img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_NETWORK,
       true, (AActivitySpace) GetEnvironment()).GetHTMLElement();
      img.SetAlt(_strAltText);
      img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      img.SetBorder(CommonHTMLStrings.ZERO);
      return img;
    }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()"></seealso>
    public override OptionalTagAttribute GetUseSpanAttribute()
    {
      return USE_SPAN;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new FederatedSearchButtonTag();
    }
  }
}