using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.login;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays the Authentication Source select.
  /// </summary>
  public class LoginAuthSourceTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag PARENT;
    public static readonly OptionalTagAttribute DEFAULT_SELECTION;
    public static readonly OptionalTagAttribute HIDDEN;
    public static readonly OptionalTagAttribute FORCE_DISPLAY;
    static LoginAuthSourceTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("loginauthsource", "This tag displays the Authentication Source input. If AllowDefaultLoginPageAuthsource " + "of portalconfig.xml is set to 3 this tag displays nothing.");
      PARENT = new RequiredParentTag(LoginFormTag.TAG);
      DEFAULT_SELECTION = new OptionalTagAttribute("defaultselection", "Sets the selected attribute to the option corresponding to this value. " + "The default selection should be specified as the Auth Source Prefix, rather " + "than the human readable description.  If you view the HTML of the Auth Source " + "dropdown, the prefix is the value of the HTML option. " + "This selection overrides the default value specified in portalconfig.xml.",
       AttributeType.STRING, "");
      HIDDEN = new OptionalTagAttribute("hidden", "Use a input type of hidden rather than select for user authentication. " + "The value of the hidden input is either the value of the defaultselection " + "attribute of this tag or the default authentication value specified in portalconfig.xml.",
       AttributeType.BOOLEAN, "false");
      FORCE_DISPLAY = new OptionalTagAttribute("forcedisplay", "Force Display overrides the normal behavior for the authsource defined in " + "portalconfig.xml -- setting force display to true will display the tag contents " + "regardless of setting the AllowDefaultLoginPageAuthSource in portalconfig.xml to 3.",
       AttributeType.BOOLEAN, "false");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      bool forceDisplay = GetTagAttributeAsBoolean(FORCE_DISPLAY);
      if (PTLoginHelper.GetDropdownMode() == 3 && !forceDisplay)
      {
        return new HTMLElementCollection();
      }
      bool isHidden = GetTagAttributeAsBoolean(HIDDEN);
      bool defaultSelectionPresent = HasTagAttribute(DEFAULT_SELECTION);
      String selectedAuthSource = GetTagAttributeAsString(DEFAULT_SELECTION);
      HTMLElementCollection result = new HTMLElementCollection();
      AActivitySpace space = TaskAPIUICommon.GetEnvTypeObject(GetEnvironment());
      HTMLSelect mySelect = LoginHTML.GetAuthSourceSelect(space, TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()).GetApplication(),
       TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()).GetIsAccessStyleNonStandard(),
       "");
      if (!isHidden)
      {
        if (defaultSelectionPresent)
        {
          // This select is cached on the application and shared between 
          // users, so we can't edit it in any way. need to make a clone...
          HTMLSelect myNewSelect = new HTMLSelect(mySelect.GetName(), mySelect.GetID());
          mySelect.GetDisplayString();
          myNewSelect.SetSize(mySelect.GetSize());
          myNewSelect.SetStyle(mySelect.GetStyle());
          myNewSelect.SetStyleClass(mySelect.GetStyleClass());
          XPArrayList myArrayList = (XPArrayList) mySelect.GetInnerHTMLElementsAsArrayList(false);
          for (int i = 0;i < myArrayList.GetSize();i++)
          {
            Object testObject = myArrayList.GetElement(i);
            if (testObject.GetType() == typeof(HTMLOption))
            {
              HTMLOption myHTMLOption = (HTMLOption) testObject;
              HTMLOption myNewOption = new HTMLOption(myHTMLOption.GetValue(),
               myHTMLOption.GetInnerHTML());
              if (selectedAuthSource.Equals(myNewOption.GetValue()))
              {
                myNewOption.SetSelected(true);
              } else
              {
                myNewOption.SetSelected(false);
              }
              myNewSelect.AddInnerHTMLElement(myNewOption);
            }
          }
          result.AddInnerHTMLElement(myNewSelect);
        } else
        {
          result.AddInnerHTMLElement(mySelect);
        }
      } else
      {
        HTMLInput htmlHidden = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, LoginHTML.PARAM_HIDDEN_AUTHSOURCE,
         "");
        if (defaultSelectionPresent)
        {
          htmlHidden.SetValue(selectedAuthSource);
        } else
        {
          htmlHidden.SetValue(mySelect.GetValue());
        }
        result.AddInnerHTMLElement(htmlHidden);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag handles both standard and 508 modes.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LoginAuthSourceTag();
    }
  }
}