using System;
using com.plumtree.portalpages.common.login;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays the login button.
  /// </summary>
  public class LoginButtonTag : ATag
  {
    private const String HTMLBUTTON_LOGIN = "in_bu_Login";
    private const String BUTTON_VALUE_DEFAULT = "International button login value";
    private const String BUTTON_TITLE_DEFAULT = "International button login title";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag PARENT;
    public static readonly OptionalTagAttribute STYLECLASS;
    public static readonly OptionalTagAttribute ONCLICK;
    public static readonly OptionalTagAttribute TITLE;
    public static readonly OptionalTagAttribute VALUE;
    static LoginButtonTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("loginbutton", "This tag displays the login button.");
      PARENT = new RequiredParentTag(LoginFormTag.TAG);
      STYLECLASS = new OptionalTagAttribute("styleclass", "styleClass attribute for the text input",
       AttributeType.STRING, PTStyleClass.FORM_BTN_TEXT.ToString());
      ONCLICK = new OptionalTagAttribute("onclick", "onClick attribute for the button. This " + "attribute is not applicable in 508 mode.",
       AttributeType.STRING, "doLogin(); return false;");
      TITLE = new OptionalTagAttribute("title", "title attribute for the button",
       AttributeType.STRING, BUTTON_TITLE_DEFAULT);
      VALUE = new OptionalTagAttribute("value", "value attribute for the button",
       AttributeType.STRING, BUTTON_VALUE_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      if (GetEnvironment().GetAccessStyle() == AccessStyles.STANDARD)
      {
        HTMLInput myLoginInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_LOGIN,
         GetEnvironment().GetString(1460, "ptmsgs_portalbrowsingmsgs"));
        myLoginInput.SetStyleClass(GetTagAttributeAsString(STYLECLASS));
        myLoginInput.SetOnClick(GetTagAttributeAsString(ONCLICK));
        String buttonTitle = GetTagAttributeAsString(TITLE);
        if (BUTTON_TITLE_DEFAULT.Equals(buttonTitle))
        {
          buttonTitle = GetEnvironment().GetString(1460, "ptmsgs_portalbrowsingmsgs");
          }
        String buttonValue = GetTagAttributeAsString(VALUE);
        if (BUTTON_VALUE_DEFAULT.Equals(buttonValue))
        {
          buttonValue = GetEnvironment().GetString(1460, "ptmsgs_portalbrowsingmsgs");
          }
        myLoginInput.SetTitle(buttonTitle);
        myLoginInput.SetValue(buttonValue);
        return myLoginInput;
      } else
      {
        String buttonValue = GetTagAttributeAsString(VALUE);
        if (BUTTON_VALUE_DEFAULT.Equals(buttonValue))
        {
          buttonValue = GetEnvironment().GetString(640, "ptmsgs_portalbrowsingmsgs");
          }
        //	508 LOGIN BUTTON
        HTMLInput myInput = new HTMLInput(HTMLInputTypes.SUBMIT_TYPE, LoginHTML.PARAM_DOLOGIN_508,
         buttonValue);
        myInput.SetStyleClass(GetTagAttributeAsString(STYLECLASS));
        myInput.SetValue(buttonValue);
        return myInput;
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag handles both standard and 508 modes.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LoginButtonTag();
    }
  }
}