using System;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.common.login;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays the login form, hidden parameters and javascript, but none of the UI.
  /// </summary>
  public class LoginFormTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RelatedChildTag CREATE_ACCOUNT;
    public const String LOGIN_PORTLET_FORM = "LoginPortletForm";
    static LoginFormTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("loginform", "This tag outputs the basic login form, but does not display " + "any buttons or links in the form.");
      CREATE_ACCOUNT = new RelatedChildTag(CreateAccountTag.TAG);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLForm myForm = new HTMLForm("loginFormID");
      myForm.bForceFormattingOn = true;
      // WilliamA - check if there's redirect-after-login URL
      // if there is, set it as a hidden input in the login form
      ISessionManager subSession = this.GetState().GetSubSession();
      String redirectAfterLoginURL = null;
      if (null != subSession)
      {
        redirectAfterLoginURL = (String) subSession.GetAttribute("PT_" + ASConstants.REDIRECT_AFTER_LOGIN);
        }
      //RaviT - We also check if redirect-after-login is set on LoginModel
      //this will be used if it is not set on subsession.
      if (null == redirectAfterLoginURL || redirectAfterLoginURL.Length == 0)
      {
        AActivitySpace space = (AActivitySpace) GetEnvironment();
        if (space.GetModelExists(LoginModel.STR_MVC_CLASS_NAME))
        {
          LoginModel model = (LoginModel) space.GetModel(LoginModel.STR_MVC_CLASS_NAME);
          Redirect r = model.GetRedirectAfterLogin();
          //RaviT - Get the url from the Redirect value if it is not null and add
          // it to hidden input.
          if (null != r)
          {
            redirectAfterLoginURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(space) + r.GetQueryString();
            //Bug fix 9351913 - Requested page after login fails with adaptive layouts disabled
            // If you set AllowGuestUser=0, bug fix 9351913 will fail for adaptive layouts with a friendly URL redirect.
            //a friendly url redirect will always be an externalURL, so the below check will always be true, so this fix
            //is applied to friendly URLS only when adaptive layout mode is enabled.
            if (r.GetIsExternalURL())
            {
              redirectAfterLoginURL = r.GetExternalURL();
            }
          }
        }
      }
      if (null != redirectAfterLoginURL && redirectAfterLoginURL.Length > 0)
      {
        // RaviT - Sets the hidden input, so when the login is successful the user
        // will be redirected to the proper page requested in the first place.
        HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.REDIRECT_AFTER_LOGIN_INPUT,
         ASConstants.REDIRECT_AFTER_LOGIN_INPUT, "This is an input");
        myInput.SetValue(redirectAfterLoginURL);
        myForm.AddInnerHTMLElement(myInput);
      }
      MakeLoginForm(myForm, LOGIN_PORTLET_FORM, LoginAS.STR_MVC_CLASS_NAME,
       "", LoginControl.STR_MVC_CLASS_NAME, "", false, false);
      myForm.AddInnerHTMLElement(ProcessTagBody());
      return myForm;
    }
    public override HTMLScriptCollection DisplaySharedJavascript()
    {
      // This method does not get called in 508 mode.
      HTMLScript script = LoginHTML.GetLoginJScript(false, LOGIN_PORTLET_FORM,
       "");
      HTMLScriptCollection result = new HTMLScriptCollection();
      result.AddInnerHTMLElement(script);
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag handles both standard and 508 modes.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LoginFormTag();
    }
    
    /// <summary>
    /// This method creates the HTML for the login form.
    /// </summary>
    private HTMLElement MakeLoginForm(HTMLForm myForm, String sFormName, String sLoginASName,
     String sSpaceID, String sControlName, String sUniquifier, bool bShowAuthSource,
     bool bAllowAuthSourceDropdownDisplay)
    {
      HTMLInput myInput;
      // mj: this code returns the right url for any security mode
      myForm.SetAction(TaskAPIUIPortalConfig.GetApplicationBaseURLToAS(GetEnvironment().GetCurrentNormalizedBaseURL(),
       sLoginASName, false));
      myForm.SetMethod(CommonHTMLStrings.POST);
      myForm.SetName(sFormName);
      // Sets the space name for the event to be passed to the server
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACENAME_INPUT,
       ASConstants.SPACENAME_INPUT, "This is an input");
      myInput.SetValue(sLoginASName);
      myForm.AddInnerHTMLElement(myInput);
      // Sets the space ID for the event to be passed to the server
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACEID_INPUT,
       ASConstants.SPACEID_INPUT, "This is an input");
      myInput.SetValue(sSpaceID);
      myForm.AddInnerHTMLElement(myInput);
      // Sets the control name for the event to be passed to the server
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.CONTROL_INPUT,
       ASConstants.CONTROL_INPUT, "This is an input");
      myInput.SetValue(sControlName);
      myForm.AddInnerHTMLElement(myInput);
      // Sets the dologin parameter
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, LoginHTML.PARAM_DOLOGIN,
       LoginHTML.PARAM_DOLOGIN, "This is an input");
      myInput.SetValue("false");
      myForm.AddInnerHTMLElement(myInput);
      return myForm;
    }
  }
}