using System;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays a login/logout link to the Plumtree login page.
  /// </summary>
  public class LoginLinkTag : APTLinkTag
  {
    private const String TAG_NAME = "login";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute REDIRECT;
    public static readonly OptionalTagAttribute USE_BASE_URL_FOR_REDIRECT;
    public static readonly OptionalTagAttribute USE_SPAN;
    static LoginLinkTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays a Login <![CDATA[/]]> Logout link to the Plumtree login " + "page depending on the current state of the user.  I.E. A logged " + "in user will see the Logout link, while a user who has not yet " + "logged in will see the Login link.  " + APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));
      REDIRECT = new OptionalTagAttribute("redirect", "This attribute specifies an URL to be redirected to after login, instead of the standard MyHome page.",
       AttributeType.STRING, "");
      USE_BASE_URL_FOR_REDIRECT = new OptionalTagAttribute("usebaseurl", "This attribute specifies whether or not the portal base URL (up to \"server.pt?\") should be prepended " + "to the redirect URL, if one is present.",
       AttributeType.BOOLEAN, "true");
      USE_SPAN = new OptionalTagAttribute(USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of either " + PTStyleID.PT_LOGIN_LINK + " or " + PTStyleID.PT_LOGOFF_LINK + COMMON_POST_USE_SPAN_DESC,
       USE_SPAN_TYPE, USE_SPAN_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      IPTURL link = TaskAPIUIUser.GetURLForLoginLogoff((AActivitySpace) GetEnvironment());
      // no link to display
      if (null == link)
      {
        return new HTMLGenericElement("");
      }
      String strURL = link.GetFullURL();
      String strStyleID;
      if (LoginHelper.INSTANCE.GetIsGuestUser(GetEnvironment().GetUserSession()))
      {
        strStyleID = PTStyleID.PT_LOGIN_LINK;
        String strRedirect = GetTagAttributeAsString(REDIRECT);
        if (!"".Equals(strRedirect))
        {
          if (GetTagAttributeAsBoolean(USE_BASE_URL_FOR_REDIRECT))
          {
            strRedirect = TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()).GetCurrentNormalizedBaseURL() + strRedirect;
            }
          strURL+=LinkConstants.AMPERSAND + ASConstants.REDIRECT_AFTER_LOGIN + LinkConstants.EQUALS + XPHttpUtility.UrlEncode(strRedirect,
           LinkConstants.UTF_8_ENCODING);
        }
      } else
      {
        strStyleID = PTStyleID.PT_LOGOFF_LINK;
      }
      HTMLElement anchor = new HTMLAnchor(strURL);
      // This adds either the inner HTML or the default text to the link.
      AddContentToLink(anchor, link.GetData(PTURLConstants.KEY_TITLE));
      return AddSpanToFinalOutput(anchor, strStyleID);
    }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()"></seealso>
    public override OptionalTagAttribute GetUseSpanAttribute()
    {
      return USE_SPAN;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LoginLinkTag();
    }
  }
}