using System;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag conditionally processes inner content based on the option
  /// parameter and PTLoginHelper settings. So if "option" is set to 
  /// "remembermypassword" and PTLoginHelper.ShowRememberMyPassword() returns
  /// true the tag body is processed.
  /// </summary>
  public class LoginOptionsEnabledTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute OPTION;
    static LoginOptionsEnabledTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("loginoptionsenabled", "Conditionally processes inner content based on the option parameter " + "and Portal settings. For example, if the option attribute is set to " + "remembermypassword and the Portal setting for remembermypassword is true, " + "then the HTML inside the tag will be displayed.<![CDATA[<p/>]]>" + "The remembermypassword setting is configured by the AllowAutoConnect parameter " + "in portalconfig.xml (setting AllowAutoConnect to true sets remembermypassword to true.) " + "The createaccount setting is set with the Allow creation of Self Registered Users " + "in the Portal Administration\'s Portal Settings.<![CDATA[<p/>]]>" + "The authsource setting is set with AllowDefaultLoginPageAuthSournce in portalconfig.xml.");
      OPTION = new RequiredTagAttribute("option", "A login option to check. This attribute " + "must be set to one of the following: " + "authsource (processes tag body if the authsource setting is set to true)," + "remembermypassword (processes tag body if the remembermypassword setting is set to true), " + "createaccount (processes tag body if the createaccount setting is set to true)",
       AttributeType.STRING);
    }
    private const String REMEMBER_MY_PASSWORD = "remembermypassword";
    private const String CREATE_ACCOUNT = "createaccount";
    private const String AUTHSOURCE = "authsource";
    private const String ERR_MSG = " is an invalid value for the loginoptionsenabled tag option attribute.";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLElementCollection myCollection = new HTMLElementCollection();
      String myOption = GetTagAttributeAsString(OPTION);
      if (null != myOption && myOption.Equals(REMEMBER_MY_PASSWORD))
      {
        if (PTLoginHelper.ShowRememberMyPassword())
        {
          myCollection.AddInnerHTMLElement(ProcessTagBody());
        }
      } else
      if (null != myOption && myOption.Equals(CREATE_ACCOUNT))
      {
        if (PTLoginHelper.GetAllowUserCreation((AActivitySpace) GetEnvironment(),
         ((AActivitySpace) GetEnvironment()).GetApplication()))
        {
          myCollection.AddInnerHTMLElement(ProcessTagBody());
        }
      } else
      if (null != myOption && myOption.Equals(AUTHSOURCE))
      {
        if (PTLoginHelper.ShowAuthDropdown())
        {
          myCollection.AddInnerHTMLElement(ProcessTagBody());
        }
      } else
      {
        myCollection.AddInnerHTMLElement(new HTMLComment(myOption + ERR_MSG));
        }
      return myCollection;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LoginOptionsEnabledTag();
    }
  }
}