using System;
using com.plumtree.portalpages.common.login;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays the username text box for a loginform.
  /// </summary>
  public class LoginUsernameTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag PARENT;
    public static readonly OptionalTagAttribute SIZE;
    public static readonly OptionalTagAttribute ONKEYPRESS;
    public static readonly OptionalTagAttribute STYLEID;
    public static readonly OptionalTagAttribute ALTTEXT;
    static LoginUsernameTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("loginusername", "This tag displays the username text box for a loginform.");
      PARENT = new RequiredParentTag(LoginFormTag.TAG);
      SIZE = new OptionalTagAttribute("size", "size of the login username text input",
       AttributeType.INT, "30");
      ONKEYPRESS = new OptionalTagAttribute("onkeypress", "onKeyPress attribute for the text input. This is only used in standard mode (i.e. not 508 mode).",
       AttributeType.STRING, "return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
      STYLEID = new OptionalTagAttribute("styleid", "styleid attribute for the text input",
       AttributeType.STRING, PTStyleID.PT_LOGIN_USERNAME_TEXTBOX);
      ALTTEXT = new OptionalTagAttribute("alttext", "alt text attribute for the text input",
       AttributeType.STRING, "ptmsgs_portalbrowsingmsgs string 633");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      String usernameText = GetEnvironment().GetString(633, "ptmsgs_portalbrowsingmsgs");
      if (null != GetTagAttributeAsString(ALTTEXT))
      {
        usernameText = GetTagAttributeAsString(ALTTEXT);
      }
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.TEXT, LoginHTML.PARAM_USERNAME,
       "id", usernameText);
      myInput.SetID(GetTagAttributeAsString(STYLEID));
      myInput.SetSize(GetTagAttributeAsInt(SIZE));
      myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT.ToString());
      if (GetEnvironment().GetAccessStyle() == AccessStyles.STANDARD)
      {
        myInput.SetOnKeyPress(GetTagAttributeAsString(ONKEYPRESS));
      }
      result.AddInnerHTMLElement(myInput);
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag handles both standard and 508 modes.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LoginUsernameTag();
    }
  }
}