using System;
using IXPList=com.plumtree.openfoundation.util.IXPList;
using XPArrayList=com.plumtree.openfoundation.util.XPArrayList;
using XPIllegalStateException=com.plumtree.openfoundation.util.XPIllegalStateException;
using XPNullPointerException=com.plumtree.openfoundation.util.XPNullPointerException;
using IPortalSettingsModelRO=com.plumtree.portalpages.browsing.portalsettings.IPortalSettingsModelRO;
using PortalSettingsModel=com.plumtree.portalpages.browsing.portalsettings.PortalSettingsModel;
using ATag=com.plumtree.portaluiinfrastructure.tags.ATag;
using Scope=com.plumtree.portaluiinfrastructure.tags.Scope;
using CommonTagAttributeConstants=com.plumtree.portaluiinfrastructure.tags.common.CommonTagAttributeConstants;
using HashtableDataObject=com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
using AttributeType=com.plumtree.portaluiinfrastructure.tags.metadata.AttributeType;
using ITagMetaData=com.plumtree.portaluiinfrastructure.tags.metadata.ITagMetaData;
using OptionalTagAttribute=com.plumtree.portaluiinfrastructure.tags.metadata.OptionalTagAttribute;
using RequiredTagAttribute=com.plumtree.portaluiinfrastructure.tags.metadata.RequiredTagAttribute;
using TagMetaData=com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using HTMLElement=com.plumtree.xpshared.htmlelements.HTMLElement;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag stores the list of My Account Settings Links in memory.
  /// Each SettingItem data object contains the following variables: 'name' for the My Account Setting name,
  /// 'url' is the link to view the Setting, 'description' will have the decription of the My Account Setting, 
  /// or 'EMPTY_STRING' if there is no description,
  /// </summary>
  /// <author>Ravi Tunuguntla</author>
  public class MyAccountDataTag : ATag
  {
    private const String TAG_NAME = "myaccountdata";
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    public const String NAME = "name";
    public const String URL = "url";
    public const String DESC = "description";
    public static readonly String TAG_DESCRIPTION = ATag.EncodeForTagDoc("This Tag stores the list of MyAccount SettingItems." + "Each SettingItem object contains the following variables: </br>" + "<ul>" + "<li> <code>" + NAME + "</code> - The name of the document.</li>" + "<li> <code>" + URL + "</code> - The link to view the document.</li>" + "<li> <code>" + DESC + "</code> - The decription of the document, or " + "\'EMPTY_STRING\' if there is no description.</li>" + "</ul>");
    static MyAccountDataTag()
    {
      TAG = new TagMetaData(TAG_NAME, TAG_DESCRIPTION);
      ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC, AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
    }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
     
    public override ATag Create()
    {
      return new MyAccountDataTag();
    }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      IPortalSettingsModelRO settingsModel = GetSettingsModel();
      int nItems = settingsModel.GetNumSettingItems();
      IXPList settingsList = new XPArrayList(nItems);
      HashtableDataObject htObject;
      for (int i = 0;i < nItems;i++)
      {
        htObject = new HashtableDataObject();
        htObject.SetData(NAME, settingsModel.GetSettingItemName(i));
        htObject.SetData(URL, settingsModel.GetSettingItemURL(i));
        htObject.SetData(DESC, settingsModel.GetSettingItemDescription(i));
        settingsList.Add(htObject);
      }
      // Adding to Memory
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, settingsList, tagScope,
       true);
      return ProcessTagBody();
    }
    
    /// <returns>The current Portal Settings Model. </returns>
    /// <throws>XPIllegalStateException if a Portal Settings Model is not found.</throws>
    protected virtual IPortalSettingsModelRO GetSettingsModel()
    {
      IPortalSettingsModelRO m_asmModel;
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      // If Model does not exist we register and get the Model.
      if (!space.GetModelExists(PortalSettingsModel.STR_MVC_CLASS_NAME))
      {
        if (!space.RegisterModel(PortalSettingsModel.STR_MVC_CLASS_NAME))
        {
          throw new XPIllegalStateException("Failed to get PortalSettingsModel");
          }
      }
      m_asmModel = (IPortalSettingsModelRO) space.GetModel(PortalSettingsModel.STR_MVC_CLASS_NAME);
      m_asmModel.InitSettings(space);
      return m_asmModel;
    }
  }
}