using System;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.portalsettings;
using com.plumtree.portalpages.browsing.sitemap.sitemappage;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays the My Account link to the account settings
  /// page if the user is logged in as a non-guest user.
  /// </summary>
  public class MyAccountTag : APTLinkTag
  {
    private const String TAG_NAME = "myaccount";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute USE_SPAN;
    static MyAccountTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays the My Account link to the account settings " + "page if the user is logged in as a non-guest user.  " + APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));
      USE_SPAN = new OptionalTagAttribute(USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " + PTStyleID.PT_MY_ACCOUNT_LINK + " " + COMMON_POST_USE_SPAN_DESC,
       USE_SPAN_TYPE, USE_SPAN_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      if (!LoginHelper.INSTANCE.GetIsGuestUser(GetEnvironment().GetUserSession()) && !MyAccountTag.IsPreviewPage((AActivitySpace) GetEnvironment()))
      {
        ASURL myAccount = new ASURL((AActivitySpace) GetEnvironment());
        myAccount.SetLinkGetSpaceIfCached(PortalSettingsAS.STR_MVC_CLASS_NAME,
         (AActivitySpace) GetEnvironment());
        HTMLElement link = myAccount.GetURLAsHTMLElement();
        AddContentToLink(link, GetEnvironment().GetString(296, "ptmsgs_portalcommonmsgs"));
        return AddSpanToFinalOutput(link, PTStyleID.PT_MY_ACCOUNT_LINK);
      }
      return null;
    }
    
    /// <summary>
    /// This function checks the MyPortalModel
    /// to see if the current page is a community preview page
    /// (certain actions are disabled in this case).
    /// </summary>
    /// <returns>boolean</returns>
    public static bool IsPreviewPage(AActivitySpace asOwner)
    {
      bool bIsPreviewPage = false;
      if (asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
      {
        MyPortalModel myPortalModel = (MyPortalModel) asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        bIsPreviewPage = myPortalModel.IsPreviewPage();
      }
      if (asOwner.GetModelExists(SiteMapModel.STR_MVC_CLASS_NAME))
      {
        SiteMapModel siteMapModel = (SiteMapModel) asOwner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
        bIsPreviewPage = siteMapModel.IsPreviewPage();
      }
      return bIsPreviewPage;
    }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()"></seealso>
    public override OptionalTagAttribute GetUseSpanAttribute()
    {
      return USE_SPAN;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new MyAccountTag();
    }
  }
}