using System;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays a link to the user's home page (MyPage or Community).
  /// </summary>
  public class MyHomeTag : APTButtonTag
  {
    private const String TAG_NAME = "myhome";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute USE_SPAN;
    static MyHomeTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays a link to the user\'s home page (MyPage or Community).  " + APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));
      USE_SPAN = new OptionalTagAttribute(USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " + PTStyleID.PT_MY_HOME_LINK + " " + COMMON_POST_USE_SPAN_DESC,
       USE_SPAN_TYPE, USE_SPAN_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      IPTURL link = TaskAPIUIUser.GetURLForMyHome((AActivitySpace) GetEnvironment());
      HTMLElement anchor = new HTMLAnchor(link.GetFullURL());
      AddContentToLink(anchor, link.GetData(PTURLConstants.KEY_TITLE), GetEnvironment().GetString(699,
       "ptmsgs_portalcommonmsgs"));
      return AddSpanToFinalOutput(anchor, PTStyleID.PT_MY_HOME_LINK, PTStyleClass.BAN_HELP_TEXT);
      }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTButtonTag#GetButtonImage()"></seealso>
    public override HTMLElement GetButtonImage(String _strAltText)
    {
      // TODO: Should this just return the image type?
      HTMLImg image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_HOME).GetHTMLElement();
      image.SetAlt(_strAltText);
      image.SetAlign("absmiddle");
      return image;
    }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()"></seealso>
    public override OptionalTagAttribute GetUseSpanAttribute()
    {
      return USE_SPAN;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new MyHomeTag();
    }
  }
}