using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.ptui
{
  /// <summary>
  /// This tag displays a debug button that pops up a window
  /// displaying the Subportal rules debug messages.
  /// </summary>
  public class RulesDebugTag : APTButtonTag
  {
    private const String TAG_NAME = "rulesdebug";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute FORCE_DISPLAY;
    public static readonly OptionalTagAttribute USE_SPAN;
    static RulesDebugTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays a debug button that displays Subportal rules debug " + "messages in a pop-up window. " + APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));
      FORCE_DISPLAY = new OptionalTagAttribute("forcedisplay", "This attribute allows you to force the rules debug link to display, overriding the server and user settings.",
       AttributeType.BOOLEAN, XPConvert.ToString(false));
      USE_SPAN = new OptionalTagAttribute(USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " + PTStyleID.PT_RULES_DEBUG_LINK + " " + COMMON_POST_USE_SPAN_DESC,
       USE_SPAN_TYPE, USE_SPAN_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      if (!GetTagAttributeAsBoolean(FORCE_DISPLAY))
      {
        if (!RulesDebugMSGAS.GetIsRulesDebugEnabled(TaskAPIUICommon.GetEnvTypeObject(GetEnvironment())))
        {
          // We are not supposed to display this link for this user.
          return null;
        }
      }
      AActivitySpace asOwner = TaskAPIUICommon.GetEnvTypeObject(GetEnvironment());
      ASURL urlDebugPopUp = new ASURL(asOwner);
      urlDebugPopUp.SetLinkGetSpaceIfCached(RulesDebugMSGAS.STR_MVC_CLASS_NAME,
       asOwner);
      urlDebugPopUp.SetDisplayPage(RulesDebugMSGDP.STR_MVC_CLASS_NAME);
      HTMLAnchor anchor;
      if (GetEnvironment().GetAccessStyle() == AccessStyles.SECTION_508)
      {
        anchor = new HTMLAnchor(urlDebugPopUp.GetURLAsString());
        anchor.SetTarget("_rulesdebug");
        anchor.SetHRef(urlDebugPopUp.GetURLAsString());
      } else
      {
        anchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
        anchor.SetOnClick("window.open( \'" + urlDebugPopUp.GetURLAsString() + "\', \'rulesDebugWindow\', \'status=no,toolbar=yes,menubar=no,resizable=yes,scrollbars=yes,location=no,width=1000,height=600\'); return false;");
        }
      AddContentToLink(anchor, GetEnvironment().GetString(2969, "ptmsgs_portaladminmsgs"),
       GetEnvironment().GetString(2969, "ptmsgs_portaladminmsgs"));
      return AddSpanToFinalOutput(anchor, PTStyleID.PT_RULES_DEBUG_LINK, PTStyleClass.BAN_HELP_TEXT);
      }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTButtonTag#GetButtonImage(java.lang.String)"></seealso>
    public override HTMLElement GetButtonImage(String _strAltText)
    {
      HTMLImg myDebugIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_SUBPORTAL_RULE).GetHTMLElement();
      myDebugIcon.SetAlt(GetEnvironment().GetString(2969, "ptmsgs_portaladminmsgs"));
      myDebugIcon.SetWidth("16");
      myDebugIcon.SetHeight("16");
      myDebugIcon.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myDebugIcon.SetBorder(CommonHTMLStrings.ZERO);
      return myDebugIcon;
    }
    
    /// <seealso cref="com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()"></seealso>
    public override OptionalTagAttribute GetUseSpanAttribute()
    {
      return USE_SPAN;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript in 508 mode, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new RulesDebugTag();
    }
  }
}