package com.plumtree.taglib.ptui;

import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag provides common behavior for all Plumtree UI buttons
 * (both with and without text links).
 */
public abstract class APTButtonTag extends APTLinkTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final OptionalTagAttribute SHOW_IMAGE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		SHOW_IMAGE = new OptionalTagAttribute(
			"showimage", "This attribute controls whether or not the button image " +
			"is displayed.", AttributeType.BOOLEAN, "true");
	}

	/**
	 * This method returns the button image with the alt text set on it.
	 * 
	 * @param _strAltText The "tool tip" text for the image. 
	 * @return HTMLElement The button image.
	 */
	public abstract HTMLElement GetButtonImage(String _strAltText);

	/**
	 * This method extends the APTLinkTag method to add the button image
	 * if necessary, in addition to adding the content.  It sets the
	 * anchor title and image alt string to the same value.
	 * 
	 * This should be called before AddSpanToFinalOutput().
	 * 
	 * Note: This calls ProcessTagBody.
	 * 
	 * @param _anchor
	 * @param _strDefaultText
	 * @param _strLinkTitle
	 */
	protected void AddContentToLink(HTMLElement _anchor, String _strDefaultText,
			String _strLinkTitle)
	{
		// We need to add this before we add the content to the link,
		// otherwise the text will come before the image.
		AddButtonImage(_anchor, _strLinkTitle);

		super.AddContentToLink(_anchor, _strDefaultText, _strLinkTitle);
	}

	protected void AddButtonImage(HTMLElement _anchor, String _strImageText)
	{
	    if (GetTagAttributeAsBoolean(SHOW_IMAGE))
	    {
	        HTMLElement button = GetButtonImage(_strImageText);
	        _anchor.AddInnerHTMLElement(button);
	    }
	}
}