package com.plumtree.taglib.ptui;

import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays the basic search button.
 */
public class BasicSearchButtonTag extends APTButtonTag
{
	private static final String TAG_NAME = "basicsearchbutton";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute USE_SPAN;
	public static final RequiredParentTag PARENT;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays the basic search button. " +
			APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " +
			PTStyleID.PT_SEARCH_SUBMIT_BUTTON + " " + COMMON_POST_USE_SPAN_DESC,
			USE_SPAN_TYPE, USE_SPAN_DEFAULT);

		PARENT = new RequiredParentTag(SearchFormTag.TAG);
	}

	/**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
    public HTMLElement DisplayTag()
    {
        HTMLElement result;

        String strSearch = GetEnvironment().GetString(341, "ptmsgs_portalcommonmsgs");

		// Full UI mode
		if (GetEnvironment().GetAccessStyle().equals(AccessStyles.STANDARD))
		{
			HTMLAnchor anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

			anchor.SetOnClick((String) GetStateVariable(SearchFormTag.ON_CLICK, Scope.TAG));

			// No text inside the link.
			AddContentToLink(anchor, null, strSearch);

			result = anchor;
		} else
		{
		    // 508 mode
		    result = GetButtonImage(strSearch);
		}

		return AddSpanToFinalOutput(result, PTStyleID.PT_SEARCH_SUBMIT_BUTTON, null);
    }

    /**
     * @see com.plumtree.taglib.ptui.APTButtonTag#GetButtonImage(String)
     */
    public HTMLElement GetButtonImage(String _strAltText)
    {
		// Full UI mode
		if (GetEnvironment().GetAccessStyle().equals(AccessStyles.STANDARD))
		{
			PTConstruct searchButton = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON,
				true, (AActivitySpace) GetEnvironment());

			HTMLImg searchButtonImg = (HTMLImg) searchButton.GetHTMLElement();

			searchButtonImg.SetAlt(_strAltText);
			searchButtonImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			searchButtonImg.SetBorder(CommonHTMLStrings.ZERO);

			return searchButtonImg;
		} else
		{
			// 508 UI mode
		    HTMLInput searchSubmitButton = new HTMLInput(HTMLInputTypes.SUBMIT, "in_su_ptbanner", _strAltText);

			searchSubmitButton.SetValue(_strAltText); 
			searchSubmitButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			searchSubmitButton.SetAlt(_strAltText);
			searchSubmitButton.SetAccessKey(GetEnvironment().GetString(4, "ptmsgs_portal508quickkeymsgs"));

			return searchSubmitButton;
		}
    }

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return true;
	}

    /**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
    public ATag Create()
    {
        return new BasicSearchButtonTag();
    }
}
