package com.plumtree.taglib.ptui;

import com.plumtree.portalpages.browsing.login.createaccount.*;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.login.PTLoginHelper;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays a create account link.
 */
public class CreateAccountTag extends APTLinkTag
{
	private static final String TAG_NAME = "createaccount";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute USE_SPAN;
	private AActivitySpace asOwner;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays a Create Account link. " +
			APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " +
			PTStyleID.PT_LOGIN_CREATE_ACCOUNT + " " + COMMON_POST_USE_SPAN_DESC,
			USE_SPAN_TYPE, USE_SPAN_DEFAULT);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		asOwner = (AActivitySpace)GetEnvironment();
		HTMLElement myCreateLink = null;
		
		// Verifying Account Creation is allowed, We show link only if it is allowed.
		if(PTLoginHelper.GetAllowUserCreation( asOwner, asOwner.GetApplication())){
			
			ASURL myHRef = new ASURL(TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()));
			myHRef.SetLinkGetSpaceIfCached(CreateAccountAS.STR_MVC_CLASS_NAME,
			        TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()));
	
			myHRef.SetControl(CreateAccountControl.STR_MVC_CLASS_NAME);
	
			// Create an account
			myHRef.AddInnerHTMLString(GetEnvironment().GetString(637,
					"ptmsgs_portalbrowsingmsgs"));
	
			// Create an account
			((HTMLAnchor) myHRef.GetURLAsHTMLElement()).SetTitle(
			        GetEnvironment().GetString(1459, "ptmsgs_portalbrowsingmsgs"));
	
			myCreateLink = myHRef.GetURLAsHTMLElement();
		}
		return AddSpanToFinalOutput(myCreateLink, PTStyleID.PT_LOGIN_CREATE_ACCOUNT);
	}

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new CreateAccountTag();
	}
}
