package com.plumtree.taglib.ptui;

import com.plumtree.openfoundation.util.IXPEnumerator;
import com.plumtree.portaluiinfrastructure.tags.ATag;
import com.plumtree.portaluiinfrastructure.tags.TagType;
import com.plumtree.portaluiinfrastructure.tags.metadata.ITagMetaData;
import com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.constants.AccessStyles;
import com.plumtree.uiinfrastructure.errordisplay.ErrorDisplayHelper;
import com.plumtree.uiinfrastructure.errordisplay.UIErrorHandler;
import com.plumtree.xpshared.htmlelements.HTMLElement;
import com.plumtree.xpshared.htmlelements.HTMLElementCollection;

/**
 * This tag displays the current extended error text on the page so that
 * it can be placed and formatted as desired. Only the first error
 * message's extened text will be displayed.  Other errors, as well as exception
 * stack traces will be ignored.
 * 
 * @author Ravi Tunuguntla
 */

public class ErrorExtendedMessageTag extends ATag
{
	
	//	All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("errorextendedmessage",
			"This tag displays the extended error text on the page so that " +
			"it can be placed and formatted as desired. Only the first error " +
			"message's extended text will be displayed.  Other errors," +
			" as well as exception stack traces will be ignored.  If " +
			"this tag is displayed on a page, errors will no longer be " +
			"displayed in the normal error location.", ErrorTag.ERROR_EXAMPLE);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		AActivitySpace currentAS = (AActivitySpace)GetEnvironment();

		// Get errors associated with this activity space
		IXPEnumerator eErrors = UIErrorHandler.GetErrors(currentAS.GetSubSession(),
			currentAS.GetApplication(), currentAS, true,
			UIErrorHandler.GetDisplayAdminErrors(currentAS));

		ErrorDisplayHelper helper = new ErrorDisplayHelper(currentAS, eErrors);
		
		HTMLElement result = new HTMLElementCollection();
		
		
		//	This is extended error message from helper.
		String strExtendedErrorText = helper.GetFirstErrorExtendedText();
		
		result.AddInnerHTMLEncodedString(strExtendedErrorText);
		
		return result;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any content by itself, and therefore
		// supports all access styles.
		return true;
	}

	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new ErrorTextTag();
	}
}