package com.plumtree.taglib.ptui;

import com.plumtree.portalpages.browsing.search.network.*;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays the federated search button.
 */
public class FederatedSearchButtonTag extends APTButtonTag
{
	private static final String TAG_NAME = "federatedsearchbutton";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute USE_SPAN;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays the federated search button. " +
			APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " +
			PTStyleID.PT_FEDERATED_SEARCH_BUTTON + " " + COMMON_POST_USE_SPAN_DESC,
			USE_SPAN_TYPE, USE_SPAN_DEFAULT);
	}

    /**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
    public HTMLElement DisplayTag()
    {
		String strNetworkSearch = GetEnvironment().GetString(340, "ptmsgs_portalcommonmsgs");

		ASURL netsearch = new ASURL((AActivitySpace) GetEnvironment());
		netsearch.SetLinkCreateNewSpace(NetworkSearchAS.STR_MVC_CLASS_NAME, (AActivitySpace) GetEnvironment());
		netsearch.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);

		HTMLElement anchor = netsearch.GetURLAsHTMLElement();

		// No text inside the link.
		AddContentToLink(anchor, null, strNetworkSearch);

		return AddSpanToFinalOutput(anchor, PTStyleID.PT_FEDERATED_SEARCH_BUTTON, null);
    }

	/**
	 * @see com.plumtree.taglib.ptui.APTButtonTag#GetButtonImage(java.lang.String)
	 */
	public HTMLElement GetButtonImage(String _strAltText)
	{
		HTMLImg img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_NETWORK,
			true, (AActivitySpace) GetEnvironment()).GetHTMLElement();

		img.SetAlt(_strAltText);
		img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		img.SetBorder(CommonHTMLStrings.ZERO);

		return img;
	}

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

    /**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
    public ATag Create()
    {
        return new FederatedSearchButtonTag();
    }
}