package com.plumtree.taglib.ptui;

import com.plumtree.portaluiinfrastructure.common.constants.ResourceConstants;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays the help link.
 * 
 * This tag extends APTLinkTag instead of APTButtonTag because the
 * link and image come pre-constructed from the HTMLConstructHelpers
 * helper method.
 */
public class HelpTag extends APTLinkTag
{
	private static final String TAG_NAME = "help";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute USE_SPAN;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays the help image and link. " +
			APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " +
			PTStyleID.PT_HELP_BUTTON + " " + COMMON_POST_USE_SPAN_DESC,
			USE_SPAN_TYPE, USE_SPAN_DEFAULT);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		// TODO: this should allow you to override the help hint too
		// TODO: this should allow you to specify which help file you want
		// TODO: This should allow you to turn off the image
		String strHelpText = GetEnvironment().GetString(337, ResourceConstants.PORTALCOMMONMSGS);
		String strHelpHint = GetEnvironment().GetString(338, ResourceConstants.PORTALCOMMONMSGS);

		HTMLAnchor helpAnchor = HTMLConstructHelpers.GetHelpAnchor((AActivitySpace) GetEnvironment(),
			null, strHelpHint);

		AddContentToLink(helpAnchor, strHelpText, strHelpHint);

		return AddSpanToFinalOutput(helpAnchor, PTStyleID.PT_HELP_BUTTON, PTStyleClass.BAN_HELP_TEXT);
	}

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new HelpTag();
	}
}