package com.plumtree.taglib.ptui;

import com.plumtree.portalpages.common.login.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays the login button.
 */
public class LoginButtonTag extends ATag
{
	private static final String HTMLBUTTON_LOGIN	 = "in_bu_Login";
	private static final String BUTTON_VALUE_DEFAULT = "International button login value";
	private static final String BUTTON_TITLE_DEFAULT = "International button login title";
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
    public static final ITagMetaData TAG;
	public static final RequiredParentTag PARENT;
	public static final OptionalTagAttribute STYLECLASS;
	public static final OptionalTagAttribute ONCLICK;
	public static final OptionalTagAttribute TITLE;
	public static final OptionalTagAttribute VALUE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("loginbutton", "This tag displays the login button.");

		PARENT = new RequiredParentTag(LoginFormTag.TAG);

		STYLECLASS = new OptionalTagAttribute("styleclass",
			"styleClass attribute for the text input",
			AttributeType.STRING, PTStyleClass.FORM_BTN_TEXT.toString());

		ONCLICK = new OptionalTagAttribute("onclick", "onClick attribute for the button. This " +
			"attribute is not applicable in 508 mode.",
			AttributeType.STRING, "doLogin(); return false;");

		TITLE = new OptionalTagAttribute("title", "title attribute for the button",
			AttributeType.STRING, BUTTON_TITLE_DEFAULT);

		VALUE = new OptionalTagAttribute("value", "value attribute for the button",
			AttributeType.STRING, BUTTON_VALUE_DEFAULT);
	}

	/**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
    public HTMLElement DisplayTag()
    {
        if (GetEnvironment().GetAccessStyle() == AccessStyles.STANDARD)
		{
			HTMLInput myLoginInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_LOGIN, GetEnvironment().GetString(1460, "ptmsgs_portalbrowsingmsgs"));
			myLoginInput.SetStyleClass(GetTagAttributeAsString(STYLECLASS));
			myLoginInput.SetOnClick(GetTagAttributeAsString(ONCLICK));
			String buttonTitle = GetTagAttributeAsString(TITLE);
			if (BUTTON_TITLE_DEFAULT.equals(buttonTitle))
			{
			    buttonTitle = GetEnvironment().GetString(1460, "ptmsgs_portalbrowsingmsgs");
			}
			String buttonValue = GetTagAttributeAsString(VALUE);
			if (BUTTON_VALUE_DEFAULT.equals(buttonValue))
			{
			    buttonValue = GetEnvironment().GetString(1460, "ptmsgs_portalbrowsingmsgs");
			}

			myLoginInput.SetTitle(buttonTitle);
			myLoginInput.SetValue(buttonValue);
			return myLoginInput;
		}
		else
		{
			String buttonValue = GetTagAttributeAsString(VALUE);
			if (BUTTON_VALUE_DEFAULT.equals(buttonValue))
			{
			    buttonValue = GetEnvironment().GetString(640, "ptmsgs_portalbrowsingmsgs");
			}	 
			//	508 LOGIN BUTTON
			HTMLInput myInput = new HTMLInput(HTMLInputTypes.SUBMIT_TYPE,
					LoginHTML.PARAM_DOLOGIN_508,
					buttonValue);
			myInput.SetStyleClass(GetTagAttributeAsString(STYLECLASS));

			myInput.SetValue(buttonValue);

			return myInput;
		}
    }

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return true;
	}

    /**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
    public ATag Create()
    {
        return new LoginButtonTag();
    }
}