package com.plumtree.taglib.ptui;

import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.login.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays a login/logout link to the Plumtree login page.
 */
public class LoginLinkTag extends APTLinkTag
{
	private static final String TAG_NAME = "login";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute REDIRECT;
	public static final OptionalTagAttribute USE_BASE_URL_FOR_REDIRECT;
	public static final OptionalTagAttribute USE_SPAN;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays a Login <![CDATA[/]]> Logout link to the Plumtree login " +
			"page depending on the current state of the user.  I.E. A logged " +
			"in user will see the Logout link, while a user who has not yet " +
			"logged in will see the Login link.  " +
			APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));

		REDIRECT = new OptionalTagAttribute("redirect",
			"This attribute specifies an URL to be redirected to after login, instead of the standard MyHome page.",
			AttributeType.STRING, "");

		USE_BASE_URL_FOR_REDIRECT = new OptionalTagAttribute("usebaseurl",
			"This attribute specifies whether or not the portal base URL (up to \"server.pt?\") should be prepended "+
			"to the redirect URL, if one is present.",
			AttributeType.BOOLEAN, "true");

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of either " +
			PTStyleID.PT_LOGIN_LINK + " or " + PTStyleID.PT_LOGOFF_LINK +
			COMMON_POST_USE_SPAN_DESC, USE_SPAN_TYPE, USE_SPAN_DEFAULT);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IPTURL link = TaskAPIUIUser.GetURLForLoginLogoff((AActivitySpace) GetEnvironment());
		// no link to display
		if ( null == link )
		{
			return new HTMLGenericElement("");
		}

		String strURL = link.GetFullURL();
		String strStyleID;

		if (LoginHelper.INSTANCE.GetIsGuestUser(GetEnvironment().GetUserSession()))
		{
			strStyleID = PTStyleID.PT_LOGIN_LINK;

			String strRedirect = GetTagAttributeAsString(REDIRECT);

			if (!"".equals(strRedirect))
			{
				if (GetTagAttributeAsBoolean(USE_BASE_URL_FOR_REDIRECT))
				{
					strRedirect = TaskAPIUICommon.GetEnvTypeObject(GetEnvironment()).GetCurrentNormalizedBaseURL() +
						strRedirect;
				}

				strURL += LinkConstants.AMPERSAND + ASConstants.REDIRECT_AFTER_LOGIN + LinkConstants.EQUALS +
					XPHttpUtility.UrlEncode(strRedirect, LinkConstants.UTF_8_ENCODING);
			}
		} else
		{
			strStyleID = PTStyleID.PT_LOGOFF_LINK;
		}

		HTMLElement anchor = new HTMLAnchor(strURL);

		// This adds either the inner HTML or the default text to the link.
		AddContentToLink(anchor, link.GetData(PTURLConstants.KEY_TITLE));

		return AddSpanToFinalOutput(anchor, strStyleID);
	}

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new LoginLinkTag();
	}
}