package com.plumtree.taglib.ptui;

import com.plumtree.portalpages.common.login.*;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays the username text box for a loginform.
 */
public class LoginUsernameTag extends ATag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
    public static final ITagMetaData TAG;
	public static final RequiredParentTag PARENT;
	public static final OptionalTagAttribute SIZE;
	public static final OptionalTagAttribute ONKEYPRESS;
	public static final OptionalTagAttribute STYLEID;
	public static final OptionalTagAttribute ALTTEXT;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("loginusername",
			"This tag displays the username text box for a loginform.");

		PARENT = new RequiredParentTag(LoginFormTag.TAG);

		SIZE = new OptionalTagAttribute("size",
			"size of the login username text input", AttributeType.INT,"30");

		ONKEYPRESS = new OptionalTagAttribute("onkeypress",
			"onKeyPress attribute for the text input. This is only used in standard mode (i.e. not 508 mode).",
			AttributeType.STRING,"return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");

		STYLEID = new OptionalTagAttribute("styleid", "styleid attribute for the text input",
			AttributeType.STRING, PTStyleID.PT_LOGIN_USERNAME_TEXTBOX);

		ALTTEXT = new OptionalTagAttribute("alttext", "alt text attribute for the text input",
			AttributeType.STRING, "ptmsgs_portalbrowsingmsgs string 633");
	}

	/**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
    public HTMLElement DisplayTag()
    {
        String usernameText = GetEnvironment().GetString(633, "ptmsgs_portalbrowsingmsgs");
        if (null != GetTagAttributeAsString(ALTTEXT))
        {
            usernameText = GetTagAttributeAsString(ALTTEXT);
        }

        HTMLElementCollection result = new HTMLElementCollection();
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.TEXT,
				LoginHTML.PARAM_USERNAME, "id", usernameText);
		myInput.SetID(GetTagAttributeAsString(STYLEID));
		myInput.SetSize(GetTagAttributeAsInt(SIZE));
		myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT.toString());

		if (GetEnvironment().GetAccessStyle() == AccessStyles.STANDARD)
		{
			myInput.SetOnKeyPress(GetTagAttributeAsString(ONKEYPRESS));
		}
		
		result.AddInnerHTMLElement(myInput);
		return result;
    }

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return true;
	}

    /**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
    public ATag Create()
    {
        return new LoginUsernameTag();
    }
}
