package com.plumtree.taglib.ptui;

import com.plumtree.openfoundation.util.IXPList;
import com.plumtree.openfoundation.util.XPArrayList;
import com.plumtree.openfoundation.util.XPIllegalStateException;
import com.plumtree.openfoundation.util.XPNullPointerException;
import com.plumtree.portalpages.browsing.portalsettings.IPortalSettingsModelRO;
import com.plumtree.portalpages.browsing.portalsettings.PortalSettingsModel;
import com.plumtree.portaluiinfrastructure.tags.ATag;
import com.plumtree.portaluiinfrastructure.tags.Scope;
import com.plumtree.portaluiinfrastructure.tags.common.CommonTagAttributeConstants;
import com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
import com.plumtree.portaluiinfrastructure.tags.metadata.AttributeType;
import com.plumtree.portaluiinfrastructure.tags.metadata.ITagMetaData;
import com.plumtree.portaluiinfrastructure.tags.metadata.OptionalTagAttribute;
import com.plumtree.portaluiinfrastructure.tags.metadata.RequiredTagAttribute;
import com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.xpshared.htmlelements.HTMLElement;

/**
 * This tag stores the list of My Account Settings Links in memory.
 * Each SettingItem data object contains the following variables: 'name' for the My Account Setting name,
 * 'url' is the link to view the Setting, 'description' will have the decription of the My Account Setting, 
 * or 'EMPTY_STRING' if there is no description,
 * 
 * @author Ravi Tunuguntla
 */


public class MyAccountDataTag extends ATag
{
	private static final String TAG_NAME = "myaccountdata";
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_ID;
	public static final OptionalTagAttribute ATTRIB_SCOPE;
	public static final String NAME = "name";
	public static final String URL = "url";
	public static final String DESC = "description";
	
	public static final String TAG_DESCRIPTION = ATag.EncodeForTagDoc(
	"This Tag stores the list of MyAccount SettingItems." +
	"Each SettingItem object contains the following variables: </br>" +
	"<ul>" +
	"<li> <code>" + NAME +"</code> - The name of the document.</li>" + 	
	"<li> <code>" + URL + "</code> - The link to view the document.</li>" + 
	"<li> <code>" + DESC +"</code> - The decription of the document, or " + 
	"'EMPTY_STRING' if there is no description.</li>" + 
	"</ul>");
	
	
	
	static
	{
		TAG = new TagMetaData(TAG_NAME, TAG_DESCRIPTION);
		
		ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
				CommonTagAttributeConstants.ATTRIB_ID_DESC,	
				AttributeType.STRING);
		
		ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
				CommonTagAttributeConstants.ATTRIB_SCOPE_DESC,
				AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
	}
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new MyAccountDataTag();
	}
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() 	
	{
		IPortalSettingsModelRO settingsModel = GetSettingsModel();
		int nItems = settingsModel.GetNumSettingItems();
		IXPList settingsList = new XPArrayList(nItems);
		HashtableDataObject htObject;
		
		for(int i =0; i < nItems; i++ )
		{
			htObject = new HashtableDataObject();
			htObject.SetData(NAME, settingsModel.GetSettingItemName(i));
			htObject.SetData(URL, settingsModel.GetSettingItemURL(i));
			htObject.SetData(DESC, settingsModel.GetSettingItemDescription(i));
			settingsList.Add(htObject);
		}
		
		
		// Adding to Memory
		
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		GetState().SetSharedVariable(strDataReference, settingsList, tagScope, true);
		
		return ProcessTagBody();
	}
	
	/**
	 * @return The current Portal Settings Model. 
	 * @throws XPIllegalStateException if a Portal Settings Model is not found.
	 */
	protected IPortalSettingsModelRO GetSettingsModel()
	{		
		IPortalSettingsModelRO m_asmModel;
		AActivitySpace space = (AActivitySpace) GetEnvironment();
		// If Model does not exist we register and get the Model.
		if(!space.GetModelExists(PortalSettingsModel.STR_MVC_CLASS_NAME))
		{			
			if(!space.RegisterModel(PortalSettingsModel.STR_MVC_CLASS_NAME))
			{
				throw new XPIllegalStateException("Failed to get PortalSettingsModel");
			}			
		}
		
		m_asmModel = (IPortalSettingsModelRO) space.GetModel(PortalSettingsModel.STR_MVC_CLASS_NAME);
		m_asmModel.InitSettings(space);
	
		return m_asmModel;
	}	
}