package com.plumtree.taglib.ptui;

import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays a link to the user's home page (MyPage or Community).
 */
public class MyHomeTag extends APTButtonTag
{
	private static final String TAG_NAME = "myhome";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute USE_SPAN;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays a link to the user's home page (MyPage or Community).  " +
			APTLinkTag.GetLinkBehaviorDescription(TAG_NAME));

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " +
			PTStyleID.PT_MY_HOME_LINK + " " + COMMON_POST_USE_SPAN_DESC,
			USE_SPAN_TYPE, USE_SPAN_DEFAULT);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IPTURL link = TaskAPIUIUser.GetURLForMyHome((AActivitySpace) GetEnvironment());

		HTMLElement anchor = new HTMLAnchor(link.GetFullURL());

		AddContentToLink(anchor, link.GetData(PTURLConstants.KEY_TITLE),
			GetEnvironment().GetString(699, "ptmsgs_portalcommonmsgs"));

		return AddSpanToFinalOutput(anchor, PTStyleID.PT_MY_HOME_LINK, PTStyleClass.BAN_HELP_TEXT);
	}

	/**
	 * @see com.plumtree.taglib.ptui.APTButtonTag#GetButtonImage()
	 */
	public HTMLElement GetButtonImage(String _strAltText)
	{
	    // TODO: Should this just return the image type?
		HTMLImg image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_HOME).GetHTMLElement();
		image.SetAlt(_strAltText);
		image.SetAlign("absmiddle");

		return image;
	}

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new MyHomeTag();
	}
}
