package com.plumtree.taglib.ptui;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.FriendlyURLConstants;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

// DCD: Constants for Top Best Bet
import com.plumtree.portalpages.browsing.topbestbethandler.*;

/**
 * This tag displays the search form, but none of the UI.
 */
public class SearchFormTag extends APTUITag
{
	public static final String TEXT_BOX_NAME = "textboxname";
	
	/**
	 * The key used to store the name of the Scope options Dropdown menu. 
	 */
	public static final String SCOPE_NAME="scopename";
	
	/**
	 * The key used to store the values of the Scope Options Dropdown menu.
	 */
	public static final String SCOPE_VALUES="scopevalues";
	
	//	 The values for each of the items in the sort list.
	
	public static final String VALUE = "value";
	public static final String TEXT = "text";
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute USE_SPAN;
	public static final OptionalTagAttribute ADD_TEXT_BOX;
	public static final RelatedChildTag BASIC_SEARCH;
	public static final RelatedChildTag ADVANCED_SEARCH;
	public static final RelatedChildTag FEDERATED_SEARCH;
	public static final RelatedChildTag TOPBESTBET_SEARCH;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("searchform",
			"This tag outputs the basic search form, but does not display " +
			"any buttons or links in the form.");

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " +
			PTStyleID.PT_SEARCH_CONTROLS + " " + COMMON_POST_USE_SPAN_DESC,
			USE_SPAN_TYPE, USE_SPAN_DEFAULT);
		
		ADD_TEXT_BOX = new OptionalTagAttribute("addtextbox", 
				"This attribute controls whether or not the search form " +
				"automatically adds the text 'Search:', Scope Dropdown menu and a text box inside form. " +
				"If set to false, the user is resposible for adding the Scope Dropdown by adding the html select, " +
				"setting the name of the variable: $" + SCOPE_NAME + " and adding options array and recursing the array" +
				" that is stored in the variable: " + SCOPE_VALUES + " and also adding the text box for Search and " +
				"setting the name to the variable: $" + TEXT_BOX_NAME,
				AttributeType.BOOLEAN, "true");

		BASIC_SEARCH = new RelatedChildTag(BasicSearchButtonTag.TAG);

		ADVANCED_SEARCH = new RelatedChildTag(AdvancedSearchButtonTag.TAG);

		FEDERATED_SEARCH = new RelatedChildTag(FederatedSearchButtonTag.TAG);

		TOPBESTBET_SEARCH = new RelatedChildTag(TopBestBetSearchButtonTag.TAG);
	}

	/**
	 * The key used to store the anchor on click in Tag Scope.
	 */
	public static final String ON_CLICK = "onclick";
	public static final String TBB_ON_CLICK = "tbbonclick";
	
	
	
	/**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
    public HTMLElement DisplayTag()
    {
		// TODO: There should be a helper method to get the page name from
        // the environment.
        AActivitySpace currentPage = (AActivitySpace) GetEnvironment();
        String strPageName = currentPage.GetName();

        if ((XPStringUtility.CompareIgnoreCase(strPageName,SearchResultAS.STR_MVC_CLASS_NAME) != 0) &&
			(XPStringUtility.CompareIgnoreCase(strPageName, AdvancedSearchAS.STR_MVC_CLASS_NAME) !=0))
		{
			// TODO: This factory stuff is responsible for adding in the ugly
			// script.  Need to track it down and get it into an include file.
			// Add search form to search controls span
            
            String sFormName = SearchFormFactory.BANNER_NAME_PREFIX + GetUniqueID();
            
			SearchFormFactory factory = new SearchFormFactory(sFormName, sFormName,
				(AActivitySpace) GetEnvironment());
			
            // DCD: Check to see if the TBB tag has been included as a child tag
            boolean bUseTopBestBet = HasChildTag(TopBestBetSearchButtonTag.TAG);
            
            // DCD: If this is a TBB-enabled tag, we can't use the factory defaults
            if(bUseTopBestBet)
            {
                factory.ForceTopBestBet();
                SetupBannerSearchSettings(factory, false);
                // DCD: set TBB target data.  The page is null, since we don't *have* a page, which
                // will be defaulted to "SearchResult" inside the factory.  This may or may not matter.
                factory.SetTarget(TopBestBetHandlerAS.CLASS_NAME, TopBestBetHandlerAS.CLASS_NAME, null);
            }
            else
            {
                // DCD: We're not a TBB-enabled tag, so proceed normally
                SetupBannerSearchSettings(factory, true);
            }

			// DCD: Only write JavaScript, etc. if this isn't 508
			if((currentPage.GetAccessStyle() == AccessStyles.STANDARD))
			{
				// Store data for child tags
				SetStateVariable(ON_CLICK, factory.GetAnchorOnClick(), Scope.TAG);
				SetStateVariable(TBB_ON_CLICK, getTBBOnClick(sFormName), Scope.TAG);
			}
			
			HTMLForm searchForm = factory.GetForm();
			
			// DCA - customers may want to add their own text box
			if (GetTagAttributeAsBoolean(ADD_TEXT_BOX)) {
				// Add "Search:" string to search form
				searchForm.AddInnerHTMLString(GetEnvironment().GetString(566, "ptmsgs_portalcommonmsgs"));
				searchForm.AddInnerHTMLElement(CreateSpacerHTMLSpan(6));
				
				// Add individual search elements to search form
				AddSearchScopePulldownToElement(searchForm, factory);
				AddSearchTextBoxToElement(searchForm, factory);
			} else {
				// DCA - set the text box name and submit button onclick in memory
				GetState().SetSharedVariable(TEXT_BOX_NAME, factory.GetInputBoxName(), Scope.TAG, true);
				GetState().SetSharedVariable(ON_CLICK, factory.GetAnchorOnClick(), Scope.TAG, true);
				
				// RT - Add Search Scope Options in memory, this can be used to display Search Scope Pull down menu.
				AddSearchScopeOptions(factory);
							
			}
		
			searchForm.AddInnerHTMLElement(ProcessTagBody());
			
			// DCD: The form has been mostly built, but we'll need to add an input for keeping track
			// 		of which search button was clicked
			if(bUseTopBestBet)
			{
			    // DCD: Create an input for storing which type of search we're executing
			    HTMLInput inTBBSearch = new HTMLInput(HTMLInputTypes.HIDDEN, TopBestBetHandlerCT.FIELDS_TBB, TopBestBetHandlerCT.FIELDS_TBB);
				searchForm.AddInnerHTMLElement(inTBBSearch);
				
				// DCD: Only write JavaScript, etc. if this isn't 508
			    if((currentPage.GetAccessStyle() == AccessStyles.STANDARD))
			    {
			        // DCD: Add javascript which will set the TBB form element, load localized error message
			        String sEmptyBoxErrorMessage = GetEnvironment().GetString(1864, "ptmsgs_portalbrowsingmsgs");
			        HTMLScript scriptTBB = buildTBBJavaScript(sEmptyBoxErrorMessage, sFormName);
			        searchForm.AddInnerHTMLElement(scriptTBB);
			    }
			}

			return AddSpanToFinalOutput(searchForm, PTStyleID.PT_SEARCH_CONTROLS, PTStyleClass.BAN_GREETING_TEXT);
		}			
		
        // DCD: We're in the search results AS or the advanced search AS, so don't do anything
        return null;
    }
    
    private HTMLScript buildTBBJavaScript(String sErrorMessage, String sFormName)
    {   
        // DCD: Define script block
        XPStringBuilder scriptText = new XPStringBuilder(300);
        scriptText.Append("function setTopBestBetAndSubmit" + sFormName + "()\n");
        scriptText.Append("{\n");
        scriptText.Append("    if(checkSearch" + sFormName + "())\n");
        scriptText.Append("    {\n");
        scriptText.Append("       var searchForm = document." + sFormName + ";\n");
        scriptText.Append("       for(var i = 0; i<searchForm.elements.length; i++)\n");
        scriptText.Append("       {\n");
        scriptText.Append("          if(searchForm.elements[i].name == \"in_hi_tbbsearch\")\n");
        scriptText.Append("          {\n");
        scriptText.Append("             searchForm.elements[i].value = \"tbb_search\";\n");
        scriptText.Append("          }\n");
        scriptText.Append("       }\n");
        scriptText.Append("       searchForm.submit();\n");
        scriptText.Append("    }\n");
        scriptText.Append("   else\n");
        scriptText.Append("   {\n");
        scriptText.Append("       alert('" + sErrorMessage + "');\n");
        scriptText.Append("   }\n");        
        scriptText.Append("}\n");
        
        HTMLScript script = new HTMLScript("text/javaScript");
        script.AddInnerHTMLString(scriptText.ToString());
		return script;   
    }
    
    private String getTBBOnClick(String sFormName)
    {
        return "setTopBestBetAndSubmit" + sFormName + "();";    
    }
    
	/**
	 *  Helper method to setup the search form with all the needed settings
	 */
	protected void SetupBannerSearchSettings(SearchFormFactory factory, boolean bForceBannerSearchDefaults)
	{
    	NavigationModel navModel = TaskAPIUICommon.GetNavigationModel((AActivitySpace) GetEnvironment());

		// NOTE: BestBets, spellchecking, and object type defaults are now applied
		// to banner search in BannerStartSearchControl, to make it easier for
		// PSOs or customers to customize these.  Here we just need to tell
		// the factory that this is a banner search.
    	if(bForceBannerSearchDefaults)
    	{
    	    factory.ForceBannerSearchDefaults();
    	}

		// Add optional pulldown settings
		if (navModel.IsCommunityPage())
		{
			factory.AddOptionalSetting("comm",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID,
				new int[] { navModel.GetCurCommunityID() });
		}
		else if (navModel.IsDirPage())
		{
			// for "All Folders", any portal object under root docdir folder
			factory.AddOptionalSetting("allfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS,
				new int[] {  /* root folder = */1 });
			factory.AddOptionalSetting("allfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS,
				PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);

			// for "This Folder", any portal object under current docdir folder
			factory.AddOptionalSetting("thisfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS,
				new int[] { navModel.GetCurDocDirFolderID() });
			factory.AddOptionalSetting("thisfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS,
				PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
		}
	}
	
	/**
	 * This method is same as AddSearchScopePulldownToElement but it sets the 
	 * SCOPE_NAME and SCOPE_VALUES in memory so they can be displayed the way user
	 * wants them in the layouts.
	 * @param factory SearchFormFactory.
	 */
	protected void AddSearchScopeOptions(SearchFormFactory factory)
	{
		NavigationModel navModel = TaskAPIUICommon.GetNavigationModel((AActivitySpace) GetEnvironment());

		// Set banner search settings.
		// Search dropdown
		boolean bIsCommPage = navModel.IsCommunityPage();
		boolean bIsDirPage  = navModel.IsDirPage();

		IXPList optionsList = new XPArrayList();
		HashtableDataObject htOption;
		
		if (bIsCommPage || bIsDirPage)
		{
			GetState().SetSharedVariable(SCOPE_NAME, factory.GetNextSelectName(), Scope.TAG, true);
			
			 htOption = new HashtableDataObject();
			 htOption.SetData(VALUE, "everything");
			 htOption.SetData(TEXT, GetEnvironment().GetString(344, "ptmsgs_portalcommonmsgs"));
			 optionsList.Add(htOption);
		} else {
			 GetState().SetSharedVariable(SCOPE_NAME, "", Scope.TAG, true);
		}
		
		if (bIsCommPage)
		{
			 htOption = new HashtableDataObject();
			 htOption.SetData(VALUE, "comm");
			 htOption.SetData(TEXT, GetEnvironment().GetString(345, "ptmsgs_portalcommonmsgs"));
			 optionsList.Add(htOption);			
		}
		else if (bIsDirPage)
		{
			 htOption = new HashtableDataObject();
			 htOption.SetData(VALUE, "allfold");
			 htOption.SetData(TEXT, GetEnvironment().GetString(346, "ptmsgs_portalcommonmsgs"));
			 optionsList.Add(htOption);		
			 
			 htOption = new HashtableDataObject();
			 htOption.SetData(VALUE, "thisfold");
			 htOption.SetData(TEXT, GetEnvironment().GetString(347, "ptmsgs_portalcommonmsgs"));
			 optionsList.Add(htOption);			
		}
		
		GetState().SetSharedVariable(SCOPE_VALUES, optionsList, Scope.TAG, true);
				
	}
	protected void AddSearchScopePulldownToElement(HTMLElement element, SearchFormFactory factory)
	{
    	NavigationModel navModel = TaskAPIUICommon.GetNavigationModel((AActivitySpace) GetEnvironment());

		// Set banner search settings.
		// Search dropdown
		boolean bIsCommPage = navModel.IsCommunityPage();
		boolean bIsDirPage  = navModel.IsDirPage();

		if (bIsCommPage || bIsDirPage)
		{
			HTMLSelect select = new HTMLSelect(factory.GetNextSelectName(), "");
			select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			HTMLOption option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("everything") );
			option.AddInnerHTMLString(GetEnvironment().GetString(344, "ptmsgs_portalcommonmsgs"));

			if (bIsCommPage)
			{
				option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("comm") );
				option.AddInnerHTMLString(GetEnvironment().GetString(345, "ptmsgs_portalcommonmsgs"));
			}
			else if (bIsDirPage)
			{
				option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("allfold") );
				option.AddInnerHTMLString(GetEnvironment().GetString(346, "ptmsgs_portalcommonmsgs"));

				option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("thisfold") );
				option.AddInnerHTMLString(GetEnvironment().GetString(347, "ptmsgs_portalcommonmsgs"));
			}

			element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			element.AddInnerHTMLElement(select);
		}
	}
	
	protected void AddSearchTextBoxToElement(HTMLElement element, SearchFormFactory factory)
	{
		// RT - Turning off the name validation for this Search input, since Search Form
		// appends query parameter to the action url and we want it to look friendly like 
		// http://protalurl/searchkeyword?q=searchstring
		
		HTMLInput textBox = new HTMLInput(HTMLInputTypes.TEXT_TYPE, "");

		// If friendly url for search is on, then we skip validation of Input Name because
		boolean bUseFriendlySearch = TaskAPIUICommon.UseFriendlyURLS(FriendlyURLConstants.FRIENDLY_SEARCH_ID, "");
		if(bUseFriendlySearch ) {
			textBox.SetValidateName(false);
		}		

		textBox.SetName(factory.GetInputBoxName());
		
		textBox.SetStyleClass(PTStyleClass.FORM_TEXTBOX_TEXT);
		textBox.SetSize(20);
		textBox.SetMaxLength(200);

		// Only set keydown if not in 508 mode
		if (GetEnvironment().GetAccessStyle() == AccessStyles.STANDARD)
		{
			String onKeyDown = factory.GetInputBoxOnKeyDown();
			if (onKeyDown != null) { textBox.SetOnKeyDown(onKeyDown); }
		}

		element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		element.AddInnerHTMLElement(textBox);
		element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}

	// TODO: Move this to common package
	protected static HTMLSpan CreateSpacerHTMLSpan(int pixelWidth)
    {
    	HTMLSpan span = new HTMLSpan();
    	span.SetStyleClass("spacer");
    	span.SetStyle("padding-left:" + pixelWidth + "px;");

    	return span;
    }

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return true;
	}

	/**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
    public ATag Create()
    {
        return new SearchFormTag();
    }
}