package com.plumtree.taglib.ptui;

import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

public class TopBestBetSearchButtonTag extends APTButtonTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
    public static final ITagMetaData TAG;
	public static final OptionalTagAttribute USE_SPAN;
	public static final RequiredParentTag PARENT;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("topbestbetsearchbutton",
			"This tag displays the top best bet search button. " );

		USE_SPAN = new OptionalTagAttribute(
			USE_SPAN_NAME, COMMON_PRE_USE_SPAN_DESC + "of " +
			PTStyleID.PT_SEARCH_SUBMIT_BUTTON + " " + COMMON_POST_USE_SPAN_DESC,
			USE_SPAN_TYPE, USE_SPAN_DEFAULT);

		PARENT = new RequiredParentTag(SearchFormTag.TAG);
	}

    public HTMLElement DisplayTag()
    {
        HTMLElement result = new HTMLElementCollection();

        // DCD: This manages the Alt text for the button, "Top Best Bet"
        String strSearch = GetEnvironment().GetString(1866, "ptmsgs_portalbrowsingmsgs");

		// Full UI mode
		if (GetEnvironment().GetAccessStyle().equals(AccessStyles.STANDARD))
		{
		    // DCD: Add an anchor to submit TBB searches, which is blank (we use JavaScript)
		    HTMLAnchor anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

		    // DCD: Set the JavaScript for this button
			anchor.SetOnClick((String) GetStateVariable(SearchFormTag.TBB_ON_CLICK, Scope.TAG));

			// No text inside the link.
			AddContentToLink(anchor, null, strSearch);

			result = anchor;
		    
		}
		else
		// DCD: This is 508 mode
		{
		    // DCD: Add a blank anchor
		    HTMLAnchor anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		    
			// No text inside the link.
			AddContentToLink(anchor, null, strSearch);
		    result = anchor;
		}

		return AddSpanToFinalOutput(result, PTStyleID.PT_SEARCH_SUBMIT_BUTTON, null);
    }
    
    /**
     * @see com.plumtree.taglib.ptui.APTButtonTag#GetButtonImage(String)
     */
    public HTMLElement GetButtonImage(String _strAltText)
    {
		// DCD: Full UI mode
		if (GetEnvironment().GetAccessStyle().equals(AccessStyles.STANDARD))
		{
		    // DCD: This manages the Alt text for the button, "Top Best Bet" 
		    String sAltText = GetEnvironment().GetString(1866, "ptmsgs_portalbrowsingmsgs");
		    
		    PTConstruct searchButton = UIConstructFactory.GetConstruct(PTImageType.ACTION_TOPBESTBET_BUTTON,
					true, (AActivitySpace) GetEnvironment());
		    
			HTMLImg imgTBBButton = (HTMLImg) searchButton.GetHTMLElement();
			
			imgTBBButton.SetAlt(sAltText);
			imgTBBButton.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			imgTBBButton.SetBorder(CommonHTMLStrings.ZERO);

			return imgTBBButton;
		} else
		{
			// 508 UI mode
		    // DCD TODO: Probably give this a name for us to detect in the Top Best Bet control
		    
		    // DCD: This manages the Alt text for the button, "Top Best Bet"
	        String strSearch = GetEnvironment().GetString(1866, "ptmsgs_portalbrowsingmsgs");
	        
	        PTConstruct searchButton = UIConstructFactory.GetConstruct(PTImageType.ACTION_TOPBESTBET_BUTTON,
					true, (AActivitySpace) GetEnvironment());
	        HTMLImg imgTBBButton = (HTMLImg) searchButton.GetHTMLElement();
	        
	        String sRelativeImageURL = PTImageType.ACTION_TOPBESTBET_BUTTON.GetFileName();
	        String sImageServerBaseURL = TaskAPIUIPortalConfig.GetImageServerBaseURL((AActivitySpace)GetEnvironment());
	        
	        HTMLInput imgTBB = new HTMLInput(HTMLInputTypes.IMAGE, "in_im_tbb", strSearch);
		    		    
		    imgTBB.SetSrc(sImageServerBaseURL + sRelativeImageURL);
	        
		    imgTBB.SetValue(strSearch); 
		    imgTBB.SetAlt(strSearch);   
			return imgTBB;
		}
    }

	/**
	 * @see com.plumtree.taglib.ptui.APTUITag#GetUseSpanAttribute()
	 */
	public OptionalTagAttribute GetUseSpanAttribute()
	{
		return USE_SPAN;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return true;
	}

    /**
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
    public ATag Create()
    {
        return new TopBestBetSearchButtonTag();
    }
	
}
