using System;
using XPConvert=com.plumtree.openfoundation.util.XPConvert;
using XPHttpUtility=com.plumtree.openfoundation.web.XPHttpUtility;
using com.plumtree.openlog;
using BannerStartSearchControl=com.plumtree.portalpages.browsing.search.results.BannerStartSearchControl;
using SearchResultAS=com.plumtree.portalpages.browsing.search.results.SearchResultAS;
using FriendlyURLConstants=com.plumtree.portaluiinfrastructure.friendlyurl.FriendlyURLConstants;
using SearchFriendlyURLParser=com.plumtree.portaluiinfrastructure.friendlyurl.SearchFriendlyURLParser;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;
using StartSearchControl=com.plumtree.portaluiinfrastructure.search.StartSearchControl;
using PTConfigHelper=com.plumtree.portaluiinfrastructure.statichelpers.PTConfigHelper;
using PTDebugHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
using com.plumtree.portaluiinfrastructure.tags;
using CommonTagAttributeConstants=com.plumtree.portaluiinfrastructure.tags.common.CommonTagAttributeConstants;
using HashtableDataObject=com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using IPTSession=com.plumtree.server.IPTSession;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using ASConstants=com.plumtree.uiinfrastructure.activityspace.ASConstants;
using HTMLElement=com.plumtree.xpshared.htmlelements.HTMLElement;
using com.plumtree.openfoundation.util;
namespace com.plumtree.taglib.pathways
{
  /// <summary>
  /// This class implements the pathways.configdata tag. This tag can be used in any adaptive layout.
  /// It returns Pathways related configuration information that supports usage of the Pathways Tag
  /// Library. 
  /// </summary>
  /// <author>BobbyT</author>
  public class PathwaysConfigDataTag : ATag
  {
    private static OpenLogger logger = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PATHWAYS),
     "com.plumtree.taglib.pathways.PathwaysConfigDataTag");
    private const String TAG_NAME = "configdata";
    // Disabling storing of API version string because we don't have a need for it right now
    // and getting this info requires another trip to Pathways. Uncomment if we
    // do need it in the future.
    // public static final String API_VERSION      		= "apiversion";
    public const String IS_ENABLED = "isenabled";
    public const String API_WEBSERVICE_URL = "apiwebserviceurl";
    public const String NG_API_WEBSERVICE_URL = "nongatewayedapiwebserviceurl";
    // This is the prefix Search URL that are used for generating the HREF's for tags
    // displayed in Search Results and the Tag Cloud. The reason that we do not generate
    // the full URL's in the tag is because the adaptive layouts can regenerate UI/update the DOM
    // (i.e. user renames a tag) and we would need this prefix to recreate the search
    // links.
    public static readonly String TAG_SEARCH_URL_PREFIX = PathwaysConstants.SEARCH_URL_PREFIX;
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    public static readonly String DATATAG_DESCRIPTION = ATag.EncodeForTagDoc("Generates Pathways configuration data and stores it in memory " + "using the variable name specified by the " + "<code>" + CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. " + "Each result is a DataObject with the following variables:<br/>" + "<ul>" + 
    // "<li> <code>" + API_VERSION + "</code> - The version of the Pathways Rest API being used.</li>" +
    "<li> <code>" + IS_ENABLED + "</code> - Whether Pathways is currently enabled or disabled.</li>" + "<li> <code>" + API_WEBSERVICE_URL + "</code> - The base URL to the Pathways REST API webservice used to make api calls. Returns empty string if Pathways is disabled.</li>" + "<li> <code>" + NG_API_WEBSERVICE_URL + "</code> - The non-gatewayed base URL to the Pathways REST API webservice used to make api calls. Returns empty string if Pathways is disabled.</li>" + "<li> <code>" + TAG_SEARCH_URL_PREFIX + "</code> - The search URL prefix for tag search click-throughs used for generated tag links.</li>" + "</ul>" + "Use tags from the Logic library to iterate over the list and display results.");
    static PathwaysConfigDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, DATATAG_DESCRIPTION);
      ATTRIB_ID = new RequiredTagAttribute("id", CommonTagAttributeConstants.ATTRIB_ID_DESC,
       AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute("scope", CommonTagAttributeConstants.ATTRIB_SCOPE_DESC,
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new PathwaysConfigDataTag();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      IPTSession session = (IPTSession) space.GetUserSession();
      IPathwaysRestAPIService service = PathwaysRestAPIService.GetInstance(space);
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      bool bUseFriendlySearch = PTConfigService.getPTInstance().UseFriendlyURLS(FriendlyURLConstants.FRIENDLY_SEARCH_ID,
       "");
      IPathwaysHelper pathwaysHelper = PathwaysHelperService.GetInstance();
      bool isLegacySearchMode = pathwaysHelper.GetLegacySearchMode();
      bool isPathwaysError = pathwaysHelper.IsErrorState();
      bool isUsingPathways = false;
      //we are checking to make sure pathways is enabled, pathways error did not occur, and the fall back mode is
      //not true (meaning advanced search didn't execute a legacy search).
      if (service.IsPathwaysEnabled() && !isPathwaysError && !isLegacySearchMode)
      {
        //setting pathways enabled to true here b/c all cases check out
        isUsingPathways = true;
      } else
      {
        //setting pathways enabled to false here so the data tag defaults to a legacy search
        //this is simpler in code to use and store in tag memory
        isUsingPathways = false;
      }
      if (isUsingPathways)
      {
        HashtableDataObject htObject = new HashtableDataObject();
        // Generate tag query click-throughs.
        String strSearchHref = PTConfigHelper.GetMainServerApplicationURL(false);
        if (XPStringUtility.EndsWith(strSearchHref, "?"))
        {
          strSearchHref = XPStringUtility.Substring(strSearchHref, 0, strSearchHref.Length - 1);
          }
        if (bUseFriendlySearch)
        {
          // Run a Pathways Query by tagname using Friendly Search URL.
          // The actual tag value will get appended in the adaptive layout to form the full search URL.
          strSearchHref = strSearchHref + "/" + SearchFriendlyURLParser.SEARCH_FRIENDLY_URL_KEYWORD + "?" + SearchFriendlyURLParser.TAG_SEARCH_QS + "=";
          } else
        {
          // Search Friendly URLs disabled, generate non-friendly URLs.
          // The query prefix "tag:" tells Pathways Search to perform a tag specific search.
          // For friendly URLs this prefix is handled in the friendly URL processing.
          String pathwaysTagQueryPrefix = XPHttpUtility.UrlEncode(PathwaysConstants.TAG_QUERY_PREFIX,
           "utf-8");
          // The actual tag value will get appended in the adaptive layout to form the full search URL. 
          strSearchHref = strSearchHref + "?" + ASConstants.SPACENAME + "=" + SearchResultAS.STR_MVC_CLASS_NAME + "&" + ASConstants.CONTROL + "=" + BannerStartSearchControl.STR_MVC_CLASS_NAME + "&" + StartSearchControl.USER_QUERY + "=" + pathwaysTagQueryPrefix;
          }
        // Disabling storing of API version string because we don't have a need for it right now
        // and getting this info requires another trip to Pathways. Uncomment if we
        // do need it in the future.
        // htObject.SetData(API_VERSION, service.GetAPIVersion());
        htObject.SetData(IS_ENABLED, XPConvert.ToString(isUsingPathways));
        htObject.SetData(API_WEBSERVICE_URL, service.GetPathwaysAPIGatewayedURL(space,
         session));
        htObject.SetData(NG_API_WEBSERVICE_URL, service.GetPathwaysAPIBaseURL(session));
        htObject.SetData(TAG_SEARCH_URL_PREFIX, strSearchHref);
        // Add tag result list to memory
        GetState().SetSharedVariable(strDataReference, htObject, tagScope,
         true);
      } else
      {
        logger.Info("Pathways is either disabled or an error occurred with Pathways. You can either enable Pathways " + "access in Portal Settings or check the logs and resolve the Pathways issue.");
        HashtableDataObject htObject = new HashtableDataObject();
        htObject.SetData(IS_ENABLED, XPConvert.ToString(isUsingPathways));
        htObject.SetData(API_WEBSERVICE_URL, "");
        htObject.SetData(NG_API_WEBSERVICE_URL, "");
        htObject.SetData(TAG_SEARCH_URL_PREFIX, "");
        // Just add empty list to memory if Pathways is disabled.
        GetState().SetSharedVariable(strDataReference, htObject, tagScope,
         true);
      }
      return ProcessTagBody();
    }
  }
}