using System;
using com.plumtree.openfoundation.util;
using MockPathwaysRestAPIService=com.plumtree.portaluiinfrastructure.mock.restconsumerframework.pathways.MockPathwaysRestAPIService;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;
using Scope=com.plumtree.portaluiinfrastructure.tags.Scope;
using IDataObject=com.plumtree.portaluiinfrastructure.tags.data.IDataObject;
using DisplayTree=com.plumtree.portaluiinfrastructure.tags.displaytree.DisplayTree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using TagLibManager=com.plumtree.portaluiinfrastructure.tags.manager.TagLibManager;
using MockPTSession=com.plumtree.server.mock.core.MockPTSession;
using com.plumtree.taglib.pathways;
using HTMLElement=com.plumtree.xpshared.htmlelements.HTMLElement;
using Assert=junit.framework.Assert;
using TestCase=junit.framework.TestCase;
namespace com.plumtree.taglib.pathways.test
{
  /// <summary>
  /// Tests for the tagclouddata data tag.
  /// </summary>
  /// <author>BobbyT</author>
  public class TestTagCloudDataTag : TestCase
  {
    public MockEnvironment m_environment;
    public MockPTSession m_session;
    public const String EVERYONE_VIEW = "ev";
    public const String MY_VIEW = "my";
    private PathwaysTagRestData[] m_tagsData;
    public override void setUp()
    {
      base.setUp();
      m_environment = new MockEnvironment();
      // Create the mock PTSession, and set it in the mock Activity Space.
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      // Create the mock TabLib manager.
      MockTagLibManager tagLibs = new MockTagLibManager();
      TagLibManager.setTestInstance(tagLibs);
      // Add the pathways.tagclouddata tag.
      tagLibs.SetTag(new TagCloudDataTag(), TagCloudDataTag.TAG.GetName(),
       PathwaysTagLibraryData.LIBRARY.GetName());
    }
    // Test storing and retrieving of Tag Cloud data.
    public virtual void testTagCloudData()
    {
      try
      {
        XPArrayList listTagCloudResults = generateTagCloudData();
        Assert.assertEquals(3, listTagCloudResults.GetSize());
        // Test and compare fake Pathways Views data.
        for (int i = 0;i < listTagCloudResults.GetSize();i++)
        {
          IDataObject tagData = (IDataObject) listTagCloudResults.GetElement(i);
          Assert.assertEquals(m_tagsData[i].count, tagData.GetData(TagCloudDataTag.COUNT));
          Assert.assertEquals(m_tagsData[i].name, tagData.GetData(TagCloudDataTag.NAME));
          Assert.assertEquals(m_tagsData[i].normalizedCount, tagData.GetData(TagCloudDataTag.NORMALIZED_COUNT));
          }
      }
      catch (XPException e)
      {
        fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
        e.PrintStackTrace();
      }
    }
    private XPArrayList generateTagCloudData()
    {
      XPArrayList listTagCloudResults;
      // Initialize the MockPathwaysRestAPIService.
      MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
      m_tagsData = new PathwaysTagRestData[3];
      // Create some fake tag data in the mock service and use it for testing.
      m_tagsData[0] = new PathwaysTagRestData();
      m_tagsData[0].count = "1";
      m_tagsData[0].name = "Tag1";
      m_tagsData[0].normalizedCount = "1";
      m_tagsData[0].isAppliedByCurrentUser = "true";
      m_tagsData[1] = new PathwaysTagRestData();
      m_tagsData[1].count = "1";
      m_tagsData[1].name = "Tag2";
      m_tagsData[1].normalizedCount = "2";
      m_tagsData[1].isAppliedByCurrentUser = "false";
      m_tagsData[2] = new PathwaysTagRestData();
      m_tagsData[2].count = "3";
      m_tagsData[2].name = "Tag3";
      m_tagsData[2].normalizedCount = "3";
      m_tagsData[2].isAppliedByCurrentUser = "true";
      pathwaysService.SetTagCloud(EVERYONE_VIEW, m_tagsData);
      PathwaysRestAPIService.setTestInstance(pathwaysService);
      // Initialize Markup
      String tagCloudTagId = "tagcloudresults";
      XMLFragmentTestHelper pathwaysTagCloudDataTag = new XMLFragmentTestHelper(PathwaysTagLibraryData.LIBRARY.GetName(),
       TagCloudDataTag.TAG.GetName());
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_ID.GetName(),
       tagCloudTagId);
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      Object[][] markup = pathwaysTagCloudDataTag.ToArrayEntireFragment();
      // Process the tag
      HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       content.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      Object oTagCloudData = scopeData.GetElement("." + tagCloudTagId);
      if (oTagCloudData == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + tagCloudTagId + " set in tag memory");
        }
      listTagCloudResults = (XPArrayList) ((SharedStateVariable) oTagCloudData).GetValue();
      return listTagCloudResults;
    }
    // Test "tagcount" attribute to see if correct number of tags specified gets returned.
    public virtual void testTagCloudTagCount()
    {
      // Initialize the MockPathwaysRestAPIService.
      MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
      PathwaysTagRestData[] tagsData = new PathwaysTagRestData[10];
      // Create some fake tag data in the mock service and use it for testing.
      for (int i = 0;i < tagsData.Length;i++)
      {
        tagsData[i] = new PathwaysTagRestData();
        tagsData[i].count = "" + i;
        tagsData[i].name = "Tag" + i;
        tagsData[i].normalizedCount = "1";
        tagsData[i].isAppliedByCurrentUser = "true";
      }
      pathwaysService.SetTagCloud(EVERYONE_VIEW, tagsData);
      PathwaysRestAPIService.setTestInstance(pathwaysService);
      // Initialize Markup
      String tagCloudTagId = "tagcloudresults";
      String tagCount = "5";
      XMLFragmentTestHelper pathwaysTagCloudDataTag = new XMLFragmentTestHelper(PathwaysTagLibraryData.LIBRARY.GetName(),
       TagCloudDataTag.TAG.GetName());
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_ID.GetName(),
       tagCloudTagId);
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_TAGCOUNT.GetName(),
       tagCount);
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      Object[][] markup = pathwaysTagCloudDataTag.ToArrayEntireFragment();
      // Process the tag
      HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       content.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      Object oTagCloudData = scopeData.GetElement("." + tagCloudTagId);
      if (oTagCloudData == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + tagCloudTagId + " set in tag memory");
        }
      try
      {
        XPArrayList listTagCloudResults = (XPArrayList) ((SharedStateVariable) oTagCloudData).GetValue();
        Assert.assertEquals(5, listTagCloudResults.GetSize());
      }
      catch (XPException e)
      {
        fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
        e.PrintStackTrace();
      }
    }
    // Test "tagview" attribute to see if correct tag cloud specified by view gets returned.
    public virtual void testTagCloudTagView()
    {
      // Initialize the MockPathwaysRestAPIService.
      MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
      PathwaysTagRestData[] evTagCloud = new PathwaysTagRestData[10];
      PathwaysTagRestData[] myTagCloud = new PathwaysTagRestData[5];
      // Create fake tag cloud for Everyone View in the mock service and use it for testing.
      for (int i = 0;i < evTagCloud.Length;i++)
      {
        evTagCloud[i] = new PathwaysTagRestData();
        evTagCloud[i].count = "" + i;
        evTagCloud[i].name = "Tag" + i;
        evTagCloud[i].normalizedCount = "1";
        evTagCloud[i].isAppliedByCurrentUser = "true";
      }
      pathwaysService.SetTagCloud(EVERYONE_VIEW, evTagCloud);
      // Create fake tag cloud for My View in the mock service and use it for testing.
      for (int i = 0;i < myTagCloud.Length;i++)
      {
        myTagCloud[i] = new PathwaysTagRestData();
        myTagCloud[i].count = "" + i;
        myTagCloud[i].name = "Tag" + i;
        myTagCloud[i].normalizedCount = "1";
        myTagCloud[i].isAppliedByCurrentUser = "true";
      }
      pathwaysService.SetTagCloud(MY_VIEW, myTagCloud);
      PathwaysRestAPIService.setTestInstance(pathwaysService);
      // Initialize Markup
      String tagCloudTagId = "tagcloudresults";
      XMLFragmentTestHelper pathwaysTagCloudDataTag = new XMLFragmentTestHelper(PathwaysTagLibraryData.LIBRARY.GetName(),
       TagCloudDataTag.TAG.GetName());
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_ID.GetName(),
       tagCloudTagId);
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_TAGVIEW.GetName(),
       EVERYONE_VIEW);
      pathwaysTagCloudDataTag.AddPTAttribute(TagCloudDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      Object[][] markup = pathwaysTagCloudDataTag.ToArrayEntireFragment();
      // Process the tag
      HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       content.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      Object oTagCloudData = scopeData.GetElement("." + tagCloudTagId);
      if (oTagCloudData == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + tagCloudTagId + " set in tag memory");
        }
      try
      {
        XPArrayList listTagCloudResults = (XPArrayList) ((SharedStateVariable) oTagCloudData).GetValue();
        Assert.assertEquals(evTagCloud.Length, listTagCloudResults.GetSize());
        }
      catch (XPException e)
      {
        fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
        e.PrintStackTrace();
      }
    }
  }
}