using System;
using com.plumtree.openfoundation.util;
using MockPathwaysRestAPIService=com.plumtree.portaluiinfrastructure.mock.restconsumerframework.pathways.MockPathwaysRestAPIService;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;
using Scope=com.plumtree.portaluiinfrastructure.tags.Scope;
using IDataObject=com.plumtree.portaluiinfrastructure.tags.data.IDataObject;
using DisplayTree=com.plumtree.portaluiinfrastructure.tags.displaytree.DisplayTree;
using SharedStateVariable=com.plumtree.portaluiinfrastructure.tags.helper.SharedStateVariable;
using TagState=com.plumtree.portaluiinfrastructure.tags.helper.TagState;
using TagLibManager=com.plumtree.portaluiinfrastructure.tags.manager.TagLibManager;
using MockPTSession=com.plumtree.server.mock.core.MockPTSession;
using com.plumtree.taglib.pathways;
using HTMLElement=com.plumtree.xpshared.htmlelements.HTMLElement;
using Assert=junit.framework.Assert;
using TestCase=junit.framework.TestCase;
namespace com.plumtree.taglib.pathways.test
{
  /// <summary>
  /// Tests for the viewsdata data tag.
  /// </summary>
  /// <author>BobbyT</author>
  public class TestViewsDataTag : TestCase
  {
    public MockEnvironment m_environment;
    public MockPTSession m_session;
    public override void setUp()
    {
      base.setUp();
      m_environment = new MockEnvironment();
      // Create the mock PTSession, and set it in the mock Activity Space.
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      // Create the mock TabLib manager.
      MockTagLibManager tagLibs = new MockTagLibManager();
      TagLibManager.setTestInstance(tagLibs);
      // Add the pathways.viewsdata tag.
      tagLibs.SetTag(new ViewsDataTag(), ViewsDataTag.TAG.GetName(), PathwaysTagLibraryData.LIBRARY.GetName());
      }
    public virtual void testViewsData()
    {
      // Initialize the MockPathwaysRestAPIService.
      MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
      PathwaysViewsRestData[] viewsData = new PathwaysViewsRestData[3];
      String dateString = "10/6/08 4:53 PM";
      // Create some fake view data in the mock service and use it for testing.
      viewsData[0] = new PathwaysViewsRestData();
      viewsData[0].id = "my";
      viewsData[0].name = "My View";
      viewsData[0].lastModified = dateString;
      viewsData[1] = new PathwaysViewsRestData();
      viewsData[1].id = "ev";
      viewsData[1].name = "Everyone\'s View";
      viewsData[1].lastModified = dateString;
      viewsData[2] = new PathwaysViewsRestData();
      viewsData[2].id = "fv";
      viewsData[2].name = "Favorites View";
      viewsData[2].lastModified = dateString;
      pathwaysService.SetViews(viewsData);
      PathwaysRestAPIService.setTestInstance(pathwaysService);
      // Initialize Markup
      String viewsTagId = "views";
      XMLFragmentTestHelper pathwaysViewsDataTag = new XMLFragmentTestHelper(PathwaysTagLibraryData.LIBRARY.GetName(),
       ViewsDataTag.TAG.GetName());
      pathwaysViewsDataTag.AddPTAttribute(ViewsDataTag.ATTRIB_ID.GetName(),
       viewsTagId);
      pathwaysViewsDataTag.AddPTAttribute(ViewsDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      Object[][] markup = pathwaysViewsDataTag.ToArrayEntireFragment();
      // Process the tag
      HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       content.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      Object oViewsData = scopeData.GetElement("." + viewsTagId);
      if (oViewsData == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + viewsTagId + " set in tag memory");
        }
      try
      {
        XPArrayList listViews = (XPArrayList) ((SharedStateVariable) oViewsData).GetValue();
        Assert.assertEquals(3, listViews.GetSize());
        // Test and compare fake Pathways Views data.
        for (int i = 0;i < listViews.GetSize();i++)
        {
          IDataObject viewData = (IDataObject) listViews.GetElement(i);
          Assert.assertEquals(viewsData[i].id, viewData.GetData(ViewsDataTag.VIEW_ID));
          Assert.assertEquals(viewsData[i].name, viewData.GetData(ViewsDataTag.NAME));
          Assert.assertEquals(viewsData[i].lastModified, viewData.GetData(ViewsDataTag.LAST_MODIFIED));
          }
      }
      catch (XPException e)
      {
        fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
        e.PrintStackTrace();
      }
    }
  }
}