package com.plumtree.taglib.pathways.test;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.XPHttpUtility;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.helpers.PTConfigService;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.restconsumerframework.pathways.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.taglib.pathways.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

import junit.framework.*;

/**
 * Tests for the configdata data tag.
 * 
 * @author BobbyT
 */
public class TestPathwaysConfigDataTag extends TestCase 
{
	public MockEnvironment m_environment;
	public MockPTSession m_session; 
	MockPTConfigHelper m_ptConfigHelper;
	MockClassTypeDescManager m_classTypeDescManager;
	IApplication m_application;
	
	// Retrieving of Pathways API Version is currently disabled.
	//private String m_strAPIVersion = "Pathways REST API V.1.5";
	private boolean m_bPathwaysEnabled = true;
	private boolean m_bPathwaysDisabled = false;
	private String m_strPathwaysRestAPIGatewayedURL = "http://mock.base.com/PTARGS_0_0_0_0_0_0/http;//pathways.base.com/graffiti/api/";
	private String m_friendlyURLKey = "search";
	private String m_friendlyURLClassId = "-25";
	public static final String TAG_SEARCH_HREF_PREFIX = "/search?tag=";
	public static final String TAG_SEARCH_NONFRIENDLY_HREF_PREFIX = "?" + ASConstants.SPACENAME + "=" + SearchResultAS.STR_MVC_CLASS_NAME + "&" +
						ASConstants.CONTROL + "=" + BannerStartSearchControl.STR_MVC_CLASS_NAME + "&" +
						StartSearchControl.USER_QUERY + "=" + XPHttpUtility.UrlEncode(PathwaysConstants.TAG_QUERY_PREFIX, "utf-8");
		
	public void setUp() throws Exception
	{
		super.setUp();
		
		m_environment = new MockEnvironment();
   		// Create the mock PTSession, and set it in the mock Activity Space.
		m_session = new MockPTSession();
		m_environment.SetUserSession(m_session);	
		
		// Create the mock TabLib manager.
   		MockTagLibManager tagLibs = new MockTagLibManager();
   		TagLibManager.setTestInstance(tagLibs);
   		
   		// Add the pathways.configdata tag.
   		tagLibs.SetTag(new PathwaysConfigDataTag(), PathwaysConfigDataTag.TAG.GetName(), PathwaysTagLibraryData.LIBRARY.GetName());
	}

	/**
	 *  Test ConfigData with Search Friendly URLs enabled and Pathways is Enabled.
	 *  Tag Search Prefix should be in friendly URL format.
	 */
	public void testConfigData()
	{
   		// Setup Config Mapping so that Search Friendly URLs will be enabled.
		setupSearchFriendlyURLMapping(true);
		
		// Initialize the MockPathwaysRestAPIService and TaskAPI.
		MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
		// Retrieving of Pathways API Version is currently disabled.
		//pathwaysService.SetAPIVersion(m_strAPIVersion);
		pathwaysService.SetPathwaysEnabled(m_bPathwaysEnabled);
		PathwaysRestAPIService.setTestInstance(pathwaysService);		
		pathwaysService.SetPathwaysAPIGatewayedBaseURL(m_strPathwaysRestAPIGatewayedURL);
		
		try 
		{
			IDataObject configData = generateConfigData();
			
			// Test and compare fake Pathways Config data.
			// Retrieving of Pathways API Version is currently disabled.
			// Assert.assertEquals(m_strAPIVersion, configData.GetData(PathwaysConfigDataTag.API_VERSION));
			Assert.assertEquals(XPConvert.ToString(m_bPathwaysEnabled), configData.GetData(PathwaysConfigDataTag.IS_ENABLED));
			Assert.assertEquals(m_strPathwaysRestAPIGatewayedURL, configData.GetData(PathwaysConfigDataTag.API_WEBSERVICE_URL));
			Assert.assertEquals(TAG_SEARCH_HREF_PREFIX, configData.GetData(PathwaysConfigDataTag.TAG_SEARCH_URL_PREFIX));
		} catch (XPException e) {
			fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
			e.PrintStackTrace();
		}
	}	
	
	/**
	 *  Test ConfigData with Search Friendly URLs disabled and Pathways is Enabled.
	 *  Tag Search Prefix should be in non-friendly URL format.
	 */
	public void testConfigDataWithSearchFriendlyURLsDisabled()
	{
   		// Setup Config Mapping without Search Friendly URLs enabled.
		setupSearchFriendlyURLMapping(false);
		
		// Initialize the MockPathwaysRestAPIService and TaskAPI.
		MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
		// Retrieving of Pathways API Version is currently disabled.
		//pathwaysService.SetAPIVersion(m_strAPIVersion);
		pathwaysService.SetPathwaysEnabled(m_bPathwaysEnabled);
		PathwaysRestAPIService.setTestInstance(pathwaysService);		
		pathwaysService.SetPathwaysAPIGatewayedBaseURL(m_strPathwaysRestAPIGatewayedURL);
		
		try 
		{
			IDataObject configData = generateConfigData();
			
			// Test and compare fake Pathways Config data.
			// Retrieving of Pathways API Version is currently disabled.
			// Assert.assertEquals(m_strAPIVersion, configData.GetData(PathwaysConfigDataTag.API_VERSION));
			Assert.assertEquals(XPConvert.ToString(m_bPathwaysEnabled), configData.GetData(PathwaysConfigDataTag.IS_ENABLED));
			Assert.assertEquals(m_strPathwaysRestAPIGatewayedURL, configData.GetData(PathwaysConfigDataTag.API_WEBSERVICE_URL));
			Assert.assertEquals(TAG_SEARCH_NONFRIENDLY_HREF_PREFIX, configData.GetData(PathwaysConfigDataTag.TAG_SEARCH_URL_PREFIX));
		} catch (XPException e) {
			fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
			e.PrintStackTrace();
		}
	}
	
	/**
	 *  Test ConfigData with Search Friendly URLs enabled and Pathways is disabled.
	 *  Config data should have all empty values since Pathways is disabled.
	 */
	public void testConfigDataWithPathwaysDisabled()
	{
		// Initialize the MockPathwaysRestAPIService and TaskAPI.
		MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
		// Retrieving of Pathways API Version is currently disabled.
		//pathwaysService.SetAPIVersion(m_strAPIVersion);
		pathwaysService.SetPathwaysEnabled(m_bPathwaysDisabled);
		PathwaysRestAPIService.setTestInstance(pathwaysService);		
		pathwaysService.SetPathwaysAPIGatewayedBaseURL(m_strPathwaysRestAPIGatewayedURL);
		
		try 
		{
			IDataObject configData = generateConfigData();
			
			// Test and compare fake Pathways Config data.
			// Retrieving of Pathways API Version is currently disabled.
			// Assert.assertEquals(m_strAPIVersion, configData.GetData(PathwaysConfigDataTag.API_VERSION));
			Assert.assertEquals(XPConvert.ToString(m_bPathwaysDisabled), configData.GetData(PathwaysConfigDataTag.IS_ENABLED));
			Assert.assertEquals("", configData.GetData(PathwaysConfigDataTag.API_WEBSERVICE_URL));
			Assert.assertEquals("", configData.GetData(PathwaysConfigDataTag.TAG_SEARCH_URL_PREFIX));
		} catch (XPException e) {
			fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
			e.PrintStackTrace();
		}
	}
	
	/**
	 *  This helper method sets up the Friendly URL mappings to enable or disable Search Friendly URLs
	 *  @param bSearchFriendlyURLsEnabled true if Search Friendly URLs should be enabled, false otherwise.
	 */
	private void setupSearchFriendlyURLMapping(boolean bSearchFriendlyURLsEnabled)
	{
   		// Setup Config Mapping without Search Friendly URLs enabled.
		m_ptConfigHelper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_ptConfigHelper);
		m_classTypeDescManager = new MockClassTypeDescManager();
		XPHashtable mapping = new XPHashtable();
		if (bSearchFriendlyURLsEnabled)
		{
			mapping.PutElement(m_friendlyURLClassId, m_friendlyURLKey);
		}
		m_classTypeDescManager.SetFriendlyURLLookupTable(mapping);

		m_application = new Application("","");
		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), m_application);
		m_application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, m_classTypeDescManager);
	}
	
	private IDataObject generateConfigData()
	{
		IDataObject configData;
		
		// Initialize Markup
		String configTagId = "pathwaysconfig";
		
		XMLFragmentTestHelper pathwaysConfigDataTag =
			new XMLFragmentTestHelper(PathwaysTagLibraryData.LIBRARY.GetName(),
					PathwaysConfigDataTag.TAG.GetName());
		pathwaysConfigDataTag.AddPTAttribute(PathwaysConfigDataTag.ATTRIB_ID.GetName(), configTagId);
		pathwaysConfigDataTag.AddPTAttribute(PathwaysConfigDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST+"");
		
		Object[][] markup = pathwaysConfigDataTag.ToArrayEntireFragment();
		
		// Process the tag
		HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
		
   		Assert.assertEquals("Checking that data tag didn't output any HTML.",
   				content.GetDisplayString(), "");
   		
		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);	
		
		Object oConfigData = scopeData.GetElement("."+configTagId);
		if(oConfigData == null)
		{
			XPSystem.Out.WriteLine("Output of processed markup:");
			XPSystem.Out.WriteLine(content.GetDisplayString());
			fail("Did not find expected tag variable with id "+configTagId+" set in tag memory");
		}
		
		configData = (IDataObject)((SharedStateVariable)oConfigData).GetValue();
		return configData;
	}
}
