/*
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.utils;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.navtags
{
  /// <summary>
  /// Implementation of the ddmenusimpletabs tag
  /// Add the mandatory tabs array
  /// </summary>
  public class PTDDMenuTabIterator : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    
    /// <summary>
    /// This attribute value is used as a reference to retrieve an IXPList of PTURL entries from a Tag scope *
    /// </summary>
    public static readonly RequiredTagAttribute DATAVAR;
    public static readonly RequiredTagAttribute CONTAINERVAR;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    static PTDDMenuTabIterator()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("ddmenusimpletabs", "Data tag for ddmenurowcontainertag to display a list of simple tabs for the set of provided data. <![CDATA[<p>]]> " + "A simple tab is a menu button that looks the same as dropdown menu tabs but instead of opening a dropdown menu on mouse-click, " + "navigates to an URL specified by PTURL DO data. <![CDATA[<p>]]>" + "This tag is also a type of data tag in itself, even though it consumes other data tags. " + "The data set by this tag is very specialized, unlike the Data tags (ptdata) which are general, " + "and it is only meant to be used with the ddmenurowcontainer display tag or a tag that is functionally very similar to it.<![CDATA[<p>]]> " + "As a data tag, this tag does not do display anything; it must be used in conjunction with a display tag.");
      DATAVAR = new RequiredTagAttribute("datavar", "The ID of the PTURL data tag or a collection of PTURL data tags to list as simple tabs.",
       AttributeType.STRING);
      CONTAINERVAR = new RequiredTagAttribute("containervar", "ID to associate this tab with a container. The value of the ID should be the value of the menuvar attribute defined in the container tag.",
       AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute("scope", "The scope used to get the data, " + Scope.PORTLET_REQUEST + " by default. See the description of this tag library " + "for a list of available scopes. ",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    
    /// <summary>
    /// Helper object for getting PTURL data *
    /// </summary>
    internal TagDataGetterPTURLDOList m_URLGetter = new TagDataGetterPTURLDOList(Scope.PORTLET_REQUEST);
    public const String MARKER_TABHTML = "tabhtml";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      // Set up the variables that child tags will use
      GetState().SetVariable(MARKER_TABHTML, null, Scope.TAG);
      // process child tags
      HTMLElement body = this.ProcessTagBody();
      // generate html/javascript for menu entries
      GenerateDataVars(body);
      // process tab html
      GenerateTabHTML(body);
      return null;
    }
    
    /// <summary>
    /// do this later
    /// </summary>
    /// <param name="result"></param>
    protected virtual void GenerateTabHTML(HTMLElement result)
    {
      Object tabHTML = GetState().GetVariable(MARKER_TABHTML, Scope.TAG);
      if (null == tabHTML)
      {
      } else
      // use default
      {
      }
    }
    // use html specified by marker
    protected virtual void GenerateDataVars(HTMLElement result)
    {
      String strDataRef = GetTagAttributeAsString(DATAVAR);
      IXPList lURLs = m_URLGetter.GetMemoryData(GetState(), strDataRef);
      // process the data vars, create the javascrdipt arrays
      if (lURLs == null || lURLs.GetSize() == 0)
      {
        // Don't need to add anything if the data array doesn't contain anything
        return;
      }
      // Get the name of the list to store the list
      String strListName = GetTagAttributeAsString(CONTAINERVAR);
      // Get the list
      Object list = GetState().GetVariable(strListName, Scope.PORTLET_REQUEST);
      // Create a new list if one does not exist already and put it on the request scope
      if (null == list)
      {
        list = new PTListMap();
        GetState().SetVariable(strListName, list, Scope.PORTLET_REQUEST);
        }
      PTListMap ltList = (PTListMap) list;
      String strTabTitle = null;
      IPTURL url = null;
      String strTabURL = null;
      // Add a tab for each URL in the list
      for (int i = 0;i < lURLs.GetSize();i++)
      {
        try
        {
          url = (IPTURL) lURLs.GetElement(i);
          if (null == url)
          {
            continue;
          }
          strTabTitle = url.GetData(PTURLConstants.KEY_TITLE);
          strTabURL = url.GetFullURL();
        }
        catch (Exception e)
        {
          XPException.GetInstance("Unable to retrieve URL data, the URL object is invalid.",
           e);
        }
        int nIndex = ltList.AddNewElement();
        ltList.AddElementToIndex(nIndex, PTDDMenuRowContainerTag.DATAVARNAME_SIMPLETABFLAG,
         "");
        ltList.AddElementToIndex(nIndex, PTDDMenuRowContainerTag.DATAVARNAME_TITLE,
         strTabTitle);
        ltList.AddElementToIndex(nIndex, PTDDMenuRowContainerTag.DATAVARNAME_SIMPLETABURL,
         strTabURL);
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new PTDDMenuTabIterator();
    }
  }
}