using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.utils;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.navtags
{
  /// <summary>
  /// Implementation of the horizontalrowtab tag
  /// </summary>
  public class PTHorizontalMenuTabTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    
    /// <summary>
    /// This attribute value is used as a reference to retrieve an IXPList of PTURL entries from a Tag scope *
    /// </summary>
    public static readonly RequiredTagAttribute DATAVAR;
    // name of the container variable in memory
    public static readonly RequiredTagAttribute CONTAINERVAR;
    public static readonly RequiredTagAttribute TABTEXT;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    static PTHorizontalMenuTabTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("horizontalrowtab", "This tag defines a horizontal menu tab that activates on mouse-click " + "and displays a row of links, which are provided by PTURL DO data tags " + "through the datavar attribute. <![CDATA[<p>]]>" + "The HTML generated around and for each link in the row of links associated " + "with this tab can be customized by defining completely new HTML for each link " + "in the body of this tag. <![CDATA[<p>]]>" + "This tag is also a type of data tag in itself, even though it consumes other data tags. " + "The data set by this tag  is very specialized, unlike the Data tags (ptdata) which are general, " + "and only meant to be used with the horizontalrowcontainermenu display tag or a tag that is functionally very similar to it. <![CDATA[<p>]]>" + "As a data tag, this tag does not do anything useful by itself; it must be used in conjunction with a display tag.");
      DATAVAR = new RequiredTagAttribute("datavar", "The ID of the PTURL data tag or set of PTURL data tags to list as links. " + "The HTML for the data set can be completely customized by specifying the " + "HTML to use on the data in the body of this tag.",
       AttributeType.STRING);
      CONTAINERVAR = new RequiredTagAttribute("containervar", "ID to associate this tab with a container.  " + "The value of the ID should be the value of the menuvar attribute defined in the container tag.",
       AttributeType.STRING);
      TABTEXT = new RequiredTagAttribute("text", "The text displayed on the tab.",
       AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute("scope", "The scope used to get the data, " + Scope.PORTLET_REQUEST + " by default. See the description of this tag library " + "for a list of available scopes. ",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    public const String MARKER_TABHTML = "tabhtml";
    
    /// <summary>
    /// Helper object for getting PTURL data *
    /// </summary>
    internal TagDataGetterPTURLDOList m_URLGetter = new TagDataGetterPTURLDOList(Scope.PORTLET_REQUEST);
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      // Set up the variables that child tags will use
      GetState().SetVariable(MARKER_TABHTML, null, Scope.TAG);
      // process child tags
      HTMLElement body = this.ProcessTagBody();
      // generate html/javascript for menu entries
      GenerateDataVars(body);
      return null;
    }
    protected virtual void GenerateDataVars(HTMLElement tagBody)
    {
      // If no html was specified, use default
      //HTMLScript script = GenerateMenuRow(tagBody);
      // Get the reference to the datalist from the attribute
      String strDataRef = GetTagAttributeAsString(DATAVAR);
      IXPList lURLs = m_URLGetter.GetMemoryData(GetState(), strDataRef);
      HTMLElement result = null;
      int nRowItems = 0;
      if (null == lURLs || lURLs.GetSize() == 0)
      {
        // Don't display anything if no data or invalid data
        return;
      } else
      if (null == tagBody)
      {
        result = GenerateDefaultRowTable(lURLs);
      } else
      {
        result = tagBody;
      }
      // get the title
      String strTabTitle = GetTagAttributeAsString(TABTEXT);
      // Get the name of the list to store the list
      String strListName = GetTagAttributeAsString(CONTAINERVAR);
      // Get the list to store the results in
      Object list = GetState().GetVariable(strListName, Scope.PORTLET_REQUEST);
      // Create a new list if one does not exist already and put it on the request scope
      if (null == list)
      {
        list = new PTListMap();
        GetState().SetVariable(strListName, list, Scope.PORTLET_REQUEST);
        }
      PTListMap ltMap = (PTListMap) list;
      // Add the generated javascript from this tab to the list
      // need tab title, row content
      // ptlisttable is a helper class to make adding/getting values for a 2d array easier
      int nIndex = ltMap.AddNewElement();
      ltMap.AddElementToIndex(nIndex, PTHorizontalMenuRowContainerTag.DATAVARNAME_TITLE,
       strTabTitle);
      ltMap.AddElementToIndex(nIndex, PTHorizontalMenuRowContainerTag.DATAVARNAME_ROWCONTENT,
       result);
    }
    
    /// <summary>
    /// Generates default HTML for menu content using the specified entries.
    /// </summary>
    /// <param name="lURLs"></param>
    /// <returns></returns>
    protected virtual HTMLElement GenerateDefaultRowTable(IXPList lURLs)
    {
      // Spacer image for padding
      HTMLImg image = null;
      image = TaskAPIUIHTML.GetSpacerImage("5", "1");
      // table containing single links item
      HTMLTable tTable = new HTMLTable();
      /*
       The HTML of the table is not displayed in a regular way.
       We get the HTML from the table as a string and put it to a javascript
       variable. The HTML will be written to the page dynamically with javascript.
       Set all these settings on the table element since we get the html from the
       table as a string
       */
       
      tTable.SetForceLineBreaksAfterSafeElements(false);
      tTable.SetImgBaseUrl(TaskAPIUIPortalConfig.GetImageServerBaseURL(TaskAPIUICommon.GetEnvTypeObject(GetEnvironment())));
      tTable.SetBorder(CommonHTMLStrings.ZERO);
      tTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      tTable.SetCellPadding(CommonHTMLStrings.ZERO);
      tTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      HTMLTableRow tRow = new HTMLTableRow();
      tRow.SetStyleClass(PTStyleClass.NAV_TABON_BG);
      tTable.AddInnerHTMLElement(tRow);
      // image in first cell
      HTMLTableCell tCell = new HTMLTableCell();
      tCell.AddInnerHTMLElement(image);
      tRow.AddInnerHTMLElement(tCell);
      // cell spawns the width of the page
      HTMLTableCell tSectionTabCell = new HTMLTableCell();
      tSectionTabCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      tSectionTabCell.SetHeight("20");
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.BREADCRUMB_TEXT);
      // Add the links
      span.AddInnerHTMLElement(GenerateRowContent(lURLs));
      tSectionTabCell.AddInnerHTMLElement(span);
      tRow.AddInnerHTMLElement(tSectionTabCell);
      return tTable;
    }
    
    /// <param name="lURLs"></param>
    /// <param name="result"></param>
    private HTMLElement GenerateRowContent(IXPList lURLs)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.SetForceLineBreaksAfterSafeElements(false);
      HTMLAnchor myAnchor;
      for (int i = 0;i < lURLs.GetSize();i++)
      {
        if (i != 0)
        {
          // Spacing between links
          result.AddInnerHTMLString(CommonHTMLStrings.SPACE + " |" + CommonHTMLStrings.SPACE);
          }
        IPTURL url = (IPTURL) lURLs.GetElement(i);
        if (url == null)
        {
          // Skip if the URL was null
          //@TODO MARTOK print out an error message
          continue;
        }
        String strURL = url.GetFullURL();
        String strLabel = url.GetData(PTURLConstants.KEY_TITLE);
        // Highlighting url - current page or community etc.
        // If URL is null, then don't make a link - just a string label
        if (url.GetData(PTURLConstants.KEY_CURRENTMARKER) != null)
        {
          String label = strLabel;
          result.AddInnerHTMLEncodedString(strLabel);
        } else
        {
          myAnchor = new HTMLAnchor(strURL);
          myAnchor.AddInnerHTMLString(strLabel);
          result.AddInnerHTMLElement(myAnchor);
        }
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new PTHorizontalMenuTabTag();
    }
  }
}