package com.plumtree.navtags;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.uiinfrastructure.utils.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the ddmenurowcontainer tag
 */
public class PTDDMenuRowContainerTag extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
		"com.plumtree.navtags.PTDDMenuRowContainerTag");
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute MENUSVAR;
	public static final OptionalTagAttribute HIDEEMPTYMENUS;
	public static final OptionalTagAttribute TITLETRUNCATIONWIDTH;
	/** dropdown menu tab tags **/
	public static final RelatedChildTag DDMENUTAB_TAG;
	/** simple menu tab tags **/
	public static final RelatedChildTag SIMPLEMENUTAB_TAG;
	
	public static final String MENU_EXAMPLE = 
		"<![CDATA[&lt;pt:plugnav.ddmenurowcontainer pt:menuvar=\"menu1\" &gt;]]><![CDATA[<br>]]>" +
		"<![CDATA[&lt;pt:plugnav.ddmenutab pt:containervar=\"menu1\" pt:datavar=\"menudata1\"/&gt;]]><![CDATA[<br>]]>" +
		"<![CDATA[&lt;pt:plugnav.ddmenusimpletabs pt:containervar=\"menu1\" pt:datavar=\"menudata2\" /&gt;]]><![CDATA[<br>]]>" +
		"<![CDATA[&lt;/pt:plugnav.ddmenurowcontainer&gt;]]><![CDATA[<br>]]>";

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("ddmenurowcontainer",
			"This tag displays rows of menu tabs. Menu tabs  have  fixed size and are wrapped to additional rows if there are too many tabs to fit in the browser window.<![CDATA[<p>]]>"+ 
			"This tag generates HTML and sets up the necessary javascript for the JSPortal DHTML dropdown menu framework.<![CDATA[<p>]]>"+
			"It manages the display and positioning of menu tabs, which activate dropdown menus, within the HTML it is located in. "+
			"To add menu tabs, define ddmenutabs (dropdown menus) or ddmenusimpletabs (just a menu button) with an ID and use that ID in the menuvar attribute.<![CDATA[<p>]]>"+
			"This tag is a display tag which only accepts ddmenutab, ddmenusimpletabs (both are available in this library) or equivalent data tags as data.",
			MENU_EXAMPLE);

		MENUSVAR = new RequiredTagAttribute("menuvar",
			"ID for this set of ddmenutabs or ddmenusimpletabs to display. ", 
			AttributeType.STRING);

		HIDEEMPTYMENUS = new OptionalTagAttribute("hideemptymenus",
		"Determines if tabs with no menu entries should be displayed. "+
		"For example, in a menu that list only communities or when a user "+
		"does not have access to any communities, do not display the tab at all. "+
		"Pass in false to disable, everything else to enable."+
		"", 
		AttributeType.BOOLEAN,
		"false");

		TITLETRUNCATIONWIDTH = new OptionalTagAttribute("titlewidth",
			"The maximum number of characters in the title to display before it is truncated. ",
			AttributeType.INT,
			"18");

		SIMPLEMENUTAB_TAG = new RelatedChildTag(PTDDMenuTabIterator.TAG);
		
		DDMENUTAB_TAG = new RelatedChildTag(PTDDMenuTabTag.TAG);
	}

	/** Javascript variable name constant */
	public static final String JSVARNAME_MANDTAB_ARRAY = "mandTabsArray";
	/** Javascript variable name constant */
	public static final String JSVARNAME_DDTABS_ARRAY = "PTDDMenuTabsArray";
	
	
		// Keys of values passed by the Tab tags
	public final static String DATAVARNAME_MENUTABFLAG = "menutab";
	public final static String DATAVARNAME_SIMPLETABFLAG = "simpletab";
	public final static String DATAVARNAME_TITLE = "title";
	public final static String DATAVARNAME_MENUARRAY = "menuarray";
	public final static String DATAVARNAME_SIMPLETABURL = "simpletaburl";
	
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		// TODO CR DLH: Why do we process this and then not do anything with it?
		HTMLElement body = this.ProcessTagBody();
		
		HTMLScriptCollection result = new HTMLScriptCollection();
		
		// RETRIEVE THE JAVASCRIPT ARRAYS FROM THE TABS, GET THE MENUS IN THIS CONTAINER

		// get the name of the request variable where the list of dropdown tab arrays are stored 
		String strMenuVariable = GetTagAttributeAsString(MENUSVAR);
		// get the list of dropdown tabs
		Object oMenus = GetState().GetVariable(strMenuVariable, Scope.PORTLET_REQUEST);
		if ( null == oMenus ) {
			log.Warn("Unable to find Tag Scope Menu variable: "+strMenuVariable);
			// TODO CR DLH: If this is null, shouldn't we do something?  Otherwise we'll
			// get an NPE later on.
		}
		PTListMap menucontentList = (PTListMap)oMenus;
		
		String strTabVariable = GetTagAttributeAsString(MENUSVAR);
		// get the list of dropdown tabs
		Object oTabs = GetState().GetVariable(strMenuVariable, Scope.PORTLET_REQUEST);
		if ( null == oTabs ) {
			log.Warn("Unable to find Tag Scope Tabs variable: "+strMenuVariable);
			// TODO CR DLH: If this is null, shouldn't we do something?  Otherwise we'll
			// get an NPE later on.
		}
		PTListMap tabsList = (PTListMap)oTabs;
		
		// Tabs with menus
		HTMLElement menucontent = GenerateTabs(menucontentList);
		result.AddInnerHTMLElement(menucontent);
			
		// Tab HTML
		 HTMLElement menuhtml = GenerateTabHTML(tabsList);
		result.AddInnerHTMLElement(menuhtml); 
		
		 // -------------------------------------------------
		 
		// get PTMenu.css location string	
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		
		String defaultStyleSheet = TaskAPIUIPortalConfig.GetImageServerBaseURL(TaskAPIUICommon.GetEnvTypeObject(GetEnvironment())) + 
																"common/private/js/jsportalmenus/" + ConfigHelper.GetJSIncluderComponentVersion(ConfigHelper.JSCOMPONENT_JSPORTALMENU) + "/styles/css/PTPMMenu.css";

		HTMLScript script = new HTMLScript("text/javaScript");
		result.AddInnerHTMLElement(script);
		
		// display the tabs
		script.AddInnerHTMLString("PTTagDDMenu.writePTDDMenuTabs(" + TaskAPIUIJavascript.GetSafeJSVariableWarn(GenerateUniqueIDString(JSVARNAME_DDTABS_ARRAY)) + ");\n");
		
		return result;
	}

	/**
	 * Create the js array for the tabs 
	 * 
	 * @param tabsList
	 * @return
	 */
	protected HTMLElement GenerateTabs(PTListMap tabsList)
	{
		HTMLScriptCollection result = new HTMLScriptCollection();
		result.SetForceLineBreaksAfterSafeElements(true);
		
		int nTruncationWidth = GetTagAttributeAsInt(TITLETRUNCATIONWIDTH);
		
		// One 2 dimensional array containing tabs data to display
		// For menu tabs:
		// element 0: Tab title
		// element 1: A javascript variable referencing the javascript array with menu entries
		//
		// For simple tabs:
		//
		// element 0: Tab title
		// element 1: Tab URL
		JS2DArrayBuilder arTabs = TaskAPIUIJavascript.GetJS2DArrayBuilder(4);
		for ( int i = 0; i < tabsList.GetSize(); i++ )
		{
			
			
			// Dropdown menu tabs
			if ( tabsList.GetElement(i, DATAVARNAME_MENUTABFLAG) != null )
			{
				String strVarName = GenerateUniqueIDString(""+i);
				String strTitle 	= tabsList.GetElementAsString(i, DATAVARNAME_TITLE);
				Object o 				= tabsList.GetElement(i, DATAVARNAME_MENUARRAY);
				String strTrimmedTitle = GeneralHelpers.TruncateLongString(strTitle, nTruncationWidth, false);
				
				// If the menu does not contain any items, display a tab or not display it at all?
				if ( null == o ) {
					if (GetTagAttributeAsBoolean(HIDEEMPTYMENUS)  ) {
						continue;
					}	else {
						o = "[  ]";
					}
						
				}
	
				// Add the array of menu entries for the dropdown tab
				String strArray =(String)o;
				HTMLScript script = TaskAPIUIJavascript.AddSafeJSVariable("DataAR"+strVarName, strArray.trim());
				result.AddInnerHTMLElement(  script  );
				
				// Add a menu tab entry
				arTabs.AddNewElement();
				arTabs.SetColumnStringValue(0, "menutab");
				arTabs.SetColumnStringValue(1, strTrimmedTitle);
				arTabs.SetColumnStringValue(2, strVarName);
				arTabs.SetColumnStringValue(3, strTitle);
			}
			// Simple tabs
			else
			{
				String strTitle 	= tabsList.GetElementAsString(i, DATAVARNAME_TITLE);
				String strURL	= tabsList.GetElementAsString(i, DATAVARNAME_SIMPLETABURL);
				String strTrimmedTitle = GeneralHelpers.TruncateLongString(strTitle, nTruncationWidth, false);
				
				// Add a simple tab entry
				arTabs.AddNewElement();
				arTabs.SetColumnStringValue(0, "simpletab");
				arTabs.SetColumnStringValue(1, strTrimmedTitle);
				arTabs.SetColumnStringValue(2, strURL);
				arTabs.SetColumnStringValue(3, strTitle);
				
			}
		}
		HTMLScript script2 = TaskAPIUIJavascript.AddSafeJSVariable(GenerateUniqueIDString(JSVARNAME_DDTABS_ARRAY), arTabs.ToString());
		result.AddInnerHTMLElement(script2);
		
		return result;
	}
	
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()
	 */
	public HTMLScriptCollection DisplaySharedJavascript()
	{
		IEnvironment env = GetEnvironment();
		
		HTMLScriptCollection result = new HTMLScriptCollection(); 
		
		
		// @TODO MARTOK Get this from the clientside JS API
		String strPathToImageServer =TaskAPIUIPortalConfig.GetImageServerBaseURL(TaskAPIUICommon.GetEnvTypeObject(env));;

			// include jsportalmenus js files
		XPLocale locale = TaskAPIUIUser.GetPersonalSettingsLocale(TaskAPIUICommon.GetEnvTypeObject(env));
		
		result.AddInnerHTMLElement( TaskAPIUIJavascript.GenerateJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTALMENU, locale, TaskAPIUICommon.GetEnvTypeObject(env)) );
		
		
		String strPortalImageServerJavaScriptURL = TaskAPIUIPortalConfig.GetPortalImageServerJavaScriptURL(TaskAPIUICommon.GetEnvTypeObject(env));
		
		// Include for js portal menu engine js functions
		HTMLScript jspmScript = new HTMLScript( HTMLScript.TYPE_JAVASCRIPT);
		jspmScript.SetSrc(strPortalImageServerJavaScriptURL + "tagnavjsportalmenufuncs.js");
		result.AddInnerHTMLElement(jspmScript);

		// Send down localized string down to js for image alts in dynamic generated html
		HTMLScript scriptMenu = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		String imgAlt = env.GetString(673, ResourceConstants.PORTALCOMMONMSGS);
		scriptMenu.AddInnerHTMLString("var gNavTabDownArrowImageAlt = '"+ imgAlt +"';");
		result.AddInnerHTMLElement(scriptMenu);
		
		HTMLScript otherscript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		// @TODO MARTOK is this a good place for this?
		// @TODO MARTOK Get this from the clientside JS API
		otherscript.AddInnerHTMLString("document.PCC.RegisterForWindowEvent(\"onload\", \"gbPageLoaded = true;\" \n);");
		otherscript.AddInnerHTMLString("var strPathToImageServer = \""+strPathToImageServer +"\""); 
		result.AddInnerHTMLElement(otherscript);
		
		return result;
	}
	
	/**
	 * 
	 * @param tabsList
	 * @return
	 */
	protected HTMLElement GenerateTabHTML(PTListMap tabsList)
	{
		return null;
	}
	
	

	protected String GenerateUniqueIDString(String strName)
	{
		return strName+"Tag"+GetUniqueID();
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new PTDDMenuRowContainerTag();
	}

}
