/*
 */
package com.plumtree.navtags;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.utils.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the ddmenutab tag
 * 
 * 
 */
public class PTDDMenuTabTag extends ATag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	/** This attribute value is used as a reference to retrieve an IXPList of PTURL entries from a Tag scope **/
	public static final RequiredTagAttribute DATAVAR;
	public static final RequiredTagAttribute CONTAINERVAR;
	public static final RequiredTagAttribute TABTEXT;
	public static final OptionalTagAttribute ATTRIB_SCOPE;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("ddmenutab", 
			"This is a data tag for ddmenurowcontainertag to display a tab that activates a dropdown menu with entries provided by PTURL DO data.<![CDATA[<p>]]>"+
			"This tag is also a type of data tag in itself, even though it consumes other data tags. " +
			"The data set by this tag  is very specialized, unlike the Data tags (ptdata) which are general, "+
			"and is only only meant to be used with the ddmenurowcontainer display tag or a tag that is functionally very similar to it.<![CDATA[<p>]]>"+
			"As a data tag, this tag does not do anything useful by itself; it must be used in conjunction with a display tag.");

		DATAVAR = new RequiredTagAttribute("datavar",												
			"The ID of the PTURL data tag or set of PTURL data tags to list as entries in a dropdown menu.", 
			AttributeType.STRING);

		CONTAINERVAR = new RequiredTagAttribute("containervar",												
			"ID to associate this tab with a container. The value of the ID should be the value of the menuvar attribute defined in the container tag.", 
			AttributeType.STRING);

		TABTEXT = new RequiredTagAttribute("text",												
			"The text displayed on the tab.", 
			AttributeType.STRING);

		ATTRIB_SCOPE = new OptionalTagAttribute("scope",
			"The scope used to get the data, "+Scope.PORTLET_REQUEST+" by default. See the description of this tag library "+
			"for a list of available scopes. ",
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
	}

	/** Helper object for getting PTURL data **/
	TagDataGetterPTURLDOList m_URLGetter = new TagDataGetterPTURLDOList(Scope.PORTLET_REQUEST);
	
	public static final String MARKER_TABHTML = "tabhtml";
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		// Set up the variables that child tags will use
		GetState().SetVariable(MARKER_TABHTML, "", Scope.TAG);
		
		// process child tags
		HTMLElement body = this.ProcessTagBody();
			
		// generate html/javascript for menu entries
		GenerateDataVars(body);
		
		// process tab html
		GenerateTabHTML(body);
		
		return null;
	}

	/**
	 * do this later
	 * 
	 * @param result
	 */
	protected void GenerateTabHTML(HTMLElement result)
	{
//		Object tabHTML = GetState().GetVariable(MARKER_TABHTML, Scope.TAG);
//		if ( null == tabHTML) {
//			// use default
//		} else {
//			// use html specified by marker
//			
//		}
	}

	/**
	 * Generate HTML for the entries in the menu and put it into the memory with the name specified by the
	 * CONTAINERVAR attribute.
	 * 
	 * @param tagBody
	 */
	protected void GenerateDataVars(HTMLElement tagBody)
	{
		// If no html was specified, use default
		//HTMLScript script = GenerateMenuRow(tagBody);
		// Get the reference to the datalist from the attribute
		
		String strDataRef = GetTagAttributeAsString(DATAVAR);
		IXPList lURLs = m_URLGetter.GetMemoryData(GetState(), strDataRef);
		
		// String the javascript array.
		String result = null;
		if (  null != lURLs && lURLs.GetSize() != 0 ) {
			// we don't display empty dropdown menus
			if ( null == tagBody )
			{
				result = GenerateDefaultJSArrays(lURLs) ;
			} else {
				result =  tagBody.GetDisplayString().trim();
			}
		}
		
		// get the title
		String strTabTitle = GetTagAttributeAsString(TABTEXT);
		
		// Get the name of the list to store the list
		String strListName = GetTagAttributeAsString(CONTAINERVAR);
		// Get the list
		Object list = GetState().GetVariable(strListName, Scope.PORTLET_REQUEST);
		
		// Create a new list if one does not exist already and put it on the request scope
		if ( null ==  list ) {
			list = new PTListMap();
			GetState().SetVariable(strListName, list, Scope.PORTLET_REQUEST);
		}
		
		// Add the generated javascript from this tab to the list
		// need tab title, row content
		// ptlisttable is a helper class to make adding/getting values for a 2d array
		PTListMap ltList = (PTListMap)list;
		int nIndex = ltList.AddNewElement();
		ltList.AddElementToIndex(nIndex, PTDDMenuRowContainerTag.DATAVARNAME_MENUTABFLAG, "");
		ltList.AddElementToIndex(nIndex, PTDDMenuRowContainerTag.DATAVARNAME_TITLE, strTabTitle);
		ltList.AddElementToIndex(nIndex, PTDDMenuRowContainerTag.DATAVARNAME_MENUARRAY, result);
		
	}
	
	/**
	 * Generates default HTML for menu content using the specified entries.
	 * 
	 * @param lURLs
	 * @return
	 */
	protected String GenerateDefaultJSArrays(IXPList lURLs)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		result.SetForceLineBreaksAfterSafeElements(false);
		HTMLAnchor myAnchor;
		
		// col 0: link image
		// col 1: link image height
		// col 2: link title
		// col3: link url
		JS2DArrayBuilder arEntries = TaskAPIUIJavascript.GetJS2DArrayBuilder(4);
		for ( int i = 0; i < lURLs.GetSize(); i++ )
		{
			IPTURL url =  (IPTURL)lURLs.GetElement(i);
			if ( url != null )
			{
				String strImg 				= url.GetData(PTURLConstants.KEY_ICONIMG);
				String strImgWidth = url.GetData(PTURLConstants.KEY_ICONIMGWIDTH);
				String strTitle 				= url.GetData(PTURLConstants.KEY_TITLE);
				// null doesn't work since the javascript array entry will be empty
				String strURL 				= "";
				
				// Don't set URL for the current community.
				if  (url.GetData(PTURLConstants.KEY_CURRENTMARKER) == null )
				{
					strURL = url.GetFullURL();
					strURL = JSHelper.escapeJS(strURL);
				} else {
					strTitle = "<b>"+strTitle+"</b>";
				}
				
				arEntries.AddNewElement();
				arEntries.SetColumnStringValue(0, strImg);
				arEntries.SetColumnStringValue(1, strImgWidth);
				arEntries.SetColumnStringValue(2, strTitle);
				arEntries.SetColumnStringValue(3, strURL);
			}
		
		}
		return arEntries.ToString();
	}
	
	
	/**
	 */
	public ATag Create()
	{
		return new PTDDMenuTabTag();
	}

}
