/*
 */
package com.plumtree.navtags;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.uiinfrastructure.utils.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
/**
 * Implementation of the horizontalrowcontainermenu tag
 * 
 */
public class PTHorizontalMenuRowContainerTag extends ATag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData  TAG;
	// name of the container variable in memory
	public static final RequiredTagAttribute TABSVAR;
	// First level customization
	public static final OptionalTagAttribute TAB_IMGNAME;
	// Second level customization
	public static final OptionalTagAttribute STYLECLASS_TABON;
	public static final OptionalTagAttribute STYLECLASS_TABOFF;

	/** Define child tag relationships **/
	public static final RelatedChildTag TAB_TAGS;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("horizontalrowcontainermenu",
			"This tag generates HTML for dynamic horizontal menus - where the content of " +
			"a menu is displayed in a row shared by multiple tabs. <![CDATA[<p>]]>"+
			"In addition to generating the HTML for the tabs, it also defines necessary " +
			"javascript functions that are shared between multiple instances of this tag. "+
			"Customization of the generated tabs, such as custom stylesheets and images, are " +
			"supported through attributes. <![CDATA[<p>]]>"+
			"This tag is a display tag which only accepts horizontalrowtab or equivalent data tags as data.");

		TABSVAR = new RequiredTagAttribute("tabsvar",
			"The ID for this set of horizontal tabs. " +
			"A horizontalrowtab displayed in this container must define the CONTAINERVAR attribute as this ID.",
			AttributeType.STRING);

		TAB_IMGNAME = new OptionalTagAttribute("defaulttabicon",
			"An icon on the image server with path from the image base URL.  " +
			"For example, <![CDATA[<code>]]>portal/public/img/icon_community.gif<![CDATA[</code>]]>. "+
			"The default image is <![CDATA[<code>]]>icon_community.gif<![CDATA[</code>]]>. ", 
			AttributeType.STRING,
			"portal/public/img/icon_community.gif");

		STYLECLASS_TABON = new OptionalTagAttribute("tabonstyle",
			"The style class used on the active tab table cell ."+
			"Default style class is <![CDATA[<code>]]>NavTabOnBg<![CDATA[</code>]]>",
			AttributeType.STRING,
			"NavTabOnBg");

		STYLECLASS_TABOFF = new OptionalTagAttribute("taboffstyle",
			"The style class used on the unactivated tab table cell ."+
			"The default style class is <![CDATA[<code>]]>NavTabOffBg<![CDATA[</code>]]>",
			AttributeType.STRING,
			"NavTabOffBg");

		TAB_TAGS = new RelatedChildTag(PTHorizontalMenuTabTag.TAG);
	}

	// javascript function name
	public final static String JSFUNCNAME_ONTABCLICKHANDLER = "tagShowGroupsTabRow";

	
	// Keys of values passed by the Tab tags 
	public final static String DATAVARNAME_TITLE = "title";
	public final static String DATAVARNAME_ROWCONTENT = "rowcontent";
	public final static String DATAVARNAME_ITEMS = "rowitems";
	// Name of div
	private static final String	DIVCONTAINERNAME_ROWS	= "rowdivcontainer";
	
	private int m_nTabsAdded = 0;
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		HTMLElement body = this.ProcessTagBody();
		
		HTMLElementCollection result = new HTMLElementCollection();
		
		// get the name of the request variable where the list of dropdown tab arrays are stored 
		String strVariable = GetTagAttributeAsString(TABSVAR);
		// get the list of dropdown tabs
		Object oTabs = GetState().GetVariable(strVariable, Scope.PORTLET_REQUEST);
		if ( null == oTabs ) {
			// Don't do anything, no tabs to display 
			return null;
		}
		PTListMap tabsList = (PTListMap)oTabs;
		
		
		
		// GENERATE THE JAVASCRIPT ARRAYS, GET THE MENUS IN THIS CONTAINER
		HTMLElement tabcontent = GenerateRowContent(tabsList);
		result.AddInnerHTMLElement(tabcontent);
		
		 HTMLElement menuhtml = GenerateMenuHTML(tabsList);
		result.AddInnerHTMLElement(menuhtml); 
		
		return result;
	}
	

	protected String BuildRowID(int nIndex)
	{
		return GetUniqueID() + "TabID" + nIndex;
	}
	
	protected String BuildUniqueTagName(String strName)
	{
		return strName+GetUniqueID();
	}
	
	/**
	 * Generates HTML for each menu row.
	 * This method generates the HTML for each horizontal menu bar (row) and retrieves and inserts 
	 * the content (list of links) that is generated by the tab tags into the menu bar. 
	 * 
	 * @param tabsList
	 * @return
	 */
	protected HTMLElement GenerateRowContent(PTListMap tabsList)
	{
		HTMLScriptCollection result = new HTMLScriptCollection();
		
		for ( int i = 0; i < tabsList.GetSize(); i++ )
		{
			String strRowID = BuildRowID(i);
			String strTitle 	= tabsList.GetElementAsString(i, PTHorizontalMenuRowContainerTag.DATAVARNAME_TITLE);
			Object o 				= tabsList.GetElement(i, PTHorizontalMenuRowContainerTag.DATAVARNAME_ROWCONTENT);
			if ( null == o ) {
				o = new HTMLGenericElement("");
			}

			HTMLElement rowTable = (HTMLElement)o;
			HTMLScript script = TaskAPIUIJavascript.AddSafeJSStringVariable(strRowID,  rowTable.GetDisplayString().trim());
			result.AddInnerHTMLElement(  script  );
		}
		
		return result;
	}

	/**
	 * @TODO MARTOK a version with customized html?
	 * 
	 * @param tabsList
	 * @return
	 */
	protected HTMLElement GenerateMenuHTML(PTListMap tabsList)
	{
		IEnvironment env = GetEnvironment();
		
		HTMLElementCollection result = new HTMLElementCollection();
		
		// Setup the Tabs HTML
		HTMLTable table			    = new HTMLTable();
		
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		table.SetBorder(CommonHTMLStrings.ZERO);
		table.SetCellPadding(CommonHTMLStrings.ZERO);
		table.SetCellSpacing(CommonHTMLStrings.ZERO);

		HTMLTableRow tRow   = new HTMLTableRow();
		
		// For each Tab tag associated with this Menu, add a Tab
		for ( int i = 0; i < tabsList.GetSize(); i++ )
		{
			Object obj 				= tabsList.GetElement(i, PTHorizontalMenuRowContainerTag.DATAVARNAME_ROWCONTENT);
			if ( null == obj ) {
				// Don't display tab if the row did not contain any items
				continue;
			}
			String strTabTitle = tabsList.GetElementAsString(i, PTHorizontalMenuRowContainerTag.DATAVARNAME_TITLE);
			
			// This generates a unique ID for this Menu Tag, there might exists several instances of horizontal menu tags on a page.
			String strRowDivID = BuildRowID(i);
			// Add a Tab to the table row
			AddDefaultTabButton(tRow, strTabTitle,	strRowDivID);
		}
		if ( m_nTabsAdded == 0 ) {
			return null;
		}
		
		// Spacer cell to pad the row to the end of the page
		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		tCell.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
		tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		table.AddInnerHTMLElement(tRow);
		// Add the Tab HTML to the return result
		result.AddInnerHTMLElement(table);
		

		// The html container where the links table html is dynamically inserted
		// @TODO +++MARTOK Set a class for this DIV with a default height so the screen doesnt jump up and down when changing rows of different heights
		HTMLDiv rowdiv = new HTMLDiv();
		rowdiv.SetID(BuildUniqueTagName( DIVCONTAINERNAME_ROWS) );
		
		//		document.PCC.RegisterForWindowEvent(\"onload\", tagshowGroupsTabRowOnLoad); 
		//		function showGroupsTabRowOnLoad() {	tagshowGroupsTabRow(\"" + BuildRowID(0) + "\", \""+uniqueid+"\"); }
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		JSFunctionCallBuilder jsonloadcall = TaskAPIUIJavascript.GetJSFunctionCallBuilder("document.PCC.RegisterForWindowEvent");
		jsonloadcall.AddStringValueArgument("onload");
		jsonloadcall.AddVariableArgument(BuildUniqueTagName("tagShowGroupsTabRowOnLoad"));
		jsonloadcall.UseSemiColon();
		
		//String strJSFuncOnclickHandler  =  GetTagAttributeAsString(CUSTOM_ONCLICKHANDLER);
		JSFunctionCallBuilder onclickhandlercall = TaskAPIUIJavascript.GetJSFunctionCallBuilder(JSFUNCNAME_ONTABCLICKHANDLER);
		onclickhandlercall.AddStringValueArgument(BuildRowID(0));
		onclickhandlercall.AddStringValueArgument(GetUniqueID());
		onclickhandlercall.UseSemiColon();
		
		script.AddInnerHTMLString("\n"+jsonloadcall.ToString());
		script.AddInnerHTMLString("\n"+"function "+BuildUniqueTagName( "tagShowGroupsTabRowOnLoad")+"() {"+onclickhandlercall.ToString()+"}");
		
		// Make an array with all the tabs in this Horizontal Menu. We switch to the tab offstyle when clicking on a new tab
		JS1DArrayBuilder tabsArray = new JS1DArrayBuilder();
		for ( int i = 0; i < tabsList.GetSize(); i++ ) 
		{
			tabsArray.AddNewStringValueElement(BuildRowID(i));
		}
		result.AddInnerHTMLElement( TaskAPIUIJavascript.AddSafeJSVariable(BuildUniqueTagName("PTHorNavTabsArray"),tabsArray.ToString()) );
		
		result.AddInnerHTMLElement(rowdiv);
		result.AddInnerHTMLElement(script);
		
		return result;
	}
	
	/**
	 * Default tag html
	 * This function generates a clickable tab used to display a horizontal menu with links.
	 *
	 * @param tRow 						The HTMLTableRow where the generated Tab is added to 
	 * @param strName 					Tab display name
	 * @param toolTip					Tooltip for the tab					
	 * @param strRowDivID					HTML ID for the generated Div element with the html of the links
	 * 									to display when this tab is actived.
	 * @throws Exception 
	 */
	protected void AddDefaultTabButton(HTMLTableRow tRow, String strName,  String strRowDivID) 
	{
		IEnvironment env = GetEnvironment();
		 
		// Tab cell
		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		tCell.SetNoWrap(true);
		tCell.SetHeight("20");
		tCell.SetID("cell" + strRowDivID);
		String strStyleClass = GetTagAttributeAsString(STYLECLASS_TABOFF);
		tCell.SetStyleClass(new StyleClass(strStyleClass));

		
		// Extra quotes and double quotes to solve javascript string issue
		// Call the javascript function that will display the links when this tab is activated.
//		String strJSFuncOnclickHandler  =  GetTagAttributeAsString(CUSTOM_ONCLICKHANDLER);
		JSFunctionCallBuilder jscall = TaskAPIUIJavascript.GetJSFunctionCallBuilder(JSFUNCNAME_ONTABCLICKHANDLER);
		jscall.AddStringValueArgumentUsingSingleQuotes(strRowDivID);
		jscall.AddStringValueArgumentUsingSingleQuotes(GetUniqueID());
		jscall.UseSemiColon();
		 
		tCell.SetOnClick(jscall.ToString()+" return false;");

		HTMLSpan span = new HTMLSpan();
		span.AddInnerHTMLString(CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);
		tCell.AddInnerHTMLElement(span);
		span.SetStyleClass(PTStyleClass.NAV_TAB_TEXT);

		// Community icon
		String strTabIcon = GetTagAttributeAsString(TAB_IMGNAME);
		HTMLImg tabImg  = new HTMLImg(strTabIcon, "");

		tabImg.SetBorder(CommonHTMLStrings.ZERO);
		tabImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		tabImg.SetAlt(strName);

		// Menu Arrow icon 		
		HTMLImg arrow = TaskAPIUIHTML.GetImageConstruct(TaskAPIUICommon.GetEnvTypeObject(env), PTImageType.ICON_ARROW_MENU);
		
		arrow.SetBorder(CommonHTMLStrings.ZERO);
		arrow.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		arrow.SetAlt(strName);
		
		span.AddInnerHTMLElement(tabImg);
		span.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		span.AddInnerHTMLString(strName);
		span.AddInnerHTMLElement(arrow);

		// AddingSpacing between tabs
		TaskAPIUIHTML.CreateHorizontalSpacerCell(tRow);
		
		m_nTabsAdded++;
		
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()
	 */
	public HTMLScriptCollection DisplaySharedJavascript()
	{
		HTMLScriptCollection result = new HTMLScriptCollection();
		
		IEnvironment env = GetEnvironment();
		
		// @TODO MARTOK Get this from the clientside JS API
		String strPortalImageServerJavaScriptURL = TaskAPIUIPortalConfig.GetPortalImageServerJavaScriptURL(TaskAPIUICommon.GetEnvTypeObject(env));
		
		result.AddInnerHTMLElement(GetDefaultJavascript());
		
		return result;
		
	}
	
	protected HTMLScriptCollection GetDefaultJavascript()
	{
		XPStringBuilder buf = new XPStringBuilder();
		
		String strTabOffStyleclass = GetTagAttributeAsString(STYLECLASS_TABOFF);
		String strTabOnStyleclass = GetTagAttributeAsString(STYLECLASS_TABON);
		// Using default name for the onclick handler function
		buf.Append(
				"\nfunction "+JSFUNCNAME_ONTABCLICKHANDLER+"(strID, strUniqueID)\n"+
				"{\n"+
				  "deactivateAllTabs(strUniqueID);\n"+
				  "var oCell = document.getElementById(\"cell\"+strID);\n"+
				  "oCell.className = \""+strTabOnStyleclass+"\"\n"+
				  "// Generate the links\n"+
				  "var oMenu = document.getElementById( \"rowdivcontainer\"+strUniqueID);\n"+
				  "var oText = getSafeVarWarn(strID);\n"+
				  "oMenu.innerHTML = \"\";\n"+
				  "oMenu.innerHTML= oText;\n"+
				"}\n"+	
				"function deactivateAllTabs(uniqueID)\n"+
				"{\n"+
				  "var tabsArray = getSafeVarWarn(\"PTHorNavTabsArray\"+uniqueID);\n"+
				  "for ( var i = 0; i < tabsArray.length; i++ ) {\n"+
				  "document.getElementById(\"cell\"+tabsArray[i]).className = \""+strTabOffStyleclass+"\";\n"+
				  "}\n"+
				"}\n"
			);
		
		HTMLScriptCollection result = new HTMLScriptCollection();
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.AddInnerHTMLString(buf.ToString());
		result.AddInnerHTMLElement(script);
		
		return result;
		
	}
	
		/*
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new PTHorizontalMenuRowContainerTag();
	}
}