using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.tags.metadata.legacy;
using com.plumtree.server;
using com.plumtree.server.impl.portlet.providers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard
{
  /// <summary>
  /// The tag instructs the gateway to include the CSAPI constructor on the
  /// current page.
  /// This tag is used by the Gateway Portlet Refresh Infrastructure and is
  /// generated in the Transformer.  Tag developers should not use this tag.
  /// </summary>
  public class AutoJSTransformTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    // Note: This uses a LegacyTagMetaData even though it is not a Legacy Tag.
    // This is because it is a private tag for the Gateway Portlet Refresh
    // Infrastructure and is generated in the Transformer.  Tag developers
    // should not use it, and therefore it should not be doc'ed.
    public static readonly ITagMetaData TAG;
    
    /// <summary>
    /// The cached javascript from an auto-generated tag. A shared variable. 
    /// </summary>
    private const String JAVASCRIPT_STATE_VARIABLE = "cachedJS";
    static AutoJSTransformTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new LegacyTagMetaData(AutoJSTransformTagConstants.TAG_NAME, "The tag instructs the gateway to include the CSAPI JavaScript includes " + "on the current page.  This tag is used by the Gateway Infrastructure " + "and is generated in the Transformer.  Tag developers should not use this tag.");
      }
    private const String PT_PORTLET_CONSTRUCTOR_FORMAT = "<script type=\"text/javascript\" >\r\n" + "pt_{0} = new PTPortlet(\'{1}\', \'{2}\', \'{3}\', \'{4}\', \'{5}\', \'{6}\', \'{7}\', \'{8}\', \'{9}\', \'{10}\');" + "</script>\r\n";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      // NOTE: If we are requesting content to use in refreshing a portlet,
      // then that content does not need the CSAPI includes, since the
      // surrounding page already has the includes.
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      if (XPStringUtility.CompareIgnoreCase(space.GetName(), GatewayAS.STR_MVC_CLASS_NAME) == 0)
      {
        GatewayModel gwModel = (GatewayModel) space.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
        if (gwModel.GetRefreshMode() > PlumtreeExtensibility.PT_REFRESH_NONE)
        {
          // This is a bit tricky. If we know we are in refresh mode,
          // we should NOT display anything, since CSAPI includes are
          // not necessary in refresh mode (parent page already has CSAPI
          // JS objects).
          return null;
        }
      }
      // Only display the csapi if we are not in 508 (no javascript) mode.
      if (AccessStyles.SECTION_508 != GetEnvironment().GetAccessStyle())
      {
        // NOTE: This assumes the auto-generated CSAPI tag is before
        // any possible user generated CSAPI tags.
        // If there are any attributes, assume that the full
        // CSAPI attribute set is present.
        if (GetTagAttributeNames().MoveNext())
        {
          // Includes jsxml javascript CSAPI constructor
          HTMLScriptCollection jsxmlScript = GetCSAPIConstructor();
          // Store the result so that a user placed tag can remove this
          // if they are trying to override our default placement.
          CacheJavaScript(jsxmlScript);
          if (GetTagAttribute(AutoJSTransformTagConstants.ATTR_MAIN_PAGE) != null)
          {
            // If we're on the main page, then the Head Preprocessor has
            // placed this tag in a specific location, and we should output
            // the JavaScript directly.
            return jsxmlScript;
          } else
          {
            // If we're not on a main page, add it to the shared js
            // so it will be displayed in the head.
            AddJavascript(jsxmlScript);
            return null;
          }
        }
      }
      return null;
    }
    
    /// <summary>
    /// This method constructs the actual JavaScript for the CSAPI constructor.
    /// </summary>
    public virtual HTMLScriptCollection GetCSAPIConstructor()
    {
      // NOTE: These attributes are not documented anywhere because there
      // is no need for documentation, since the tag is only auto-generated.
      String[] strArgs = new String[11];
      strArgs[0] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_OBJECT_ID);
      strArgs[1] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_OBJECT_ID);
      strArgs[2] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_PORTLET_UUID);
      strArgs[3] = PortletProviderConstants.escapeJS(GetTagAttribute(AutoJSTransformTagConstants.ATTR_PORTLET_NAME));
      strArgs[4] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_PORTLET_CONTAINER);
      strArgs[5] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_SERVER_SOURCE_URL);
      strArgs[6] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_SOURCE_URL);
      strArgs[7] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_GATEWAY_URI);
      strArgs[8] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_SECURE_GATEWAY_URI);
      strArgs[9] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_COLLAPSED);
      strArgs[10] = GetTagAttribute(AutoJSTransformTagConstants.ATTR_REFRESH_URL);
      String constructor = XPFormat.Format(PT_PORTLET_CONSTRUCTOR_FORMAT,
       strArgs);
      HTMLScriptCollection result = new HTMLScriptCollection();
      HTMLGenericElement script = new HTMLGenericElement(constructor);
      result.AddInnerHTMLElement(script);
      return result;
    }
    
    /// <summary>
    /// Cache the displayed javascript.
    /// </summary>
    /// <param name="_javaScript"></param>
    public virtual void CacheJavaScript(HTMLElement _javaScript)
    {
      XPArrayList cachedJavaScript = (XPArrayList) GetStateSharedVariable(JAVASCRIPT_STATE_VARIABLE,
       Scope.HTTP_REQUEST);
      if (cachedJavaScript == null)
      {
        cachedJavaScript = new XPArrayList();
        SetStateSharedVariable(JAVASCRIPT_STATE_VARIABLE, cachedJavaScript,
         Scope.HTTP_REQUEST, false);
      }
      cachedJavaScript.Add(_javaScript);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      //	Only display the csapi if we are not in 508 (no javascript) mode.
      if (AccessStyles.SECTION_508 == _style)
      {
        return false;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new AutoJSTransformTag();
    }
  }
}