using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard
{
  /// <summary>
  /// The choose, when and otherwise tags allow you to insert
  /// content on a page based on conditional statements of user
  /// and group membership. The choose tag denotes the start of a
  /// secured content section, and the when tags include a test
  /// condition that defines who has access to the enclosed content.
  /// The otherwise tags include content that should be displayed
  /// as default.
  /// </summary>
  public class ChooseTag : ATag
  {
    public const String CHOOSE_DESCRIPTION = "The choose, when and otherwise tags allow you to insert " + "content on a page based on conditional statements of user " + "and group membership. The choose tag denotes the start of a " + "secured content section, and the when tags include a test " + "condition that defines who has access to the enclosed content. " + "The otherwise tags includes content that should be displayed as " + "default.  The only valid options for the test condition are " + "stringToAclGroup(...).isMember($currentuser) and isGuest($currentuser). " + "The logic.if tag can also be used to create conditional content.";
    public const String CHOOSE_EXAMPLE_SYNTAX = "The syntax is as follows: <![CDATA[<p>]]>" + 
    // Sample 1
    "<![CDATA[&lt;pt:standard.choose&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.when pt:test=\"stringToACLGroup(\'user=userid1,userid2,...;group=groupid1,groupid2,groupid3;\').isMember($currentuser)\"&gt;]]><![CDATA[<br>]]>" + "    ... content ...<![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.when&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.otherwise&gt;]]> <![CDATA[<br>]]>" + "    ... default content ...<![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.otherwise&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.choose&gt;]]> <![CDATA[<p>]]>" + "The value for the pt:test attribute is case-sensitive. " + "Multiple users or groups should be separated by commas, " + "with semi-colons separating user values from group values. <![CDATA[<p>]]>";
    public const String CHOOSE_EXAMPLE_1 = "Example 1: <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.choose&gt;]]><![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.when pt:test=\"isGuest($currentuser)\"&gt;]]><![CDATA[<br>]]>" + "    ... guest user content ...<![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.when&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.otherwise&gt;]]> <![CDATA[<br>]]>" + "    ... logged in user content ...<![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.otherwise&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.choose&gt;]]> <![CDATA[<p>]]>" + "The value for the pt:test attribute is case-sensitive. " + "Since there can be multiple guest users in the portal, " + "simply testing for user ID 2 (default guest user) does not work. <![CDATA[<p>]]>";
    public const String CHOOSE_EXAMPLE_2 = "Example 2: <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.choose&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.when pt:test=\"stringToACLGroup(\'user=1;\').isMember($currentuser)\"&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;title&gt;welcome administrator&lt;/title&gt;&lt;/head&gt;]]> <![CDATA[<br>]]>" + "    ... secret administrator content ...<![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.when&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.when pt:test=\"stringToACLGroup(\'user=200,201;group=200;\').isMember($currentuser)\"&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;title&gt;the 200 club&lt;/title&gt;&lt;/head&gt;]]> <![CDATA[<br>]]>" + "    ... content only group 200 or users 200 and 201 can see ...<![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.when&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;pt:standard.otherwise&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;title>everyone else</title></head&gt;]]> <![CDATA[<br>]]>" + "    ... content any user can see ...<![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.otherwise&gt;]]> <![CDATA[<br>]]>" + "<![CDATA[&lt;/pt:standard.choose&gt;]]> ";
    public const String HAS_ACCESS_VARIABLE = "bHasAccess";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RelatedChildTag WHEN;
    public static readonly RelatedChildTag OTHERWISE;
    static ChooseTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("choose", CHOOSE_DESCRIPTION, CHOOSE_EXAMPLE_SYNTAX + CHOOSE_EXAMPLE_1 + CHOOSE_EXAMPLE_2);
      WHEN = new RelatedChildTag(WhenTag.TAG);
      OTHERWISE = new RelatedChildTag(OtherwiseTag.TAG);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      // Cache the previous value so we can restore it later.
      Object oPrevValue = GetStateVariable(HAS_ACCESS_VARIABLE, Scope.PORTLET_REQUEST);
      SetStateVariable(ChooseTag.HAS_ACCESS_VARIABLE, false, Scope.PORTLET_REQUEST);
      HTMLElement result = ProcessTagBody();
      // Restore the previous value
      SetStateVariable(ChooseTag.HAS_ACCESS_VARIABLE, oPrevValue, Scope.PORTLET_REQUEST);
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccesStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any content, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new ChooseTag();
    }
  }
}