using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taglib.standard.basetags;
namespace com.plumtree.taglib.standard
{
  /// <summary>
  /// This tag is used in a gateway page (as opposed to a MyPage or Community
  /// page) to set whether or not the page should be displayed in
  /// Hosted Mode.  If the page is displayed in Hosted Mode, it will
  /// be surrounded by the Portal banner (header and footer).  It can
  /// also be used to set the page title and subtitle, as well as the
  /// values returned by the pagename and realmname tags on a gateway
  /// page.
  /// </summary>
  public class DisplayModeTag : ADisplayModeTag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    
    /// <summary>
    /// The public static final ITagMetaData has to be in this
    /// class instead of the base class, otherwise dynamic
    /// discovery will get confused if we try to override it.
    /// </summary>
    public static readonly ITagMetaData TAG;
    static DisplayModeTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("displaymode", DISPLAY_MODE_TAG_DESCRIPTION);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new DisplayModeTag();
    }
  }
}