using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard
{
  /// <summary>
  /// The choose, when and otherwise tags allow you to insert
  /// content on a page based on conditional statements of user
  /// and group membership. The choose tag denotes the start of a
  /// secured content section, and the when tags include a test
  /// condition that defines who has access to the enclosed content.
  /// The otherwise tags include content that should be displayed
  /// as default.
  /// </summary>
  public class OtherwiseTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag CHOOSE;
    static OtherwiseTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("otherwise", ChooseTag.CHOOSE_DESCRIPTION, ChooseTag.CHOOSE_EXAMPLE_SYNTAX + ChooseTag.CHOOSE_EXAMPLE_1 + ChooseTag.CHOOSE_EXAMPLE_2);
      CHOOSE = new RequiredParentTag(ChooseTag.TAG);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      bool bHasAccess = false;
      Object oHasAccess = GetStateVariable(ChooseTag.HAS_ACCESS_VARIABLE,
       Scope.PORTLET_REQUEST);
      if (null != oHasAccess)
      {
        try
        {
          bHasAccess = XPConvert.ToBoolean(oHasAccess);
        }
        catch (XPFormatException xpfe)
        {
          // todo - log an error
          bHasAccess = false;
        }
      }
      if (!bHasAccess)
      {
        return ProcessTagBody();
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccesStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new OtherwiseTag();
    }
  }
}