using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taglib.standard.basetags;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard
{
  /// <summary>
  /// This tag creates a form button to a popup window that allows users to
  /// select options from a structured list of Plumtree objects.
  /// </summary>
  public class TreeTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute WINDOW_NAME;
    public static readonly OptionalTagAttribute WINDOW_FEATURES;
    // The legacy attributes are listed here because we don't have a legacy version of this
    // tag (tree is the same in both lower case and camelCase).  Therefore we have to handle
    // both sets of attributes in this tag.
    public static readonly OptionalTagAttribute LEGACY_WINDOW_NAME;
    public static readonly OptionalTagAttribute LEGACY_WINDOW_FEATURES;
    static TreeTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("tree", "This tag creates a form button to a popup window that allows users to " + "select options from a structured list of Plumtree objects.",
       "The code below creates a button with an \"onclick\" action " + "that opens a popup window to a tree that can be used to select " + "a user.<![CDATA[<p>]]>" + "<![CDATA[&lt;pt:standard.tree value=\"Button Name\" class=\"gContentSection\" " + "pt:windowname=\"myWindow\" pt:windowfeatures=\"location=no,menubar=no,height=500,width=300\" " + "pt:RootID=\"1\" pt:Multi=\"false\" pt:SelectMd=\"2\" pt:SubmitMd=\"2\" " + "pt:Submit=\"PickerSubmit\" pt:Title=\"User\" pt:SubTitle=\"Pick a user\" pt:Class=\"1\"/&gt;]]><![CDATA[<p>]]>" + "See the DevCenter documentation for more details on tree arguments.");
      WINDOW_NAME = new OptionalTagAttribute("windowname", ATreeLinkTag.WINDOW_NAME_DESCRIPTION,
       AttributeType.STRING, ATreeLinkTag.WINDOW_NAME_DEFAULT);
      WINDOW_FEATURES = new OptionalTagAttribute("windowfeatures", ATreeLinkTag.WINDOW_FEATURES_DESCRIPTION,
       AttributeType.STRING, ATreeLinkTag.WINDOW_FEATURES_DEFAULT);
      LEGACY_WINDOW_NAME = new OptionalTagAttribute("windowName", ATreeLinkTag.WINDOW_NAME_DESCRIPTION,
       AttributeType.STRING, ATreeLinkTag.WINDOW_NAME_DEFAULT);
      LEGACY_WINDOW_FEATURES = new OptionalTagAttribute("windowFeatures",
       ATreeLinkTag.WINDOW_FEATURES_DESCRIPTION, AttributeType.STRING, ATreeLinkTag.WINDOW_FEATURES_DEFAULT);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLElement result = new HTMLElementCollection();
      // Get the window name attribute
      String strWindowName = GetTagAttributeAsString(WINDOW_NAME);
      if (ATreeLinkTag.WINDOW_NAME_DEFAULT.Equals(strWindowName))
      {
        strWindowName = GetTagAttributeAsString(LEGACY_WINDOW_NAME);
      }
      // Get the window features attribute
      String strWindowFeatures = GetTagAttributeAsString(WINDOW_FEATURES);
      if (ATreeLinkTag.WINDOW_FEATURES_DEFAULT.Equals(strWindowFeatures))
      {
        strWindowFeatures = GetTagAttributeAsString(LEGACY_WINDOW_FEATURES);
        }
      String strOnClick = ATreeLinkTag.GetTreeOnClick(this, strWindowName,
       strWindowFeatures);
      // input button
      result.AddInnerHTMLElement(new HTMLGenericElement("<input type=\"button\" onclick=\"" + strOnClick + "\" " + GetXMLTagAttributesAsString() + ">"));
      // Add the inner HTML and tags to this link.
      result.AddInnerHTMLElement(ProcessTagBody());
      // Close the anchor tag.
      result.AddInnerHTMLElement(new HTMLGenericElement("</input>"));
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new TreeTag();
    }
  }
}