using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard.basetags
{
  /// <summary>
  /// Base class for the CurrentTimeTag which prints the current time for the user.
  /// </summary>
  public abstract class ACurrentTimeTag : ATag
  {
    // The public static final ITagMetaData cannot be in this
    // class, otherwise dynamic discovery will get confused if
    // we try to override it.
    public const String CURRENTTIMETAG_DESCRIPTION = "This tag displays the date and time in the current user\'s locale. " + "Only the full date and time can be displayed; there is no way to " + "return just the date, just the time, or any other subset of information.";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      String strTZ = GetEnvironment().GetTimeZone();
      // build an XPTimeZone, handle the case where strTZ is null -jas
      XPTimeZone xpTZ;
      if (null == strTZ)
      {
        xpTZ = new XPTimeZone();
      } else
      {
        xpTZ = XPTimeZone.GetTimeZone(strTZ);
      }
      // format and display the current time -jas
      XPDateFormat xpFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.DEFAULT,
       XPDateFormat.DEFAULT, new XPLocale(this.GetEnvironment().GetLocale()),
       xpTZ);
      XPDateTime xpNow = new XPDateTime();
      return new HTMLGenericElement(xpFormat.Format(xpNow));
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any content by itself, and therefore
      // supports all access styles.
      return true;
    }
  }
}