using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard.basetags
{
  /// <summary>
  /// This tag is used in a gateway page (as opposed to a MyPage or Community
  /// page) to set whether or not the page should be displayed in
  /// Hosted Mode.  If the page is displayed in Hosted Mode, it will
  /// be surrounded by the Portal banner (header and footer).  It can
  /// also be used to set the page title and subtitle, as well as the
  /// values returned by the pagename and realmname tags on a gateway
  /// page.
  /// </summary>
  public abstract class ADisplayModeTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.taglib.standard.basetags.ADisplayModeTag");
    // The public static final ITagMetaData cannot be in this
    // class, otherwise dynamic discovery will get confused if
    // we try to override it.
    public const String DISPLAY_MODE_TAG_DESCRIPTION = "This tag is used in a gateway page (as opposed to a MyPage or Community " + "page) to set whether or not the page should be displayed in " + "Hosted Mode.  If the page is displayed in Hosted Mode, it will " + "be surrounded by the Portal banner (header and footer).  It can " + "also be used to set the page title and subtitle, as well as the " + "values returned by the pagename and realmname tags on a gateway " + "page.";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly OptionalTagAttribute MODE;
    public static readonly OptionalTagAttribute TITLE;
    public static readonly OptionalTagAttribute SUBTITLE;
    static ADisplayModeTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      MODE = new OptionalTagAttribute("mode", "This controls whether or not the page should be displayed in " + "Hosted Mode.  If the page is displayed in Hosted Mode, it will " + "be surrounded by the Portal banner (header and footer). To turn " + "Hosted Mode on, this attribute should be \"Hosted\". The default " + "value for this attribute, \"\", will display the page in Plain Mode.",
       AttributeType.STRING, "");
      TITLE = new OptionalTagAttribute("title", "This sets the title used for the Hosted Mode page, as well as the " + "value returned by the realmname tag on a gateway page.",
       AttributeType.STRING, "");
      SUBTITLE = new OptionalTagAttribute("subtitle", "This sets the subtitle used for the Hosted Mode page, as well as the " + "value returned by the pagename tag on a gateway page.",
       AttributeType.STRING, "");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      if (asOwner.GetModelExists(GatewayModel.strModelName))
      {
        GatewayModel gatewayModel = (GatewayModel) asOwner.GetModel(GatewayModel.strModelName);
        // Hosted Display Mode
        String strHostedMode = GetTagAttributeAsString(MODE);
        bool bHostedModePTTagPresent = ((!"".Equals(strHostedMode)) && XPStringUtility.EqualsIgnoreCase(XPStringUtility.Trim(strHostedMode),
         ("Hosted")));
        gatewayModel.SetIsHostedModePTTagPresent(bHostedModePTTagPresent);
        // Title
        String strTitle = GetTagAttributeAsString(TITLE);
        if (!"".Equals(strTitle))
        {
          gatewayModel.SetTitle(strTitle);
        }
        // Subtitle
        String strSubtitle = GetTagAttributeAsString(SUBTITLE);
        if (!"".Equals(strSubtitle))
        {
          gatewayModel.SetSubtitle(strSubtitle);
        }
        log.Debug("DisplayModeTag: Stored " + "DISPLAYMODEKEY=[" + strHostedMode + "]\r\n" + "TITLEKEY=[" + strTitle + "]\r\n" + "SUBTITLEKEY=[" + strSubtitle + "]\r\n" + " on Gateway Model.");
        }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any content by itself, and therefore
      // supports all access styles.
      return true;
    }
  }
}