using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard.basetags
{
  /// <summary>
  /// Base Tag for anchor links that adds the XML attributes from the tag.
  /// </summary>
  public abstract class ALinkTag : ATag
  {
    // The public static final ITagMetaData cannot be in this
    // class, otherwise dynamic discovery will get confused if
    // we try to override it.
    
    /// <summary>
    /// This method returns the href or url to use in the link.
    /// </summary>
    /// <returns>String the href or url to use in the link.</returns>
    public abstract String GetHREF();
    
    /// <summary>
    /// This method returns the onClick string to use in the link.
    /// If this method returns a non-null result, the Anchor
    /// will use '#' as the href instead of the String returned
    /// by GetHREF.
    /// Override this method if you would like to use an onclick instead
    /// of a normal link.
    /// </summary>
    /// <returns>String the onClick javascript string to use in the link.</returns>
    public virtual String GetOnClick()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // We can't use an HTMLAnchor HTMLElement because there is no way to add a
      // group of Tag attributes to an HTML Element.
      String strOnClick = GetOnClick();
      if (null != strOnClick)
      {
        // onclick with no link.
        result.AddInnerHTMLElement(new HTMLGenericElement("<a href=\"#\" " + "onclick=\"" + strOnClick + "\" " + GetXMLTagAttributesAsString() + ">"));
        } else
      {
        // normal link with no onclick.
        result.AddInnerHTMLElement(new HTMLGenericElement("<a href=\"" + GetHREF() + "\" " + GetXMLTagAttributesAsString() + ">"));
        }
      // Add the inner HTML and tags to this link.
      result.AddInnerHTMLElement(ProcessTagBody());
      // Close the anchor tag.
      result.AddInnerHTMLElement(new HTMLGenericElement("</a>"));
      return result;
    }
  }
}