using System;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.login;
namespace com.plumtree.taglib.standard.basetags
{
  /// <summary>
  /// Base class for the LoginLinkTag which prints a login link.
  /// </summary>
  public abstract class ALoginLinkTag : ALinkTag
  {
    // The public static final ITagMetaData cannot be in this
    // class, otherwise dynamic discovery will get confused if
    // we try to override it.
    public const String LOGINLINKTAG_DESCRIPTION = "The pt:loginLink tag creates a link to the portal login page. " + "It is a best practice to include this link when the user accessing " + "the page is a guest.";
    public const String LOGINLINKTAG_EXAMPLE = "<![CDATA[&lt;pt:standard.loginlink&gt;Log in&lt;/pt:standard.loginlink&gt;]]><![CDATA[<p>]]>" + "This code is replaced with a link of the following form:<![CDATA[<p>]]>" + "<![CDATA[&lt;a href=\"http://portal.plumtree.com/portal/server.pt?space=Login&parentname=MyPage&parentid=9&in_hi_userid=1&control=Login&login=\"&gt;Log in&lt;/a&gt;]]>";
    
    /// <seealso cref="com.plumtree.taglib.standard.ALinkTag#GetHREF()"></seealso>
    public override String GetHREF()
    {
      AActivitySpace currentSpace = (AActivitySpace) GetEnvironment();
      // TODO: Note: the other login tag (ptui.login) uses Task API
      // to generate the login / logout link URL. We should eventually
      // try to unify it, if it's appropriate.
      ASURL login = new ASURL(currentSpace);
      login.SetLinkCreateNewSpace(LoginAS.STR_MVC_CLASS_NAME, currentSpace);
      login.SetControl(LoginControl.STR_MVC_CLASS_NAME);
      // Bug 58441: 
      // This "&login=" query string param is necessary for proper
      // login sequence to kick in, which does not always use the default
      // login page (e.q., SSO)
      login.AddControlArgument(LoginHelper.PARAM_LOGIN, "");
      return login.GetURLAsString();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
  }
}