using System;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.browsing.portletpreview;
using ResourceConstants=com.plumtree.portalpages.common.constants.ResourceConstants;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard.basetags
{
  /// <summary>
  /// The tag outputs either the name of the current Community
  /// or portal page type ("My Pages," "Documents,"
  /// "Administration," or "Gateway").
  /// </summary>
  public abstract class ARealmNameTag : ATag
  {
    // The public static final ITagMetaData cannot be in this
    // class, otherwise dynamic discovery will get confused if
    // we try to override it.
    public const String REALM_NAME_TAG_DESCRIPTION = "The tag outputs either the name of the current Community" + "or portal page type (\"My Pages,\" \"Documents,\" " + "\"Administration,\" or \"Gateway\"). This value can " + "also be controlled through the displaymode tag when on a " + "gateway page.";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLElement result = new HTMLElementCollection();
      String strRealmName = null;
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      if (TaskAPIUIMyPages.IsCurrentPageMyPage(asOwner))
      {
        // My Pages
        strRealmName = GetEnvironment().GetString(672, "ptmsgs_portalbrowsingmsgs");
        } else
      // strRealmName = modelNavigation.GetCurPageName();
      if (TaskAPIUICommunity.IsCurrentPageCommunityPage(asOwner))
      {
        strRealmName = TaskAPIUICommunity.GetCurrentCommunityName(asOwner);
        } else
      if (asOwner.GetModelExists(PreviewPortletModel.STR_MVC_CLASS_NAME))
      {
        // We are in portlet preview mode
        // This needs to come before any NavModel checks, because the portlet
        // preview mode has a navmodel as well as a portlet preview model, but
        // it is not fully initialized.
        strRealmName = GetEnvironment().GetString(617, ResourceConstants.PORTALBROWSINGMSGS);
        } else
      if (asOwner.GetModelExists(GatewayModel.strModelName))
      {
        // Gateway has to come before any NavModel checks, because the NavModel
        // will call GetPage on the gateway space, which will start gateway
        // page processing over again, leading to an infinite loop.
        GatewayModel gatewayModel = (GatewayModel) asOwner.GetModel(GatewayModel.strModelName);
        strRealmName = gatewayModel.GetTitle();
      } else
      if (TaskAPIUICommon.GetNavigationModelExists(asOwner))
      {
        NavigationModel navModel = TaskAPIUICommon.GetNavigationModel(asOwner);
        strRealmName = navModel.GetTitleForBanner();
      }
      if (null != strRealmName)
      {
        // DCA - Need to HTMLEncode for community names
        result.AddInnerHTMLEncodedString(strRealmName);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
  }
}