using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard.basetags
{
  /// <summary>
  /// This tag creates a link to a popup window that allows users to
  /// select options from a structured list of Plumtree objects.
  /// </summary>
  public abstract class ATreeLinkTag : ATag
  {
    // The public static final ITagMetaData cannot be in this
    // class, otherwise dynamic discovery will get confused if
    // we try to override it.
    public const String TREE_LINK_TAG_DESCRIPTION = "This tag creates a link to a popup window that allows users to " + "select options from a structured list of Plumtree objects.";
    public const String TREE_LINK_TAG_EXAMPLES = "The code below creates a link that opens a popup " + "window to a tree that can be used to select a user. " + "See the DevCenter documentation for more details.<![CDATA[<p>]]>" + "<![CDATA[&lt;pt:standard.treelink pt:windowname=\"myWindow\" pt:windowfeatures=\"location=no,menubar=no,height=500,width=300\" pt:RootID=\"1\" pt:Multi=\"false\" pt:SelectMd=\"2\" pt:SubmitMd=\"2\" pt:Submit=\"PickerSubmit\" pt:Title=\"User\" pt:SubTitle=\"Pick a user\" pt:Class=\"1\"&gt;Pick a user!&lt;/pt:standard.treelink&gt;]]>";
    public const String WINDOW_NAME_DESCRIPTION = "Window name of the popup tree, used in the resulting window.open() function call. " + "The name may only contain alphanumeric and underscore (_) characters.";
    public const String WINDOW_NAME_DEFAULT = "_blank1";
    public const String WINDOW_FEATURES_DESCRIPTION = "Allows you to define the features argument for the resulting " + "window.open() function call, specifying the features for a " + "standard browser window.";
    public static readonly String WINDOW_FEATURES_DEFAULT = TreeConstants.GetJavascriptTreeWindowAttributes();
    // The TagAttributes cannot go in the base class because they
    // are all lower case for the standard tags and camelCase for
    // the legacy tags.
    public abstract ATagAttribute GetWindowNameAttribute();
    public abstract ATagAttribute GetWindowFeaturesAttribute();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLElement result = new HTMLElementCollection();
      String strOnClick = ATreeLinkTag.GetTreeOnClick(this, GetTagAttributeAsString(GetWindowNameAttribute()),
       GetTagAttributeAsString(GetWindowFeaturesAttribute()));
      // input button
      result.AddInnerHTMLElement(new HTMLGenericElement("<a href=\"#\" onclick=\"" + strOnClick + "\" " + GetXMLTagAttributesAsString() + ">"));
      // Add the inner HTML and tags to this link.
      result.AddInnerHTMLElement(ProcessTagBody());
      // Close the anchor tag.
      result.AddInnerHTMLElement(new HTMLGenericElement("</a>"));
      return result;
    }
    
    /// <summary>
    /// Build an onclick attribute that will open the standard tree control, using attributes from a PT XML tag -jas
    /// </summary>
    /// <param name="as">Activity Space</param>
    /// <param name="objXML">Plumtree XML tag in PT_XML_ARRAY_COLS format</param>
    /// <returns>value of an onclick attribute without quotes</returns>
    public static String GetTreeOnClick(ATag _tag, String _strWindowName,
     String _strWindowFeatures)
    {
      // The URL to open a tree -jas
      ASURL newUserTree = ATreeURLTag.BuildTreeURL(_tag);
      return "window.open(&quot;" + newUserTree.GetURLAsString() + "&quot;, &quot;" + _strWindowName + "&quot;, &quot;" + _strWindowFeatures + "&quot;);";
      }
  }
}