using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taglib.standard.basetags
{
  /// <summary>
  /// This tag outputs a URL to a tree that allows users to
  /// select options from a structured list of Plumtree objects.
  /// This URL is suitable for use in JavaScript.
  /// </summary>
  public abstract class ATreeURLTag : ATag
  {
    // The public static final ITagMetaData cannot be in this
    // class, otherwise dynamic discovery will get confused if
    // we try to override it.
    public const String TREE_URL_TAG_DESCRIPTION = "This tag outputs a URL to a tree that allows users to " + "select options from a structured list of Plumtree objects. " + "This URL is suitable for use in JavaScript.";
    public const String TREE_URL_TAG_EXAMPLES = "The code below creates a URL to a tree that can be used " + "to select a user. See the DevCenter documentation for more details.<![CDATA[<p>]]>" + "<![CDATA[&lt;pt:standard.treeurl pt:RootID=\"1\" pt:Multi=\"false\" pt:SelectMd=\"2\" pt:SubmitMd=\"2\" pt:Submit=\"PickerSubmit\" pt:Title=\"User\" pt:SubTitle=\"Pick a user\" pt:Class=\"1\"/&gt;]]>";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      HTMLElement result = new HTMLElementCollection();
      // Output just the url (for use in javascript).
      result.AddInnerHTMLString(ATreeURLTag.BuildTreeURL(this).GetURLAsString());
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()"></seealso>
    public override TagType GetTagType()
    {
      return TagType.NO_BODY;
    }
    
    /// <summary>
    /// Build a URL that will open the standard tree control, using attributes from a PT XML tag
    /// </summary>
    /// <param name="ATag">the current tag.</param>
    /// <returns>ASURL for the tree.</returns>
    public static ASURL BuildTreeURL(ATag _tag)
    {
      AActivitySpace asOwner = (AActivitySpace) _tag.GetEnvironment();
      bool isCached = false;
      // The URL to open a tree -jas
      ASURL newUserTree = new ASURL(asOwner);
      newUserTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, asOwner);
      // JF- We need to set the sub space key, this way in security mode 1, 
      // the tree will have the same security as the parent page
      // (it's important, as the tree often calls JavaScripts on the parent page, see bug 24726)  
      newUserTree.SetSubSpaceKey("GatewayTree");
      IXPEnumerator names = _tag.GetTagAttributeNames();
      // Pass the PT attributes through as query string args -jas
      while (names.MoveNext())
      {
        String strName = (String) names.GetCurrent();
        String strValue = _tag.GetTagAttribute(strName);
        newUserTree.AddControlArgument(strName, strValue);
        if (0 == strName.CompareTo(ASConstants.SPACEID))
        {
          isCached = true;
        }
      }
      if (!isCached)
      {
        newUserTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      }
      return newUserTree;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript, and therefore
      // supports all access styles.
      return true;
    }
  }
}