using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.tags.metadata.legacy;
using com.plumtree.server;
using com.plumtree.taglib.standard;
using com.plumtree.taglib.standard.basetags;
namespace com.plumtree.taglib.standard.legacynames
{
  /// <summary>
  /// This tag is exactly the same as the GatewayLinkTag, but it uses the
  /// legacy CamelCase tag name.
  /// </summary>
  public class LegacyGatewayLinkTag : AGatewayLinkTag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    
    /// <summary>
    /// The public static final ITagMetaData has to be in this
    /// class instead of the base class, otherwise dynamic
    /// discovery will get confused if we try to override it.
    /// </summary>
    public static readonly ITagMetaData TAG;
    // The TagAttributes cannot go in the base class because they
    // are all lower case for the standard tags and camelCase for
    // the legacy tags.
    // These attributes are all camel case.
    public static readonly OptionalTagAttribute COMMUNITY_ID;
    public static readonly OptionalTagAttribute PAGE_ID;
    public static readonly RequiredTagAttribute OBJECT_ID;
    public static readonly OptionalTagAttribute CLASS_ID;
    static LegacyGatewayLinkTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new LegacyTagMetaData("gatewayLink", GATEWAY_LINK_TAG_DESCRIPTION,
       GATEWAY_LINK_TAG_EXAMPLES);
      COMMUNITY_ID = new OptionalTagAttribute("communityID", COMMUNITY_ID_DESCRIPTION,
       AttributeType.INT, "0");
      PAGE_ID = new OptionalTagAttribute("pageID", PAGE_ID_DESCRIPTION, AttributeType.INT,
       "0");
      OBJECT_ID = new RequiredTagAttribute(AttributeConstants.OBJECT_ID_ATTRIBUTE_LEGACY,
       AttributeConstants.OBJECT_ID_DESCRIPTION, AttributeType.INT);
      CLASS_ID = new OptionalTagAttribute(AttributeConstants.CLASS_ID_ATTRIBUTE_LEGACY,
       CLASS_ID_DESCRIPTION, AttributeType.INT, XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
      }
    public override ATagAttribute GetCommunityIDAttribute()
    {
      return COMMUNITY_ID;
    }
    public override ATagAttribute GetPageIDAttribute()
    {
      return PAGE_ID;
    }
    public override ATagAttribute GetObjectIDAttribute()
    {
      return OBJECT_ID;
    }
    public override ATagAttribute GetClassIDAttribute()
    {
      return CLASS_ID;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LegacyGatewayLinkTag();
    }
  }
}