using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.portaluiinfrastructure.tags.metadata.legacy;
using com.plumtree.taglib.standard.basetags;
namespace com.plumtree.taglib.standard.legacynames
{
  /// <summary>
  /// This tag creates a link to a popup window that allows users to
  /// select options from a structured list of Plumtree objects.
  /// </summary>
  public class LegacyTreeLinkTag : ATreeLinkTag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    
    /// <summary>
    /// The public static final ITagMetaData has to be in this
    /// class instead of the base class, otherwise dynamic
    /// discovery will get confused if we try to override it.
    /// </summary>
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute WINDOW_NAME;
    public static readonly OptionalTagAttribute WINDOW_FEATURES;
    static LegacyTreeLinkTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new LegacyTagMetaData("treeLink", TREE_LINK_TAG_DESCRIPTION, TREE_LINK_TAG_EXAMPLES);
      WINDOW_NAME = new OptionalTagAttribute("windowName", WINDOW_NAME_DESCRIPTION,
       AttributeType.STRING, WINDOW_NAME_DEFAULT);
      WINDOW_FEATURES = new OptionalTagAttribute("windowFeatures", WINDOW_FEATURES_DESCRIPTION,
       AttributeType.STRING, WINDOW_FEATURES_DEFAULT);
    }
    
    /// <seealso cref="com.plumtree.taglib.standard.basetags.ATreeLinkTag#GetWindowNameAttribute()"></seealso>
    public override ATagAttribute GetWindowNameAttribute()
    {
      return WINDOW_NAME;
    }
    
    /// <seealso cref="com.plumtree.taglib.standard.basetags.ATreeLinkTag#GetWindowFeaturesAttribute()"></seealso>
    public override ATagAttribute GetWindowFeaturesAttribute()
    {
      return WINDOW_FEATURES;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new LegacyTreeLinkTag();
    }
  }
}