package com.plumtree.taglib.standard;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.taglib.standard.basetags.*;

/**
 * This tag creates a gateway link.
 */
public class GatewayLinkTag extends AGatewayLinkTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.

	/**
	 * The public static final ITagMetaData has to be in this
	 * class instead of the base class, otherwise dynamic
	 * discovery will get confused if we try to override it.
	 */
	public static final ITagMetaData TAG;

	// The TagAttributes cannot go in the base class because they
	// are all lower case for the standard tags and camelCase for
	// the legacy tags.

	// These attributes are all lower case.
	public static final OptionalTagAttribute COMMUNITY_ID;
	public static final OptionalTagAttribute PAGE_ID;
	public static final RequiredTagAttribute OBJECT_ID;
	public static final OptionalTagAttribute CLASS_ID;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("gatewaylink",
			GATEWAY_LINK_TAG_DESCRIPTION, GATEWAY_LINK_TAG_EXAMPLES);

		COMMUNITY_ID = new OptionalTagAttribute("communityid",
			COMMUNITY_ID_DESCRIPTION, AttributeType.INT, "0");

		PAGE_ID = new OptionalTagAttribute("pageid",
			PAGE_ID_DESCRIPTION, AttributeType.INT, "0");

		OBJECT_ID = new RequiredTagAttribute(
			AttributeConstants.OBJECT_ID_ATTRIBUTE, AttributeConstants.OBJECT_ID_DESCRIPTION,
			AttributeType.INT);

		CLASS_ID = new OptionalTagAttribute(
			AttributeConstants.CLASS_ID_ATTRIBUTE, CLASS_ID_DESCRIPTION,
			AttributeType.INT, XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
	}

	public ATagAttribute GetCommunityIDAttribute()
	{
		return COMMUNITY_ID;
	}

	public ATagAttribute GetPageIDAttribute()
	{
		return PAGE_ID;
	}

	public ATagAttribute GetObjectIDAttribute()
	{
		return OBJECT_ID;
	}

	public ATagAttribute GetClassIDAttribute()
	{
		return CLASS_ID;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new GatewayLinkTag();
	}
}