package com.plumtree.taglib.standard;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The choose, when and otherwise tags allow you to insert
 * content on a page based on conditional statements of user
 * and group membership. The choose tag denotes the start of a
 * secured content section, and the when tags include a test
 * condition that defines who has access to the enclosed content.
 * The otherwise tags include content that should be displayed
 * as default.
 */
public class OtherwiseTag extends ATag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredParentTag CHOOSE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("otherwise", ChooseTag.CHOOSE_DESCRIPTION,
			ChooseTag.CHOOSE_EXAMPLE_SYNTAX + ChooseTag.CHOOSE_EXAMPLE_1 +
			ChooseTag.CHOOSE_EXAMPLE_2);

		CHOOSE = new RequiredParentTag(ChooseTag.TAG);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		boolean bHasAccess = false;

		Object oHasAccess = GetStateVariable(ChooseTag.HAS_ACCESS_VARIABLE, Scope.PORTLET_REQUEST);

		if (null != oHasAccess)
		{
			try
			{
				bHasAccess = XPConvert.ToBoolean(oHasAccess);
			} catch (XPFormatException xpfe)
			{
				// todo - log an error
				bHasAccess = false;
			}
		}

		if (!bHasAccess)
		{
			return ProcessTagBody();
		}

		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccesStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new OtherwiseTag();
	}
}