package com.plumtree.taglib.standard;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taglib.standard.basetags.*;

/**
 * This tag creates a link to a popup window that allows users to
 * select options from a structured list of Plumtree objects.
 */
public class TreeLinkTag extends ATreeLinkTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.

	/**
	 * The public static final ITagMetaData has to be in this
	 * class instead of the base class, otherwise dynamic
	 * discovery will get confused if we try to override it.
	 */
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute WINDOW_NAME;
	public static final OptionalTagAttribute WINDOW_FEATURES;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("treelink", TREE_LINK_TAG_DESCRIPTION,
			TREE_LINK_TAG_EXAMPLES);

		WINDOW_NAME = new OptionalTagAttribute("windowname",
			WINDOW_NAME_DESCRIPTION, AttributeType.STRING, WINDOW_NAME_DEFAULT);

		WINDOW_FEATURES = new OptionalTagAttribute("windowfeatures",
			WINDOW_FEATURES_DESCRIPTION, AttributeType.STRING, WINDOW_FEATURES_DEFAULT);
	}

	/**
	 * @see com.plumtree.taglib.standard.basetags.ATreeLinkTag#GetWindowNameAttribute()
	 */
	public ATagAttribute GetWindowNameAttribute()
	{
		return WINDOW_NAME;
	}

	/**
	 * @see com.plumtree.taglib.standard.basetags.ATreeLinkTag#GetWindowFeaturesAttribute()
	 */
	public ATagAttribute GetWindowFeaturesAttribute()
	{
		return WINDOW_FEATURES;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new TreeLinkTag();
	}
}