package com.plumtree.taglib.standard;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taglib.standard.basetags.*;

/**
 * This tag outputs a URL to a tree that allows users to
 * select options from a structured list of Plumtree objects.
 * This URL is suitable for use in JavaScript.
 */
public class TreeURLTag extends ATreeURLTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.

	/**
	 * The public static final ITagMetaData has to be in this
	 * class instead of the base class, otherwise dynamic
	 * discovery will get confused if we try to override it.
	 */
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("treeurl",
			TREE_URL_TAG_DESCRIPTION, TREE_URL_TAG_EXAMPLES);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new TreeURLTag();
	}
}