package com.plumtree.taglib.standard.basetags;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Base class for the CurrentTimeTag which prints the current time for the user.
 */
public abstract class ACurrentTimeTag extends ATag
{
	// The public static final ITagMetaData cannot be in this
	// class, otherwise dynamic discovery will get confused if
	// we try to override it.

	public static final String CURRENTTIMETAG_DESCRIPTION =
		"This tag displays the date and time in the current user's locale. " +
		"Only the full date and time can be displayed; there is no way to " +
		"return just the date, just the time, or any other subset of information.";

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		String strTZ = GetEnvironment().GetTimeZone();

		// build an XPTimeZone, handle the case where strTZ is null -jas
		XPTimeZone xpTZ;
		if (null == strTZ)
		{
			xpTZ = new XPTimeZone();
		}
		else
		{
			xpTZ = XPTimeZone.GetTimeZone(strTZ);
		}

		// format and display the current time -jas
		XPDateFormat xpFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.DEFAULT, XPDateFormat.DEFAULT,
			new XPLocale(this.GetEnvironment().GetLocale()), xpTZ);
		XPDateTime xpNow = new XPDateTime();

		return new HTMLGenericElement(xpFormat.Format(xpNow));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any content by itself, and therefore
		// supports all access styles.
		return true;
	}
}
