package com.plumtree.taglib.standard.basetags;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portalpages.common.constants.ResourceConstants;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag outputs the name of the current portal page
 * (My Page or Community) or is left blank otherwise. The
 * localized name is used if one is available.
 */
public abstract class APageNameTag extends ATag
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.taglib.standard.basetags.APageNameTag");
	
	// The public static final ITagMetaData cannot be in this
	// class, otherwise dynamic discovery will get confused if
	// we try to override it.

	public static final String PAGE_NAME_TAG_DESCRIPTION =
		"This tag outputs the name of the current portal page " +
		"(My Page or Community) or nothing if the current page " +
		"is not a My Page or Community. The localized name is " +
		"used if one is available. This value can also be " +
		"controlled through the displaymode tag when on a " +
		"gateway page.";

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		HTMLElement result = new HTMLElementCollection();
		String strPageName = null;

		AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
		try {
			if (TaskAPIUIMyPages.IsCurrentPageMyPage(asOwner))
			{
				strPageName = TaskAPIUIMyPages.GetCurrentMyPageName(asOwner);
			} else if (TaskAPIUICommunity.IsCurrentPageCommunityPage(asOwner))
			{
				strPageName = TaskAPIUICommunity.GetCurrentCommunityPageName(asOwner);
			} else if (asOwner.GetModelExists(GatewayModel.STR_MVC_CLASS_NAME))
			{
				GatewayModel gatewayModel = (GatewayModel) asOwner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
	
				strPageName = gatewayModel.GetSubtitle();
			} else if (asOwner.GetModelExists(PreviewPortletModel.STR_MVC_CLASS_NAME))
			{
				// We are in portlet preview mode
				strPageName = GetEnvironment().GetString(618, ResourceConstants.PORTALBROWSINGMSGS);
			}
		} catch (XPException e) {
			log.Debug(e, "Failed retrieving page name, not on a MyPage or Community page.");
		}

		if (null != strPageName)
		{
			// DCA - Need to HTMLEncode for community page and My Page names
			result.AddInnerHTMLEncodedString(strPageName);
		}

		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}
}