package com.plumtree.taglib.standard.basetags;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays the current portal stylesheet links
 * for display in the HEAD of any non-hosted gatewayed HTML page.
 */
public abstract class AStyleSheetsTag extends ATag
{
	// The public static final ITagMetaData cannot be in this
	// class, otherwise dynamic discovery will get confused if
	// we try to override it.

	public static final String STYLE_SHEETS_TAG_DESCRIPTION =
		"This tag displays the current portal stylesheet links " +
		"for display in the HEAD of any non-hosted gatewayed HTML page or layout page." +
		"It will always return the legacy stylesheet link regardless if adaptive layout " +
		"mode is enabled or not.<![CDATA[<p>]]>" +
		"Note: Hosted pages and portlets cannot contain " +
		"<![CDATA[&lt;HEAD&gt; or &lt;BODY&gt;]]> " +
		"tags. The page must be gatewayed to be transformed.";

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		HTMLElement result = new HTMLElementCollection();

		AActivitySpace asOwner = (AActivitySpace) GetEnvironment();

		int nCommunityID = 0;

		// Try the gateway model first, since this tag is designed only
		// to be used on non-hosted gateway pages.
		if (asOwner.GetModelExists(GatewayModel.strModelName))
		{
			GatewayModel model = (GatewayModel) asOwner.GetModel(GatewayModel.strModelName);

			nCommunityID = model.GetCommunityID();
		} else
		{
			try
			{
				// This will work for Plumtree banner pages, but this tag is
				// not supposed to be usuable with banner pages.
				nCommunityID = TaskAPIUICommunity.GetCurrentCommunityID(asOwner);
			} catch (XPIllegalArgumentException xpiae)
			{
				// Ignore this exception.  It means that we are not on a
				// Plumtree banner page.  This means that we are on the devices
				// MyPage and there is no community.
				nCommunityID = 0;
			}
		}

		// this function will return the community or subportal style sheet link -jas
		PTStyleSheetLink ptStyleSheetLink = AppDataObject.GetStyleSheet(nCommunityID,
			(IPTSession) GetEnvironment().GetUserSession(), asOwner);
		result.AddInnerHTMLElement(ptStyleSheetLink.GetLinkAsHTMLElement(
			ConfigHelper.GetStyleSheetsBaseURL(asOwner)));

		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag does not display any JavaScript, and therefore
		// supports all access styles.
		return true;
	}
}