package com.plumtree.taglib.standard.legacynames;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.legacy.*;
import com.plumtree.taglib.standard.basetags.*;

/**
 * This tag is used in a gateway page (as opposed to a MyPage or Community
 * page) to set whether or not the page should be displayed in
 * Hosted Mode.  If the page is displayed in Hosted Mode, it will
 * be surrounded by the Portal banner (header and footer).  It can
 * also be used to set the page title and subtitle, as well as the
 * values returned by the pagename and realmname tags on a gateway
 * page.
 */
public class LegacyDisplayModeTag extends ADisplayModeTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.

	/**
	 * The public static final ITagMetaData has to be in this
	 * class instead of the base class, otherwise dynamic
	 * discovery will get confused if we try to override it.
	 */
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new LegacyTagMetaData("displayMode", DISPLAY_MODE_TAG_DESCRIPTION);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new LegacyDisplayModeTag();
	}
}