package com.plumtree.taglib.standard.legacynames;

import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.legacy.*;
import com.plumtree.taglib.standard.basetags.*;

/**
 * This tag displays the current portal stylesheet links
 * for display in the HEAD of any non-hosted gatewayed HTML page.
 */
public class LegacyStyleSheetsTag extends AStyleSheetsTag
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.

	/**
	 * The public static final ITagMetaData has to be in this
	 * class instead of the base class, otherwise dynamic
	 * discovery will get confused if we try to override it.
	 */
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new LegacyTagMetaData("styleSheets", STYLE_SHEETS_TAG_DESCRIPTION);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new LegacyStyleSheetsTag();
	}
}