package com.plumtree.taglib.advancedSearch;

import com.plumtree.openfoundation.util.XPHashtable;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portalpages.common.documentlanguage.CardLanguagePlugInView;
import com.plumtree.portalpages.common.search.TypeSelectorView;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.CommonTagAttributeConstants;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.PT_CLASSIDS;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag implements the advancedsearch.advsearchbutton tag.  This tag can only be used in an advanced search layout.
 * This tag adds the search button in the advanced search page that will execute an advanced search.  
 * This doesn't create the advanced search Form tag as the mainform AFormDP will generate that for us.
 * @author lmah
 *
 */

public class AdvSearchButtonTag extends AdvancedSearchPageTag {

	private static final String TAG_NAME = "advsearchbutton";
	
	public static final ITagMetaData TAG;
	
	public static final String DATATAG_DESCRIPTION = ATag.EncodeForTagDoc(
			"This tag outputs the advanced search button that executes the advanced search.  This tag can only be used" +
			"for an advanced search layout.<br/>");

	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, DATATAG_DESCRIPTION);
	}

	@Override
	public ATag Create() {
		return new AdvSearchButtonTag();
	}

	@Override
	public HTMLElement DisplayTag() {
		
	    AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
	    
	    //creates the search button
	    ASButtonView myButtonView = new ASButtonView();
	    IAdvancedSearchModelRO mymodel = GetAdvancedSearchModel();
	    myButtonView.Init(mymodel, asOwner);
	    
	    HTMLElement searchFormItems = new HTMLElementCollection();
	    searchFormItems.AddInnerHTMLElement(myButtonView.Display());
	    return searchFormItems;
	}
}
