package com.plumtree.taglib.advancedSearch;

import com.plumtree.portalpages.browsing.search.advanced.IAdvancedSearchModelRO;
import com.plumtree.portalpages.common.search.SimpleSelectorView;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.CommonTagAttributeConstants;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag implements the advancedsearch.resultcount tag.  This tag can only be used in an advanced search layout.
 * It returns the result count filter to set the max number of results returned in a single page.
 * @author lmah
 *
 */
public class AdvancedSearchResultCountTag extends AdvancedSearchPageTag {

	private static final String TAG_NAME = "resultcount";
	
	public static final ITagMetaData TAG;
	
	public static final String DATATAG_DESCRIPTION = ATag.EncodeForTagDoc(
			"This tag creates the result count selector for the advanced search.  This tag can only be used for" +
			"an advanced search layout<br/>");

	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, DATATAG_DESCRIPTION);
	}

	
	@Override
	public ATag Create() {
		return new AdvancedSearchResultCountTag();
	}

	@Override
	public HTMLElement DisplayTag() {
		AActivitySpace asOwner = (AActivitySpace)GetEnvironment();
		//We are checking to ensure that this tag is only being used for an advanced search layout, not used otherwise.
		IAdvancedSearchModelRO advSearchModel = GetAdvancedSearchModel();
		
		HTMLElement resultCount = asOwner.GetView(SimpleSelectorView.STR_MVC_CLASS_NAME).Display();
		HTMLElement resultItem = new HTMLElementCollection();
		resultItem.AddInnerHTMLElement(resultCount);
		return resultItem;
	}

}
