package com.plumtree.taglib.advancedSearch;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.portaluiinfrastructure.tags.ATag;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class implements the advancedsearch.clearbutton tag.  This tag can only be used in an advanced search layout.
 * This creates the clear button in the advanced search page that will clear the advanced search page.  
 * This doesn't create the advanced search Form tag as the mainform AFormDP will generate that for us.
 * @author lmah
 *
 */

public class ClearButtonTag extends AdvancedSearchPageTag {
	
	private static final String TAG_NAME = "clearbutton";
	
	public static final ITagMetaData TAG;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag outputs the clear button on the advanced search page.  This tag can only be used for an advanced" +
			"search layout.<br/>");
	}

	@Override
	public ATag Create() {
		return new ClearButtonTag();
	}

	@Override
	public HTMLElement DisplayTag() {
	    AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
	    
	    //creates the clear button
	    ASFooterView myClearButton = new ASFooterView();
	    IAdvancedSearchModelRO mymodel = GetAdvancedSearchModel();
	    myClearButton.Init(mymodel, asOwner);
	    HTMLElement clearButton = myClearButton.Display();
	    
	    HTMLElement searchFormItems = new HTMLElementCollection();
	    	    
	    searchFormItems.AddInnerHTMLElement(clearButton);
	    return searchFormItems;
	}
	

}
