package com.plumtree.taglib.advancedSearch;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.CommonTagAttributeConstants;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag implements the advancedsearch.searchcriteria tag.  This tag can only be used with an advanced search layout.
 * This tag generates the search criteria filter.
 * @author lmah
 *
 */
public class SearchCriteriaDisplayTag extends AdvancedSearchPageTag {
	
	public static final String TAG_NAME = "searchcriteria";
		
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.	
	public static final ITagMetaData TAG;

	public static final String DATATAG_DESCRIPTION = ATag.EncodeForTagDoc(
			"Generates the search criteria data, which includes the properties that a user has access to search against," +
			" the operators associated to each property, and property value text.  This tag can only be used for an" +
			"advanced search layout.<br/>");

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, DATATAG_DESCRIPTION);
	}

	@Override
	public ATag Create() {
		return new SearchCriteriaDisplayTag();
	}

	@Override
	public HTMLElement DisplayTag() {
		AActivitySpace ownerAS = (AActivitySpace)GetEnvironment();
		//We are checking to ensure that this tag is only being used for an advanced search layout, not used otherwise.
		IAdvancedSearchModelRO advSearchModel = GetAdvancedSearchModel();

		HTMLElement filterElement = new HTMLElementCollection();
		filterElement.AddInnerHTMLElement(ownerAS.GetView(ASFilterView.STR_MVC_CLASS_NAME).Display());
		return filterElement;
		
	}
}
