using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.basepage
{
  // *** CR rob - add some log statements to make debugging easier
  public class NavAreaTag : ATag
  {
    private const String TAG_NAME = "navarea";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute AREA;
    static NavAreaTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays the required html for this navigational area.");
      XPStringBuilder attrdoc = new XPStringBuilder("This attribute is used to specify the location of the navigation area. The allowable values for this attribute are: ");
      for (int i = 0;i < NavAreaEnum.m_navAreaEnums.Length;i++)
      {
        attrdoc.Append((i < (NavAreaEnum.m_navAreaEnums.Length - 1) ? NavAreaEnum.m_navAreaEnums[i].ToString() + ", " : "and " + NavAreaEnum.m_navAreaEnums[i].ToString() + "."));
        }
      AREA = new RequiredTagAttribute("area", attrdoc.ToString(), AttributeType.STRING);
      }
    protected virtual PlumtreeDP GetPlumtreeDP()
    {
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      IDisplayPage basePage = space.GetCurrentPage();
      if (!(basePage is PlumtreeDP))
      {
        throw new XPException(TAG_NAME + " tag can only be used with " + "pages that extend PlumtreeDP.  " + basePage.GetName() + " does not.");
        }
      return (PlumtreeDP) basePage;
    }
    private IView GetNavAreaView()
    {
      PlumtreeDP page = GetPlumtreeDP();
      String sArea = GetTagAttributeAsString(AREA);
      NavAreaEnum navArea = null;
      if (null != sArea)
      {
        navArea = NavAreaEnum.GetNavArea(sArea);
      } else
      {
        throw new XPException("Value for area attribute " + sArea + " is not valid.");
        }
      if (navArea == null)
      {
        return null;
      }
      INavTypes navType = ((ITypes) GetEnvironment()).GetNavType(page.GetNavScheme());
      String strView = navType.GetNavAreaView(navArea);
      if (strView == null)
      {
        return null;
      }
      IView navAreaView = ((AActivitySpace) GetEnvironment()).GetView(strView);
      //	*** CR rob - would be useful if an html comment was added in case the nav area returned empty result
      if (null == navAreaView)
      {
        throw new XPException("Navigation view for the area " + sArea + " is null");
        }
      return navAreaView;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      // TODO CR DLH: The DisplayTag() method should return an HTMLCollection,
      // not an HTMLScriptCollection.  JavaScript should be handled by calling
      // the AddJavascript() method on the tag with the JS.
      HTMLElementCollection navCol = new HTMLElementCollection();
      if (GetNavAreaView() != null)
      {
        navCol.AddInnerHTMLElement(GetNavAreaView().Display());
      } else
      {
        navCol.AddInnerHTMLElement(ProcessTagBody());
      }
      AddJavascript(DisplayJavascript());
      return navCol;
    }
    
    /// <summary>
    /// This method gets JavaScript once per page regardless of the 
    /// number of NavAreaTags included in the page.
    /// </summary>
    /// <returns>JavaScript Collection shared between multiple NavArea Tags</returns>
    public override HTMLScriptCollection DisplaySharedJavascript()
    {
      HTMLScriptCollection result = new HTMLScriptCollection();
      INavTypes navType = ((ITypes) GetEnvironment()).GetNavType(GetPlumtreeDP().GetNavScheme());
      result.AddInnerHTMLElement(navType.JavaScriptIncludes((AActivitySpace) GetEnvironment()));
      HTMLScript tempIncl = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      tempIncl.AddInnerHTMLString(NavigationCommonHelpers.writeURLTemplateParseFunction((AActivitySpace) GetEnvironment()));
      result.AddInnerHTMLElement(tempIncl);
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayJavascript()"></seealso>
    public virtual HTMLScriptCollection DisplayJavascript()
    {
      if (GetNavAreaView() != null)
      {
        HTMLScriptCollection result = new HTMLScriptCollection();
        result.AddInnerHTMLElement(GetNavAreaView().DisplayJavascript());
        return result;
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag handles both standard and 508 modes.
      return (_style.GetAccessID() == AccessStyles.STANDARD.GetAccessID() || _style.GetAccessID() == AccessStyles.SECTION_508.GetAccessID());
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new NavAreaTag();
    }
  }
}