using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.basepage
{
  public class PageBodyTag : ABasePageTag
  {
    private const String TAG_NAME = "pagebody";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    static PageBodyTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag displays the body tag for this page and initializes page JavaScript. " + "HTML tag attributes for the body tag can be added as normal XML attributes and " + "they will get processed and added to the body tag.");
      }
    
    /// <summary>
    /// This method generates the body tag for the page.  It gets custom onloads from the child
    /// page and merges them with any onloads in the attributes of the tag in the layout.  It
    /// displays the rest of the page, and then initializes the PCC eventing framework. 
    /// </summary>
    public override HTMLElement DisplayTag()
    {
      PlumtreeDP page = GetPlumtreeDP();
      String strOnLoadValue = "";
      String strXMLAttributes = null;
      IXPEnumerator names = GetXMLTagAttributeNames();
      // Check if there is an onload value from the tag HTML attributes
      while (names.MoveNext())
      {
        if (XPStringUtility.CompareIgnoreCase((String) names.GetCurrent(),
         "onload") == 0)
        {
          strOnLoadValue = GetXMLTagAttribute((String) names.GetCurrent());
          }
      }
      // Get the tag HTML attributes to be added to the body tag.
      if (strOnLoadValue.Length > 0)
      {
        // If there was an onload value in the tag attributes, get the rest of the HTML attributes.
        names = GetXMLTagAttributeNames();
        XPStringBuilder attributes = new XPStringBuilder();
        while (names.MoveNext())
        {
          if (XPStringUtility.CompareIgnoreCase((String) names.GetCurrent(),
           "onload") != 0)
          {
            if (attributes.GetLength() > 0)
            {
              attributes.Append(" ");
            }
            // build the name/value pair
            attributes.Append(names.GetCurrent()).Append("=\"").Append(GetXMLTagAttribute((String) names.GetCurrent())).Append("\"");
            }
        }
        strXMLAttributes = attributes.ToString();
      } else
      {
        // Otherwise get all of the HTML attributes.
        strXMLAttributes = GetXMLTagAttributesAsString();
      }
      String strOnLoad = "";
      // If we are in 508 or low-bandwidth mode, the onload string will just be empty.
      // This means that it will also remove custom onload attributes present in the layout
      // for 508 users.
      if (page.GetUseJavascript())
      {
        // NOTE: no one uses this - do we really need it?
        // It just makes this tag about 10x more complicated.
        String strOnLoadPageValue = page.GetOnLoad();
        if (strOnLoadPageValue != null)
        {
          // merge the page onload with the tag attribute onload statement.
          // check that the javascript statement ends with ; so another
          // can be appended to it.
          if (XPStringUtility.EndsWith(strOnLoadPageValue, ";"))
          {
            strOnLoadValue = strOnLoadPageValue + strOnLoadValue;
          } else
          {
            strOnLoadValue = strOnLoadPageValue + ";" + strOnLoadValue;
          }
        }
        // Setup the onload name/value pair
        if ((strOnLoadValue != null) && (strOnLoadValue.Length > 0))
        {
          strOnLoad = " onload=\"" + strOnLoadValue + "\"";
        } else
        {
          strOnLoad = "";
        }
      }
      // Generate the open body tag, with onload and passed-thru HTML tag attributes.
      String strOpenTag;
      if ((strXMLAttributes != null) && (strXMLAttributes.Length > 0))
      {
        strOpenTag = "<body" + strOnLoad + " " + strXMLAttributes + ">";
      } else
      {
        strOpenTag = "<body" + strOnLoad + ">";
      }
      // Generate the close body tag
      String strCloseTag = "</body>";
      HTMLElementCollection body = new HTMLElementCollection();
      body.AddInnerHTMLString(strOpenTag);
      // Display everything inside the tag
      body.AddInnerHTMLElement(ProcessTagBody());
      if (page.GetUseJavascript())
      {
        // Initialize the PCC eventing framework
        body.AddInnerHTMLElement(page.GetInitializeEventsJavaScript());
      }
      body.AddInnerHTMLString(strCloseTag);
      return body;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag handles both standard and 508 modes, since it checks if the user
      // can display javascript, and only adds javascript if the user is not in 508 mode.
      return true;
    }
    public override ATag Create()
    {
      return new PageBodyTag();
    }
  }
}