using System;
using junit.framework;
using com.bea.alui.taglib.basepage;
using com.bea.alui.taglib.basepage.test.integration;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.basepage.test
{
  /// <summary>
  /// This class tests the pagebody tag.
  /// 1) Does it display?
  /// 2) Does it merge an onload attribute from the page with one from the tag attributes?
  /// 3) Can it do the merge if the supplied onload doesn't end with a semi-colon?
  /// In general, the tests build up a markup array, pass it to the tag engine, and then
  /// verify the results.
  /// </summary>
  public class TestPageBodyTag : TestCase
  {
    private const String TEST_JAVASCRIPT_OPEN_TAG = "<script type=\"text/javascript\">";
    private const String TEST_JAVASCRIPT_CLOSE_TAG = "</script>";
    private const String TEST_HTML_CONTENT = "Test content.";
    private const String TEST_BODY_ATTRIBUTE_NAME = "marginwidth";
    private const String TEST_BODY_ATTRIBUTE_VALUE = "0";
    private const String TEST_BODY_ONLOAD_NAME = "onLoad";
    private const String TEST_BODY_ONLOAD_VALUE = "var testcustomonload=true;";
    private const String TEST_BODY_PAGE_ONLOAD_VALUE_NO_SEMICOLON = "var testcustompageonload=true";
    private static readonly String TEST_JS_INIT = TEST_JAVASCRIPT_OPEN_TAG + PlumtreeDP.JAVASCRIPT_INITIALIZE_EVENTS + TEST_JAVASCRIPT_CLOSE_TAG;
    private static readonly String TEST_BODY_PROCESSED_SUFFIX = TEST_BODY_ATTRIBUTE_NAME + "=\"" + TEST_BODY_ATTRIBUTE_VALUE + "\">" + TEST_HTML_CONTENT + TEST_JS_INIT + "</body>";
    public TestLayoutPlumtreeAS m_environment;
    public TestLayoutPlumtreeDP m_page;
    public override void setUp()
    {
      m_environment = new TestLayoutPlumtreeAS();
      m_page = new TestLayoutPlumtreeDP();
      m_page.SetLayoutMode(true);
      m_page.Init(m_environment);
      m_environment.SetTrackCurrentPage(true);
      m_environment.SetCurrentPage(m_page);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PageBodyTag(), PageBodyTag.TAG.GetName(), BasePageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// This method tests basic display of the pagebody tag, and pass-thru of an HTML tag attribute.
    /// </summary>
    public virtual void testPageBodyTag()
    {
      // generate the markup array for this test case.
      // Can't put this directly as an argument because of jump issues.
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[3];
      }
      int i = 0;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyOpenTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
       PT_XML_TYPES.PT_XML_TYPES_XHTML_ATT}, new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName(),
       TEST_BODY_ATTRIBUTE_NAME}, new Object[]{null, TEST_BODY_ATTRIBUTE_VALUE}};
      // Add the open tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyOpenTagObjXML;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_CONTENT;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyCloseTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE},
       new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName()},
       new Object[]{null}};
      // Add the close tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyCloseTagObjXML;
      i++;
      // Run the markup array through the tag engine.
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      assertNotNull("Tag Engine should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content with page body tag.", "<body onload=\"" + TestLayoutPlumtreeDP.TEST_JAVASCRIPT_PAGE_ONLOAD_DEFAULT + "\" " + TEST_BODY_PROCESSED_SUFFIX,
       result.GetDisplayString());
      HTMLElement resultJavaScript = TagState.GetSharedJavascriptCollection(m_environment);
      assertEquals("Checking no javascript was displayed.", "", resultJavaScript.GetDisplayString());
      }
    
    /// <summary>
    /// This tests merging an onload attribute supplied by the layout
    /// with one supplied by PlumtreeDP.
    /// </summary>
    public virtual void testPageBodyTagWithOnLoad()
    {
      // generate the markup array for this test case.
      // Can't put this directly as an argument because of jump issues.
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[3];
      }
      int i = 0;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyOpenTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
       PT_XML_TYPES.PT_XML_TYPES_XHTML_ATT, PT_XML_TYPES.PT_XML_TYPES_XHTML_ATT},
       new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName(),
       TEST_BODY_ATTRIBUTE_NAME, TEST_BODY_ONLOAD_NAME}, new Object[]{null,
       TEST_BODY_ATTRIBUTE_VALUE, TEST_BODY_ONLOAD_VALUE}};
      // Add the open tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyOpenTagObjXML;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_CONTENT;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyCloseTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE},
       new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName()},
       new Object[]{null}};
      // Add the close tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyCloseTagObjXML;
      i++;
      // Run the markup array through the tag engine.
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      assertNotNull("Page should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content with page body tag with onload aggregation.",
       "<body onload=\"" + TestLayoutPlumtreeDP.TEST_JAVASCRIPT_PAGE_ONLOAD_DEFAULT + TEST_BODY_ONLOAD_VALUE + "\" " + TEST_BODY_PROCESSED_SUFFIX,
       result.GetDisplayString());
      HTMLElement resultJavaScript = TagState.GetSharedJavascriptCollection(m_environment);
      assertEquals("Checking no javascript was displayed.", "", resultJavaScript.GetDisplayString());
      }
    
    /// <summary>
    /// This tests merging an onload attribute supplied by the layout
    /// with one supplied by PlumtreeDP where one of them doesn't end with
    /// a semicolon.
    /// </summary>
    public virtual void testPageBodyTagWithOnLoadMissingSemicolon()
    {
      // generate the markup array for this test case.
      // Can't put this directly as an argument because of jump issues.
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[3];
      }
      int i = 0;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyOpenTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
       PT_XML_TYPES.PT_XML_TYPES_XHTML_ATT, PT_XML_TYPES.PT_XML_TYPES_XHTML_ATT},
       new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName(),
       TEST_BODY_ATTRIBUTE_NAME, TEST_BODY_ONLOAD_NAME}, new Object[]{null,
       TEST_BODY_ATTRIBUTE_VALUE, TEST_BODY_ONLOAD_VALUE}};
      // Add the open tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyOpenTagObjXML;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_CONTENT;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyCloseTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE},
       new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName()},
       new Object[]{null}};
      // Add the close tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyCloseTagObjXML;
      i++;
      // Set the page to use javascript that doesn't have a colon after it.
      m_page.SetOnLoad(TEST_BODY_PAGE_ONLOAD_VALUE_NO_SEMICOLON);
      // Run the markup array through the tag engine.
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      assertNotNull("Page should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content with page body tag with onload aggregation. " + "Semicolons should have been added between statements.",
       "<body onload=\"" + TEST_BODY_PAGE_ONLOAD_VALUE_NO_SEMICOLON + ";" + TEST_BODY_ONLOAD_VALUE + "\" " + TEST_BODY_PROCESSED_SUFFIX,
       result.GetDisplayString());
      HTMLElement resultJavaScript = TagState.GetSharedJavascriptCollection(m_environment);
      assertEquals("Checking no javascript was displayed.", "", resultJavaScript.GetDisplayString());
      }
  }
}