using System;
using junit.framework;
using com.bea.alui.taglib.basepage;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.basepage.test.integration
{
  public class PlumtreeDPLayoutIntegrationTest : TestCase
  {
    private const String TEST_HTML_OPEN_TAG = "<html>";
    private const String TEST_HTML_CLOSE_TAG = "</html>";
    private const String TEST_HEAD_OPEN_TAG = "<head>";
    private const String TEST_HEAD_CLOSE_TAG = "</head>";
    private const String TEST_JAVASCRIPT_OPEN_TAG = "<script type=\"text/javascript\">";
    private const String TEST_JAVASCRIPT_CLOSE_TAG = "</script>";
    private const String TEST_BODY_OPEN_TAG = "<body>";
    // The head preprocessor adds the headincludes tag.
    private const String TEST_HTML_PROCESSED_PREFIX = "<html><head><pt:common.headincludes/></head>";
    private const String TEST_PROCESSED_PREFIX = "<pt:common.headincludes/>";
    private static readonly String TEST_HTML_PROCESSED_WITH_META_PREFIX = "<html><head><meta http-equiv=\"refresh\" content=\"" + TestLayoutPlumtreeDP.TEST_META_REFRESH_URL + "\"></meta><pt:common.headincludes/></head>";
    private const String TEST_HTML_CONTENT = "Test content.";
    private static readonly String TEST_BODY_PROCESSED = "<body onload=\"" + TestLayoutPlumtreeDP.TEST_JAVASCRIPT_PAGE_ONLOAD_DEFAULT + "\">" + TEST_HTML_CONTENT + TEST_JAVASCRIPT_OPEN_TAG + PlumtreeDP.JAVASCRIPT_INITIALIZE_EVENTS + TEST_JAVASCRIPT_CLOSE_TAG + "</body>";
    private const String TEST_HTML_SUFFIX = "</body></html>";
    public TestLayoutPlumtreeDP m_layoutPage;
    public MockLayoutManager m_layoutManager;
    public MockEnvironment m_environment;
    public MockPTConfigHelper m_helper;
    public override void setUp()
    {
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      // Enable layouts globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      m_environment = new TestLayoutPlumtreeAS();
      m_layoutPage = new TestLayoutPlumtreeDP();
      m_layoutPage.SetLayoutMode(true);
      m_layoutPage.Init(m_environment);
      m_environment.SetTrackCurrentPage(true);
      m_environment.SetCurrentPage(m_layoutPage);
      m_layoutManager = new MockLayoutManager();
      LayoutService.setManagerTestInstance(m_layoutManager);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new ContentTag(), ContentTag.TAG.GetName(), BasePageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PageBodyTag(), PageBodyTag.TAG.GetName(), BasePageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PageRefreshTag(), PageRefreshTag.TAG.GetName(), BasePageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new HeaderTag(), HeaderTag.TAG.GetName(), BasePageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new FooterTag(), FooterTag.TAG.GetName(), BasePageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    //		MockConfigHelper mockIncluder = new MockConfigHelper();
    //		ConfigService.setTestInstance(mockIncluder);
    //		MockPTOpenerHelper mockOpener = new MockPTOpenerHelper();
    //		PTOpenerService.setTestInstance(mockOpener);
    public virtual void testContentTag()
    {
      // Can't put this directly as an argument because of jump issues.
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[9];
      }
      int i = setEmptyHeadHTML(objArrMarkup);
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_BODY_OPEN_TAG;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] singletonTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
       PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE}, new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + ContentTag.TAG.GetName(),
       null}, new Object[]{null, null}};
      // Add a singleton tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = singletonTagObjXML;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_SUFFIX;
      i++;
      m_layoutManager.SetLayout(Layouts.BASE_PAGE.GetDefaultWebServiceID(),
       objArrMarkup);
      HTMLElement result = m_layoutPage.GetLayoutTestResult();
      assertNotNull("Page should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content", TEST_HTML_PROCESSED_PREFIX + TEST_BODY_OPEN_TAG + TestLayoutPlumtreeDP.TEST_BODY_CONTENT + TEST_HTML_SUFFIX,
       result.GetDisplayString());
      HTMLElement resultJavaScript = TagState.GetSharedJavascriptCollection(m_environment);
      assertEquals("Checking basic PTDP javascript was displayed.", TEST_JAVASCRIPT_OPEN_TAG + TestLayoutPlumtreeDP.TEST_JAVASCRIPT_BASIC_CONTENT + TEST_JAVASCRIPT_CLOSE_TAG,
       resultJavaScript.GetDisplayString());
    }
    
    /// <summary>
    /// This method tests simple integration.  A more complete testing of the PageBodyTag
    /// can be found in the TestPageBodyTag class.
    /// </summary>
    public virtual void testPageBodyTag()
    {
      // Can't put this directly as an argument because of jump issues.
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[10];
      }
      int i = setEmptyHeadHTML(objArrMarkup);
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyOpenTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI},
       new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName()},
       new Object[]{null}};
      // Add the open tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyOpenTagObjXML;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_CONTENT;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
      // Can't put this directly as an argument because of jump issues.
      Object[][] bodyCloseTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE},
       new Object[]{BasePageTagLibraryData.LIBRARY.GetName() + "." + PageBodyTag.TAG.GetName()},
       new Object[]{null}};
      // Add the close tag
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = bodyCloseTagObjXML;
      i++;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_CLOSE_TAG;
      i++;
      m_layoutManager.SetLayout(Layouts.BASE_PAGE.GetDefaultWebServiceID(),
       objArrMarkup);
      HTMLElement result = m_layoutPage.GetLayoutTestResult();
      assertNotNull("Page should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content with page body tag.", TEST_HTML_PROCESSED_PREFIX + TEST_BODY_PROCESSED + TEST_HTML_CLOSE_TAG,
       result.GetDisplayString());
    }
    public virtual void testPageRefreshTag()
    {
      // Can't put this directly as an argument because of jump issues.
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[8];
      }
      int i = setHeadHTML(objArrMarkup, BasePageTagLibraryData.LIBRARY.GetName() + "." + PageRefreshTag.TAG.GetName(),
       null);
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX;
      i++;
      m_layoutManager.SetLayout(Layouts.BASE_PAGE.GetDefaultWebServiceID(),
       objArrMarkup);
      HTMLElement result = m_layoutPage.GetLayoutTestResult();
      assertNotNull("Page should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content with page refresh tag.", TEST_HTML_PROCESSED_WITH_META_PREFIX + TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX,
       result.GetDisplayString());
    }
    public virtual void testHeaderTag()
    {
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[8];
      }
      int i = setHeadHTML(objArrMarkup, BasePageTagLibraryData.LIBRARY.GetName() + "." + HeaderTag.TAG.GetName(),
       null);
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX;
      i++;
      m_layoutManager.SetLayout(Layouts.BASE_PAGE.GetDefaultWebServiceID(),
       objArrMarkup);
      HTMLElement result = m_layoutPage.GetLayoutTestResult();
      assertNotNull("Page should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content with Header tag.", TEST_HTML_OPEN_TAG + TEST_HEAD_OPEN_TAG + TestLayoutPlumtreeDP.TEST_HEADER_CONTENT + TEST_PROCESSED_PREFIX + TEST_HEAD_CLOSE_TAG + TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX,
       result.GetDisplayString());
    }
    public virtual void testFooterTag()
    {
      Object[][] objArrMarkup = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        objArrMarkup[j2c_index] = new Object[8];
      }
      int i = setHeadHTML(objArrMarkup, BasePageTagLibraryData.LIBRARY.GetName() + "." + FooterTag.TAG.GetName(),
       null);
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX;
      i++;
      m_layoutManager.SetLayout(Layouts.BASE_PAGE.GetDefaultWebServiceID(),
       objArrMarkup);
      HTMLElement result = m_layoutPage.GetLayoutTestResult();
      assertNotNull("Page should return non-null HTMLElement.", result);
      assertEquals("Checking displayed content with Footer tag.", TEST_HTML_OPEN_TAG + TEST_HEAD_OPEN_TAG + TestLayoutPlumtreeDP.TEST_FOOTER_CONTENT + TEST_PROCESSED_PREFIX + TEST_HEAD_CLOSE_TAG + TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX,
       result.GetDisplayString());
    }
    
    /// <summary>
    /// This method sets up an empty head tag (with html open).  It uses
    /// up 6 spots in the array.
    /// </summary>
    /// <param name="_markup"></param>
    /// <returns>the index into the next empty spot in the array</returns>
    public virtual int setEmptyHeadHTML(Object[][] _markup)
    {
      return setHeadHTML(_markup, null, null);
    }
    
    /// <summary>
    /// This method sets up an empty head tag (with html open).  It uses
    /// up 6 spots in the array, plus one if you add HTML.
    /// </summary>
    /// <param name="_markup"></param>
    /// <param name="The">full name (lib.name) of the adaptive tag to insert into the head.</param>
    /// <returns>the index into the next empty spot in the array</returns>
    public virtual int setHeadHTML(Object[][] _markup, String _strFullTagName,
     XPHashtable attMap)
    {
      int i = 0;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_OPEN_TAG;
      i++;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML;
      i++;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HEAD_OPEN_TAG;
      i++;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD;
      i++;
      if (_strFullTagName != null)
      {
        _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML;
        if (attMap != null)
        {
          int arrSize = attMap.GetSize() + 2;
          Object[] tagType = new Object[arrSize];
          Object[] tagInfo = new Object[arrSize];
          Object[] tagVals = new Object[arrSize];
          tagType[0] = PT_XML_TYPES.PT_XML_TYPES_PTUI;
          tagInfo[0] = BasePageTagLibraryData.LIBRARY.GetName() + "." + NavAreaTag.TAG.GetName();
          tagVals[0] = null;
          int k = 1;
          for (IXPEnumerator e = attMap.GetKeys();e.MoveNext();)
          {
            tagType[k] = PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT;
            tagInfo[k] = e.GetCurrent();
            tagVals[k] = attMap.GetElement(e.GetCurrent());
            k++;
          }
          tagType[arrSize - 1] = PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE;
          tagInfo[arrSize - 1] = null;
          tagVals[arrSize - 1] = null;
          Object[][] singletonTagObjXML = {tagType, tagInfo, tagVals};
          _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = singletonTagObjXML;
          i++;
        } else
        {
          // Can't put this directly as an argument because of jump issues.
          Object[][] singletonTagObjXML = {new Object[]{PT_XML_TYPES.PT_XML_TYPES_PTUI,
           PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE}, new Object[]{_strFullTagName,
           null}, new Object[]{null, null}};
          // Add a singleton tag
          _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = singletonTagObjXML;
          i++;
        }
      }
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD;
      i++;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] = PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED;
      _markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HEAD_CLOSE_TAG;
      i++;
      return i;
    }
  }
}