package com.bea.alui.taglib.basepage;

import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

public class ContentTag extends ABasePageTag
{
	private static final String TAG_NAME = "content";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute DISPLAY_HTML;
	
	private boolean _bHTML = true;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays the body content for this page.");
		DISPLAY_HTML = new OptionalTagAttribute("html",
				"This optional boolean attribute is used to specify if HTML and JavaScript will be displayed or not. " 
				+ "If this is false no HTML and JS will be displayed by this tag.", AttributeType.BOOLEAN, "true");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		
		PlumtreeDP page = GetPlumtreeDP();

		HTMLElementCollection content = new HTMLElementCollection();
		
	
		_bHTML = GetTagAttributeAsBoolean(DISPLAY_HTML);
		
		// If optional 'html' tag attribute is set to false then no wrapping HTML will
		// be displayed by this tag and inner content is directly displayed.
		// This is mainly useful to display XML pages.
		if(!_bHTML) 
		{
			content.AddInnerHTMLElement(page.PageDisplay());
			return content;
		}

		HTMLElementCollection myHTMLBeforeForm = page.DisplayHTMLBeforeForm();
		if (null != myHTMLBeforeForm)
		{
			content.AddInnerHTMLElement(myHTMLBeforeForm);
		}
		
		if (page.GetAddMainForm())
		{
			// NOTE: This displays the form header, footer, and status views.
			// Customers may want to customize this HTML as well.
			content.AddInnerHTMLElement(page.DisplayForm());
		}
		else
		{
			content.AddInnerHTMLElement(page.PageDisplay());
		}

		// NOTE: PlumtreeDP didn't properly display the HTMLAfterForm before,
		// but we add it here anyways.
		HTMLElementCollection myHTMLAfterForm = page.DisplayHTMLAfterForm();
		if (null != myHTMLAfterForm)
		{
			content.AddInnerHTMLElement(myHTMLAfterForm);
		}

		return content;
	}

	public HTMLScriptCollection DisplaySharedJavascript()
	{
		_bHTML = GetTagAttributeAsBoolean(DISPLAY_HTML);
		PlumtreeDP page = GetPlumtreeDP();

		// If optional 'html' tag attribute is set to false then no JS will
		// be displayed by this tag and inner content is directly displayed. 
		// This is mainly useful to display XML pages.

		if (page.GetUseJavascript() && _bHTML)
		{
			return page.GetBasicJavascript();
		}

		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new ContentTag();
	}
}