/*******************************************************************************
 *  BEA Systems, Inc. CONFIDENTIAL
 * _______________________________
 * 
 *  (c) Copyright 2007  BEA Systems, Inc.
 *  All Rights Reserved.
 * 
 *  NOTICE:  All information contained herein is, and remains
 *  the property of BEA Systems, Inc. and its suppliers, if any.
 *  The intellectual and technical concepts contained herein
 *  are proprietary to BEA Systems, Inc. and its suppliers and may
 *  be covered by U.S. and Foreign Patents, patents in process,
 *  and are protected by trade secret or copyright law.
 *  Dissemination of this information or reproduction of this material
 *  is strictly forbidden unless prior written permission is obtained
 *  from BEA Systems, Inc..
 *******************************************************************************/
package com.bea.alui.taglib.basepage;

import com.plumtree.openfoundation.util.XPException;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag displays a Layout Footer.
 * @author Ravi Tunuguntla
 *
 */
public class FooterTag extends ABasePageTag
{
	private static final String TAG_NAME = "footer";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag displays the footer content for this page.");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		
		HTMLElementCollection myFooterHTML = null;		
		INavigationModelRO navModel = (INavigationModelRO)((AActivitySpace)GetEnvironment()).GetModel(NavigationModel.STR_MVC_CLASS_NAME);;
		
		if(navModel != null){
			myFooterHTML = navModel.GetFooterElement();
		} else{
			throw new XPException("Navigation Model is null, ActivitySpace did not initialize properly");
		}
		return myFooterHTML;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new FooterTag();
	}
}