/*******************************************************************************
 *  BEA Systems, Inc. CONFIDENTIAL
 * _______________________________
 * 
 *  (c) Copyright 2007  BEA Systems, Inc.
 *  All Rights Reserved.
 * 
 *  NOTICE:  All information contained herein is, and remains
 *  the property of BEA Systems, Inc. and its suppliers, if any.
 *  The intellectual and technical concepts contained herein
 *  are proprietary to BEA Systems, Inc. and its suppliers and may
 *  be covered by U.S. and Foreign Patents, patents in process,
 *  and are protected by trade secret or copyright law.
 *  Dissemination of this information or reproduction of this material
 *  is strictly forbidden unless prior written permission is obtained
 *  from BEA Systems, Inc..
 *******************************************************************************/
package com.bea.alui.taglib.basepage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.navtype.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

// *** CR rob - add some log statements to make debugging easier
public class NavAreaTag extends ATag
{
	private static final String TAG_NAME = "navarea";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute AREA;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, "This tag displays the required html for this navigational area.");

		XPStringBuilder attrdoc = new XPStringBuilder("This attribute is used to specify the location of the navigation area. The allowable values for this attribute are: ");
		for(int i = 0; i < NavAreaEnum.m_navAreaEnums.length ; i++ ){
			attrdoc.Append( (i < (NavAreaEnum.m_navAreaEnums.length-1) ? NavAreaEnum.m_navAreaEnums[i].toString() + ", ": "and " + NavAreaEnum.m_navAreaEnums[i].toString() + "."));
		}

		AREA = new RequiredTagAttribute( "area", attrdoc.toString() , AttributeType.STRING);
	}

	protected PlumtreeDP GetPlumtreeDP()
	{
		AActivitySpace space = (AActivitySpace) GetEnvironment();
		IDisplayPage basePage = space.GetCurrentPage();

		if (!(basePage instanceof PlumtreeDP))
		{
			throw new XPException(TAG_NAME + " tag can only be used with " +
				"pages that extend PlumtreeDP.  " + basePage.GetName() + " does not.");
		}

		return (PlumtreeDP) basePage;
	}
	
	private IView GetNavAreaView()
	{
		PlumtreeDP page = GetPlumtreeDP();
		
		String sArea = GetTagAttributeAsString(AREA);
		NavAreaEnum navArea = null;
		if(null != sArea){
			navArea = NavAreaEnum.GetNavArea(sArea);
		}else{
			throw new XPException("Value for area attribute " + sArea + " is not valid." );
		}
	
		if(navArea == null){
			return null;
		}
		
		INavTypes navType = ((ITypes)GetEnvironment()).GetNavType(page.GetNavScheme());


		String strView = navType.GetNavAreaView(navArea);

		if(strView == null){
			return null;
		}
		
		IView navAreaView =  ((AActivitySpace)GetEnvironment()).GetView(strView);

		//	*** CR rob - would be useful if an html comment was added in case the nav area returned empty result

		if(null == navAreaView)
		{
			throw new XPException("Navigation view for the area " + sArea + " is null");
		}

		return navAreaView;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		// TODO CR DLH: The DisplayTag() method should return an HTMLCollection,
		// not an HTMLScriptCollection.  JavaScript should be handled by calling
		// the AddJavascript() method on the tag with the JS.
		HTMLElementCollection navCol = new HTMLElementCollection();
		if(GetNavAreaView() != null){
			navCol.AddInnerHTMLElement(GetNavAreaView().Display());
		}else{
			navCol.AddInnerHTMLElement(ProcessTagBody());
		}

		AddJavascript(DisplayJavascript());
		return navCol;
	}
	
	
	/**
	 * This method gets JavaScript once per page regardless of the 
	 * number of NavAreaTags included in the page.
	 * @return JavaScript Collection shared between multiple NavArea Tags
	 * 
	 */
	public HTMLScriptCollection DisplaySharedJavascript()
	{
		HTMLScriptCollection result = new HTMLScriptCollection();

		INavTypes navType = ((ITypes)GetEnvironment()).GetNavType(GetPlumtreeDP().GetNavScheme());
		result.AddInnerHTMLElement(navType.JavaScriptIncludes((AActivitySpace)GetEnvironment()));
		
		HTMLScript tempIncl = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		tempIncl.AddInnerHTMLString(NavigationCommonHelpers.writeURLTemplateParseFunction(
				(AActivitySpace) GetEnvironment()));
		
		result.AddInnerHTMLElement( tempIncl);
			
		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayJavascript()
	 * 
	 */
	public HTMLScriptCollection DisplayJavascript(){

		if(GetNavAreaView() != null){
			HTMLScriptCollection result = new HTMLScriptCollection();		
			result.AddInnerHTMLElement(GetNavAreaView().DisplayJavascript());		
			return result;
		}
		
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag handles both standard and 508 modes.
		return (_style.GetAccessID() == AccessStyles.STANDARD.GetAccessID() || _style.GetAccessID() == AccessStyles.SECTION_508.GetAccessID() );
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new NavAreaTag();
	}
}