/*******************************************************************************
 *  BEA Systems, Inc. CONFIDENTIAL
 * _______________________________
 * 
 *  (c) Copyright 2007  BEA Systems, Inc.
 *  All Rights Reserved.
 * 
 *  NOTICE:  All information contained herein is, and remains
 *  the property of BEA Systems, Inc. and its suppliers, if any.
 *  The intellectual and technical concepts contained herein
 *  are proprietary to BEA Systems, Inc. and its suppliers and may
 *  be covered by U.S. and Foreign Patents, patents in process,
 *  and are protected by trade secret or copyright law.
 *  Dissemination of this information or reproduction of this material
 *  is strictly forbidden unless prior written permission is obtained
 *  from BEA Systems, Inc..
 *******************************************************************************/
package com.bea.alui.taglib.basepage.test;

import junit.framework.*;

import com.bea.alui.taglib.basepage.*;
import com.bea.alui.taglib.basepage.test.integration.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.layout.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

// *** CR rob - high level description of what is tested by this class missing 
public class TestNavAreaTag extends TestCase
{
	private static final String TEST_HTML_OPEN_TAG = "<html>";
	private static final String TEST_HEAD_OPEN_TAG = "<head>";
	private static final String TEST_JS_TAG = "<script type=\"text/javascript\"></script>";
	private static final String TEST_HEAD_CLOSE_TAG = "</head>";
	private static final String TEST_BODY_OPEN_TAG = "<body>";
	private static final String TEST_HTML_SUFFIX = "</body></html>";
	private static final String TEST_PROCESSED_PREFIX = "<pt:common.headincludes/>";
	
	public TestLayoutPlumtreeAS m_environment;
	public TestLayoutPlumtreeDP m_layoutPage;
	public MockLayoutManager m_layoutManager;
	public MockPTSession m_session;
	public MockConfigHelper m_configHelper;
	public MockPTConfigHelper m_helper;

	public void setUp()
	{
		m_configHelper = new MockConfigHelper();
		ConfigService.setTestInstance(m_configHelper);
	
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);

		// Enable layouts globally in the config file
		m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
			PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");

		m_environment = new TestLayoutPlumtreeAS();

		m_layoutPage = new TestLayoutPlumtreeDP();
		m_session = new MockPTSession();
		
		m_layoutPage.SetLayoutMode(true);
		m_layoutPage.Init(m_environment);

		m_environment.SetTrackCurrentPage(true);
		m_environment.SetCurrentPage(m_layoutPage);
		m_environment.SetUserSession(m_session);
		
		m_layoutManager = new MockLayoutManager();
		LayoutService.setManagerTestInstance(m_layoutManager);

		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new NavAreaTag(), NavAreaTag.TAG.GetName(), BasePageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	public void testNavAreaTag(){
		Object[][] objArrMarkup = new Object[2][8];
		XPHashtable attrTab = new XPHashtable();
		attrTab.PutElement("area", "ABOVEHEADER");

		int i = setHeadHTML(objArrMarkup,
			BasePageTagLibraryData.LIBRARY.GetName() + "." + NavAreaTag.TAG.GetName(), attrTab);

		/**
		 * HTML Fragment
		 */
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] =
			TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX;
		i++;

		m_layoutManager.SetLayout(Layouts.BASE_PAGE.GetDefaultWebServiceID(), objArrMarkup);

		HTMLElement result = m_layoutPage.GetLayoutTestResult();

		assertNotNull("Page should return non-null HTMLElement.", result);
		assertEquals("Checking displayed content with NavArea tag.", TEST_HTML_OPEN_TAG + TEST_HEAD_OPEN_TAG 
		+ TEST_PROCESSED_PREFIX 
		+ TEST_HEAD_CLOSE_TAG + TEST_BODY_OPEN_TAG + TEST_HTML_SUFFIX, result.GetDisplayString());		
	}
	
	/**
	 * This method sets up an empty head tag (with html open).  It uses
	 * up 6 spots in the array, plus one if you add HTML.
	 * 
	 * @param _markup
	 * @param The full name (lib.name) of the adaptive tag to insert into the head.
	 * @return the index into the next empty spot in the array
	 */
	public int setHeadHTML(Object[][] _markup, String _strFullTagName, XPHashtable attMap)
	{
		int i = 0;

		/**
		 * HTML Fragment
		 */
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HTML_OPEN_TAG;
		i++;

		/**
		 * Begin HTML marker Fragment
		 */
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HTML);
		i++;

		/**
		 * HTML Fragment
		 */
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HEAD_OPEN_TAG;
		i++;

		/**
		 * Begin Head marker Fragment
		 */
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_BEGIN_HEAD);
		i++;

		if (_strFullTagName != null)
		{
			/**
			 * Singleton PT Tag
			 */
			_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
				new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML);

			if(attMap != null){
				
				int arrSize = attMap.GetSize() + 2;
		
				Object[] tagType = new Object[arrSize];
				Object[] tagInfo = new Object[arrSize];
				Object[] tagVals = new Object[arrSize];
				
			
				tagType[0] = new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI);
				tagInfo[0] = BasePageTagLibraryData.LIBRARY.GetName() + "." + NavAreaTag.TAG.GetName();
				tagVals[0] = null;
				
				int k = 1;
				for ( IXPEnumerator e = attMap.GetKeys(); e.MoveNext();){
					tagType[k] = new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT);
					tagInfo[k] = e.GetCurrent() ;
					tagVals[k] = attMap.GetElement(e.GetCurrent());
					k++;
				}
				tagType[arrSize -1] = new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE);
				tagInfo[arrSize -1 ] = null;
				tagVals[arrSize -1] = null;
				
				Object[][] singletonTagObjXML = { tagType, tagInfo, tagVals };
				
				_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = singletonTagObjXML;
				i++;
			}else{

				// Can't put this directly as an argument because of jump issues.
				Object[][] singletonTagObjXML = {
					{ new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI), new Integer(PT_XML_TYPES.PT_XML_TYPES_PTUI_CLOSE) },
					{ _strFullTagName, null },
					{ null, null} };
	
				// Add a singleton tag
				_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = singletonTagObjXML;
				i++;
			}
		}

		/**
		 * End Head marker Fragment
		 */
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_END_HEAD);
		i++;

		/**
		 * HTML Fragment
		 */
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i] =
			new Integer(PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED);
		_markup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i] = TEST_HEAD_CLOSE_TAG;
		i++;

		return i;
	}
}