using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.joincommunitypageeditor
{
  /// <summary>
  /// This tag stores the communities in tag memory.
  /// </summary>
  /// <author>Bobby Tse</author>
  public class CommunityDataTag : ATag
  {
    public const String TAG_NAME = "communitydata";
    public const String NAME = "name";
    public const String DESCRIPTION = "description";
    public const String ID = "id";
    public const String IS_ALREADY_JOINED = "isalreadyjoined";
    public const String INVITATION_ID = "invitationid";
    public const String LAST_MODIFIED = "lastmodified";
    public const String MANDATORY = "mandatory";
    public static readonly String DATATAG_DESCRIPTION = ATag.EncodeForTagDoc(JoinCommunityPageEditorTagLibraryData.FLYOUT_ONLY + "Generates the data required to show a list of communities for the page editor " + "and stores it in memory using the variable name specified by the " + "<code>" + CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. " + "Each result is a DataObject with the following variables:<br/>" + "<ul>" + "<li> <code>" + NAME + "</code> - The name of the community.</li>" + "<li> <code>" + DESCRIPTION + "</code> - The description of the community.</li>" + "<li> <code>" + ID + "</code> - The community ID.</li>" + "<li> <code>" + IS_ALREADY_JOINED + "</code> - True if the user has already joined the community.</li>" + "<li> <code>" + INVITATION_ID + "</code> - The ID to be used in the invitation javascript function. Invitation is disabled if this is -1.</li>" + "<li> <code>" + LAST_MODIFIED + "</code> - The last modified date of the community.</li>" + "<li> <code>" + MANDATORY + "</code> - True if the community is mandatory for the user.</li>" + "</ul>" + "Use tags from the Logic library to iterate over the list and display the results. <br/>" + "NOTE: This tag must be displayed before other joincommunitypageeditor tags so that the page " + "can be initialized properly.");
    public static readonly String DATATAG_EXAMPLE = ATag.EncodeForTagDoc("This simple example loops through results and shows the name for each result.<br/><br/>" + "<code>" + "<pt:" + JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName() + "." + TAG_NAME + " pt:id=\"communities\"/>" + "<pt:logic.foreach pt:data=\"communities\" pt:var=\"community\">" + "  <pt:logic.value pt:value=\"community." + NAME + "\"/>" + "  <br/>" + "</pt:logic.foreach>" + "</code>");
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    static CommunityDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, DATATAG_DESCRIPTION, DATATAG_EXAMPLE);
      ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC, AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      if (objectModel == null)
      {
        throw new XPIllegalStateException("This tag requires a page with the ObjectSelectionModel. None was found in the current ActivitySpace.");
        }
      ISearchResultModelRO searchModel = (ISearchResultModelRO) asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
      if (searchModel == null)
      {
        throw new XPIllegalStateException("This tag requires a page with the SearchResultModel. None was found in the current ActivitySpace.");
        }
      bool bSearch = objectModel.GetDisplaySearch();
      // Since we add and remove objects without using this model,
      // we should requery for the objects on the page every time
      // we display the objects again, otherwise they will show
      // their old state if they have been changed.
      ((IObjectSelectionModel) objectModel).RefreshSelectedObjects();
      int nResultsToDisplay;
      int nFirstResult;
      if (bSearch)
      {
        // Assume ungrouped display
        nResultsToDisplay = searchModel.GetNumDisplayableItems();
        // The search model handles pagination for us.
        nFirstResult = 0;
      } else
      {
        // Cycle through and process all the objects from the object model in browse mode.
        int nResults = objectModel.GetObjectCount();
        // This returns us the number of results to display based on the
        // default items per page and the number of columns being displayed.
        // I.E.  If there are no subfolders and we are displaying 3 columns,
        // this should return 9 instead of 10 so that there isn't an extra
        // result on the last row.
        int nItemsPerPage = objectModel.GetItemsPerPage();
        // Make this 0 based
        nFirstResult = objectModel.GetFirstDisplayableItem() - 1;
        nResultsToDisplay = nFirstResult + nItemsPerPage;
        if (nResultsToDisplay > nResults)
        {
          // Store how many results of type 2 we can display
          nResultsToDisplay = nResults;
          if (nFirstResult > nResultsToDisplay)
          {
            nResultsToDisplay = nFirstResult;
          }
        }
      }
      // Create array list that will hold data objects for each result.
      IXPList resultsList = new XPArrayList();
      // For each result,
      for (int i = nFirstResult;i < nResultsToDisplay;i++)
      {
        // Add the data object of the result to the list of results.
        resultsList.Add(PopulateObject(i, bSearch, objectModel, searchModel));
        }
      // Add list to memory
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, resultsList, tagScope,
       true);
      return ProcessTagBody();
    }
    
    /// <summary>
    /// This helper method gets the current community object and
    /// populates a DataObject with it.
    /// </summary>
    /// <param name="_nIndex">the index of the current community</param>
    /// <param name="_bSearch">are we in search mode</param>
    /// <param name="_objectModel"></param>
    /// <param name="_searchModel"></param>
    /// <returns>the IDataObject for the community</returns>
    public virtual IDataObject PopulateObject(int _nIndex, bool _bSearch,
     IObjectSelectionModelRO _objectModel, ISearchResultModelRO _searchModel)
    {
      // Create the data object.
      HashtableDataObject htObject = new HashtableDataObject();
      // **********************************************************************************************
      // The data added for each result somewhat replicates the logic in:
      // com.plumtree.portalpages.browsing.objectselection.communities.CommunitySelectionViewHelper.DisplayObject()
      //
      // That is the method responsible for displaying each result in the original join communities page.
      // **********************************************************************************************
      // Add the name (html encoded)
      String strName;
      if (_bSearch)
      {
        strName = _searchModel.GetResultName(_nIndex);
      } else
      {
        strName = (String) _objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_NAME);
        }
      htObject.SetData(NAME, strName);
      // Add the description (html encoded)
      String strDescription;
      if (_bSearch)
      {
        // The description is not available in search, so we use the KWIC
        // (Key word in context) instead.  This contains HTML marking the key word,
        // and search HTML encodes the rest of the string to make sure that it
        // can't be hacked.  Therefore, we don't need to HTML encode KWIC.
        strDescription = _searchModel.GetKWIC(_nIndex);
      } else
      {
        // HTML encode this.
        strDescription = XPHttpUtility.HtmlEncode((String) _objectModel.GetObjectFields(_nIndex,
         PT_PROPIDS.PT_PROPID_DESCRIPTION));
      }
      // BT: Bug 70052 - Set to empty string if null. Tag replacement can't handle null value.
      if (strDescription == null)
      {
        strDescription = "";
      }
      htObject.SetData(DESCRIPTION, strDescription);
      // Add the ID
      int nObjectID;
      // NOTE: In search mode, this is a String, but in browse mode, it's an Integer.
      if (_bSearch)
      {
        nObjectID = XPConvert.ToInteger(_searchModel.GetResultObjectID(_nIndex));
        } else
      {
        nObjectID = XPConvert.ToInteger(_objectModel.GetObjectFields(_nIndex,
         PT_PROPIDS.PT_PROPID_OBJECTID));
      }
      htObject.SetData(ID, XPConvert.ToString(nObjectID));
      // The class ID is used lower down
      int nClassID;
      if (_bSearch)
      {
        nClassID = _searchModel.GetResultClassID(_nIndex);
      } else
      {
        // Apparently the object model queries don't include class IDs, and
        // we have to ask the model whether it's a portlet or a bundle.
        nClassID = _objectModel.GetObjectType();
      }
      int nInvitationID = _nIndex;
      // The invitation ID is just the community index in the results. (-1 if a bundle).
      // The invitation popup uses it to lookup the community name and ID.
      htObject.SetData(INVITATION_ID, XPConvert.ToString(nInvitationID));
      // Whether or not the user is already a member of the community.
      bool bAlreadyJoined = false;
      if (nClassID == PT_CLASSIDS.PT_COMMUNITY_ID)
      {
        bAlreadyJoined = _objectModel.GetIsObjectSelected(nObjectID);
      }
      htObject.SetData(IS_ALREADY_JOINED, XPConvert.ToString(bAlreadyJoined));
      // Whether or not this community is mandatory and cannot be unsubscribed
      bool bManadatory = false;
      if (nClassID == PT_CLASSIDS.PT_COMMUNITY_ID)
      {
        bManadatory = _objectModel.DoNotShowObjectWithID(nObjectID);
      }
      htObject.SetData(MANDATORY, XPConvert.ToString(bManadatory));
      XPDateTime dtLMDate;
      if (_bSearch)
      {
        dtLMDate = _searchModel.GetResultLastModified(_nIndex);
      } else
      {
        dtLMDate = (XPDateTime) _objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_LASTMODIFIED);
        }
      XPDateFormat dateFormat = _searchModel.GetDateFormat((AActivitySpace) GetEnvironment());
      htObject.SetData(LAST_MODIFIED, dateFormat.Format(dtLMDate));
      return htObject;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag only handles standard mode.
      return _style == AccessStyles.STANDARD;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new CommunityDataTag();
    }
  }
}