using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.joincommunitypageeditor
{
  /// <summary>
  /// This tag stores the bread crumb path to the current folder in memory.
  /// TODO: Refactor this class.
  /// </summary>
  /// <author>Bobby Tse</author>
  public class JoinCommunityBrowseBreadCrumbDataTag : ATag
  {
    private const String TAG_NAME = "browsebreadcrumbsdata";
    // This is the same as the constant in AKDPageTag
    public const String EMPTY_STRING = "EMPTY_STRING";
    public const String NAME = "name";
    public const String ID = "id";
    public const String URL = "url";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    static JoinCommunityBrowseBreadCrumbDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "This tag stores the breadcrumb path to the current folder in memory. " + "Each breadcrumb data object will have the following variables: <code>" + NAME + "</code> for the breadcrumbs folder name, <code>" + ID + "</code> for the folder ID, " + "and <code>" + URL + "</code> for the URL to access the folder. The current folder will not contain the URL, instead it will have the constant \'" + EMPTY_STRING + "\'. " + "This tag requires the " + JoinCommunityBrowseModeTag.TAG.GetName() + " to be displayed on the page before it." + JoinCommunityPageEditorTagLibraryData.FLYOUT_ONLY);
      ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC, AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new JoinCommunityBrowseBreadCrumbDataTag();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      IXPList breadCrumbsList = new XPArrayList();
      if (!objectModel.GetDisplaySearch())
      {
        // NOTE: This basically follows the BreadCrumbsDataTag for KD 
        // get bread crumb path from model
        IASQueryResult qrFolders = objectModel.GetBreadCrumbPath();
        for (int i = 0;i < qrFolders.GetCount();i++)
        {
          // get name and id from query result
          String strName = (String) qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
          int nFolderID = XPConvert.ToInteger(qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
          // get URL
          ASURL asurl = new ASURL(asOwner);
          asurl.SetLinkGetCachedSpace(asOwner);
          asurl.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
          asurl.AddControlArgument(OpenSubFolderControl.m_SubFolderID, nFolderID);
          // populate data object
          HashtableDataObject htObject = new HashtableDataObject();
          htObject.SetData(NAME, strName);
          htObject.SetData(ID, XPConvert.ToString(nFolderID));
          // Do not add the URL for the last item, since that will be
          // the current folder.
          if (i == qrFolders.GetCount() - 1)
          {
            htObject.SetData(URL, EMPTY_STRING);
          } else
          {
            htObject.SetData(URL, asurl.GetURLAsString());
          }
          breadCrumbsList.Add(htObject);
        }
      } else
      {
      }
      // Only output breadcrumbs if we are in browse mode.
      // add list to memory
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, breadCrumbsList, tagScope,
       true);
      return ProcessTagBody();
    }
  }
}