using System;
using FlyoutJSTag=com.bea.alui.taglib.portletpageeditor.FlyoutJSTag;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.joincommunitypageeditor
{
  /// <summary>
  /// This tag stores the Join Community browse mode flag in memory.
  /// TODO: Refactor this class.
  /// </summary>
  /// <author>Bobby Tse</author>
  public class JoinCommunityBrowseModeTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute JS_OPEN_NAME;
    public static readonly RequiredTagAttribute FLYOUT_ID;
    public static readonly OptionalTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    static JoinCommunityBrowseModeTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      JS_OPEN_NAME = new OptionalTagAttribute("openFolder", "Used to insert a javascript function to open a subfolder. " + "The function has one argument: the folder ID.",
       AttributeType.STRING, "openFolder");
      FLYOUT_ID = JoinCommunityPageEditorTagLibraryData.ATTRIB_FLYOUTID;
      ATTRIB_ID = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       "The name of the variable in memory where the browse mode flag will be stored. " + "If this attribute is not present, then the flag will not be stored.",
       AttributeType.STRING, "");
      ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
      // Put this last because the example references the attributes.  Any relatedchildtag
      // references would need to come after this.
      TAG = new TagMetaData("joincommunitybrowsemode", "Displays the javaScript required to switch to browse mode. The current community\'s folder can be opened directly by using -1 as the id argument." + JoinCommunityPageEditorTagLibraryData.FLYOUT_ONLY,
       ATag.EncodeForTagDoc("<pt:" + JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName() + ".joincommunitybrowsemode pt:" + JS_OPEN_NAME.GetName() + "=\'openFolder\' " + "pt:" + FLYOUT_ID.GetName() + "=\'flyoutControl\'/>"));
      }
    
    /// <returns>HTMLScript the Javascript for opening a folder.</returns>
    public virtual HTMLScript getOpenFolderJS()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      IObjectSelectionModelRO model = (IObjectSelectionModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      // Construct the open folder URL
      ASURL asurl = new ASURL(asOwner);
      asurl.SetLinkGetCachedSpace(asOwner);
      asurl.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
      XPStringBuilder sb = new XPStringBuilder(200);
      // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
      sb.Append(GetTagAttributeAsString(JS_OPEN_NAME)).Append(" = function(id)\n");
      sb.Append("{\n");
      // DCA - add a way to open the community folder directly by using -1 as id
      if (1 <= model.GetSelectorCommunityFolderID())
      {
        sb.Append("  if (id == -1) {\n");
        sb.Append("    id = ").Append(model.GetSelectorCommunityFolderID()).Append(";\n");
        sb.Append("  }\n");
      }
      sb.Append("  var strURL = \'").Append(asurl.GetURLAsString()).Append("&").Append(OpenSubFolderControl.m_SubFolderID).Append("=\' + id;\n");
      sb.Append("  var request = new PTHTTPGETRequest(strURL, ").Append(FlyoutJSTag.FLYOUT_OBJECT).Append(GetTagAttributeAsString(FLYOUT_ID)).Append(".").Append(FlyoutJSTag.ADD_CONTENT).Append(");\n");
      sb.Append("  request.invoke();\n");
      sb.Append("}\n");
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString(sb.ToString());
      return script;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new JoinCommunityBrowseModeTag();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      HTMLElement result = null;
      result = new HTMLElementCollection();
      // NOTE: Since this page doesn't have a HEAD tag, we need to display
      // the javascript directly.
      result.AddInnerHTMLElement(getOpenFolderJS());
      result.AddInnerHTMLElement(ProcessTagBody());
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      if ((strDataReference != null) && (strDataReference.Length > 0))
      {
        // Add browse mode flag to memory
        Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
        GetState().SetSharedVariable(strDataReference, !objectModel.GetDisplaySearch(),
         tagScope, true);
      }
      return result;
    }
  }
}