using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.joincommunitypageeditor
{
  /// <summary>
  /// This tag stores a list of subfolders of the current folder in memory.
  /// TODO: Refactor this class
  /// </summary>
  /// <author>Bobby Tse</author>
  public class JoinCommunityBrowseSubFoldersDataTag : ATag
  {
    public const String NAME = "name";
    public const String DESCRIPTION = "description";
    public const String ID = "id";
    public const String URL = "url";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    static JoinCommunityBrowseSubFoldersDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("joincommunitybrowsesubfoldersdata", "Stores a list of subfolders of the current folder in memory. " + "Each subfolder data object will have the following variables: <code>" + NAME + "</code> - the name of the subfolder, <code>" + DESCRIPTION + "</code> - the subfolder description, <code>" + ID + "</code> - the subfolder ID, and <code>" + URL + "</code> - the URL to access the folder. " + "This list will only be populated if the page is in browse mode. " + "This tag requires the " + JoinCommunityBrowseModeTag.TAG.GetName() + " to be displayed on the page before it." + JoinCommunityPageEditorTagLibraryData.FLYOUT_ONLY);
      ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC, AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      IFolderModelRO objectModel = (IFolderModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      IXPList subFoldersList = new XPArrayList();
      // Only display subfolders if we're in browse mode
      if (!((IObjectSelectionModelRO) objectModel).GetDisplaySearch())
      {
        IASQueryResult qrFolders = objectModel.GetFolderQueryResult();
        for (int i = 0;i < qrFolders.GetCount();i++)
        {
          subFoldersList.Add(GetFolderDataObjectFromQuery(i, qrFolders, asOwner));
          }
      }
      // add to memory
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, subFoldersList, tagScope,
       true);
      return ProcessTagBody();
    }
    
    /// <summary>
    /// Gets the information of the folder in row: index from the query result creates the data object
    /// out of it.
    /// </summary>
    /// <param name="index">the index of the folder wanted</param>
    /// <param name="qrFolders">the query result containing folders</param>
    /// <param name="_asOwner">the current activity space</param>
    /// <returns>	HashtableDataObject</returns>
    private HashtableDataObject GetFolderDataObjectFromQuery(int index, IASQueryResult qrFolders,
     AActivitySpace _asOwner)
    {
      String strName = (String) qrFolders.GetFields(index, PT_PROPIDS.PT_PROPID_NAME);
      String strDescription = (String) qrFolders.GetFields(index, PT_PROPIDS.PT_PROPID_DESCRIPTION);
      int nFolderID = XPConvert.ToInteger(qrFolders.GetFields(index, PT_PROPIDS.PT_PROPID_OBJECTID));
      ASURL asurl = new ASURL(_asOwner);
      asurl.SetLinkGetCachedSpace(_asOwner);
      asurl.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
      asurl.AddControlArgument(OpenSubFolderControl.m_SubFolderID, nFolderID);
      HashtableDataObject htObject = new HashtableDataObject();
      htObject.SetData(NAME, strName);
      htObject.SetData(DESCRIPTION, XPHttpUtility.HtmlEncode(strDescription));
      htObject.SetData(ID, XPConvert.ToString(nFolderID));
      htObject.SetData(URL, asurl.GetURLAsString());
      return htObject;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new JoinCommunityBrowseSubFoldersDataTag();
    }
  }
}