using System;
using junit.framework;
using com.bea.alui.taglib.joincommunitypageeditor;
using com.bea.alui.taglib.portletpageeditor.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.joincommunitypageeditor.test
{
  /// <summary>
  /// This tests the basic functionality of the sub folders data tag.
  /// </summary>
  public class TestJoinCommunityBrowseSubFoldersDataTag : TestCase
  {
    private static String ID_VALUE = "my-subfolders";
    private int subFolder1Id = 201;
    private String subFolder1Name = "subfolder 1";
    private int subFolder2Id = 3425;
    private String subFolder2Name = "subfolder 2";
    private int subFolder3Id = 341;
    private String subFolder3Name = "subfolder 3";
    private AActivitySpace m_environment;
    private MockObjectSelectionModel m_objModel;
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      MockConfigHelper helper = new MockConfigHelper();
      ConfigService.setTestInstance(helper);
      MockPTConfigHelper ptHelper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(ptHelper);
      MockPTQueryResult qrSubFolders = new MockPTQueryResult();
      // False means the data needs to be flipped.
      qrSubFolders.SetData(new int[]{PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME},
       new Object[][]{new Object[]{subFolder1Id, subFolder1Name}, new Object[]{subFolder2Id,
       subFolder2Name}, new Object[]{subFolder3Id, subFolder3Name}}, false);
      IASQueryResult folderQueryResult = new ASQueryResultWrapper(qrSubFolders);
      m_objModel = new MockObjectSelectionModel();
      m_objModel.SetFolderQueryResult(folderQueryResult);
      m_environment = new MockEnvironment();
      ((MockEnvironment) m_environment).m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
       m_objModel);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new JoinCommunityBrowseSubFoldersDataTag(), JoinCommunityBrowseSubFoldersDataTag.TAG.GetName(),
       JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
      m_environment = null;
      m_objModel = null;
    }
    
    /// <summary>
    /// Test doing nothing if we're in search mode.
    /// </summary>
    public virtual void testNoSubFolders()
    {
      m_objModel.m_bDisplaySearch = true;
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(),
       JoinCommunityBrowseSubFoldersDataTag.TAG.GetName());
      helper.AddPTAttribute(JoinCommunityBrowseSubFoldersDataTag.ATTRIB_ID.GetName(),
       ID_VALUE);
      helper.AddPTAttribute(JoinCommunityBrowseSubFoldersDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       result.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // public variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      Assert.assertNotNull("Checking data list exists.", ssVariable);
      IXPList subFolders = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the subfolders list in memory is incorrect.",
       0, subFolders.GetSize());
    }
    
    /// <summary>
    /// Test outputting the subfolder data if we're in browse mode.
    /// </summary>
    public virtual void testSubFolders()
    {
      m_objModel.m_bDisplaySearch = false;
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(),
       JoinCommunityBrowseSubFoldersDataTag.TAG.GetName());
      helper.AddPTAttribute(JoinCommunityBrowseSubFoldersDataTag.ATTRIB_ID.GetName(),
       ID_VALUE);
      helper.AddPTAttribute(JoinCommunityBrowseSubFoldersDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       result.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // public variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      Assert.assertNotNull("Checking data list exists.", ssVariable);
      IXPList subFolders = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the subfolders list in memory is incorrect.",
       3, subFolders.GetSize());
      int nIndex = 0;
      checkSubFolder((IDataObject) subFolders.GetElement(nIndex), nIndex,
       subFolder1Name, subFolder1Id);
      nIndex++;
      checkSubFolder((IDataObject) subFolders.GetElement(nIndex), nIndex,
       subFolder2Name, subFolder2Id);
      nIndex++;
      checkSubFolder((IDataObject) subFolders.GetElement(nIndex), nIndex,
       subFolder3Name, subFolder3Id);
      nIndex++;
    }
    
    /// <summary>
    /// Helper method to check the subfolder data.
    /// </summary>
    /// <param name="_folder"></param>
    /// <param name="_nIndex"></param>
    /// <param name="_strName"></param>
    /// <param name="_nID"></param>
    public virtual void checkSubFolder(IDataObject _folder, int _nIndex, String _strName,
     int _nID)
    {
      String name = _folder.GetData(JoinCommunityBrowseSubFoldersDataTag.NAME);
      Assert.assertEquals("Wrong name returned for subfolder " + _nIndex + ".",
       _strName, name);
      int id = XPConvert.ToInteger(_folder.GetData(JoinCommunityBrowseSubFoldersDataTag.ID));
      Assert.assertEquals("Wrong id returned for subfolder " + _nIndex + ".",
       _nID, id);
    }
  }
}