using System;
using junit.framework;
using com.bea.alui.taglib.joincommunitypageeditor;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.joincommunitypageeditor.test
{
  public class TestJoinCommunityJSTag : TestCase
  {
    public MockEnvironment m_environment;
    // All of our AJAX JS funcs should be of the form "name = function(args)".
    public const String JS_FUNCTION_SUFFIX = " = function(";
    public const String FLYOUTID = "mockFlyoutId";
    public const String JOIN_JS_NAME = "testJoinCommunity";
    public const String LEAVE_JS_NAME = "testLeaveCommunity";
    public const String PREVIEW_JS_NAME = "testPreviewCommunity";
    public const String INVITE_JS_NAME = "testCommunityInvitation";
    public override void setUp()
    {
      ConfigService.setTestInstance(new MockConfigHelper());
      m_environment = new MockEnvironment();
      m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
       new ObjectSelectionModel());
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new CommunityJSTag(), CommunityJSTag.TAG.GetName(), JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// This method tests basic display of the JavaScript functions.
    /// </summary>
    public virtual void testJS()
    {
      // initialize markup
      XMLFragmentTestHelper CommunityJSTagHelper = new XMLFragmentTestHelper(JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(),
       CommunityJSTag.TAG.GetName());
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.ATTRIB_FLYOUT_ID.GetName(),
       FLYOUTID);
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.JOIN_NAME.GetName(),
       JOIN_JS_NAME);
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.LEAVE_NAME.GetName(),
       LEAVE_JS_NAME);
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.PREVIEW_NAME.GetName(),
       PREVIEW_JS_NAME);
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.INVITATION_NAME.GetName(),
       INVITE_JS_NAME);
      Object[][] objArrMarkup = CommunityJSTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      CheckFunctionName(JOIN_JS_NAME, strResult, true);
      CheckFunctionName(LEAVE_JS_NAME, strResult, true);
      CheckFunctionName(PREVIEW_JS_NAME, strResult, true);
      CheckFunctionName(INVITE_JS_NAME, strResult, true);
    }
    
    /// <summary>
    /// This method tests that no JavaScript displays if you don't request it.
    /// </summary>
    public virtual void testNoJS()
    {
      // initialize markup
      XMLFragmentTestHelper CommunityJSTagHelper = new XMLFragmentTestHelper(JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(),
       CommunityJSTag.TAG.GetName());
      Object[][] objArrMarkup = CommunityJSTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      CheckFunctionName(JOIN_JS_NAME, strResult, false);
      CheckFunctionName(LEAVE_JS_NAME, strResult, false);
      CheckFunctionName(PREVIEW_JS_NAME, strResult, false);
      CheckFunctionName(INVITE_JS_NAME, strResult, false);
    }
    
    /// <summary>
    /// This method tests partial display of some of the JavaScript functions.
    /// </summary>
    public virtual void testPartialJS()
    {
      // initialize markup
      XMLFragmentTestHelper CommunityJSTagHelper = new XMLFragmentTestHelper(JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(),
       CommunityJSTag.TAG.GetName());
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.ATTRIB_FLYOUT_ID.GetName(),
       FLYOUTID);
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.JOIN_NAME.GetName(),
       JOIN_JS_NAME);
      CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.PREVIEW_NAME.GetName(),
       PREVIEW_JS_NAME);
      Object[][] objArrMarkup = CommunityJSTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      // These should be present.
      CheckFunctionName(JOIN_JS_NAME, strResult, true);
      CheckFunctionName(PREVIEW_JS_NAME, strResult, true);
      // These should not be present.
      CheckFunctionName(LEAVE_JS_NAME, strResult, false);
      CheckFunctionName(INVITE_JS_NAME, strResult, false);
    }
    public virtual void CheckFunctionName(String _strJSName, String _strOutput,
     bool bPresent)
    {
      String strFunction = _strJSName + JS_FUNCTION_SUFFIX;
      if (bPresent)
      {
        // Check that it's there.
        Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction + "] is present in output: " + _strOutput,
         XPStringUtility.IndexOf(_strOutput, strFunction) >= 0);
      } else
      {
        // Check that it's not there.
        Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction + "] is not present in output: " + _strOutput,
         XPStringUtility.IndexOf(_strOutput, strFunction) < 0);
      }
    }
  }
}