package com.bea.alui.taglib.joincommunitypageeditor;

import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.uitasks.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Implementation of the AddCommunitiesFlyoutAction PTURL DO Data Tag
 * 
 * @author Bobby Tse
 *
 */
public class AddCommunitiesFlyoutActionDataTag extends ATag 
{
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_ID;
	public static final OptionalTagAttribute ATTRIB_SCOPE;
	public static final OptionalTagAttribute MAX_RESULT_COLUMNS;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("addcommunitiesflyoutdata", 	
			"URL to add Communities Selection Flyout Editor on a page. (The flyout editor allows users to join and " +
			"unsubscribe communities for the current user.) "
			);
		
		ATTRIB_ID = new RequiredTagAttribute("id",
			"The name of the variable in memory where the PTURL DO data created by this tag is stored. "+
			"Specify this ID in the data attribute (most commonly the DATAVAR attribute) for any display tag consuming PTURL DO data. "+
			"Multiple data tags can share the same ID, in which case they are added to a list in the order they were processed. ",	
			AttributeType.STRING);

		ATTRIB_SCOPE = new OptionalTagAttribute("scope",
			"The scope used to store the data. See the Logic tag library for a list of all available scopes. ",
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
		
		MAX_RESULT_COLUMNS = new OptionalTagAttribute("maxresultcolumns",
			"The maximum number of columns used to display results. " +
			"Used to make sure the search results divide evenly " +
			"by the number of columns.  Also used in browse mode " +
			"if there are no subfolders to display.",
			AttributeType.INT, "3");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		IEnvironment env = GetEnvironment();
		IPTURL url = TaskAPIUICommunity.GetURLForJoinCommunitiesFlyout(TaskAPIUICommon.GetEnvTypeObject(env));

		if (url != null) {
			// Set the number of search columns being used so that our results will match evenly.
			url.AddControlParameter(ObjSelQueryArguments.MAX_RESULT_COLUMNS, GetTagAttributeAsInt(MAX_RESULT_COLUMNS));
		}

		GetState().SetSharedVariable(	GetTagAttributeAsString(ATTRIB_ID), 
										url, Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE)), 
										false);
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create()
	{
		return new AddCommunitiesFlyoutActionDataTag();
	}
}
