package com.bea.alui.taglib.joincommunitypageeditor;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.objectselection.communities.*;
import com.plumtree.portalpages.common.uiparts.UnsubscribeCurCommunityControl;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.helpers.ConfigService;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag creates the JS for the community action links.
 * 
 * @author Bobby Tse
 *
 */
public class CommunityJSTag extends ATag 
{
	public static final String ATTRIBUTE_DESCRIPTION =
		"If this attribute is not present, the javascript will not be displayed. " +
		"The value of this attribute will be the name of the javascript function.";

	public static final String SWAP_DESCRIPTION =
		"In order to change the state of a community from joined to unsubscribed and vice-versa, " +
		"the community div needs to have the current type in the class attribute " +
		"(i.e. ali-edit-portlets-narrow) and the other type in the swapclass attribute " +
		"(i.e. ali-edit-portlets-chosen).  The join and leave community links both need to " +
		"be displayed on the page with the style attribute being 'display:none;' or " +
		"'display:visible;', depending on which link is supposed to be shown.  The preview " +
		"community link needs to have an isalreadyjoined attribute with a value of 'true' or 'false' " +
		"depending on whether or not the user has joined community.  The community div and join " +
		"and leave community links and preview community link all need to have ids of " +
		"'communityxx', 'join-communityxx', 'leave-communityxx', and 'preview-communityxx' where " +
		"'xx' is the id of the community.";

	public static final String SWAP_COMMUNITY_JS = "swapCommunity";
	public static final String JOIN_COMMUNITY_PREVIEW_JS = "joinCommunityFromPreview";
	public static final String POPUP_REFERENCE = "popupWindow";
	public static final String COMMUNITY_DIV_ID_PREFIX = "pt-community-";
	public static final String JOIN_COMMUNITY_JSON_JS = "jc.processJoinCommunity";
	public static final String LEAVE_COMMUNITY_JSON_JS = "jc.processLeaveCommunity";
	public static final String JOIN_LEAVE_JSON_RESOURCE_URL = "/api/v1/user/current";
	
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final OptionalTagAttribute JOIN_NAME;
	public static final OptionalTagAttribute LEAVE_NAME;
	public static final OptionalTagAttribute PREVIEW_NAME;
	public static final OptionalTagAttribute INVITATION_NAME;
	public static final RequiredTagAttribute ATTRIB_FLYOUT_ID;

	static
	{
		ATTRIB_FLYOUT_ID = JoinCommunityPageEditorTagLibraryData.ATTRIB_FLYOUTID;
		
		JOIN_NAME = new OptionalTagAttribute("join",
			"Used to insert a javascript function allow the user to join a community. " +
			ATTRIBUTE_DESCRIPTION + " " +
			"The function has one argument: community ID. " + SWAP_DESCRIPTION,
			AttributeType.STRING, "");

		LEAVE_NAME = new OptionalTagAttribute("leave",
			"Used to insert a javascript function allow the user to leave a community. " +
			ATTRIBUTE_DESCRIPTION + " " +
			"The function has one argument: community ID. " + SWAP_DESCRIPTION,
			AttributeType.STRING, "");

		PREVIEW_NAME = new OptionalTagAttribute("preview",
			"Used to insert a javascript function to preview a community. " +
			ATTRIBUTE_DESCRIPTION + " " +
			"The function has two arguments: community ID, and whether or not the community " +
			"is already joined (i.e. this.attributes.isalreadyjoined.nodeValue).",
			AttributeType.STRING, "");

		INVITATION_NAME = new OptionalTagAttribute("invitation",
			"Used to insert a javascript function to display a popup " +
			"with an invitation link to the community. " +
			ATTRIBUTE_DESCRIPTION + " " +
			"The function has one argument: community invitation ID.",
			AttributeType.STRING, "");
		
		// Put this last because the example references the attributes.  Any relatedchildtag
		// references would need to come after this.
		TAG = new TagMetaData("communityjs",
			"Generates the javascript functions required for community preview and invitation. " +
			JoinCommunityPageEditorTagLibraryData.FLYOUT_ONLY,
			ATag.EncodeForTagDoc(
				"<pt:" + JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName() +
				".communityjs pt:" + JOIN_NAME.GetName() + "='joinCommunity' pt:" +
				LEAVE_NAME.GetName() + "='leaveCommunity' pt:" + PREVIEW_NAME.GetName() +
				"='previewCommunity' pt:" + INVITATION_NAME.GetName() + "='invite'/>"));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		HTMLScriptCollection scripts = new HTMLScriptCollection();

		AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
		IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO)
			asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);

		// Page ID on the model is deprecated, so use object ID instead.
		int nPageID = objectModel.GetSelectorObjectID();

		// **********************************************************************************************
		// The JS for preview and invitations somewhat replicates the js in:
		// com.plumtree.portalpages.browsing.objectselection.communities.CommunitySelectionViewHelper.DisplayJavascriptCollection()
		//
		// That is the method responsible for displaying the javascript in the original join communities page.
		// **********************************************************************************************

		// Insert the various JS functions
		boolean bRequiresSwapJS = false;
		bRequiresSwapJS = insertJoinCommunityJS(scripts, asOwner, nPageID) || bRequiresSwapJS;
		bRequiresSwapJS = insertLeaveCommunityJS(scripts, asOwner, nPageID) || bRequiresSwapJS;
		boolean bRequiresWindowJS = false;
		bRequiresWindowJS = insertPreviewCommunityJS(scripts, asOwner, nPageID) || bRequiresWindowJS;
		bRequiresWindowJS = insertInvitationJS(scripts, asOwner, nPageID) || bRequiresWindowJS;

		if (bRequiresSwapJS)
		{
			insertSwapJS(scripts, asOwner, nPageID);
		}

		if (bRequiresWindowJS)
		{
			// The open new window scripts that either js method requires.
			HTMLScript include = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			include.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(asOwner) + "opennewwindow.js");
			scripts.AddInnerHTMLElement(include);
		}

		// NOTE: Since this page doesn't have a HEAD tag, we need to display
		// the javascript directly.
		return scripts;
	}

	/**
	 * This method adds the JS for the Join Community function.
	 * 
	 * @param _scripts Add the JS into this collection.
	 * @param _asOwner The current Activity Space
	 * @param _nPageID The current page iD
	 * @return Whether or not we need the swap JS
	 */
	public boolean insertJoinCommunityJS(HTMLScriptCollection _scripts,
		AActivitySpace _asOwner, int _nPageID)
	{
		String addName = GetTagAttributeAsString(JOIN_NAME);
		if ((addName != null) && (addName.length() > 0))
		{
			// Construct the JSON Join/Leave REST API URL so we can call it.
			String jsonURL = ConfigService.getInstance().GetApplicationBaseURL(_asOwner);
			
			// Get rid of '?' at the end of base URL.
			if (jsonURL.endsWith("?")) {
				jsonURL = jsonURL.substring(0, jsonURL.length() - 1);
			}
			jsonURL += JOIN_LEAVE_JSON_RESOURCE_URL;
			
			// Construct the base join URL
			ASURL asurl = new ASURL(_asOwner);
			asurl.SetLinkGetCachedSpace(_asOwner.GetParentSpace());
			asurl.SetControl(JoinCommunityControl.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(_nPageID));
			asurl.AddControlArgument(ASConstants.PAGE, MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
	
			XPStringBuilder sb = new XPStringBuilder(200);

			// We need to be able to cache the reference to the preview community popup
			// so we can close it after the join community AJAX request has finished.
			sb.Append("var ").Append(POPUP_REFERENCE).Append(" = null;\n");
			sb.Append("closePopup = function()\n");
			sb.Append("{\n");
			sb.Append("  ").Append(POPUP_REFERENCE).Append(".close();\n");
			sb.Append("  ").Append(POPUP_REFERENCE).Append(" = null;\n");
			sb.Append("}\n");
			sb.Append("\n");
			
			// We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
			sb.Append(addName).Append(" = function(id)\n");
			sb.Append("{\n");
			
			// Swap community state (join/leave)
			// Call SWAP_COMMUNITY_JS from the JSON JS after determining if the request
			// was successful instead of calling it here.			
			//sb.Append("  ").Append(SWAP_COMMUNITY_JS).Append("(id);\n");
			
			// Call JSON Join Community API
			sb.Append("  ").Append(JOIN_COMMUNITY_JSON_JS).Append("(id, '").Append(jsonURL).Append("');\n");
			
			// We need to close the preview community popup after the join
			// community AJAX request has finished, otherwise the request
			// will be cancelled.
			sb.Append("		if (").Append(POPUP_REFERENCE).Append(" != null)\n");
			sb.Append("     {\n");
			sb.Append("		  setTimeout('closePopup()', 1);\n");
			sb.Append("	    }\n");
			sb.Append("}\n");
	
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString(sb.ToString());
			_scripts.AddInnerHTMLElement(script);

			// We need the swap JS
			return true;
		}

		// We don't need the swap JS
		return false;
	}

	/**
	 * This method adds the JS for the Leave Community function.
	 * 
	 * @param _scripts Add the JS into this collection.
	 * @param _asOwner The current Activity Space
	 * @param _nPageID The current page iD
	 * @return Whether or not we need the swap JS
	 */
	public boolean insertLeaveCommunityJS(HTMLScriptCollection _scripts,
		AActivitySpace _asOwner, int _nPageID)
	{
		String leaveName = GetTagAttributeAsString(LEAVE_NAME);
		if ((leaveName != null) && (leaveName.length() > 0))
		{
			// Construct the JSON Join/Leave REST API URL so we can call it.
			String jsonURL = ConfigService.getInstance().GetApplicationBaseURL(_asOwner);
			
			// Get rid of '?' at the end of base URL.
			if (jsonURL.endsWith("?")) {
				jsonURL = jsonURL.substring(0, jsonURL.length() - 1);
			}
			jsonURL += JOIN_LEAVE_JSON_RESOURCE_URL;
			
			// Construct the base remove URL
			ASURL asurl = new ASURL(_asOwner);
			asurl.SetLinkGetCachedSpace(_asOwner.GetParentSpace());
			asurl.SetControl(UnsubscribeCurCommunityControl.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(_nPageID));
			asurl.AddControlArgument(ASConstants.PAGE, MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
	
			XPStringBuilder sb = new XPStringBuilder(200);
			// We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
			sb.Append(leaveName).Append(" = function(id)\n");
			sb.Append("{\n");
			
			// Swap community state (join/leave)
			// Call SWAP_COMMUNITY_JS from the JSON JS after determining if the request
			// was successful instead of calling it here.
			//sb.Append("  ").Append(SWAP_COMMUNITY_JS).Append("(id);\n");
			
			// Call JSON Leave Community API
			sb.Append("  ").Append(LEAVE_COMMUNITY_JSON_JS).Append("(id, '").Append(jsonURL).Append("');\n");

			sb.Append("}\n");
	
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString(sb.ToString());
			_scripts.AddInnerHTMLElement(script);

			// We need the swap JS
			return true;
		}

		// We don't need the swap JS
		return false;
	}	
	
	/**
	 * This method adds the JS for swapping the community join/leave state.
	 * 
	 * @param _scripts Add the JS into this collection.
	 * @param _asOwner The current Activity Space
	 * @param _nPageID The current page iD
	 */
	public void insertSwapJS(HTMLScriptCollection _scripts,
		AActivitySpace _asOwner, int _nPageID)
	{
		String joinName = GetTagAttributeAsString(JOIN_NAME);
		String leaveName = GetTagAttributeAsString(LEAVE_NAME);
		
		XPStringBuilder sb = new XPStringBuilder(200);
		// We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
		sb.Append(SWAP_COMMUNITY_JS).Append(" = function(id)\n");
		sb.Append("{\n");

		// NOTE: For reserved names like class and style, it's usually safest
		// to use the specific member variable rather than the generic getAttribute().

		// Swap the class of the div controlling the image
		sb.Append("  var communityImg = document.getElementById('community' + id);\n");
		// If this community isn't displayed in the community search list, just return.
		sb.Append("  if (communityImg == null) { return }\n");
		sb.Append("  var origImg = communityImg.src;\n");
		sb.Append("  communityImg.src = communityImg.getAttribute('swapsrc');\n");
		sb.Append("  communityImg.setAttribute('swapsrc', origImg);\n");
		
		// Swap the link onclick for the anchor around the img
		sb.Append("  var imgAnchor = communityImg.parentNode;\n");
		// If this community isn't displayed in the community search list, just return.
		sb.Append("  if (imgAnchor == null) { return }\n");
		sb.Append("  var onclickString = imgAnchor.getAttribute('onclickstring');\n");
		sb.Append("  if (onclickString.indexOf('").Append(joinName).Append("') > -1) {\n");
		sb.Append("    onclickString = onclickString.replace('").Append(joinName).Append("','").Append(leaveName).Append("');\n");
		sb.Append("  } else if (onclickString.indexOf('").Append(leaveName).Append("') > -1) {\n");
		sb.Append("    onclickString = onclickString.replace('").Append(leaveName).Append("','").Append(joinName).Append("');\n");
		sb.Append("  }\n");
		sb.Append("  imgAnchor.setAttribute('onclickstring', onclickString);\n");
		sb.Append("  imgAnchor.onclick = function() {eval(onclickString); return false;};\n");

		// Swap the display of the join/leave links
		sb.Append("  var communityJoin = document.getElementById('join-community' + id);\n");
		sb.Append("  var communityLeave = document.getElementById('leave-community' + id);\n");
		sb.Append("  var origJoinStyle = communityJoin.style.display;\n");
		sb.Append("  communityJoin.style.display = communityLeave.style.display;\n");
		sb.Append("  communityLeave.style.display = origJoinStyle;\n");

		// Swap whether the community is already joined or not
		sb.Append("  var communityPreview = document.getElementById('preview-community' + id);\n");
		sb.Append("  if (communityPreview.getAttribute('isalreadyjoined') == 'true')\n");
		sb.Append("  {\n");
		sb.Append("    communityPreview.setAttribute('isalreadyjoined', 'false');\n");
		sb.Append("  } else {\n");
		sb.Append("    communityPreview.setAttribute('isalreadyjoined', 'true');\n");
		sb.Append("  }\n");
		
		sb.Append("}\n");

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.AddInnerHTMLString(sb.ToString());
		_scripts.AddInnerHTMLElement(script);
	}

	/**
	 * This method adds the JS for the Preview Community function.
	 * 
	 * @param _scripts Add the JS into this collection.
	 * @param _asOwner The current Activity Space
	 * @param _nPageID The current page iD
	 * @return Whether or not we need the window opening JS
	 */
	public boolean insertPreviewCommunityJS(HTMLScriptCollection _scripts,
		AActivitySpace _asOwner, int _nPageID)
	{
		String previewName = GetTagAttributeAsString(PREVIEW_NAME);
		if ((previewName != null) && (previewName.length() > 0))
		{
			// Construct the base preview URL
			ASURL asurl = new ASURL(_asOwner);
			asurl.SetSubSpaceKey("CommunitySelection");
			asurl.SetLinkCreateNewSpace(PreviewCommunityAS.STR_MVC_CLASS_NAME, _asOwner);
			asurl.SetControl(PreviewCommunityControl.STR_MVC_CLASS_NAME);
			asurl.SetDisplayPage(PreviewCommunityDP.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(PreviewCommunityControl.m_PreviewType,
				XPConvert.ToString(PreviewCommunityModel.SELECTIONPREVIEWHEADER));
			asurl.AddControlArgument(PreviewCommunityControl.m_strJoinCommunityJavascriptOverride,
				"parent.opener." + JOIN_COMMUNITY_PREVIEW_JS);
	
			XPStringBuilder sb = new XPStringBuilder(200);
			// We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
			sb.Append(previewName).Append(" = function(id, isalreadyjoined)\n");
			sb.Append("{\n");
			sb.Append("  var strURL = '").Append(asurl.GetURLAsString()).
				Append("&").Append(PreviewCommunityControl.m_CommunityID).
				Append("=' + id + '&").Append(PreviewCommunityControl.m_CommunityChecked).
				Append("=' + isalreadyjoined;\n");
			sb.Append("  OpenLargePreviewWindow(strURL);\n");
			sb.Append("}\n");

			// TODO: If they don't specify the join js and don't allow users to join
			// (an unlikely scenario), we probably need some way to remove the join
			// button in the preview popup if joining is disabled.

			// We pass in the name of this JS method in the preview URL
			// so that the preview popup knows how to join the community correctly.
			String joinName = GetTagAttributeAsString(JOIN_NAME);
			if ((joinName != null) && (joinName.length() > 0))
			{
				// We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
				sb.Append(JOIN_COMMUNITY_PREVIEW_JS).Append(" = function(id, popup)\n");
				sb.Append("{\n");
				// NOTE: We can't close the popup here, because that will abort the AJAX request,
				// so we just store it so that the ajax request can close it.
				sb.Append("  ").Append(POPUP_REFERENCE).Append(" = popup;\n");
				sb.Append("  ").Append(joinName).Append("(id);\n");
				sb.Append("}\n");
			}
	
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString(sb.ToString());
			_scripts.AddInnerHTMLElement(script);

			// We need the window opening JS.
			return true;
		}

		// We don't require the window opening JS
		return false;
	}

	/**
	 * This method adds the JS for the Invitation function.
	 * 
	 * @param _scripts Add the JS into this collection.
	 * @param _asOwner The current Activity Space
	 * @param _nPageID The current page iD
	 * @return Whether or not we need the window opening JS
	 */
	public boolean insertInvitationJS(HTMLScriptCollection _scripts,
		AActivitySpace _asOwner, int _nPageID)
	{
		String invitationName = GetTagAttributeAsString(INVITATION_NAME);
		if ((invitationName != null) && (invitationName.length() > 0))
		{
			ASURL asurl = new ASURL(_asOwner);
			asurl.SetLinkGetCachedSpace(_asOwner);
			asurl.SetControl(InvitationPopupControl.STR_MVC_CLASS_NAME);
			asurl.SetDisplayPage(CommunityInvitationPopupDP.STR_MVC_CLASS_NAME);
	
			XPStringBuilder sb = new XPStringBuilder(200);

			// We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
			sb.Append("\n").Append(invitationName).Append(" = function(invitationID)\n");
			sb.Append("{\n");
			sb.Append("  OpenNewWindow('").Append(asurl.GetURLAsString()).
				Append("&").Append(InvitationPopupControl.strInviteIndex).
				Append("=' + invitationID").Append(", 'SendToOthers', 'status=no,toolbar=no,menubar=no,resizable=yes,scrollbars=yes,location=no,width=600,height=250');\n");
			sb.Append("}\n");
	
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString(sb.ToString());
			_scripts.AddInnerHTMLElement(script);

			// We need the window opening JS.
			return true;
		}

		// We don't require the window opening JS
		return false;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new CommunityJSTag();
	}
}
