package com.bea.alui.taglib.joincommunitypageeditor.test;

import com.bea.alui.taglib.joincommunitypageeditor.*;
import com.bea.alui.taglib.portletpageeditor.test.integration.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.mock.search.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

import junit.framework.*;

/**
 * This class tests that the community data outputs the right data for the join community flyout.
 * 
 * In general, the tests build up a markup array, pass it to the tag engine, and then
 * verify the results.
 */
public class TestCommunityDataTag extends TestCase 
{
	public static final String DATA_ID = "myID";

	// Community 1 data
	public static final String COMMUNITY_1_NAME = "my First Community";
	public static final String COMMUNITY_1_DESCRIPTION = "my First Community description";
	public static final int COMMUNITY_1_CLASS_ID = PT_CLASSIDS.PT_COMMUNITY_ID;
	public static final int COMMUNITY_1_OBJECT_ID = 345;

	// Community 1 results
	public static final boolean COMMUNITY_1_IS_ALREADY_JOINED = true;

	// Community 2 data
	public static final String COMMUNITY_2_NAME = "my Second Community";
	public static final String COMMUNITY_2_DESCRIPTION = "my Second Community description";
	public static final int COMMUNITY_2_CLASS_ID = PT_CLASSIDS.PT_COMMUNITY_ID;
	public static final int COMMUNITY_2_OBJECT_ID = 658;

	// Community 2 results
	public static final boolean COMMUNITY_2_IS_ALREADY_JOINED = false;

	public static final String INNER_CONTENT = "test content!";

	public MockEnvironment m_environment;
	public MockObjectSelectionModel m_objectModel;
	public MockSearchResultModel m_searchModel;

	public void setUp()
	{
		ConfigService.setTestInstance(new MockConfigHelper());

		m_environment = new MockEnvironment();

		m_objectModel = new MockObjectSelectionModel();
		m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME, m_objectModel);

		m_searchModel = new MockSearchResultModel();
		m_environment.m_models.PutElement(SearchResultModel.STR_MVC_CLASS_NAME, m_searchModel);

		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new CommunityDataTag(), CommunityDataTag.TAG.GetName(), JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * This method tests basic functioning of the community data tag in search mode.
	 */
	public void testCommunityDataTagSearch()
	{
		m_objectModel.m_bDisplaySearch = true;
		// Put community 1 on the page
		m_objectModel.m_nSelectedObjectID = COMMUNITY_1_OBJECT_ID;

		// 1) Initialize the Mock search model.
		XPArrayList arrayListResults = new XPArrayList();
		
		// Create a fake community result and add it to the result list.
		MockSearchResult result1 = new MockSearchResult();
		arrayListResults.Add(result1);
		result1.setClassID(COMMUNITY_1_CLASS_ID);
		result1.setObjectID(COMMUNITY_1_OBJECT_ID);
		result1.setKwic(COMMUNITY_1_DESCRIPTION);
		result1.setName(COMMUNITY_1_NAME);
		result1.setLastModified(new XPDateTime());

		// Create a second fake community result and add it to the result list.
		MockSearchResult result2 = new MockSearchResult();
		arrayListResults.Add(result2);
		result2.setClassID(COMMUNITY_2_CLASS_ID);
		result2.setObjectID(COMMUNITY_2_OBJECT_ID);
		result2.setKwic(COMMUNITY_2_DESCRIPTION);
		result2.setName(COMMUNITY_2_NAME);
		result2.setLastModified(new XPDateTime());

		// Initialize the search model.
		m_searchModel.SetFirstDisplayableItem(2);
		m_searchModel.SetNumDisplayableItems(2);
		m_searchModel.SetResultsList(arrayListResults);

		// initialize markup
		XMLFragmentTestHelper communityDataTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			CommunityDataTag.TAG.GetName());
		communityDataTagHelper.AddPTAttribute(CommunityDataTag.ATTRIB_ID.GetName(), DATA_ID);
		communityDataTagHelper.AddPTAttribute(CommunityDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
  		
   		Object[][] objArrMarkup = communityDataTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		Assert.assertEquals("Checking that data tag didn't output any HTML.",
   			result.GetDisplayString(), "");

   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);

   		// Shared state variables are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + DATA_ID);
		Assert.assertNotNull("Checking data list variable is present.", ssVariable);
		XPArrayList dataList = (XPArrayList) ssVariable.GetValue();

		check2CommunityData(dataList);
	}

	/**
	 * This method tests basic functioning of the community data tag in folder query mode.
	 */
	public void testCommunityDataTagFolderQuery()
	{
		m_objectModel.m_bDisplaySearch = false;
		// Put community 1 on the page
		m_objectModel.m_nSelectedObjectID = COMMUNITY_1_OBJECT_ID;

		// Set the page index for the object view
		m_objectModel.SetObjectViewIndex(0);
		
		// Add a community to the object model.
		m_objectModel.AddObjectType(PT_CLASSIDS.PT_COMMUNITY_ID);
		XPHashtable data = new XPHashtable();
		m_objectModel.AddResultItem(data);
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_NAME), COMMUNITY_1_NAME);
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_DESCRIPTION), COMMUNITY_1_DESCRIPTION);
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_OBJECTID), XPConvert.ToString(COMMUNITY_1_OBJECT_ID));
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_LASTMODIFIED), new XPDateTime());

		// Add a second community to the object model
		m_objectModel.AddObjectType(PT_CLASSIDS.PT_COMMUNITY_ID);
		data = new XPHashtable();
		m_objectModel.AddResultItem(data);
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_NAME), COMMUNITY_2_NAME);
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_DESCRIPTION), COMMUNITY_2_DESCRIPTION);
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_OBJECTID), XPConvert.ToString(COMMUNITY_2_OBJECT_ID));
		data.PutElement(new Integer(PT_PROPIDS.PT_PROPID_LASTMODIFIED), new XPDateTime());

		// initialize markup
		XMLFragmentTestHelper communityDataTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			CommunityDataTag.TAG.GetName());
		communityDataTagHelper.AddPTAttribute(CommunityDataTag.ATTRIB_ID.GetName(), DATA_ID);
		communityDataTagHelper.AddPTAttribute(CommunityDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
  		
   		Object[][] objArrMarkup = communityDataTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		Assert.assertEquals("Checking that data tag didn't output any HTML.",
   	   			result.GetDisplayString(), "");
	
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);

   		// Shared state variables are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + DATA_ID);
		Assert.assertNotNull("Checking data list variable is present.", ssVariable);
		XPArrayList dataList = (XPArrayList) ssVariable.GetValue();

		check2CommunityData(dataList);
	}

	/**
	 * This method tests that the tag displays whatever's inside it.
	 */
	public void testCommunityDataTagBodyPassThru()
	{
		m_objectModel.m_bDisplaySearch = true;

		// initialize markup
		XMLFragmentTestHelper communityDataTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			CommunityDataTag.TAG.GetName());
		communityDataTagHelper.AddPTAttribute(CommunityDataTag.ATTRIB_ID.GetName(), DATA_ID);
		communityDataTagHelper.AddContent(INNER_CONTENT);

   		Object[][] objArrMarkup = communityDataTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		Assert.assertEquals("Checking that data tag outputs the inner body content.",
   	   			result.GetDisplayString(), INNER_CONTENT);
	}

	/**
	 * This helper method checks that a community is present in the results.
	 * @param _dataList the results.
	 */
	public void check2CommunityData(XPArrayList _dataList)
	{
		Assert.assertNotNull("Checking data list is present.", _dataList);
		Assert.assertEquals("Checking data list contains 2 communities.", 2, _dataList.GetSize());

		int index = 0;

		IDataObject doCurrentCommunity = (IDataObject) _dataList.GetElement(index);
		// Check pass-thru data
		Assert.assertEquals("Checking name of community " + index + ".",
			COMMUNITY_1_NAME, doCurrentCommunity.GetData(CommunityDataTag.NAME));
		Assert.assertEquals("Checking description of community " + index + ".",
			COMMUNITY_1_DESCRIPTION, doCurrentCommunity.GetData(CommunityDataTag.DESCRIPTION));
		Assert.assertEquals("Checking ID of community " + index + ".",
			COMMUNITY_1_OBJECT_ID, XPConvert.ToInteger(doCurrentCommunity.GetData(CommunityDataTag.ID)));

		// Check derived data
		Assert.assertEquals("Checking invitation ID for community " + index + ".",
			index, XPConvert.ToInteger(doCurrentCommunity.GetData(CommunityDataTag.INVITATION_ID)));
		Assert.assertEquals("Checking if community " + index + " is already joined.",
			COMMUNITY_1_IS_ALREADY_JOINED, XPConvert.ToBoolean(doCurrentCommunity.GetData(CommunityDataTag.IS_ALREADY_JOINED)));
		index++;

		doCurrentCommunity = (IDataObject) _dataList.GetElement(index);
		// Check pass-thru data
		Assert.assertEquals("Checking name of community " + index + ".",
			COMMUNITY_2_NAME, doCurrentCommunity.GetData(CommunityDataTag.NAME));
		Assert.assertEquals("Checking description of community " + index + ".",
			COMMUNITY_2_DESCRIPTION, doCurrentCommunity.GetData(CommunityDataTag.DESCRIPTION));
		Assert.assertEquals("Checking ID of community " + index + ".",
			COMMUNITY_2_OBJECT_ID, XPConvert.ToInteger(doCurrentCommunity.GetData(CommunityDataTag.ID)));

		// Check derived data
		Assert.assertEquals("Checking for no invitation ID for community " + index + ".",
			index, XPConvert.ToInteger(doCurrentCommunity.GetData(CommunityDataTag.INVITATION_ID)));
		Assert.assertEquals("Checking if community " + index + " is already joined.",
			COMMUNITY_2_IS_ALREADY_JOINED, XPConvert.ToBoolean(doCurrentCommunity.GetData(CommunityDataTag.IS_ALREADY_JOINED)));
		index++;
	}
}
