package com.bea.alui.taglib.joincommunitypageeditor.test;

import junit.framework.*;

import com.bea.alui.taglib.joincommunitypageeditor.*;
import com.bea.alui.taglib.portletpageeditor.FlyoutJSTag;
import com.bea.alui.taglib.portletpageeditor.test.integration.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.mock.search.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

public class TestJoinCommunityBrowseModeTag extends TestCase 
{
	public static final String FLYOUT_ID = "my-flyout-div";
	public static final String TEST_CONTENT = "my test content";
	public static final String BROWSE_FLAG_KEY = "my-browse-flag";
	public static final String OPEN_NAME = "my-open-function";

	// All of our AJAX JS funcs should be of the form "name = function(args)".
	public static final String JS_FUNCTION_SUFFIX = " = function(";

	public MockEnvironment m_environment;
	public MockObjectSelectionModel m_objectModel;
	public MockSearchResultModel m_searchModel;

	public void setUp()
	{
		ConfigService.setTestInstance(new MockConfigHelper());

		m_environment = new MockEnvironment();

		m_objectModel = new MockObjectSelectionModel();
		m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME, m_objectModel);

		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new JoinCommunityBrowseModeTag(), JoinCommunityBrowseModeTag.TAG.GetName(), JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * This method tests the tag in browse mode (should not output an URL).
	 */
	public void testPortletBrowseMode()
	{
		m_objectModel.m_bDisplaySearch = false;

		// initialize markup
		XMLFragmentTestHelper JoinCommunityBrowseModeTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			JoinCommunityBrowseModeTag.TAG.GetName());
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.FLYOUT_ID.GetName(), FLYOUT_ID);
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.ATTRIB_ID.GetName(), BROWSE_FLAG_KEY);
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());

   		Object[][] objArrMarkup = JoinCommunityBrowseModeTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

		String strJSOpenFolderName = JoinCommunityBrowseModeTag.JS_OPEN_NAME.GetDefaultValue() + JS_FUNCTION_SUFFIX;
		int nIndex = XPStringUtility.IndexOf(strResult, strJSOpenFolderName);
		Assert.assertTrue("Checking that data tag output the correct JS function name [" + strJSOpenFolderName +
			"] in search mode for opening a folder in result " + strResult + ".", nIndex >= 0);

		String strAddContentName = FlyoutJSTag.FLYOUT_OBJECT + FLYOUT_ID + "." + FlyoutJSTag.ADD_CONTENT;
		nIndex = XPStringUtility.IndexOf(strResult, strAddContentName);
		Assert.assertTrue("Checking that data tag JS is using the correct div replacement function name [" +
			strAddContentName + "] in search mode in result " + strResult + ".", nIndex >= 0);

   		checkBrowseFlag(BROWSE_FLAG_KEY, true);
	}

	/**
	 * This method tests the tag in search mode (should output an URL).
	 */
	public void testPortletSearchMode()
	{
		m_objectModel.m_bDisplaySearch = true;

		// initialize markup
		XMLFragmentTestHelper JoinCommunityBrowseModeTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			JoinCommunityBrowseModeTag.TAG.GetName());
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.FLYOUT_ID.GetName(), FLYOUT_ID);
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.ATTRIB_ID.GetName(), BROWSE_FLAG_KEY);
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
		JoinCommunityBrowseModeTagHelper.AddContent(TEST_CONTENT);

		Object[][] objArrMarkup = JoinCommunityBrowseModeTagHelper.ToArrayEntireFragment();
		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

		String strResult = result.GetDisplayString();

		int nIndex = XPStringUtility.IndexOf(strResult, TEST_CONTENT);
		Assert.assertTrue("Checking that data tag output the content HTML [" + TEST_CONTENT +
			"] in search mode in result " + strResult + ".", nIndex >= 0);

		String strJSOpenFolderName = JoinCommunityBrowseModeTag.JS_OPEN_NAME.GetDefaultValue() + JS_FUNCTION_SUFFIX;
		nIndex = XPStringUtility.IndexOf(strResult, strJSOpenFolderName);
		Assert.assertTrue("Checking that data tag output the correct JS function name [" + strJSOpenFolderName +
			"] in search mode for opening a folder in result " + strResult + ".", nIndex >= 0);

		String strAddContentName = FlyoutJSTag.FLYOUT_OBJECT + FLYOUT_ID + "." + FlyoutJSTag.ADD_CONTENT;
		nIndex = XPStringUtility.IndexOf(strResult, strAddContentName);
		Assert.assertTrue("Checking that data tag JS is using the correct div replacement function name [" +
			strAddContentName + "] in search mode in result " + strResult + ".", nIndex >= 0);

   		checkBrowseFlag(BROWSE_FLAG_KEY, false);
	}

	/**
	 * This method tests renaming the JS functions in search mode.
	 */
	public void testPortletSearchModeRenamedJS()
	{
		m_objectModel.m_bDisplaySearch = true;

		// initialize markup
		XMLFragmentTestHelper JoinCommunityBrowseModeTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			JoinCommunityBrowseModeTag.TAG.GetName());
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.JS_OPEN_NAME.GetName(), OPEN_NAME);
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.FLYOUT_ID.GetName(), FLYOUT_ID);
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.ATTRIB_ID.GetName(), BROWSE_FLAG_KEY);
		JoinCommunityBrowseModeTagHelper.AddPTAttribute(JoinCommunityBrowseModeTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
		JoinCommunityBrowseModeTagHelper.AddContent(TEST_CONTENT);

		Object[][] objArrMarkup = JoinCommunityBrowseModeTagHelper.ToArrayEntireFragment();
		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

		String strResult = result.GetDisplayString();

		int nIndex = XPStringUtility.IndexOf(strResult, TEST_CONTENT);
		Assert.assertTrue("Checking that data tag output the content HTML [" + TEST_CONTENT +
			"] in search mode in result " + strResult + ".", nIndex >= 0);

		String strJSOpenFolderName = OPEN_NAME + JS_FUNCTION_SUFFIX;
		nIndex = XPStringUtility.IndexOf(strResult, strJSOpenFolderName);
		Assert.assertTrue("Checking that data tag output the correct JS function name [" + strJSOpenFolderName +
			"] in search mode for opening a folder in result " + strResult + ".", nIndex >= 0);

		String strAddContentName = FlyoutJSTag.FLYOUT_OBJECT + FLYOUT_ID + "." + FlyoutJSTag.ADD_CONTENT;
		nIndex = XPStringUtility.IndexOf(strResult, strAddContentName);
		Assert.assertTrue("Checking that data tag JS is using the correct div replacement function name [" +
			strAddContentName + "] in search mode in result " + strResult + ".", nIndex >= 0);

   		checkBrowseFlag(BROWSE_FLAG_KEY, false);
	}

	/**
	 * This helper method checks that the browse flag has the proper value.
	 * @param _strKey
	 * @param _bExpectedResult
	 */
	public void checkBrowseFlag(String _strKey, boolean _bExpectedResult)
	{
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);

   		// Shared state variables are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + _strKey);
		Assert.assertNotNull("Checking browse flag is present.", ssVariable);

		boolean bResult = XPConvert.ToBoolean(ssVariable.GetValue());
		Assert.assertEquals("Checking value of browse flag.", _bExpectedResult, bResult);
	}
}
