package com.bea.alui.taglib.joincommunitypageeditor.test;

import junit.framework.*;

import com.bea.alui.taglib.joincommunitypageeditor.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

public class TestJoinCommunityJSTag extends TestCase 
{
	public MockEnvironment m_environment;

	// All of our AJAX JS funcs should be of the form "name = function(args)".
	public static final String JS_FUNCTION_SUFFIX = " = function(";
	
	public static final String FLYOUTID = "mockFlyoutId";
	public static final String JOIN_JS_NAME = "testJoinCommunity";
	public static final String LEAVE_JS_NAME = "testLeaveCommunity";
	public static final String PREVIEW_JS_NAME = "testPreviewCommunity";
	public static final String INVITE_JS_NAME = "testCommunityInvitation";

	public void setUp()
	{
		ConfigService.setTestInstance(new MockConfigHelper());

		m_environment = new MockEnvironment();

		m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
			new ObjectSelectionModel());

		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new CommunityJSTag(), CommunityJSTag.TAG.GetName(), JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * This method tests basic display of the JavaScript functions.
	 */
	public void testJS()
	{
		
		
		// initialize markup
		XMLFragmentTestHelper CommunityJSTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			CommunityJSTag.TAG.GetName());
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.ATTRIB_FLYOUT_ID.GetName(), FLYOUTID);
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.JOIN_NAME.GetName(), JOIN_JS_NAME);
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.LEAVE_NAME.GetName(), LEAVE_JS_NAME);
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.PREVIEW_NAME.GetName(), PREVIEW_JS_NAME);
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.INVITATION_NAME.GetName(), INVITE_JS_NAME);
  		
   		Object[][] objArrMarkup = CommunityJSTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		CheckFunctionName(JOIN_JS_NAME, strResult, true);
   		CheckFunctionName(LEAVE_JS_NAME, strResult, true);
   		CheckFunctionName(PREVIEW_JS_NAME, strResult, true);
   		CheckFunctionName(INVITE_JS_NAME, strResult, true);
	}

	/**
	 * This method tests that no JavaScript displays if you don't request it.
	 */
	public void testNoJS()
	{
		// initialize markup
		XMLFragmentTestHelper CommunityJSTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			CommunityJSTag.TAG.GetName());
  		
   		Object[][] objArrMarkup = CommunityJSTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		CheckFunctionName(JOIN_JS_NAME, strResult, false);
   		CheckFunctionName(LEAVE_JS_NAME, strResult, false);
   		CheckFunctionName(PREVIEW_JS_NAME, strResult, false);
   		CheckFunctionName(INVITE_JS_NAME, strResult, false);
	}

	/**
	 * This method tests partial display of some of the JavaScript functions.
	 */
	public void testPartialJS()
	{
		// initialize markup
		XMLFragmentTestHelper CommunityJSTagHelper = new XMLFragmentTestHelper(
			JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), 
			CommunityJSTag.TAG.GetName());
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.ATTRIB_FLYOUT_ID.GetName(), FLYOUTID);
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.JOIN_NAME.GetName(), JOIN_JS_NAME);
		CommunityJSTagHelper.AddPTAttribute(CommunityJSTag.PREVIEW_NAME.GetName(), PREVIEW_JS_NAME);
  		
   		Object[][] objArrMarkup = CommunityJSTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		// These should be present.
   		CheckFunctionName(JOIN_JS_NAME, strResult, true);
   		CheckFunctionName(PREVIEW_JS_NAME, strResult, true);

   		// These should not be present.
   		CheckFunctionName(LEAVE_JS_NAME, strResult, false);
   		CheckFunctionName(INVITE_JS_NAME, strResult, false);
	}

	public void CheckFunctionName(String _strJSName, String _strOutput, boolean bPresent)
	{
   		String strFunction = _strJSName + JS_FUNCTION_SUFFIX;
   		if (bPresent)
   		{
   			// Check that it's there.
	   		Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction +
	   			"] is present in output: " + _strOutput,
	   			XPStringUtility.IndexOf(_strOutput, strFunction) >= 0);
   		} else
   		{
   			// Check that it's not there.
	   		Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction +
		   		"] is not present in output: " + _strOutput,
	   			XPStringUtility.IndexOf(_strOutput, strFunction) < 0);
   		}
	}
}
