package com.bea.alui.taglib.joincommunitypageeditor.test;

import junit.framework.*;

import com.bea.alui.taglib.joincommunitypageeditor.*;
import com.bea.alui.taglib.portletpageeditor.test.integration.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.mock.search.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

public class TestJoinCommunityPaginationDataTag extends TestCase 
{
	public static String ID_VALUE = "paginationdata";
	public static String PAGINATE_JS_NAME = "mypaginatefunc";
	public static String FIRST_ITEM_BROWSE = "firstitem";
	public static String FIRST_ITEM_SEARCH = "first";

	private int firstIndex = 1;
	private int lastIndex = 10;
	private int displayedCount = 10;
	private int totalCount = 32;
	private int totalPages = 4;

	private MockEnvironment m_environment;
	private MockObjectSelectionModel m_objectModel;
	public MockSearchResultModel m_searchModel;
	
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		ConfigService.setTestInstance(new MockConfigHelper());

		m_environment = new MockEnvironment();		

		m_objectModel = new MockObjectSelectionModel();   		
   		m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME, m_objectModel);

		m_searchModel = new MockSearchResultModel();
		m_environment.m_models.PutElement(SearchResultModel.STR_MVC_CLASS_NAME, m_searchModel);

   		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new JoinCommunityPaginationDataTag(), JoinCommunityPaginationDataTag.TAG.GetName(), JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		
		m_environment = null;
		m_objectModel = null;
	}

	public void testBrowsePagination() 
	{
		m_objectModel.SetDisplaySearch(false);

		m_objectModel.m_nTotalItems = totalCount;

		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), JoinCommunityPaginationDataTag.TAG.GetName());
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_PAGES_LIST.GetName(), "plist");
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_PAGES_TO_DISPLAY.GetName(), "2");
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.PAGINATE_NAME.GetName(), PAGINATE_JS_NAME);
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_FLYOUT_ID.GetName(), "mock-flyout-id");

   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		TaglibJoinCommunityPageEditorTestSuite.CheckFunctionName(PAGINATE_JS_NAME, strResult, true);

   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
		// for some reason the names are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);
		IDataObject doViewItems = (IDataObject) ssVariable.GetValue();

		CheckMainDataObject(doViewItems, FIRST_ITEM_BROWSE, false);

		// Testing variables shared between the main data object and the pages objects
		
		ssVariable = (SharedStateVariable) scopeData.GetElement(".plist");
		XPArrayList pagesList = (XPArrayList) ssVariable.GetValue();

		CheckPageList(pagesList, FIRST_ITEM_BROWSE, false);
	}

	public void testSearchPagination() 
	{
		m_objectModel.SetDisplaySearch(true);

		m_searchModel.SetTotalItems(totalCount);
		m_searchModel.SetFirstDisplayableItem(1);

		// Hack - set drill down depth to a large number so we don't try to
		// get the search args.
		m_searchModel.SetDrilldownDepth(50);

		// Make sure we're not using old object model data.
		m_objectModel.m_nTotalItems = 0;

		m_environment.SetTrackCurrentPage(true);
		m_environment.SetCurrentPage(new SearchResultDP());

		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(JoinCommunityPageEditorTagLibraryData.LIBRARY.GetName(), JoinCommunityPaginationDataTag.TAG.GetName());
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_PAGES_LIST.GetName(), "plist");
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_PAGES_TO_DISPLAY.GetName(), "2");
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.PAGINATE_NAME.GetName(), PAGINATE_JS_NAME);
   		helper.AddPTAttribute(JoinCommunityPaginationDataTag.ATTRIB_FLYOUT_ID.GetName(), "mock-flyout-id");

   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		TaglibJoinCommunityPageEditorTestSuite.CheckFunctionName(PAGINATE_JS_NAME, strResult, true);

   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
		// for some reason the names are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);
		IDataObject doViewItems = (IDataObject) ssVariable.GetValue();

		CheckMainDataObject(doViewItems, FIRST_ITEM_SEARCH, true);

		// Testing variables shared between the main data object and the pages objects
		
		ssVariable = (SharedStateVariable) scopeData.GetElement(".plist");
		XPArrayList pagesList = (XPArrayList) ssVariable.GetValue();

		CheckPageList(pagesList, FIRST_ITEM_SEARCH, true);
	}

	public void CheckMainDataObject(IDataObject _object, String _strFirstKey, boolean _bIsSearch)
	{
		String value = _object.GetData(PaginationDataConstants.TOTAL_RESULTS);
		Assert.assertEquals("Wrong totalcount returned for pagination component[" + value + "] " +
			GetIsSearch(_bIsSearch) + ".",
			totalCount, XPConvert.ToInteger(value));
		
		value = _object.GetData(PaginationDataConstants.NUM_PER_PAGE);
		Assert.assertEquals("Wrong Displayed per page returned for pagination component[" + value + "] " +
			GetIsSearch(_bIsSearch) + ".",
			displayedCount, XPConvert.ToInteger(value));

		value = _object.GetData(PaginationDataConstants.START_COUNT);
		Assert.assertEquals("Wrong firstIndex returned for pagination component[" + value + "] " +
			GetIsSearch(_bIsSearch) + ".",
			firstIndex, XPConvert.ToInteger(value));
		
		value = _object.GetData(PaginationDataConstants.END_COUNT);
		Assert.assertEquals("Wrong lastIndex returned for pagination component[" + value + "] " +
			GetIsSearch(_bIsSearch) + ".",
			lastIndex, XPConvert.ToInteger(value));
		
		value = _object.GetData(PaginationDataConstants.PREVIOUS_URL);
		Assert.assertEquals("Wrong previousurl returned for pagination component[" + value + "] " +
			GetIsSearch(_bIsSearch) + ".",
			null, value);
		
		value = _object.GetData(PaginationDataConstants.NEXT_URL);
		int nFirstItem = firstIndex + displayedCount;
		String strArg = _strFirstKey + "=" + nFirstItem;
		Assert.assertTrue("Wrong nexturl starting range returned for pagination component [" +
			value + "], expected first item [" + strArg + "] " +
			GetIsSearch(_bIsSearch) + ".",
			XPStringUtility.IndexOf(value, strArg) > 0);

		value = _object.GetData(PaginationDataConstants.LAST_PAGE);
		Assert.assertEquals("Wrong totalPages returned for pagination component[" + value + "] " +
			GetIsSearch(_bIsSearch) + ".",
			totalPages, XPConvert.ToInteger(value));

		value = _object.GetData(PaginationDataConstants.FIRST_PAGE_URL);
		Assert.assertEquals("Wrong firstpageurl returned for pagination component[" + value + "] " +
			GetIsSearch(_bIsSearch) + ".",
			null, value);
		
		value = _object.GetData(PaginationDataConstants.LAST_PAGE_URL);
		nFirstItem = totalCount - 1;
		strArg = _strFirstKey + "=" + nFirstItem;
		Assert.assertTrue("Wrong nexturl starting range returned for pagination component[" +
			value + "], expected first item [" + strArg + "] " +
			GetIsSearch(_bIsSearch) + ".",
			XPStringUtility.IndexOf(value, strArg) > 0);
	}

	public void CheckPageList(XPArrayList _pages, String _strFirstKey, boolean _bIsSearch)
	{

		// This should be 3 and not 5 since the starting page is 1 and # of pages is 2.
		Assert.assertEquals("Wrong number of pages returned for pagination pageslist component " +
			GetIsSearch(_bIsSearch) + ".",
			3, _pages.GetSize());

		for (int i = 0; i < _pages.GetSize(); i++)
		{
			HashtableDataObject htObj = (HashtableDataObject)_pages.GetElement(i);
			String value = htObj.GetData(PaginationDataConstants.PAGE_NUMBER);
			
			Assert.assertEquals("Wrong page number returned for pagination page " + i + " in list " +
					GetIsSearch(_bIsSearch) + ".",
				i+1 , XPConvert.ToInteger(value));
			
			value = htObj.GetData(PaginationDataConstants.PAGINATION_URL);
			if(i ==0)
			{
				Assert.assertEquals("Wrong url value returned for pagination page " + i + " in list " +
					GetIsSearch(_bIsSearch) + ".",
					null , value);
			}
			else
			{
				int nFirstItem = (i * displayedCount) + 1;
				String strArg = _strFirstKey + "=" + nFirstItem;
				Assert.assertTrue("Wrong nexturl starting range returned for page " + i +
					" in list, expected first item [" + strArg + "] " +
					GetIsSearch(_bIsSearch) + ".",
					XPStringUtility.IndexOf(value, strArg) > 0);
			}
		}
	}

	public String GetIsSearch(boolean _bIsSearch)
	{
		if (_bIsSearch)
		{
			return "in Search";
		} else
		{
			return "in Browse";
		}
	}
}
