using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form.sort;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.kdpage
{
  /// <summary>
  /// This tag only works with the Knowledge Directory activity space. It stores the document column headers in memory.
  /// Each header data object contains the following variables: 'name' for the header's name, 'id' for the property Id of the header,
  /// 'sorturl' for the URL to sort by that header, and 'sorton' to indicate whether documents are currently being sorted by that header.
  /// The 'sorton' variable will have the value of 'false' if it is not
  /// currently sorted by the header, 'true' if it is sorted by corresponding header.
  /// </summary>
  /// <author>Dustin Ang</author>
  public class DocumentColumnHeadersDataTag : AKDPageTag
  {
    private const String TAG_NAME = "documentcolumnheadersdata";
    public const String NAME = "name";
    public const String ID = "id";
    public const String SORT_URL = "sorturl";
    public const String SORT_ON = "sorton";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    private AActivitySpace m_asOwner = null;
    static DocumentColumnHeadersDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, ATag.EncodeForTagDoc(KD_PAGE_ONLY_CONSTANT + "It stores the document column headers in memory. " + "Each header data object contains the following variables: <br/>" + "<ul>" + "<li> <code>" + NAME + "</code> - The header name.</li>" + "<li> <code>" + ID + "</code> - The property ID of the header.</li>" + "<li> <code>" + SORT_URL + "</code> - The URL to sort by that header.</li>" + "<li> <code>" + SORT_ON + "</code> - Indicates whether documents are currently being sorted by the header " + "and whether it is sorted in ascending or descending order. Returns \'false\' " + " if it is not currently sorted by the header, \'true\' if it is sorted by the corresponding header.</li>" + "</ul>"));
      }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
     
    public override ATag Create()
    {
      return new DocumentColumnHeadersDataTag();
    }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      m_asOwner = (AActivitySpace) GetEnvironment();
      IDirModelRO dirModel = GetDirModel();
      int nSortedHeader = 0;
      // DCA - try to cast dirModel to ISortModelRO so that we can get the sorting variables
      if (dirModel is ISortModelRO)
      {
        ISortModelRO asSortModel = (ISortModelRO) dirModel;
        nSortedHeader = asSortModel.GetSortedHeader();
      }
      IXPList headersList = new XPArrayList();
      IXPList xpHeaders = dirModel.GetHeaderProperties();
      // DCA - convert header properties array into data objects
      for (int i = 0;i < xpHeaders.GetSize();i++)
      {
        HashtableDataObject htObjectAsc = new HashtableDataObject();
        HashtableDataObject htObjectDes = new HashtableDataObject();
        // Creating URL for both Ascending and Descending Orders
        String[] header = (String[]) xpHeaders.GetElement(i);
        int nHeaderIndex = XPConvert.ToInteger(header[DirModel.HEADER_ID_INDEX]);
        String strName = header[DirModel.HEADER_NAME_INDEX];
        // Adding Name
        htObjectAsc.SetData(NAME, strName + " " + m_asOwner.GetString(1880,
         "ptmsgs_portaladminmsgs"));
        htObjectDes.SetData(NAME, strName + " " + m_asOwner.GetString(1881,
         "ptmsgs_portaladminmsgs"));
        // Adding ID Value
        htObjectAsc.SetData(ID, "" + nHeaderIndex);
        htObjectDes.SetData(ID, "-" + nHeaderIndex);
        // Adding Sort URL
        if (null == header[DirModel.HEADER_SORT_URL_INDEX])
        {
          htObjectAsc.SetData(SORT_URL, EMPTY_STRING);
          htObjectDes.SetData(SORT_URL, EMPTY_STRING);
        } else
        {
          String inUrl = header[DirModel.HEADER_SORT_URL_INDEX];
          int pidx = XPStringUtility.LastIndexOf(inUrl, DirConstants.QS_SORTBY);
          String urlPrefix = XPStringUtility.Substring(inUrl, 0, pidx);
          urlPrefix+=DirConstants.QS_SORTBY + LinkConstants.EQUALS;
          htObjectAsc.SetData(SORT_URL, urlPrefix + nHeaderIndex);
          htObjectDes.SetData(SORT_URL, urlPrefix + "-" + nHeaderIndex);
        }
        // Adding Sort Flag
        htObjectAsc.SetData(SORT_ON, XPConvert.ToString(nSortedHeader == nHeaderIndex));
        htObjectDes.SetData(SORT_ON, XPConvert.ToString(nSortedHeader == -nHeaderIndex));
        headersList.Add(htObjectAsc);
        headersList.Add(htObjectDes);
      }
      // Add to memory
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, headersList, tagScope,
       true);
      return ProcessTagBody();
    }
  }
}