using System;
using IXPList=com.plumtree.openfoundation.util.IXPList;
using XPArrayList=com.plumtree.openfoundation.util.XPArrayList;
using XPConvert=com.plumtree.openfoundation.util.XPConvert;
using XPStringBuilder=com.plumtree.openfoundation.util.XPStringBuilder;
using XPStringTokenizer=com.plumtree.openfoundation.util.XPStringTokenizer;
using DirConstants=com.plumtree.portalpages.browsing.directory.DirConstants;
using DirRepostControl=com.plumtree.portalpages.browsing.directory.DirRepostControl;
using IDirModelRO=com.plumtree.portalpages.browsing.directory.IDirModelRO;
using com.plumtree.portaluiinfrastructure.tags;
using HashtableDataObject=com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using ASURL=com.plumtree.uiinfrastructure.activityspace.ASURL;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.kdpage
{
  /// <summary>
  /// This tag only works with the Knowledge Directory activity space. It takes 'value' as RequiredTagAttribute and 
  /// it is comma seperated list of integers. It in turn stores a list of documentsperpage objects and each object
  /// contains 'name' the name that can be used show as display name. 'url' that is the link to set Items per Page.
  /// 'selected' value either 'true' or 'false' based on the current setting. 
  /// </summary>
  /// <author>Ravi Tunuguntla</author>
  public class DocumentsPerPageDataTag : AKDPageTag
  {
    private const String TAG_NAME = "documentsperpagedata";
    public const String NAME = "name";
    public const String URL = "url";
    public const String SELECTED = "selected";
    public static readonly RequiredTagAttribute VALUE;
    private AActivitySpace m_asOwner;
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly String TAG_DESCRIPTION = ATag.EncodeForTagDoc(KD_PAGE_ONLY_CONSTANT + "The pt:value attribute takes " + " in a comma separated list of integers and " + "stores a list of documentsperpage objects. Each object contains the following variables: <code>" + NAME + "</code> - The name to " + "be displayed, <code>" + URL + "</code> - The link to set the items per page, and <code>" + SELECTED + "</code> - Either \'true\' or \'false\' based on the current setting.");
    static DocumentsPerPageDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      VALUE = new RequiredTagAttribute("value", "This attributr takes comma seperated list of integers as input values. ",
       AttributeType.STRING);
      TAG = new TagMetaData(TAG_NAME, TAG_DESCRIPTION);
    }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
     
    public override ATag Create()
    {
      return new DocumentsPerPageDataTag();
    }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      IDirModelRO dirModel = GetDirModel();
      int nCurVal = dirModel.GetNumDocsPerPage();
      XPStringBuilder strValues = new XPStringBuilder(GetTagAttributeAsString(VALUE));
      XPStringTokenizer strList = new XPStringTokenizer(strValues.ToString(),
       ",");
      m_asOwner = (AActivitySpace) GetEnvironment();
      IXPList headersList = new XPArrayList();
      bool bSelinList = false;
      while (strList.HasMoreTokens())
      {
        int nVal = XPConvert.ToInteger(strList.GetNextToken());
        HashtableDataObject htObject = new HashtableDataObject();
        ASURL asurl = new ASURL(m_asOwner);
        asurl.SetLinkGetCachedSpace(m_asOwner);
        asurl.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(DirConstants.QS_PER_PAGE, nVal);
        htObject.SetData(URL, asurl.GetURLAsString());
        htObject.SetData(NAME, XPConvert.ToString(nVal));
        // Verify This from DirModel if this number has been selected previously
        htObject.SetData(SELECTED, XPConvert.ToString(nCurVal == nVal));
        headersList.Add(htObject);
        /* Verifying if the previously set number is in the list at all, if not
         * then this flag will be false and we will add that number to the list.
         */
         
        if (nCurVal == nVal)
        {
          bSelinList = true;
        }
      }
      if (!bSelinList)
      {
        HashtableDataObject htObject = new HashtableDataObject();
        ASURL asurl = new ASURL(m_asOwner);
        asurl.SetLinkGetCachedSpace(m_asOwner);
        asurl.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(DirConstants.QS_PER_PAGE, nCurVal);
        htObject.SetData(URL, asurl.GetURLAsString());
        htObject.SetData(NAME, XPConvert.ToString(nCurVal));
        htObject.SetData(SELECTED, "true");
        headersList.Add(htObject);
      }
      //		 Add to memory
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, headersList, tagScope,
       true);
      return ProcessTagBody();
    }
  }
}