using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portaluiinfrastructure.tags;
using PaginationDataConstants=com.plumtree.portaluiinfrastructure.tags.common.PaginationDataConstants;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using ASURL=com.plumtree.uiinfrastructure.activityspace.ASURL;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.kdpage
{
  /// <summary>
  /// This tag only works with the Knowledge Directory activity space. It contains information about the documents pagination.
  /// This tag generates the data for the pagination links for documents in current folder and stores it in memory using the 
  /// variable name specified by the 'id' attribute. The main data is stored as a DataObject with the following variables:
  /// total  - The total number of results
  /// numperpage  - The number of results to display per page
  /// start  - The first result displayed on the current page
  /// end - The last result displayed on the current page
  /// lastpage  - The index of the last page
  /// previousurl  - The URL to the previous page
  /// nexturl  - The URL to the next page
  /// firstpageurl  - The URL to the first page
  /// lastpageurl - The URL to the last page
  /// Additionally, the list of page links to display is stored in memory using the variable name specified by the 
  /// 'pagestodisplay' attribute. Each result is a DataObject with the following variables:
  /// number  - The index of the page
  /// start  - The first result displayed on the page
  /// end - The last result displayed on the page
  /// url - The URL to the page.  This will not be present if the page is the current page.
  /// Use the logic tags to iterate over the list and display the results."
  /// </summary>
  /// <author>Ravi Tunuguntla</author>
  public class ViewItemsDataTag : AKDPageTag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_PAGES_LIST;
    public static readonly OptionalTagAttribute PAGES_TO_DISPLAY;
    static ViewItemsDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      ATTRIB_PAGES_LIST = new RequiredTagAttribute(PaginationDataConstants.ATTRIB_PAGESLIST_NAME,
       PaginationDataConstants.ATTRIB_PAGESLIST_DESCRIPTION, AttributeType.STRING);
      PAGES_TO_DISPLAY = new OptionalTagAttribute(PaginationDataConstants.ATTRIB_NUM_PAGES_NAME,
       PaginationDataConstants.ATTRIB_NUM_PAGES_DESCRIPTION, AttributeType.INT,
       PaginationDataConstants.ATTRIB_NUM_PAGES_DEFAULT);
      TAG = new TagMetaData(PaginationDataConstants.TAG_NAME, KD_PAGE_ONLY_CONSTANT + PaginationDataConstants.MAIN_DESCRIPTION_PREFIX + " for the documents in the current folder " + PaginationDataConstants.MAIN_DESCRIPTION_SUFFIX + PaginationDataConstants.MAIN_DATA_DESCRIPTION + PaginationDataConstants.PAGES_DATA_DESCRIPTION,
       PaginationDataConstants.EXAMPLE);
    }
    private AActivitySpace m_asOwner;
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
     
    public override ATag Create()
    {
      return new ViewItemsDataTag();
    }
    /*
     * (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      IDirModelRO dirModel = GetDirModel();
      int[] arrCardRange = dirModel.GetCardRange();
      // Populate data object
      int nStartCount = arrCardRange[DirModel.BEGIN_INDEX];
      int nEndCount = arrCardRange[DirModel.END_INDEX];
      int nTotalCount = arrCardRange[DirModel.TOTAL_CNT_INDEX];
      // int nPerPage = arrCardRange[DirModel.CARD_CNT];
      int nPerPage = dirModel.GetNumDocsPerPage();
      int nPagesToDisplay = GetTagAttributeAsInt(PAGES_TO_DISPLAY);
      int nPages = nTotalCount / nPerPage;
      if (nTotalCount % nPerPage > 0)
      {
        nPages+=1;
      }
      int nCurrPage = (nStartCount - 1) / nPerPage;
      int nFirstPageToDisplay = nCurrPage - nPagesToDisplay;
      if (nFirstPageToDisplay < 0)
      {
        nFirstPageToDisplay = 0;
      }
      int nLastPageToDisplay = nCurrPage + nPagesToDisplay;
      if (nLastPageToDisplay > nPages)
      {
        nLastPageToDisplay = nPages;
      }
      HashtableDataObject htObject = new HashtableDataObject();
      htObject.SetData(PaginationDataConstants.START_COUNT, XPConvert.ToString(nStartCount));
      htObject.SetData(PaginationDataConstants.TOTAL_RESULTS, XPConvert.ToString(nTotalCount));
      htObject.SetData(PaginationDataConstants.NUM_PER_PAGE, XPConvert.ToString(nPerPage));
      htObject.SetData(PaginationDataConstants.LAST_PAGE, XPConvert.ToString(nPages));
      htObject.SetData(PaginationDataConstants.END_COUNT, XPConvert.ToString(nEndCount));
      // Creating PreviousPage URL		
      int nPrevBegin = 0;
      if (nStartCount > nPerPage)
      {
        nPrevBegin = nStartCount - nPerPage;
      } else
      if (nStartCount > 1)
      {
        nPrevBegin = 1;
      }
      if (0 < nPrevBegin)
      {
        htObject.SetData(PaginationDataConstants.PREVIOUS_URL, makeURL(nPrevBegin,
         nPrevBegin + nPerPage - 1));
      }
      // Creating NextPage URL
      int nNextBegin = nStartCount + nPerPage;
      if (nNextBegin > nTotalCount)
      {
        nNextBegin = 0;
      }
      if (0 != nNextBegin)
      {
        int numOnNextPage = nTotalCount - nNextBegin + 1;
        if (numOnNextPage > nPerPage)
        {
          numOnNextPage = nPerPage - 1;
        }
        htObject.SetData(PaginationDataConstants.NEXT_URL, makeURL(nNextBegin,
         nNextBegin + numOnNextPage));
      }
      // Creating FirstPage URL
      if (nFirstPageToDisplay > 0)
      {
        htObject.SetData(PaginationDataConstants.FIRST_PAGE_URL, makeURL(1,
         nPerPage));
      }
      // Creating LastPage URL
      if (nLastPageToDisplay < (nPages - 1))
      {
        htObject.SetData(PaginationDataConstants.LAST_PAGE_URL, makeURL(((nPages - 1) * nPerPage) + 1,
         nTotalCount));
      }
      // Creating Page List		
      IXPList listPages = new XPArrayList();
      HashtableDataObject htPageData;
      for (int page = nFirstPageToDisplay;page <= nLastPageToDisplay;page++)
      {
        if (page < 0)
        {
          continue;
        }
        int firstResultInPage = (page * nPerPage) + 1;
        int lastResultInPage = (firstResultInPage + nPerPage) - 1;
        if (firstResultInPage > nTotalCount)
        {
          if (page == 0)
          {
            htPageData = new HashtableDataObject();
            htPageData.SetData(PaginationDataConstants.PAGE_NUMBER, XPConvert.ToString(page + 1));
            htPageData.SetData(PaginationDataConstants.START_COUNT, "1");
            htPageData.SetData(PaginationDataConstants.END_COUNT, "1");
            listPages.Add(htPageData);
          }
          break;
        }
        if (lastResultInPage > nTotalCount)
        {
          lastResultInPage = nTotalCount;
        }
        htPageData = new HashtableDataObject();
        htPageData.SetData(PaginationDataConstants.PAGE_NUMBER, XPConvert.ToString(page + 1));
        htPageData.SetData(PaginationDataConstants.START_COUNT, XPConvert.ToString(firstResultInPage));
        htPageData.SetData(PaginationDataConstants.END_COUNT, XPConvert.ToString(lastResultInPage));
        if (page != nCurrPage)
        {
          htPageData.SetData(PaginationDataConstants.PAGINATION_URL, makeURL(firstResultInPage,
           lastResultInPage));
        }
        listPages.Add(htPageData);
      }
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      GetState().SetSharedVariable(strDataReference, htObject, tagScope, true);
      // Adding List of Pages
      if (listPages.GetSize() > 0)
      {
        GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_PAGES_LIST),
         listPages, tagScope, true);
      }
      return ProcessTagBody();
    }
    private String makeURL(int sIndex, int eIndex)
    {
      m_asOwner = (AActivitySpace) GetEnvironment();
      ASURL asurl = new ASURL(m_asOwner);
      asurl.SetLinkGetCachedSpace(m_asOwner);
      asurl.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
      asurl.AddControlArgument(DirConstants.QS_RANGE_FROM, sIndex);
      asurl.AddControlArgument(DirConstants.QS_RANGE_TO, eIndex);
      return asurl.GetURLAsString();
    }
  }
}