using System;
using junit.framework;
using com.bea.alui.taglib.kdpage;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.mock.directory;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.mock.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.web;
namespace com.bea.alui.taglib.kdpage.test
{
  public class CurrentFolderDataTagTest : TestCase
  {
    private static String ID_VALUE = "currentfolder";
    private int folderId = 200;
    private String folderName = "my folder";
    private int folderLevel = 2;
    private bool canaddexpert = false;
    private AActivitySpace m_environment;
    private MockDirModel m_dirModel;
    public CurrentFolderDataTagTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      MockPTConfigHelper helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(helper);
      // Enable layouts globally in the config file
      helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      IApplication application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      XPHashtable htLookupTable = new XPHashtable();
      htLookupTable.PutElement(PT_CLASSIDS.PT_CATALOGFOLDER_ID + "", "directory");
      IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
      friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
      application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER,
       friendlyURLManager);
      m_dirModel = new MockDirModel();
      m_environment = new MockEnvironment();
      ((MockEnvironment) m_environment).m_models.PutElement(DirModel.STR_MVC_CLASS_NAME,
       m_dirModel);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new CurrentFolderDataTag(), CurrentFolderDataTag.TAG.GetName(),
       KDPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
      m_environment = null;
      m_dirModel = null;
    }
    public virtual void testDisplayTag()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(),
       CurrentFolderDataTag.TAG.GetName());
      helper.AddPTAttribute(CurrentFolderDataTag.ATTRIB_ID.GetName(), ID_VALUE);
      helper.AddPTAttribute(CurrentFolderDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      IDataObject doCurrentFolder = (IDataObject) ssVariable.GetValue();
      String name = doCurrentFolder.GetData(CurrentFolderDataTag.NAME);
      Assert.assertEquals("Wrong name returned for current folder.", folderName,
       name);
      String id = doCurrentFolder.GetData(CurrentFolderDataTag.ID);
      Assert.assertEquals("Wrong id returned for current folder.", folderId,
       XPConvert.ToInteger(id));
      String level = doCurrentFolder.GetData(CurrentFolderDataTag.LEVEL);
      Assert.assertEquals("Wrong level returned for current folder.", folderLevel,
       XPConvert.ToInteger(level));
      String bExpert = doCurrentFolder.GetData(CurrentFolderDataTag.CAN_ADD_EXPERT);
      Assert.assertEquals("Wrong value returned for current folder\'s can add as expert.",
       canaddexpert, XPConvert.ToBoolean(bExpert));
    }
  }
}