using System;
using junit.framework;
using com.bea.alui.taglib.kdpage;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.mock.directory;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.bea.alui.taglib.kdpage.test
{
  public class DocumentColumnHeadersDataTagTest : TestCase
  {
    private static String ID_VALUE = "headers";
    private String header1Name = "header1";
    private int header1Id = 1;
    private String header1SortURL = "http://www.sortheader2.com/directory/bidme/200?control=DirRepost&sortBy=1";
    private String header2Name = "header2";
    private int header2Id = 4;
    private String header2SortURL = "http://www.sortheader2.com/directory/bidme/202?control=DirRepost&sortBy=-4";
    private AActivitySpace m_environment;
    private MockDirModel m_dirModel;
    public DocumentColumnHeadersDataTagTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      IXPList headerProperties = new XPArrayList();
      String[] header = new String[DirModel.HEADER_PROPERTIES_SIZE];
      header[DirModel.HEADER_NAME_INDEX] = header1Name;
      header[DirModel.HEADER_ID_INDEX] = XPConvert.ToString(header1Id);
      header[DirModel.HEADER_SORT_URL_INDEX] = header1SortURL;
      headerProperties.Add(header);
      header = new String[DirModel.HEADER_PROPERTIES_SIZE];
      header[DirModel.HEADER_NAME_INDEX] = header2Name;
      header[DirModel.HEADER_ID_INDEX] = XPConvert.ToString(header2Id);
      header[DirModel.HEADER_SORT_URL_INDEX] = header2SortURL;
      headerProperties.Add(header);
      m_dirModel = new MockDirModel();
      m_dirModel.SetHeaderProperties(headerProperties);
      m_environment = new MockEnvironment();
      ((MockEnvironment) m_environment).m_models.PutElement(DirModel.STR_MVC_CLASS_NAME,
       m_dirModel);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new DocumentColumnHeadersDataTag(), DocumentColumnHeadersDataTag.TAG.GetName(),
       KDPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
    }
    public virtual void testDisplayTag()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(),
       DocumentColumnHeadersDataTag.TAG.GetName());
      helper.AddPTAttribute(DocumentColumnHeadersDataTag.ATTRIB_ID.GetName(),
       ID_VALUE);
      helper.AddPTAttribute(DocumentColumnHeadersDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      IXPList headers = (IXPList) ssVariable.GetValue();
      /* For both Ascending and Descending */
      Assert.assertEquals("The size of the headers list in memory is incorrect.",
       m_dirModel.GetHeaderProperties().GetSize() * 2, headers.GetSize());
      IDataObject dataObject = (IDataObject) headers.GetElement(0);
      String name = dataObject.GetData(DocumentColumnHeadersDataTag.NAME);
      Assert.assertTrue("Wrong name returned for header1.", XPStringUtility.StartsWith(name,
       header1Name));
      //		Assert.assertEquals("Wrong name returned for header1.", header1Name, name);
      String id = dataObject.GetData(DocumentColumnHeadersDataTag.ID);
      Assert.assertEquals("Wrong id returned for header1.", header1Id, XPConvert.ToInteger(id));
      String sortURL = dataObject.GetData(DocumentColumnHeadersDataTag.SORT_URL);
      Assert.assertEquals("Wrong sort URL returned for header1.", header1SortURL,
       sortURL);
      String sortUp = dataObject.GetData(DocumentColumnHeadersDataTag.SORT_ON);
      Assert.assertEquals("Wrong value returned for header1\'s sort Up.",
       false, XPConvert.ToBoolean(sortUp));
      // Getting Third since 2nd one belongs to Descending
      dataObject = (IDataObject) headers.GetElement(3);
      name = dataObject.GetData(DocumentColumnHeadersDataTag.NAME);
      Assert.assertTrue("Wrong name returned for header2.", XPStringUtility.StartsWith(name,
       header2Name));
      id = dataObject.GetData(DocumentColumnHeadersDataTag.ID);
      // Id will be -ve since sortup is false
      Assert.assertEquals("Wrong id returned for header2.", -header2Id, XPConvert.ToInteger(id));
      sortURL = dataObject.GetData(DocumentColumnHeadersDataTag.SORT_URL);
      Assert.assertEquals("Wrong sort URL returned for header2.", header2SortURL,
       sortURL);
      sortUp = dataObject.GetData(DocumentColumnHeadersDataTag.SORT_ON);
      Assert.assertEquals("Wrong value returned for header2\'s sort Up.",
       false, XPConvert.ToBoolean(sortUp));
    }
  }
}