using System;
using junit.framework;
using com.bea.alui.taglib.kdpage;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.mock.directory;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.mock.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.web;
namespace com.bea.alui.taglib.kdpage.test
{
  public class RelatedResourcesDataTagTest : TestCase
  {
    private static String ID_VALUE = "resources";
    private int resource1Id = 200;
    private String resource1Name = "resource 1";
    private String resource1Desc = "description for resource 1";
    private int resource2Id = 201;
    private String resource2Name = "resource 2";
    private String resource2Desc = "EMPTY_STRING";
    private int resource3Id = 202;
    private String resource3Name = "resource 3";
    private String resource3Desc = "description for resource 3";
    private int limit = 2;
    private AActivitySpace m_environment;
    private MockDirModel m_dirModel;
    public RelatedResourcesDataTagTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      MockPTConfigHelper helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(helper);
      // Enable layouts globally in the config file
      helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      IApplication application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      XPHashtable htLookupTable = new XPHashtable();
      htLookupTable.PutElement(PT_CLASSIDS.PT_CATALOGFOLDER_ID + "", "directory");
      htLookupTable.PutElement(PT_CLASSIDS.PT_COMMUNITY_ID + "", "community");
      htLookupTable.PutElement(PT_CLASSIDS.PT_USER_ID + "", "user");
      htLookupTable.PutElement(PT_CLASSIDS.PT_GADGET_ID + "", "portlet");
      IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
      friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
      application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER,
       friendlyURLManager);
      int[] columns = {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME,
       PT_PROPIDS.PT_PROPID_DESCRIPTION};
      Object[][] data = {new Object[]{resource1Id, resource1Name, resource1Desc},
       new Object[]{resource2Id, resource2Name, null}, new Object[]{resource3Id,
       resource3Name, resource3Desc}};
      // False means the data needs to be flipped.
      MockPTQueryResult.SetStaticData(columns, data, false);
      MockPTQueryResult qrRelatedResources = new MockPTQueryResult();
      IASQueryResult relatedResources = new ASQueryResultWrapper(qrRelatedResources);
      m_dirModel = new MockDirModel();
      m_environment = new MockEnvironment();
      m_dirModel.Init(m_environment);
      m_dirModel.SetRelatedResource(PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES,
       relatedResources);
      ((MockEnvironment) m_environment).m_models.PutElement(DirModel.STR_MVC_CLASS_NAME,
       m_dirModel);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new RelatedResourcesDataTag(), RelatedResourcesDataTag.TAG.GetName(),
       KDPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
      m_environment = null;
      m_dirModel = null;
      MockPTQueryResult.ClearStaticData();
    }
    public virtual void testDisplayTagNoLimit()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(),
       RelatedResourcesDataTag.TAG.GetName());
      helper.AddPTAttribute(RelatedResourcesDataTag.ATTRIB_ID.GetName(), ID_VALUE);
      helper.AddPTAttribute(RelatedResourcesDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      helper.AddPTAttribute(RelatedResourcesDataTag.ATTRIB_TYPE.GetName(),
       XPConvert.ToString(PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES));
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      IXPList relatedResources = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the headers list in memory is incorrect.",
       m_dirModel.GetRelatedResource(PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES).GetCount(),
       relatedResources.GetSize());
      IDataObject dataObject = (IDataObject) relatedResources.GetElement(0);
      String name = dataObject.GetData(RelatedResourcesDataTag.NAME);
      Assert.assertEquals("Wrong name returned for resource1.", resource1Name,
       name);
      String id = dataObject.GetData(RelatedResourcesDataTag.ID);
      Assert.assertEquals("Wrong id returned for resource1.", resource1Id,
       XPConvert.ToInteger(id));
      String desc = dataObject.GetData(RelatedResourcesDataTag.DESC);
      Assert.assertEquals("Wrong description returned for resource1.", resource1Desc,
       desc);
      dataObject = (IDataObject) relatedResources.GetElement(1);
      name = dataObject.GetData(RelatedResourcesDataTag.NAME);
      Assert.assertEquals("Wrong name returned for resource2.", resource2Name,
       name);
      id = dataObject.GetData(RelatedResourcesDataTag.ID);
      Assert.assertEquals("Wrong id returned for resource2.", resource2Id,
       XPConvert.ToInteger(id));
      desc = dataObject.GetData(RelatedResourcesDataTag.DESC);
      Assert.assertEquals("Wrong description returned for resource2.", resource2Desc,
       desc);
      dataObject = (IDataObject) relatedResources.GetElement(2);
      name = dataObject.GetData(RelatedResourcesDataTag.NAME);
      Assert.assertEquals("Wrong name returned for resource3.", resource3Name,
       name);
      id = dataObject.GetData(RelatedResourcesDataTag.ID);
      Assert.assertEquals("Wrong id returned for resource3.", resource3Id,
       XPConvert.ToInteger(id));
      desc = dataObject.GetData(RelatedResourcesDataTag.DESC);
      Assert.assertEquals("Wrong description returned for resource3.", resource3Desc,
       desc);
    }
    public virtual void testDisplayTagWithLimit()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(),
       RelatedResourcesDataTag.TAG.GetName());
      helper.AddPTAttribute(RelatedResourcesDataTag.ATTRIB_ID.GetName(), ID_VALUE);
      helper.AddPTAttribute(RelatedResourcesDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      helper.AddPTAttribute(RelatedResourcesDataTag.ATTRIB_TYPE.GetName(),
       XPConvert.ToString(PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES));
      helper.AddPTAttribute(RelatedResourcesDataTag.ATTRIB_LIMIT.GetName(),
       XPConvert.ToString(limit));
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      IXPList relatedResources = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the headers list in memory is incorrect.",
       limit, relatedResources.GetSize());
      IDataObject dataObject = (IDataObject) relatedResources.GetElement(0);
      String name = dataObject.GetData(RelatedResourcesDataTag.NAME);
      Assert.assertEquals("Wrong name returned for resource1.", resource1Name,
       name);
      String id = dataObject.GetData(RelatedResourcesDataTag.ID);
      Assert.assertEquals("Wrong id returned for resource1.", resource1Id,
       XPConvert.ToInteger(id));
      String desc = dataObject.GetData(RelatedResourcesDataTag.DESC);
      Assert.assertEquals("Wrong description returned for resource1.", resource1Desc,
       desc);
      dataObject = (IDataObject) relatedResources.GetElement(1);
      name = dataObject.GetData(RelatedResourcesDataTag.NAME);
      Assert.assertEquals("Wrong name returned for resource2.", resource2Name,
       name);
      id = dataObject.GetData(RelatedResourcesDataTag.ID);
      Assert.assertEquals("Wrong id returned for resource2.", resource2Id,
       XPConvert.ToInteger(id));
      desc = dataObject.GetData(RelatedResourcesDataTag.DESC);
      Assert.assertEquals("Wrong description returned for resource2.", resource2Desc,
       desc);
    }
  }
}