using System;
using junit.framework;
using com.bea.alui.taglib.kdpage;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.taskapi.portalui;
using com.plumtree.taskapi.portalui.util;
using com.plumtree.taskapi.test.portalui.mock;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.helpers;
namespace com.bea.alui.taglib.kdpage.test
{
  /// <summary>
  /// This class tests retrieving the data sources from the DirModel
  /// for use in submitting to the KD.
  /// </summary>
  public class SubmitSourceDataTagTest : TestCase
  {
    public const int DATA_SOURCE_ID_1 = 12;
    public const String DATA_SOURCE_NAME_1 = "First data source";
    public const String DATA_SOURCE_URL_1 = "";
    public const int DATA_SOURCE_ID_2 = 232;
    public const String DATA_SOURCE_NAME_2 = "Second data source";
    public const String DATA_SOURCE_URL_2 = "www.test.com";
    public const int WEB_SERVICE_ID_2 = 111232;
    public const int DATA_SOURCE_ID_3 = 784;
    public const String DATA_SOURCE_NAME_3 = "Third data source";
    public const String DATA_SOURCE_URL_3 = "www.anothertest.com";
    public const int WEB_SERVICE_ID_3 = 111784;
    public const String ID_VALUE = "myID";
    private AActivitySpace m_environment;
    
    /// <seealso cref="TestCase#setUp()"></seealso>
    public override void setUp()
    {
      base.setUp();
      ConfigService.setTestInstance(new MockConfigHelper());
      MockTaskAPIUIDirectoryService taskAPIDirectory = new MockTaskAPIUIDirectoryService();
      TaskAPIUIDirectoryService.SetMockInstanceForDebug(taskAPIDirectory);
      IXPList xpDataSources = new XPArrayList();
      HashtableDataObject source = new HashtableDataObject();
      source.SetData(SubmitDataSourceConstants.NAME, DATA_SOURCE_NAME_1);
      source.SetData(SubmitDataSourceConstants.TYPE, SubmitDataSourceConstants.TYPE_WEB);
      source.SetData(SubmitDataSourceConstants.ID, XPConvert.ToString(DATA_SOURCE_ID_1));
      xpDataSources.Add(source);
      source = new HashtableDataObject();
      source.SetData(SubmitDataSourceConstants.NAME, DATA_SOURCE_NAME_2);
      source.SetData(SubmitDataSourceConstants.TYPE, SubmitDataSourceConstants.TYPE_FILE);
      source.SetData(SubmitDataSourceConstants.ID, XPConvert.ToString(DATA_SOURCE_ID_2));
      source.SetData(SubmitDataSourceConstants.WEB_SERVICE_ID, XPConvert.ToString(WEB_SERVICE_ID_2));
      xpDataSources.Add(source);
      source = new HashtableDataObject();
      source.SetData(SubmitDataSourceConstants.NAME, DATA_SOURCE_NAME_3);
      source.SetData(SubmitDataSourceConstants.TYPE, SubmitDataSourceConstants.TYPE_FILE);
      source.SetData(SubmitDataSourceConstants.ID, XPConvert.ToString(DATA_SOURCE_ID_3));
      source.SetData(SubmitDataSourceConstants.WEB_SERVICE_ID, XPConvert.ToString(WEB_SERVICE_ID_3));
      xpDataSources.Add(source);
      taskAPIDirectory.SetDataSource(xpDataSources);
      XPHashtable xpURLs = new XPHashtable();
      xpURLs.PutElement(DATA_SOURCE_NAME_1, DATA_SOURCE_URL_1);
      xpURLs.PutElement(DATA_SOURCE_NAME_2, DATA_SOURCE_URL_2);
      xpURLs.PutElement(DATA_SOURCE_NAME_3, DATA_SOURCE_URL_3);
      taskAPIDirectory.SetURLsToAdd(xpURLs);
      m_environment = new MockEnvironment();
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new SubmitSourceDataTag(), SubmitSourceDataTag.TAG.GetName(),
       KDPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
      m_environment = null;
      TaskAPIUIDirectoryService.SetMockInstanceForDebug(null);
    }
    public virtual void testResults()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(),
       SubmitSourceDataTag.TAG.GetName());
      helper.AddPTAttribute(SubFoldersDataTag.ATTRIB_ID.GetName(), ID_VALUE);
      helper.AddPTAttribute(SubFoldersDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // public variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      Assert.assertNotNull("The data source list in memory should be non-null.",
       ssVariable);
      IXPList dataSources = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the data source list in memory is incorrect.",
       3, dataSources.GetSize());
      ValidateSource((HashtableDataObject) dataSources.GetElement(0), 1, DATA_SOURCE_NAME_1,
       DATA_SOURCE_ID_1, DATA_SOURCE_URL_1);
      ValidateSource((HashtableDataObject) dataSources.GetElement(1), 2, DATA_SOURCE_NAME_2,
       DATA_SOURCE_ID_2, DATA_SOURCE_URL_2);
      ValidateSource((HashtableDataObject) dataSources.GetElement(2), 3, DATA_SOURCE_NAME_3,
       DATA_SOURCE_ID_3, DATA_SOURCE_URL_3);
    }
    public virtual void ValidateSource(HashtableDataObject _source, int _nIndex,
     String _strName, int _nID, String _strURL)
    //		boolean _bLocal, boolean _bDefault, String _strURL)
    {
      assertEquals("Checking name on source " + _nIndex, _strName, _source.GetData(SubmitDataSourceConstants.NAME));
      assertEquals("Checking ID on source " + _nIndex, _nID, XPConvert.ToInteger(_source.GetData(SubmitDataSourceConstants.ID)));
      String strGWURL = _source.GetData(SubmitDataSourceConstants.URL);
      if ((_strURL == null) || (_strURL.Length == 0))
      {
        assertEquals("Checking for empty GW URL on source " + _nIndex, "",
         strGWURL);
      } else
      {
        assertTrue("Checking GW URL on source " + _nIndex, XPStringUtility.IndexOf(strGWURL,
         _strURL) >= 0);
        assertTrue("Checking GW URL was transformed for source " + _nIndex + ". Expected URL to be different from original, but it was the same.",
         XPStringUtility.CompareIgnoreCase(_strURL, strGWURL) != 0);
      }
    }
  }
}
// TODO: Check other data
/*
 // file or web
 public static final String TYPE = "type";
 public static final String URL = "url";
 */
 
