package com.bea.alui.taglib.kdpage;

import com.plumtree.openfoundation.util.XPStringBuilder;
import com.plumtree.portalpages.browsing.directory.DirRepostControl;
import com.plumtree.portalpages.browsing.directory.FolderBannerView;
import com.plumtree.portalpages.common.createfolder.CreateFolderDP;
import com.plumtree.portaluiinfrastructure.tags.ATag;
import com.plumtree.portaluiinfrastructure.tags.TagType;
import com.plumtree.portaluiinfrastructure.tags.metadata.AttributeType;
import com.plumtree.portaluiinfrastructure.tags.metadata.ITagMetaData;
import com.plumtree.portaluiinfrastructure.tags.metadata.OptionalTagAttribute;
import com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.ASURL;
import com.plumtree.xpshared.htmlelements.HTMLAnchor;
import com.plumtree.xpshared.htmlelements.HTMLElement;
import com.plumtree.xpshared.htmlelements.HTMLElementCollection;
import com.plumtree.xpshared.htmlelements.HTMLScript;
import com.plumtree.xpshared.htmlelements.HTMLScriptCollection;



/**
 * This tag only works with the Knowledge Directory activity space. It displays the Link to create new subFolder at the visible folder level.
 * Clicking the link generated by this tag opens a dialog for creating new sub folder. The 'text' optional attribute for this tag can be used
 * specify the text that appears for the Create Folder link. 
 * @author Ravi Tunuguntla
 */


public class CreateFolderDisplayTag extends AKDPageTag 
{
	
	
	private static final String TAG_NAME = "createfolderdisplay";
	public static final OptionalTagAttribute TEXT;
	public static final ITagMetaData TAG;

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			KD_PAGE_ONLY_CONSTANT + "Displays the link to create a new subfolder at the visible folder level. " +
				"Clicking the link generated by this tag opens a dialog for creating a new subfolder");
		TEXT = new OptionalTagAttribute("text", "Text for the Create Folder link. The default value is 'Create Folder'", 
				AttributeType.STRING, "Create Folder");
	}
	
	
	AActivitySpace m_asOwner = null;
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new CreateFolderDisplayTag();
	}

	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() {
		String strText = GetTagAttributeAsString(TEXT);		
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLAnchor elmLink= new HTMLAnchor("#");
		elmLink.SetOnClick(FolderBannerView.JAVASCRIPT_CREATEFOLDER_POPUP + "(); return false;" );
		elmLink.SetTitle(strText);
		elmLink.AddInnerHTMLString(strText);
		result.AddInnerHTMLElement(elmLink);
		return result;
	}	
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()
	 */
	public HTMLScriptCollection DisplaySharedJavascript()
	{
		HTMLScriptCollection scripts = new HTMLScriptCollection();
		HTMLScript myScript = new HTMLScript("text/javaScript");
		
		XPStringBuilder sb = new XPStringBuilder();
		m_asOwner = (AActivitySpace) GetEnvironment();
		ASURL myCreateFolderURL = new ASURL(m_asOwner);
		myCreateFolderURL.SetLinkGetCachedSpace(m_asOwner);
		myCreateFolderURL.SetDisplayPage(CreateFolderDP.STR_MVC_CLASS_NAME);
		myCreateFolderURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
		myCreateFolderURL.AddControlArgument(CreateFolderDP.QS_PARENT_FOLDER, GetDirModel().GetCurrentFolderID());
		
		
		
		//	Open create folder popup function
		sb.Append("function ").Append(FolderBannerView.JAVASCRIPT_CREATEFOLDER_POPUP)
		.Append("()\n");
		sb.Append("{\n");
		sb.Append("  window.open('")
		.Append(myCreateFolderURL.GetURLAsString()).Append("', 'CreateFolder', 'location=no,menubar=no,height=180,width=400');\n");
		sb.Append("}\n");

		myScript.AddInnerHTMLString(sb.ToString());

		scripts.AddInnerHTMLElement(myScript);
		return scripts;
	}
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#GetTagType()
	 */
	public TagType GetTagType()
	{
		return TagType.NO_BODY;
	}
}