package com.bea.alui.taglib.kdpage;


import com.plumtree.openfoundation.util.IXPList;
import com.plumtree.openfoundation.util.XPArrayList;
import com.plumtree.openfoundation.util.XPConvert;
import com.plumtree.portalpages.browsing.directory.DirConstants;
import com.plumtree.portalpages.browsing.directory.DirRepostControl;
import com.plumtree.portalpages.browsing.directory.IDirModelRO;
import com.plumtree.portaluiinfrastructure.resultwrapper.ASQueryResultWrapper;
import com.plumtree.portaluiinfrastructure.resultwrapper.IASQueryResult;
import com.plumtree.portaluiinfrastructure.tags.ATag;
import com.plumtree.portaluiinfrastructure.tags.Scope;
import com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
import com.plumtree.portaluiinfrastructure.tags.metadata.ITagMetaData;
import com.plumtree.portaluiinfrastructure.tags.metadata.TagMetaData;
import com.plumtree.server.IPTQueryResult;
import com.plumtree.server.PT_PROPIDS;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.ASURL;
import com.plumtree.xpshared.htmlelements.HTMLElement;




/**
 * This tag only works with the Knowledge Directory activity space. It stores the list of document types in the memory.
 * Each document type data object contains the following variables: 'name' for the document type name, 'id' for the Id 
 * of the document type, 'url' is the link to view the documents filtered by that type, 'on'"is true if the document 
 * filter has been set by that type and for all other types it is false.
 * 		
 * @author Ravi Tunuguntla
 */


public class DocumentFilterDataTag extends AKDPageTag 
{	
	private static final String TAG_NAME = "documentfilterdata";
	public static final String NAME = "name";
	public static final String URL = "url";
	public static final String ID = "id";
	public static final String ON = "on";
	private static final int NONE_SELECTED_ID = -1;
	
	public static final ITagMetaData TAG;

	public static final String DESCRIPTION = ATag.EncodeForTagDoc(
		KD_PAGE_ONLY_CONSTANT + "Stores the list of document types in memory. " +
		"Each document type data object contains the following variables: <br/>"  +
		"<ul>" +
		"<li> <code>" + NAME +"</code> - The document type name.</li>" + 
		"<li> <code>" + ID + "</code> - The ID of the document type.</li>" + 
		"<li> <code>" + URL +"</code> - The link to view the documents filtered by that type.</li>" + 
		"<li> <code>" + ON + "</code> - True if the document filter has been set by that type and false for other types.</li>" + 
		"</ul>"
		);

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, DESCRIPTION);		
	}
	
	
	AActivitySpace m_asOwner; 
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new DocumentFilterDataTag();
	}

	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() {

		m_asOwner = (AActivitySpace) GetEnvironment();
		
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		IDirModelRO dirModel = GetDirModel();
		int nSelDocType = dirModel.GetDocumentTypeId();

		IPTQueryResult ptQR = dirModel.GetSession().GetDocumentTypes().Query(PT_PROPIDS.PT_PROPID_OBJECTID |
				PT_PROPIDS.PT_PROPID_NAME, -1,
				PT_PROPIDS.PT_PROPID_NAME, 0,
				-1, null);
				
		IASQueryResult asQR = new ASQueryResultWrapper(ptQR);		
		int nNumDocTypes = asQR.GetCount();		
		IXPList docsList = new XPArrayList(nNumDocTypes);
		
		HashtableDataObject htObject;
		for (int i = 0; i < nNumDocTypes; i++)
		{
			int nDocTypeID		  = XPConvert.ToInteger(asQR.GetFields(i,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String strDocTypeName = (String) asQR.GetFields(i,
					PT_PROPIDS.PT_PROPID_NAME);
			
			htObject = new HashtableDataObject();
			htObject.SetData(NAME, strDocTypeName);
			htObject.SetData(URL, makeURL(nDocTypeID));
			htObject.SetData(ID, XPConvert.ToString(nDocTypeID));
			htObject.SetData(ON, (nDocTypeID == nSelDocType) ? "true" : "false");
			
			docsList.Add(htObject);
		}
		
		// Adding one more option for No Filter
		htObject = new HashtableDataObject();
		htObject.SetData(NAME, m_asOwner.GetString(817, "ptmsgs_portaladminmsgs"));
		htObject.SetData(URL, makeURL(NONE_SELECTED_ID));
		htObject.SetData(ID, XPConvert.ToString(NONE_SELECTED_ID));
		htObject.SetData(ON, (NONE_SELECTED_ID == nSelDocType) ? "true" : "false");
		
		docsList.Add(htObject);
		
		
				
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		GetState().SetSharedVariable(strDataReference, docsList, tagScope, true);
		
		return ProcessTagBody();
	}
	
	private String makeURL(int nTypeId)
	{

		ASURL asurl = new ASURL(m_asOwner);
		asurl.SetLinkGetCachedSpace(m_asOwner);
		asurl.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
		asurl.AddControlArgument(DirConstants.QS_DOCUMENT_TYPEID, nTypeId);

		return asurl.GetURLAsString();
	}
	
}