package com.bea.alui.taglib.kdpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.XPHttpUtility;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.search.results.BannerStartSearchControl;
import com.plumtree.portalpages.browsing.search.results.SearchResultAS;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.opener.IPTOpenerConstants;
import com.plumtree.portaluiinfrastructure.opener.PTOpenerLinks;
import com.plumtree.portaluiinfrastructure.pathways.tagging.ITaggingModel;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.PathwaysConstants;
import com.plumtree.portaluiinfrastructure.search.StartSearchControl;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag only works with the Knowledge Directory activity space. It stores the list of documents in the current folder in memory.
 * Each document data object contains the following variables: 'name' for the document's name, 'id' for the Id of the document,
 * 'url' is the link to view the document, 'createdate' is the date that the document was created, 'modifieddate' is the date that
 * the document was last modified, 'description' will have the decription of the document, or 'EMPTY_STRING' if there is no description,
 * 'imagesrc' has the src for the document's img tag, 'custompropskey' contains the key to access the documents custom properties
 * data collection. The custom properties data collection is ordered based on the Knowledge Directory Preference Page and each property data object has a variable
 * called 'value' that returns the value for that property. The 'tagskey' contains the key to access the document tags data collection
 * The tags data collection contains pathways tag property data object and has variables called 'value'  that returns the name of the tag and
 * 'isAppliedByCurrentUser' that returns true if this tag is applied by current user. The Pathways Tags data collection is available only if 
 * pathways is enabled and user can tag the documents.'pid' is the concatenated id containing PTCLASSID_OBJECTID for this document.This is used 
 * for adding/removing pathways tags. 'ptsource' is the source of the documents it can be WCI or collab or publisher... For WCI it is PTPORTAL
 * and for collab it is PTCOLLAB this is used by pathways to identify a document when adding/removing tags.
 * @author Dustin Ang
 * @author Ravi Tunuguntla
 */
public class DocumentsDataTag extends AKDPageTag 
{	
	private static final String TAG_NAME = "documentsdata";
	private static final String CUSTOM_PROP_PREFIX = "customprop";
	private static final String PATHWAYS_TAGS_PREFIX= "tags";
	
	public static final String NAME = "name";
	public static final String ID = "id";
	public static final String URL = "url";
	public static final String CREATE_DATE = "createdate";
	public static final String MODIFIED_DATE = "modifieddate";
	public static final String DESC = "description";
	public static final String IMAGE_SRC = "imagesrc";
	public static final String CUSTOM_PROPS_KEY = "custompropskey";
	public static final String TYPE_ID = "typeid";
	public static final String PATHWAYS_TAGS_KEY = "tagskey";
	public static final String PATHWAYS_ENABLED = "cantag";
	public static final String PATHWAYS_OID = "pid";
	public static final String PATHWAYS_OBJECT_SOURCE ="ptsource";
	
	
	public static final String VALUE = "value";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;

	public static final String TAG_DESCRIPTION = ATag.EncodeForTagDoc(
		KD_PAGE_ONLY_CONSTANT + "Stores the list of documents in the current folder in memory. " +
		"Each document data object contains the following variables: <br/>" + 
		"<ul>" + 
		"<li> <code>" + NAME +"</code> - The name of the document.</li>" + 
		"<li> <code>" + ID + "</code> - The ID of the document.</li>" + 
		"<li> <code>" + URL + "</code> - The link to view the document.</li>" + 
		"<li> <code>" + CREATE_DATE +"</code> - The date that the document was created.</li>" + 
		"<li> <code>" + MODIFIED_DATE + "</code> - The date that the document was last modified.</li>" + 
		"<li> <code>" + DESC +"</code> - The decription of the document, or '" + 
		EMPTY_STRING +"' if there is no description.</li>" + 
		"<li> <code>" + IMAGE_SRC + "</code> - The src for the document's img tag.</li>" + 
		"<li> <code>" + PATHWAYS_ENABLED + "</code> - This returns true if Pathways is enabled, this can be used to display tags on the documents. </li>" +
		"<li> <code>" + CUSTOM_PROPS_KEY + "</code> - The key to access the document's custom properties " +
		"data collection. The custom properties data collection is ordered based on the Knowledge Directory Preference page and each property data object has a variable " +
		"called <code>" + VALUE +"</code> that returns the value for that property.</li>" +
		"<li> <code>" + PATHWAYS_TAGS_KEY + "</code> - The key to access the document's pathways Tags properties " +
		"data collection. The Pathways Tags data collection property data object has variables " +
		"called <code>" + PathwaysConstants.TAG_VALUE +"</code> - that returns the name for that Tag.</li>" + 
		"<li> <code>" + PathwaysConstants.TAG_OWNER + "</code> - that returns if this tag is applied by current user.</li>" +
		"<li><code>" + PATHWAYS_OID + "</code> - that returns the concatenated id containing PTCLASSID_OBJECTID for this document." +
		"This is used for adding/removing pathways tags. </li>" +
		"<li><code>"+PATHWAYS_OBJECT_SOURCE+"</code> - The source of the documents it can be WCI or collab or publisher... For WCI it is 'PTPORTAL'" +
		"and for collab it is 'PTCOLLAB' this is used by pathways to identify a document when adding/removing tags. " +
		"The Pathways Tags data collection is available only if pathways is enabled and user can tag the documents.</li>" +
		"<li><code>"+ PathwaysConstants.SEARCH_URL_PREFIX + "<code>This is Prefix URL that refers to the link that generates search result page with all the" +
		"documents with this tag. In the layout the complete url can be generated by just appending the tag name to this prefix as follows" +
		"if SEARCH_URL_PREFIX is http://wci.oracle.com:9999/portal/server.pt/search?tag=" +
		"and TAG is 'sound of music' the final url will be 'http://wci.oracle.com:9999/portal/server.pt/search?tag=sound+of+music'" +
		"</li></ul>"
		);

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, TAG_DESCRIPTION);
	}
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new DocumentsDataTag();
	}

	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() 
	{
		Scope scope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		IDirModelRO dirModel = GetDirModel();
		IXPList docsList = new XPArrayList();
		
		// DCA - figure out how many documents to return
		// The actual figuring out which documents to fetch happens in the background, see DirModel:LoadFoldersAndDocuments()
		// By this point, the documents have already been fetched and we're just iterating through them to store them in memory.
		int[] arrCardRange = dirModel.GetCardRange();
		int nFirstObjectIndex = 0;
		int nLastObjectIndex  = arrCardRange[DirModel.CARD_CNT];
		
		boolean bBrowseBySearch = (DirConstants.BROWSE_BY_SEARCH == dirModel.GetBrowseBySource());
		// DCA - get documents in range
		for (int i=nFirstObjectIndex; i<nLastObjectIndex; i++) {
			HashtableDataObject htObject = GetDocumentDataObject(i, bBrowseBySearch);
			docsList.Add(htObject);

			// DCA - we only display custom properties if we're browsing by search
			if (bBrowseBySearch)
			{
				IXPList customPropList = GetCustomPropDataObject(i);
				GetState().SetSharedVariable(htObject.GetData(CUSTOM_PROPS_KEY), customPropList, scope, true);
			}
			
			// RaviT - Adding Pathways Tags data list for each document.
			IXPList pathwaysTagsList = ((ITaggingModel) dirModel).GetObjectTags(XPConvert.ToInteger(htObject.GetData(ID)));
			GetState().SetSharedVariable(htObject.GetData(PATHWAYS_TAGS_KEY), pathwaysTagsList, scope, true);
		}
		
		// DCA - add to memory
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		GetState().SetSharedVariable(strDataReference, docsList, scope, true);
		
		// RaviT - adding Pathways Tag URL Prefix to Memory
		GetState().SetSharedVariable(PathwaysConstants.SEARCH_URL_PREFIX, GetTagSearchURLPrefix(), scope, true);

		return ProcessTagBody();
	}

	private IXPList GetCustomPropDataObject(int i) 
	{
		IDirModelRO dirModel = GetDirModel();
		XPArrayList xpCustomProps  = dirModel.GetPropColumns();
		IXPList customPropList = new XPArrayList();

		// DCA - check if we have custom properties to display
		if (xpCustomProps.GetSize() > 0) {
			// DCA - get the current document's values for those custom properties
			XPArrayList xpCustomFields     = dirModel.GetCustomFields(i, xpCustomProps, dirModel.GetUserPrefLocale(), dirModel.GetUserPrefTimeZone());
			for (int j = 0; j < xpCustomFields.GetSize(); j++)
			{
				HashtableDataObject htObject = new HashtableDataObject();
				htObject.SetData(VALUE, (String) xpCustomFields.GetElement(j));
				customPropList.Add(htObject);
			}
		}
		return customPropList;
	}

	private HashtableDataObject GetDocumentDataObject(int index, boolean bBrowseBySearch) 
	{
		IDirModelRO dirModel = GetDirModel();
		// Card ID
		int nCardID = XPConvert.ToInteger(dirModel.GetObjectFields(index, 
				(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_OBJECTID
									 : PT_PROPIDS.PT_PROPID_OBJECTID)));

		// Name
		String strName = (String) dirModel.GetObjectFields(index, 
				(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_OBJECTNAME
									 : PT_PROPIDS.PT_PROPID_NAME));
		// Doc Type
		int nDocType = XPConvert.ToInteger(dirModel.GetObjectFields(index,
				(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_DOCUMENTTYPEID
						: PT_PROPIDS.PT_PROPID_CARD_DOCUMENTTYPEID)));
		// Image uiid
		String strImageUIID = (String) dirModel.GetObjectFields(index,
				(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID
									: PT_PROPIDS.PT_PROPID_IMAGEUUID));
		HTMLImg myImg = PlumtreeHelpers.GetHTMLImage(strImageUIID, true);
		String strImageBaseURL = ConfigHelper.GetImageServerBaseURL(ConfigHelper.GetIsSpaceSecure(GetEnvironment().GetCurrentHTTPRequest().IsSecureConnection()));
		myImg.SetImgBaseUrl(strImageBaseURL);
		
		// DCA - create a date time formate to convert dates to strings
		XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT,
				XPDateFormat.SHORT, dirModel.GetUserPrefLocale(), dirModel.GetUserPrefTimeZone());
		
		// Created
		XPDateTime dtCreatedDate = (XPDateTime) dirModel.GetObjectFields(index,
				(bBrowseBySearch? PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED
									: PT_PROPIDS.PT_PROPID_CREATED ));
		String strCreatedDate = xpDateTimeFormat.Format(dtCreatedDate);

		// Last Modified
		XPDateTime dtLastModifiedDate = (XPDateTime) dirModel.GetObjectFields(index,
				(bBrowseBySearch? PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED
									: PT_PROPIDS.PT_PROPID_LASTMODIFIED ));
		String strLastModifiedDate = xpDateTimeFormat.Format(dtLastModifiedDate);

		// Description
		String strDescType = dirModel.GetDocDescriptionType();
		String strDesc     = "";

		if (false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE,strDescType))
		{
			strDesc = (String) dirModel.GetObjectFields(index,
					(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY
										: PT_PROPIDS.PT_PROPID_DESCRIPTION));
			
			if (null == strDesc)
			{
				strDesc = EMPTY_STRING;
			}

			// abbreviate the description if necessary
			if (true == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_ABBR,strDescType))
			{
				if (DirConstants.DESCRIPTION_ABBR_LENGTH < strDesc.length())
				{
					strDesc = strDesc.substring(0, DirConstants.DESCRIPTION_ABBR_LENGTH) + "...";
				}
			}
		} else {
			strDesc = EMPTY_STRING;
		}

		IPTURL ptDocURL = TaskAPIUIDirectory.CreateCommonOpenerDocumentURL((AActivitySpace) GetEnvironment(), strName, nCardID, strName);
		
        // Bug-9380820: Adding the code to check UserPrefrence for Documents should open in new window or the same window.
		
		String strURL;
		if(dirModel.GetUserPrefOpenDocInNewWindow())
		{
			// open document URL in new window.
			strURL = PTOpenerLinks.GetJSOpenInNewWindow(
				PTOpenerLinks.GetOpenerJSURLOpenObjID(PT_CLASSIDS.PT_CATALOGCARD_ID, nCardID,
					null, IPTOpenerConstants.OPENER_MODE_VIEW),
				PTOpenerLinks.GetWindowName("" + PT_CLASSIDS.PT_CATALOGCARD_ID + "_" + nCardID),
			    	"800", "600", true);
		}
		else
		{
			// open document URL in same window.
			strURL = PTOpenerLinks.GetJSOpenInSameWindow(
				PTOpenerLinks.GetOpenerJSURLOpenObjID(PT_CLASSIDS.PT_CATALOGCARD_ID, nCardID,
					null, IPTOpenerConstants.OPENER_MODE_VIEW));
		}
		
		strURL = strURL + "; return false;";

		// DCA - create the key to access the document's custom properties
		String strCustomPropKey = CUSTOM_PROP_PREFIX + index;

		// RaviT - Adding the pathways tags key for each document 		
		String strPathwaysTagsKey = PATHWAYS_TAGS_PREFIX + index;
		
		// RaviT - Adding the Pathways Tags enabled Parameter
		boolean bPathwaysEnabled = ((ITaggingModel) dirModel).IsTaggingEnabled();
		
		//RaviT - Creating Pathways Concatenated ID for Adding/Removing Tags.
		XPStringBuilder strClassID = new XPStringBuilder();
		
		strClassID.Append( dirModel.GetObjectFields(index, 
				(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_CLASSID
						 : PT_PROPIDS.PT_PROPID_CLASSID)) + "_" + nCardID);		
		
		
		
		HashtableDataObject htObject = new HashtableDataObject();
		htObject.SetData(NAME, strName);
		htObject.SetData(ID, XPConvert.ToString(nCardID));
		htObject.SetData(IMAGE_SRC, myImg.GetSrc());
        // Bug:9380820 -- Changing Second argument ptDocURL.GetFullURL() to strURL. 
        // ptDocURL.GetFullURL() was giving static URL of the document. 
        // It was not checking for the UserPrefrence. That is document should open in new window or same window.
		htObject.SetData(URL, strURL);
		htObject.SetData(CREATE_DATE, strCreatedDate);
		htObject.SetData(MODIFIED_DATE, strLastModifiedDate);
		htObject.SetData(DESC, strDesc);
		htObject.SetData(CUSTOM_PROPS_KEY, strCustomPropKey);
		htObject.SetData(TYPE_ID, XPConvert.ToString(nDocType));
		htObject.SetData(PATHWAYS_TAGS_KEY, strPathwaysTagsKey);
		htObject.SetData(PATHWAYS_ENABLED, XPConvert.ToString(bPathwaysEnabled));
		htObject.SetData(PATHWAYS_OID, strClassID.ToString());
		htObject.SetData(PATHWAYS_OBJECT_SOURCE, PathwaysConstants.PTSOURCE_PORTAL);
		
		return htObject;
	}
	
	
	private  String GetTagSearchURLPrefix () {
		// Generate tag query click-throughs.
		// String strSearchHref = PTConfigHelper.GetMainServerApplicationURL(false);
		String strSearchHref = TaskAPIUIPortalConfig.GetApplicationBaseURL((AActivitySpace) GetEnvironment());
		
		if (strSearchHref.endsWith("?")) 
		{
			strSearchHref = strSearchHref.substring(0, strSearchHref.length() - 1);
		}
		
		if (TaskAPIUICommon.UseFriendlyURLS(FriendlyURLConstants.FRIENDLY_SEARCH_ID))
		{
			// Run a Pathways Query by tagname.
			strSearchHref = strSearchHref + "/" + SearchFriendlyURLParser.SEARCH_FRIENDLY_URL_KEYWORD + "?" 
							+ SearchFriendlyURLParser.TAG_SEARCH_QS + "=" ;
		}
		else
		{
			// Search Friendly URLs disabled, generate non-friendly URLs.
			// Run a Pathways Query by tagname.
			String pathwaysTagQuery = XPHttpUtility.UrlEncode(PathwaysConstants.TAG_QUERY_PREFIX , "utf-8");
			
			strSearchHref = strSearchHref + "?" + ASConstants.SPACENAME + "=" + SearchResultAS.STR_MVC_CLASS_NAME + "&" + 
							ASConstants.CONTROL + "=" + BannerStartSearchControl.STR_MVC_CLASS_NAME + "&" + 
							StartSearchControl.USER_QUERY + "=" + pathwaysTagQuery;
		}
		
		return strSearchHref;
	}
}
