package com.bea.alui.taglib.kdpage;


import com.plumtree.openfoundation.util.IXPList;
import com.plumtree.openfoundation.util.XPArrayList;
import com.plumtree.openfoundation.util.XPConvert;
import com.plumtree.openfoundation.util.XPStringBuilder;
import com.plumtree.openfoundation.util.XPStringTokenizer;
import com.plumtree.portalpages.browsing.directory.DirConstants;
import com.plumtree.portalpages.browsing.directory.DirRepostControl;
import com.plumtree.portalpages.browsing.directory.IDirModelRO;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.ASURL;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag only works with the Knowledge Directory activity space. It takes 'value' as RequiredTagAttribute and 
 * it is comma seperated list of integers. It in turn stores a list of documentsperpage objects and each object
 * contains 'name' the name that can be used show as display name. 'url' that is the link to set Items per Page.
 * 'selected' value either 'true' or 'false' based on the current setting. 
 * 
 * @author Ravi Tunuguntla
 */
public class DocumentsPerPageDataTag extends AKDPageTag 
{	
	private static final String TAG_NAME = "documentsperpagedata";
	
	public static final String NAME = "name";
	public static final String URL = "url";
	public static final String SELECTED = "selected";
	
	public static final RequiredTagAttribute VALUE;
	
	private AActivitySpace m_asOwner;
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;

	public static final String TAG_DESCRIPTION = ATag.EncodeForTagDoc(
		KD_PAGE_ONLY_CONSTANT + "The pt:value attribute takes " +
		" in a comma separated list of integers and " +
		"stores a list of documentsperpage objects. Each object contains the following variables: <code>" + NAME + "</code> - The name to " +
		"be displayed, <code>" + URL + "</code> - The link to set the items per page, and <code>"+ SELECTED +
		"</code> - Either 'true' or 'false' based on the current setting."
		);

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		
		VALUE = new RequiredTagAttribute("value", "This attributr takes comma seperated list of integers as input values. ", AttributeType.STRING);
		
		TAG = new TagMetaData(TAG_NAME, TAG_DESCRIPTION);
	}
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new DocumentsPerPageDataTag();
	}

	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() 
	{
		IDirModelRO dirModel = GetDirModel();
		int nCurVal = dirModel.GetNumDocsPerPage();
		
		XPStringBuilder strValues = new XPStringBuilder(GetTagAttributeAsString(VALUE));		
		XPStringTokenizer strList = new XPStringTokenizer(strValues.ToString() , ",");
		

		m_asOwner = (AActivitySpace) GetEnvironment();		
		IXPList headersList = new XPArrayList();
		
		boolean bSelinList = false;
				
		while(strList.HasMoreTokens())
		{
			int nVal = XPConvert.ToInteger(strList.GetNextToken());
			HashtableDataObject htObject = new HashtableDataObject();
			
			ASURL asurl = new ASURL(m_asOwner);
			asurl.SetLinkGetCachedSpace(m_asOwner);
			asurl.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(DirConstants.QS_PER_PAGE, nVal);
			
			htObject.SetData(URL, asurl.GetURLAsString());
			htObject.SetData(NAME, XPConvert.ToString(nVal));
			
			// Verify This from DirModel if this number has been selected previously
			htObject.SetData(SELECTED, XPConvert.ToString( nCurVal == nVal));
			
			headersList.Add(htObject);
			
			/* Verifying if the previously set number is in the list at all, if not
			 * then this flag will be false and we will add that number to the list.
			 */
			if(nCurVal == nVal)
			{
				bSelinList = true ;
			}
						
						
		}
		

		if(!bSelinList)
		{
			HashtableDataObject htObject = new HashtableDataObject();
			
			ASURL asurl = new ASURL(m_asOwner);
			asurl.SetLinkGetCachedSpace(m_asOwner);
			asurl.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(DirConstants.QS_PER_PAGE, nCurVal);
			
			htObject.SetData(URL, asurl.GetURLAsString());
			htObject.SetData(NAME, XPConvert.ToString(nCurVal));
			
			htObject.SetData(SELECTED, "true");
			
			headersList.Add(htObject);			
		}
		
		//		 Add to memory
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		GetState().SetSharedVariable(strDataReference, headersList, tagScope, true);
		
		return ProcessTagBody();
	}
}