package com.bea.alui.taglib.kdpage.test;

import junit.framework.*;

import com.bea.alui.taglib.kdpage.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.mock.directory.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;

public class BreadCrumbsDataTagTest extends TestCase 
{
	private static String ID_VALUE = "breadcrumbs";
	
	private int breadCrumb1Id = 200;
	private String breadCrumb1Name = "breadcrumb 1";
	private int breadCrumb2Id = 201;
	private String breadCrumb2Name = "breadcrumb 2";
	
	private AActivitySpace m_environment;
	private MockDirModel m_dirModel;

	/**
	 */
	public BreadCrumbsDataTagTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();
   		
   		MockPTConfigHelper helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(helper);
		// Enable layouts globally in the config file
		helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
				PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
   		
   		IApplication application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
   		XPHashtable htLookupTable = new XPHashtable();
		htLookupTable.PutElement(PT_CLASSIDS.PT_CATALOGFOLDER_ID+"", "directory");
   		
   		IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
		friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, friendlyURLManager);
   		
   		int[] columns = {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME};
		Object[][] data = {{new Integer(breadCrumb1Id), breadCrumb1Name},{new Integer(breadCrumb2Id), breadCrumb2Name}};
		// False means the data needs to be flipped.
		MockPTQueryResult.SetStaticData(columns, data, false);
   		
   		MockPTQueryResult qrBreadCrumbs = new MockPTQueryResult();
   		IASQueryResult breadCrumbsPath = new ASQueryResultWrapper(qrBreadCrumbs);
   		m_dirModel = new MockDirModel();
   		m_dirModel.SetBreadCrumbPath(breadCrumbsPath);
   		m_environment = new MockEnvironment();
   		((MockEnvironment) m_environment).m_models.PutElement(DirModel.STR_MVC_CLASS_NAME, m_dirModel);
   		
   		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new BreadCrumbsDataTag(), BreadCrumbsDataTag.TAG.GetName(), KDPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		
		m_environment = null;
		m_dirModel = null;
		MockPTQueryResult.ClearStaticData();
	}
	
	public void testDisplayTag() 
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(), BreadCrumbsDataTag.TAG.GetName());
   		helper.AddPTAttribute(BreadCrumbsDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(BreadCrumbsDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
		// for some reason the names are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);
		IXPList breadCrumbs = (IXPList) ssVariable.GetValue();
		Assert.assertEquals("The size of the brad crumbs list in memory is incorrect.", m_dirModel.GetBreadCrumbPath().GetCount(), breadCrumbs.GetSize());
		
		IDataObject dataObject = (IDataObject) breadCrumbs.GetElement(0);
		String name = dataObject.GetData(BreadCrumbsDataTag.NAME);
		Assert.assertEquals("Wrong name returned for breadCrumb1.", breadCrumb1Name, name);
		String id = dataObject.GetData(BreadCrumbsDataTag.ID);
		Assert.assertEquals("Wrong id returned for breadCrumb1.", breadCrumb1Id, XPConvert.ToInteger(id));
		
		dataObject = (IDataObject) breadCrumbs.GetElement(1);
		name = dataObject.GetData(BreadCrumbsDataTag.NAME);
		Assert.assertEquals("Wrong name returned for breadCrumb2.", breadCrumb2Name, name);
		id = dataObject.GetData(BreadCrumbsDataTag.ID);
		Assert.assertEquals("Wrong id returned for breadCrumb2.", breadCrumb2Id, XPConvert.ToInteger(id));
	}
}
