package com.bea.alui.taglib.kdpage.test;

import junit.framework.*;

import com.bea.alui.taglib.kdpage.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.mock.directory.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;

public class DocumentsDataTagTest extends TestCase {

	private static String ID_VALUE = "documents";

	private int document1Id = 200;
	private String document1Name = "document 1";
	private String document1Desc = "description for document 1";
	private XPDateTime document1CreateDate = new XPDateTime(1000);
	private XPDateTime document1ModifiedDate = new XPDateTime(1000);
	private String document1ImageUUID = "{52a5a5a0-84c9-11d2-a0c5-0060979c42d1}";
	private String document1ImageSrc = "portal/public/img/sml{52a5a5a0-84c9-11d2-a0c5-0060979c42d1}.gif";
	private int document1TypeId = 106;
	
	private int document2Id = 201;
	private String document2Name = "document 2";
	private String document2Desc = "EMPTY_STRING";
	private XPDateTime document2CreateDate = new XPDateTime(2000);
	private XPDateTime document2ModifiedDate = new XPDateTime(2000);
	private String document2ImageUUID = "{52a5a5a0-84c9-11d2-a0c5-0060979c42d2}";
	private String document2ImageSrc = "portal/public/img/sml{52a5a5a0-84c9-11d2-a0c5-0060979c42d2}.gif";
	private int document2TypeId = 106;
	
	private int document3Id = 202;
	private String document3Name = "document 3";
	private String document3Desc = "description for document 3";
	private XPDateTime document3CreateDate = new XPDateTime(3000);
	private XPDateTime document3ModifiedDate = new XPDateTime(3000);
	private String document3ImageUUID = "{52a5a5a0-84c9-11d2-a0c5-0060979c42d3}";
	private String document3ImageSrc = "portal/public/img/sml{52a5a5a0-84c9-11d2-a0c5-0060979c42d3}.gif";
	private int document3TypeId = 106;
	
	private AActivitySpace m_environment;
	private MockDirModel m_dirModel;
	private IASQueryResult m_documents;
	
	/**
	 */
	public DocumentsDataTagTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();
   		
   		MockPTConfigHelper helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(helper);
		// Enable layouts globally in the config file
		helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
				PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
   		
   		IApplication application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
   		XPHashtable htLookupTable = new XPHashtable();
		htLookupTable.PutElement(PT_CLASSIDS.PT_CATALOGCARD_ID+"", "document");
   		
   		IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
		friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, friendlyURLManager);
   		
   		int[] columns = {PT_INTRINSICS.PT_PROPERTY_OBJECTID, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME, PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY,
   				PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID, PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED, PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED, PT_INTRINSICS.PT_PROPERTY_DOCUMENTTYPEID};
		Object[][] data = {{new Integer(document1Id), document1Name, document1Desc, document1ImageUUID, document1CreateDate, document1ModifiedDate, new Integer(document1TypeId)},
				{new Integer(document2Id), document2Name, null, document2ImageUUID, document2CreateDate, document2ModifiedDate, new Integer(document2TypeId)},
				{new Integer(document3Id), document3Name, document3Desc, document3ImageUUID, document3CreateDate, document3ModifiedDate, new Integer(document3TypeId)}};
		
   		MockPTQueryResult qrDocuments = new MockPTQueryResult();
		// False means the data needs to be flipped.
   		qrDocuments.SetData(columns, data, false);
   		
   		m_documents = new ASQueryResultWrapper(qrDocuments);
   		int[] cardRange = new int[4];
		cardRange[DirModel.BEGIN_INDEX] = 0;
		cardRange[DirModel.END_INDEX] = m_documents.GetCount();
		cardRange[DirModel.CARD_CNT] = m_documents.GetCount();
		cardRange[DirModel.TOTAL_CNT_INDEX] = m_documents.GetCount();
   		
   		m_dirModel = new MockDirModel();
   		m_environment = new MockEnvironment();
   		m_dirModel.Init(m_environment);
   		m_dirModel.SetDocuments(m_documents);
   		m_dirModel.SetCardRange(cardRange);
   		((MockEnvironment) m_environment).m_models.PutElement(DirModel.STR_MVC_CLASS_NAME, m_dirModel);
   		
   		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new DocumentsDataTag(), DocumentsDataTag.TAG.GetName(), KDPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		
		m_documents = null;
	}
	
	public void testDisplayTag() 
	{
		XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT,
				XPDateFormat.SHORT, m_dirModel.GetUserPrefLocale(), m_dirModel.GetUserPrefTimeZone());
		
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(), DocumentsDataTag.TAG.GetName());
   		helper.AddPTAttribute(DocumentsDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(DocumentsDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
		// for some reason the names are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);   		
		IXPList documents = (IXPList) ssVariable.GetValue();
		Assert.assertEquals("The size of the headers list in memory is incorrect.", m_documents.GetCount(), documents.GetSize());
		
		IDataObject dataObject = (IDataObject) documents.GetElement(0);
		String name = dataObject.GetData(DocumentsDataTag.NAME);
		Assert.assertEquals("Wrong name returned for document1.", document1Name, name);
		String id = dataObject.GetData(DocumentsDataTag.ID);
		Assert.assertEquals("Wrong id returned for document1.", document1Id, XPConvert.ToInteger(id));
		String desc = dataObject.GetData(DocumentsDataTag.DESC);
		Assert.assertEquals("Wrong description returned for document1.", document1Desc, desc);
		String createDate = dataObject.GetData(DocumentsDataTag.CREATE_DATE);
		Assert.assertEquals("Wrong create date returned for document1.", xpDateTimeFormat.Format(document1CreateDate), createDate);
		String modifiedDate = dataObject.GetData(DocumentsDataTag.MODIFIED_DATE);
		Assert.assertEquals("Wrong modified date returned for document1.", xpDateTimeFormat.Format(document1ModifiedDate), modifiedDate);
		String imageSrc = dataObject.GetData(DocumentsDataTag.IMAGE_SRC);
		Assert.assertEquals("Wrong image src returned for document1.", document1ImageSrc, imageSrc);
		String typeid = dataObject.GetData(DocumentsDataTag.TYPE_ID);
		Assert.assertEquals("Wrong Type ID returned for document1.", document1TypeId, XPConvert.ToInteger(typeid));
		
		
		dataObject = (IDataObject) documents.GetElement(1);
		name = dataObject.GetData(DocumentsDataTag.NAME);
		Assert.assertEquals("Wrong name returned for document2.", document2Name, name);
		id = dataObject.GetData(DocumentsDataTag.ID);
		Assert.assertEquals("Wrong id returned for document2.", document2Id, XPConvert.ToInteger(id));
		desc = dataObject.GetData(DocumentsDataTag.DESC);
		Assert.assertEquals("Wrong description returned for document2.", document2Desc, desc);
		createDate = dataObject.GetData(DocumentsDataTag.CREATE_DATE);
		Assert.assertEquals("Wrong create date returned for document2.", xpDateTimeFormat.Format(document2CreateDate), createDate);
		modifiedDate = dataObject.GetData(DocumentsDataTag.MODIFIED_DATE);
		Assert.assertEquals("Wrong modified date returned for document2.", xpDateTimeFormat.Format(document2ModifiedDate), modifiedDate);
		imageSrc = dataObject.GetData(DocumentsDataTag.IMAGE_SRC);
		Assert.assertEquals("Wrong image src returned for document2.", document2ImageSrc, imageSrc);
		typeid = dataObject.GetData(DocumentsDataTag.TYPE_ID);
		Assert.assertEquals("Wrong Type ID returned for document2.", document2TypeId, XPConvert.ToInteger(typeid));

		dataObject = (IDataObject) documents.GetElement(2);
		name = dataObject.GetData(DocumentsDataTag.NAME);
		Assert.assertEquals("Wrong name returned for document3.", document3Name, name);
		id = dataObject.GetData(DocumentsDataTag.ID);
		Assert.assertEquals("Wrong id returned for document3.", document3Id, XPConvert.ToInteger(id));
		desc = dataObject.GetData(DocumentsDataTag.DESC);
		Assert.assertEquals("Wrong description returned for document3.", document3Desc, desc);
		createDate = dataObject.GetData(DocumentsDataTag.CREATE_DATE);
		Assert.assertEquals("Wrong create date returned for document3.", xpDateTimeFormat.Format(document3CreateDate), createDate);
		modifiedDate = dataObject.GetData(DocumentsDataTag.MODIFIED_DATE);
		Assert.assertEquals("Wrong modified date returned for document3.", xpDateTimeFormat.Format(document3ModifiedDate), modifiedDate);
		imageSrc = dataObject.GetData(DocumentsDataTag.IMAGE_SRC);
		Assert.assertEquals("Wrong image src returned for document3.", document3ImageSrc, imageSrc);
		typeid = dataObject.GetData(DocumentsDataTag.TYPE_ID);
		Assert.assertEquals("Wrong Type ID returned for document3.", document3TypeId, XPConvert.ToInteger(typeid));
	}
}
