package com.bea.alui.taglib.kdpage.test;

import junit.framework.*;

import com.bea.alui.taglib.kdpage.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.mock.directory.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;

public class SubFoldersDataTagTest extends TestCase {

	private static String ID_VALUE = "subfolders";
	
	private int subFolder1Id = 201;
	private String subFolder1Name = "subfolder 1";
	private String subFolder1Desc = "subfolder 1 description";
	private String subFolder1Level = "3";
	
	private int subFolder2Id = 202;
	private String subFolder2Name = "subfolder 2";
	private String subFolder2Desc = "EMPTY_STRING";
	private String subFolder2Level = "4";
	
	private int subFolder3Id = 203;
	private String subFolder3Name = "subfolder 3";
	private String subFolder3Desc = "subfolder 3 description";
	private String subFolder3Level = "3";

	private AActivitySpace m_environment;
	private MockDirModel m_dirModel;
	
	/**
	 */
	public SubFoldersDataTagTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();
   		
   		MockPTConfigHelper helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(helper);
		// Enable layouts globally in the config file
		helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
				PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
   		
   		IApplication application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);
   		XPHashtable htLookupTable = new XPHashtable();
		htLookupTable.PutElement(PT_CLASSIDS.PT_CATALOGFOLDER_ID+"", "directory");
   		
   		IFriendlyURLManager friendlyURLManager = new MockClassTypeDescManager();
		friendlyURLManager.SetFriendlyURLLookupTable(htLookupTable);
		application.GetCachingManager().SetEntry(AppWarmUp.KEY_CACHEMAN_CLASS_TYPE_MANAGER, friendlyURLManager);
   		
   		int[] columns = {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME, PT_PROPIDS.PT_PROPID_DESCRIPTION, PT_PROPIDS.PT_PROPID_FOLDER_LEVEL};
		Object[][] data = {{new Integer(subFolder1Id), subFolder1Name, subFolder1Desc, subFolder1Level},
				{new Integer(subFolder2Id), subFolder2Name, DirConstants.DIR_FOLD_DESC_NONE, subFolder2Level},
				{new Integer(subFolder3Id), subFolder3Name, subFolder3Desc, subFolder3Level}};
		// False means the data needs to be flipped.
		MockPTQueryResult.SetStaticData(columns, data, false);
   		
   		MockPTQueryResult qrSubFolders = new MockPTQueryResult();
   		IASQueryResult folderQueryResult = new ASQueryResultWrapper(qrSubFolders);
   		m_dirModel = new MockDirModel();
   		m_dirModel.SetFolderQueryResult(folderQueryResult);
   		m_environment = new MockEnvironment();
   		((MockEnvironment) m_environment).m_models.PutElement(DirModel.STR_MVC_CLASS_NAME, m_dirModel);
   		
   		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new SubFoldersDataTag(), SubFoldersDataTag.TAG.GetName(), KDPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		
		m_environment = null;
		m_dirModel = null;
		MockPTQueryResult.ClearStaticData();
	}
	
	public void testDisplayTag() 
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(), SubFoldersDataTag.TAG.GetName());
   		helper.AddPTAttribute(SubFoldersDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(SubFoldersDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
		// public variables are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);
		IXPList subFolders = (IXPList) ssVariable.GetValue();
		Assert.assertEquals("The size of the subfolders list in memory is incorrect.", 2, subFolders.GetSize());

		checkSubFolder((IDataObject) subFolders.GetElement(0), 1,
				subFolder1Name, subFolder1Id, subFolder1Desc);
		
		checkSubFolder((IDataObject) subFolders.GetElement(1), 3,
				subFolder3Name, subFolder3Id, subFolder3Desc);

		// DCA - check sub sub folder
		ssVariable = (SharedStateVariable) scopeData.GetElement(".subfoldersof"+subFolder1Id);
		IXPList subsubFolders = (IXPList) ssVariable.GetValue();
		Assert.assertEquals("The size of the subsubfolders list in memory is incorrect.", 1, subsubFolders.GetSize());

		checkSubFolder((IDataObject) subsubFolders.GetElement(0), 2,
				subFolder2Name, subFolder2Id, subFolder2Desc);
	}

	/**
	 * Helper method to check the subfolder data.
	 * @param _folder
	 * @param _nIndex
	 * @param _strName
	 * @param _nID
	 * @param _strDesc
	 */
	public void checkSubFolder(IDataObject _folder, int _nIndex, String _strName, int _nID, String _strDesc)
	{
		String name = _folder.GetData(SubFoldersDataTag.NAME);
		Assert.assertEquals("Wrong name returned for subfolder " + _nIndex + ".", _strName, name);
		int id = XPConvert.ToInteger(_folder.GetData(SubFoldersDataTag.ID));
		Assert.assertEquals("Wrong id returned for subfolder " + _nIndex + ".", _nID, id);
		String desc = _folder.GetData(SubFoldersDataTag.DESC);
		Assert.assertEquals("Wrong description returned for subfolder " + _nIndex + ".", _strDesc, desc);

	}
}