package com.bea.alui.taglib.kdpage.test;

import junit.framework.*;

import com.bea.alui.taglib.kdpage.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.mock.directory.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.helpers.*;

/**
 * 
 * @author Ravi Tunuguntla
 *
 */
public class ViewItemsDataTagTest extends TestCase {

	private static String ID_VALUE = "paginationdata";
	
	private int firstIndex = 1;
	private int lastIndex = 10;
	private int displayedCount = 10;
	private int totalCount = 32;
	private int totalPages = 4;


	private AActivitySpace m_environment;
	private MockDirModel m_dirModel;
	
	/**
	 */
	public ViewItemsDataTagTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		int[] cardRange = new int[4];
		cardRange[DirModel.BEGIN_INDEX] = firstIndex;
		cardRange[DirModel.END_INDEX] = lastIndex;
		cardRange[DirModel.CARD_CNT] = displayedCount;
		cardRange[DirModel.TOTAL_CNT_INDEX] = totalCount;
		
   		
   		ConfigService.setTestInstance(new MockConfigHelper());

		m_environment = new MockEnvironment();		

		m_dirModel = new MockDirModel();
   		m_dirModel.SetCardRange(cardRange);
   		m_dirModel.SetNumDocsPerPage(displayedCount);
   		
   		((MockEnvironment) m_environment).m_models.PutElement(DirModel.STR_MVC_CLASS_NAME, m_dirModel);
   		
   		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new ViewItemsDataTag(), ViewItemsDataTag.TAG.GetName(), KDPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		
		m_environment = null;
		m_dirModel = null;
	}
	
	public void testDisplayTag() 
	{
		
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(KDPageTagLibraryData.LIBRARY.GetName(), ViewItemsDataTag.TAG.GetName());
   		helper.AddPTAttribute(ViewItemsDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(ViewItemsDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		helper.AddPTAttribute(ViewItemsDataTag.ATTRIB_PAGES_LIST.GetName(), "plist");
   		helper.AddPTAttribute(ViewItemsDataTag.PAGES_TO_DISPLAY.GetName(), "2");
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
		// for some reason the names are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);
		IDataObject doViewItems = (IDataObject) ssVariable.GetValue();
		
		String value = doViewItems.GetData(PaginationDataConstants.TOTAL_RESULTS);
		Assert.assertEquals("Wrong totalcount returned for pagination component.", totalCount, XPConvert.ToInteger(value));
		
		value = doViewItems.GetData(PaginationDataConstants.NUM_PER_PAGE);
		Assert.assertEquals("Wrong Displayed per page returned for pagination component.", displayedCount, XPConvert.ToInteger(value));

		value = doViewItems.GetData(PaginationDataConstants.START_COUNT);
		Assert.assertEquals("Wrong firstIndex returned for pagination component.", firstIndex, XPConvert.ToInteger(value));
		
		value = doViewItems.GetData(PaginationDataConstants.END_COUNT);
		Assert.assertEquals("Wrong lastIndex returned for pagination component.", lastIndex, XPConvert.ToInteger(value));
		
		value = doViewItems.GetData(PaginationDataConstants.PREVIOUS_URL);
		Assert.assertEquals("Wrong previousurl returned for pagination component.", null, value);
		
		value = doViewItems.GetData(PaginationDataConstants.NEXT_URL);
		Assert.assertTrue("Wrong nexturl starting range returned for pagination component.",XPStringUtility.IndexOf(value, "rangeFrom="+ (firstIndex + displayedCount)) > 0);
		Assert.assertTrue("Wrong nexturl starting range returned for pagination component.",XPStringUtility.IndexOf(value, "rangeTo="+ (firstIndex + displayedCount*2 -1)) > 0);

		value = doViewItems.GetData(PaginationDataConstants.LAST_PAGE);
		Assert.assertEquals("Wrong totalPages returned for pagination component.", totalPages, XPConvert.ToInteger(value));

		value = doViewItems.GetData(PaginationDataConstants.FIRST_PAGE_URL);
		Assert.assertEquals("Wrong firstpageurl returned for pagination component.", null, value);
		
		value = doViewItems.GetData(PaginationDataConstants.LAST_PAGE_URL);
		Assert.assertTrue("Wrong nexturl starting range returned for pagination component.",XPStringUtility.IndexOf(value, "rangeFrom=31") > 0);
		Assert.assertTrue("Wrong nexturl starting range returned for pagination component.",XPStringUtility.IndexOf(value, "rangeTo=32") > 0);


		// Testing variables shared between the main data object and the pages objects
		
		ssVariable = (SharedStateVariable) scopeData.GetElement(".plist");
		XPArrayList pagesList = (XPArrayList) ssVariable.GetValue();

		// This should be 3 and not 5 since the starting page is 1 and # of pages is 2.
		Assert.assertEquals("Wrong number of pages returned for pagination pageslist component.", 3, pagesList.GetSize());

		for (int i = 0; i < pagesList.GetSize(); i++)
		{
			HashtableDataObject htObj = (HashtableDataObject)pagesList.GetElement(i);
			value = htObj.GetData(PaginationDataConstants.PAGE_NUMBER);
			
			Assert.assertEquals("Wrong page number returned for pagination pageslist component.", i+1 , XPConvert.ToInteger(value));
			
			value = htObj.GetData(PaginationDataConstants.PAGINATION_URL);
			if(i ==0)
			{
				Assert.assertEquals("Wrong url value returned for pagination pageslist component.", null , value);
			}
			else
			{
				Assert.assertTrue("Wrong nexturl starting range returned for pagination component.",XPStringUtility.IndexOf(value, "rangeFrom=" + (i*displayedCount + 1)) > 0);
				
				int rangeEnd = (i+1)*(displayedCount);
				if( rangeEnd > totalCount)
				{
					rangeEnd = totalCount;
				}
				Assert.assertTrue("Wrong nexturl starting range returned for pagination component.",XPStringUtility.IndexOf(value, "rangeTo=" + rangeEnd) > 0);
			}
			
		}
		
		



		
	}
}
