using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage
{
  /// <author>rozhang</author>
  public class LayoutMetaDataTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     typeof(LayoutMetaDataTag));
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_COLUMNS;
    static LayoutMetaDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("layoutmeta", "Sets the number of portlet regions/columns used by the current Adaptive Layout for use by Portlet layout editor in the Page Editor. " + "Add this tag to each Adaptive Layout file and specify the number of columns used by the layout. " + "The Portlet layout editor in Edit Page editor will display the specified number of portlet columns after reloading a WCI page using the updated Adaptive Layout",
       ATag.EncodeForTagDoc("<pt:portletpage.layoutmeta pt:columns=\"2\"/>"));
      ATTRIB_COLUMNS = new RequiredTagAttribute("columns", "Number of portlet regions/columns in this Adaptive Layout. Valid values are 1, 2 or 3.",
       AttributeType.INT);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      int currLayoutId = GetCurrentLayoutId();
      int colValue = GetTagAttributeAsInt(ATTRIB_COLUMNS);
      if (colValue < 1 || colValue > 3)
      {
        // throw error
        String error = "Invalid number of portlet columns: " + colValue + " specified for Adaptive layout with id: " + currLayoutId + ". Valid values are: 1,2 or 3.";
        log.Warn(error);
        return new HTMLGenericElement("<!-- pt:portletpage.layoutmeta Adaptive Tag Error: " + error + " -->");
        }
      LayoutColumnStore store = new LayoutColumnStore();
      bool result = store.SetLayoutColumnCount(currLayoutId, colValue);
      if (result)
      {
        if (log.IsInfoEnabled())
        {
          log.Info("Updated portlet column count for Adaptive Layout id: " + currLayoutId + " to " + colValue + " columns.");
          }
      } else
      {
        if (log.IsDebugEnabled())
        {
          log.Debug("Tag layoutmeta: Correct number of portlet columns (" + colValue + ") already stored for Adaptive layout with id: " + currLayoutId);
          }
      }
      return null;
    }
    protected virtual int GetCurrentLayoutId()
    {
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      MyPortalModel model = null;
      int layoutID = -1;
      try
      {
        if (space.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
        {
          model = (MyPortalModel) space.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
          layoutID = model.GetPageType();
        }
      }
      catch (Exception e)
      {
      }
      // DCA - we're not on a my page or community page
      // set layout id as -1 (default)
      if (layoutID == -1)
      {
        log.Info("Tag currpagelayoutid is not used on a Mypage or Community Page. No page layout id is available, -1 is used");
        }
      return layoutID;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      // Disable drag and drop portlet layout editor used for IE browsers. Only the alternate editor works with 
      // configurable number of columns for Adaptive layout portlets. This is set by this tag so that customers
      // who wishes to keep the drag and drop portlet layout editor can choose not to install the tag library version
      // with this tag
      LayoutColumnStore store = new LayoutColumnStore();
      store.SetDisableDragDropLayoutEditor();
      log.Info("Disabling Drag and Drop Portlet Layout editor for Internet Explorer browsers. Use 1.0 version of portletpage Tag library to keep the drag and drop layout editor. ");
      return new LayoutMetaDataTag();
    }
  }
}