using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage
{
  /// <author>btse</author>
  public class PageNameBreadCrumbsDataTag : ATag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.bea.alui.taglib.portletpage.PageNameBreadCrumbsDataTag");
    private const String TAG_NAME = "pagenamebreadcrumbsdata";
    protected const String PORTLET_PAGE_ONLY_CONSTANT = "This tag only works with the Portlet Page Adaptive Layout. ";
    public const String EMPTY_STRING = "EMPTY_STRING";
    public const String NAME = "name";
    public const String URL = "url";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_MAXDEPTH;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    static PageNameBreadCrumbsDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, PORTLET_PAGE_ONLY_CONSTANT + "Stores the breadcrumb path to the current page in memory. " + "Each breadcrumb data object will have the following variables: <code>" + NAME + "</code> for the breadcrumbs\' MyPage or Community name, " + " and <code>" + URL + "</code> for the URL to access the parent breadcrumb. The current page will not contain the URL, instead it will have the constant \'" + EMPTY_STRING + "\'.");
      ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC, AttributeType.STRING);
      ATTRIB_MAXDEPTH = new OptionalTagAttribute("maxdepth", "This is used to specify the number of levels that the breadcrumbs should track from the current location.  " + "Default value is -1 which means the breadcrumbs path will display up to the root parent (super parent). " + "The value of this attribute should be at least 1 if specifying a limit for the breadcrumbs or else -1 if " + "displaying the entire breadcrumb path. The value of this attribute is ignored when the layout is used in MyPages. " + "Use this tag together with the logic.foreach tag to iterate over all the breadcrumbs in a collection and display them all.",
       AttributeType.INT, "-1");
      ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
    }
    /*
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      IXPList portletLayoutBreadCrumbsList = new XPArrayList();
      // Track how many levels we should generate bread crumbs for.
      int nMaxDepth = GetTagAttributeAsInt(ATTRIB_MAXDEPTH);
      if (0 == nMaxDepth || -1 > nMaxDepth)
      {
        throw new XPIllegalArgumentException("Invalid max depth specified for displaying bread crumbs: " + nMaxDepth + ". Either specify -1 or a value of 1 or more.");
        }
      // Check to see if current page is a MyPage or Community Page
      if (TaskAPIUICommunity.IsCurrentPageCommunityPage(space))
      {
        int nCommunityDepth = 0;
        // Get the page name for the bread crumb. No URL is needed since we don't need 
        // to link to the current page.
        String strCommPageName = TaskAPIUICommunity.GetCurrentCommunityPageName(space);
        // Get the current community ID and community name that the page belongs to and
        // create the URL for the bread crumb.
        int nCurrCommunityID = TaskAPIUICommunity.GetCurrentCommunityID(space);
        String strCurrCommunityName = TaskAPIUICommunity.GetCurrentCommunityName(space);
        IPTURL currCommURL = TaskAPIUICommunity.CreateCommunityCommonOpenerURL(space,
         nCurrCommunityID, strCurrCommunityName);
        log.Debug("Tag pagenamebreadcrumbsdata, Community Page ID: " + TaskAPIUICommunity.GetCurrentCommunityPageID(space) + ", Page Name: " + strCommPageName);
        log.Debug("pagenamebreadcrumbsdata, Community Name: " + strCurrCommunityName + ", Community URL: " + currCommURL.GetFullURL());
        // Create a bread crumb data object for the page and the community.
        HashtableDataObject htBreadcrumbObject = CreateBreadcrumbDataObject(strCurrCommunityName,
         currCommURL.GetFullURL());
        portletLayoutBreadCrumbsList.Add(htBreadcrumbObject);
        htBreadcrumbObject = CreateBreadcrumbDataObject(strCommPageName, EMPTY_STRING);
        portletLayoutBreadCrumbsList.Add(htBreadcrumbObject);
        nCommunityDepth++;
        int nParentCommunityID = TaskAPIUICommunity.GetParentCommunityID(space,
         nCurrCommunityID);
        while (0 < nParentCommunityID)
        {
          // Keep adding parent community bread crumbs if unlimited maxdepth is specified (-1)
          // or we've reached the specified maxdepth.
          if (-1 == nMaxDepth || (nCommunityDepth < nMaxDepth))
          {
            String strParentCommunityName = TaskAPIUICommunity.GetCommunityName(space,
             nParentCommunityID);
            IPTURL parentURL = TaskAPIUICommunity.CreateCommunityCommonOpenerURL(space,
             nParentCommunityID, strParentCommunityName);
            log.Debug("Parent Community Name: " + strParentCommunityName + ", Parent Community URL: " + parentURL.GetFullURL());
            htBreadcrumbObject = CreateBreadcrumbDataObject(strParentCommunityName,
             parentURL.GetFullURL());
            portletLayoutBreadCrumbsList.Insert(0, htBreadcrumbObject);
            nCommunityDepth++;
          } else
          {
            htBreadcrumbObject = CreateBreadcrumbDataObject("...", EMPTY_STRING);
            portletLayoutBreadCrumbsList.Insert(0, htBreadcrumbObject);
            break;
          }
          nParentCommunityID = TaskAPIUICommunity.GetParentCommunityID(space,
           nParentCommunityID);
        }
      } else
      {
        String strMyPageName = TaskAPIUIMyPages.GetCurrentMyPageName(space);
        IPTURL homePageURL = TaskAPIUIUser.GetURLForMyHome(TaskAPIUICommon.GetEnvTypeObject(space));
        HashtableDataObject htBreadcrumbObject = null;
        if (null != homePageURL)
        {
          log.Debug("Tag pagenamebreadcrumbsdata, My Page Home URL: " + homePageURL.GetFullURL() + ", Page Name: " + strMyPageName);
          htBreadcrumbObject = CreateBreadcrumbDataObject("Home", homePageURL.GetFullURL());
          } else
        {
          htBreadcrumbObject = CreateBreadcrumbDataObject("Home", EMPTY_STRING);
          }
        portletLayoutBreadCrumbsList.Add(htBreadcrumbObject);
        htBreadcrumbObject = CreateBreadcrumbDataObject(strMyPageName, EMPTY_STRING);
        portletLayoutBreadCrumbsList.Add(htBreadcrumbObject);
      }
      // BT - add list to memory
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, portletLayoutBreadCrumbsList,
       tagScope, true);
      return ProcessTagBody();
    }
    private HashtableDataObject CreateBreadcrumbDataObject(String strName,
     String url)
    {
      // BT - populate data object
      HashtableDataObject htObject = new HashtableDataObject();
      htObject.SetData(NAME, strName);
      htObject.SetData(URL, url);
      return htObject;
    }
    /*
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
     
    public override ATag Create()
    {
      return new PageNameBreadCrumbsDataTag();
    }
  }
}