using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage
{
  /// <author>Bobby Tse</author>
  public class PortletHelpButtonDisplayTag : APortletBaseDisplayTag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.bea.alui.taglib.portletpage.PortletHelpButtonDisplayTag");
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute DATA_VAR;
    public static readonly OptionalTagAttribute COLINDEX;
    public static readonly OptionalTagAttribute SCOPE;
    public static readonly String DISPLAYTAG_EXAMPLE = ATag.EncodeForTagDoc("<pt:logic.foreach pt:data=\"var1\" pt:var=\"curr\"><br/>" + "<pt:portletpage.portlethelpbuttondisplay pt:datavar=\"curr\"/><br/>" + "</pt:logic.foreach><br/>");
    public static readonly String DISPLAYTAG_COLLECTION_EXAMPLE = ATag.EncodeForTagDoc("Displays the first entry in the collection<br/>" + "<pt:portletpage.portlethelpbuttondisplay pt:datavar=\"var1\" colindex=\"0\" /><br/>");
    static PortletHelpButtonDisplayTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("portlethelpbuttondisplay", "Displays the help button of a portlet from a data object, specified by the pt:datavar attribute. ",
       PortletRegionDataTag.DATATAG_EXAMPLE + DISPLAYTAG_EXAMPLE + DISPLAYTAG_COLLECTION_EXAMPLE);
      DATA_VAR = new RequiredTagAttribute("datavar", "The key to the tag memory variable with portlet data to display. The data is set by portletpage.portletregiondata and other similar data tags. " + "This tag is also able to display a single portlet in a collection of portlet data. " + "Use the pt:colindex attribute to specify the index in the collection.");
      COLINDEX = new OptionalTagAttribute("colindex", "Used to get portlet data from a specific index in a collection if the pt:datavar attribute references a " + "portlet data collection instead of a single portlet. The default value is 0 (the first entry in the collection). " + "The value of this attribute is ignored if pt:datavar refers to a single portlet data IDataObject. " + "Use this tag together with the logic.foreach tag to iterate over all portlets in a collection and display them all.",
       AttributeType.INT, "0");
      SCOPE = new OptionalTagAttribute("scope", "The scope used to store the data collection. See the Logic tag library for further information on scope.",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    /*
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      // Get the view and portlet index to retrieve the portlet content.
      MyPortalContentView view = GetMyPortalContentView();
      int portletIndex = GetPortletIndex(DATA_VAR, SCOPE, COLINDEX);
      // Get the help button content of the portlet		
      HTMLElement result = new HTMLElementCollection();
      // TODO: CR ROB: An empty collection is return if there is an exception in the view method. Maybe it should return an exception instead so 
      // that you can print out an informative error message instead of just returning empty content or if you can check that there
      // was an error somehow and handle it
      if (-1 != portletIndex)
      {
        log.Debug("Tag portlethelpbuttondisplay displaying portlet help button with index {0} from datavar {0}, scope {1}, colindex {2}.",
         portletIndex, GetTagAttributeAsString(DATA_VAR), GetTagAttributeAsString(SCOPE),
         GetTagAttributeAsInt(COLINDEX));
        result.AddInnerHTMLElement(view.GetPortletHelpButtonContent(portletIndex));
        } else
      {
        log.Info("Tag portlethelpbuttondisplay not able to lookup portlet index from datavar {0}, scope {1}, colindex {2}",
         GetTagAttributeAsString(DATA_VAR), GetTagAttributeAsString(SCOPE),
         GetTagAttributeAsInt(COLINDEX));
      }
      return result;
    }
    /*
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
     
    public override ATag Create()
    {
      return new PortletHelpButtonDisplayTag();
    }
  }
}