using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage
{
  /// <author>DustinA</author>
  public class PortletPreferenceActionsDataTag : APortletBaseDisplayTag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.bea.alui.taglib.portletpage.PortletPreferenceActionsDataTag");
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute DATA_VAR;
    public static readonly OptionalTagAttribute COLINDEX;
    public static readonly OptionalTagAttribute SCOPE;
    public static readonly OptionalTagAttribute STORE_SCOPE;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly String COMMON_POSTTAGMETADATA_DESC = "<![CDATA[<p>]]>" + "This URL contains the following standard URL components: " + "<![CDATA[<code>]]>" + PTURLConstants.KEY_TITLE + ", " + PTURLConstants.KEY_FULLURL + ", " + PTURLConstants.KEY_URI + ", " + PTURLConstants.KEY_ICONIMG + ", " + PTURLConstants.KEY_ICONIMGHEIGHT + ", " + PTURLConstants.KEY_ICONIMGWIDTH + " and " + PTURLConstants.KEY_PARAMS + "<![CDATA[</code>]]>. <![CDATA[<br>]]>" + "In addition, the name of each parameter in the query string of the URL in the link is also " + "a valid component key. So param1 could be used as a key to retrieve the value of the query string parameter " + "<![CDATA[<code>]]>param1=value1<![CDATA[</code>]]>. For instance, if the url is " + "<![CDATA[http://...server.pt?open=518&objID=58411...]]> you can get the objid data as a name/value pair stored under objid (all lower case).<![CDATA[<br>]]>";
    static PortletPreferenceActionsDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      DATA_VAR = new RequiredTagAttribute("datavar", "The key to the tag memory variable with portlet data to display. The data is set by portletpage.portletregiondata and other similar data tags. " + "This tag is also able to display a single portlet in a collection of portlet data. " + "Use the pt:colindex attribute to specify the index in the collection.");
      TAG = new TagMetaData("portletpreferencesdata", "Sets PTURL DO data on the scope specified with List of URLs to portlet preferences of portlet specified by " + DATA_VAR.GetName() + "." + COMMON_POSTTAGMETADATA_DESC);
      COLINDEX = new OptionalTagAttribute("colindex", "Used to get portlet data from a specific index in a collection if the pt:datavar attribute references a " + "portlet data collection instead of a single portlet. The default value is 0 (the first entry in the collection). " + "The value of this attribute is ignored if pt:datavar refers to a single portlet data IDataObject. " + "Use this tag together with the logic.foreach tag to iterate over all portlets in a collection and display them all.",
       AttributeType.INT, "0");
      SCOPE = new OptionalTagAttribute("scope", "The scope used to retrieve the datavar collection. See the Logic tag library for further information on scope.",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
      ATTRIB_ID = new RequiredTagAttribute("id", "Name of the variable in memory where the PTURL DO data created by this tag is stored. " + "Specify this ID in the data attribute (most commonly the DATAVAR attribute) for any display tag consuming PTURL DO data. " + "Multiple data tags can share the same ID, in which case they are added to a list in the order they were processed. ",
       AttributeType.STRING);
      STORE_SCOPE = new OptionalTagAttribute("storescope", "The scope used to store the data collection. See the Logic tag library for further information on scope.",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
    }
    /*
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
     */
     
    public override HTMLElement DisplayTag()
    {
      // Get the view and portlet index to retrieve the portlet content.
      IMyPortalModelRO model = GetMyPortalModel();
      int portletIndex = GetPortletIndex(DATA_VAR, SCOPE, COLINDEX);
      // Get the preference button content of the portlet
      if (-1 != portletIndex)
      {
        log.Debug("Tag portletpreferencesdata returning pref URLs with index {0} from datavar {0}, scope {1}, colindex {2}.",
         portletIndex, GetTagAttributeAsString(DATA_VAR), GetTagAttributeAsString(SCOPE),
         GetTagAttributeAsInt(COLINDEX));
        IXPList arPrefURLs = model.GetPortletPreferenceActionsData(portletIndex);
        // DCA - reverse list for the tool bar
        IXPList arPrefsURLsReverse = new XPArrayList();
        for (int i = arPrefURLs.GetSize() - 1;i >= 0;i--)
        {
          arPrefsURLsReverse.Add(arPrefURLs.GetElement(i));
        }
        Scope varScope = Scope.GetScope(GetTagAttributeAsString(STORE_SCOPE));
        String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
        GetState().SetSharedVariable(strDataReference, arPrefsURLsReverse,
         varScope, true);
      } else
      {
        log.Info("Tag portletpreferencesdata not able to lookup portlet index from datavar {0}, scope {1}, colindex {2}",
         GetTagAttributeAsString(DATA_VAR), GetTagAttributeAsString(SCOPE),
         GetTagAttributeAsInt(COLINDEX));
      }
      return null;
    }
    /*
     * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
     */
     
    public override ATag Create()
    {
      return new PortletPreferenceActionsDataTag();
    }
  }
}