using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage
{
  /// <TODO>: Implement horizontal direction once we have the html mockups</TODO>
  /// <author>rozhang</author>
  public class PortletRegionDisplayTag : ATag
  {
    
    /// <summary>
    /// HTML comment at the beginning of each portlet region *
    /// </summary>
    public const String REGION_BEGINCOMMENT = "Begin Portlet Region ";
    
    /// <summary>
    /// HTML comment at the end of each portlet region *
    /// </summary>
    public const String REGION_ENDCOMMENT = "End Portlet Region ";
    public static readonly String BEGINTAG_EXAMPLE = ATag.EncodeForTagDoc("<pt:portletpage.portletregiondisplay pt:region=\"1\"><br/>");
    public static readonly String ENDTAG_EXAMPLE = ATag.EncodeForTagDoc("</pt:portletpage.portletregiondisplay><br/>");
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute REGIONINDEX;
    public static readonly OptionalTagAttribute WIDTH;
    public static readonly OptionalTagAttribute HEIGHT;
    static PortletRegionDisplayTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("portletregiondisplay", "Generates the HTML for a portlet region, a container for portlets that specifies where and how portlets inside the region are displayed. " + "All portlets on a page must be put in a region tag.",
       PortletRegionDataTag.DATATAG_EXAMPLE + BEGINTAG_EXAMPLE + PortletDisplayTag.DISPLAYTAG_EXAMPLE + ENDTAG_EXAMPLE);
      REGIONINDEX = new RequiredTagAttribute("region", "The ID of the portlet region to use with this data tag. Valid region values are 1, 2 or 3.",
       AttributeType.INT);
      HEIGHT = new OptionalTagAttribute("height", "Height of a region (only used in horizontal mode). " + "The value is set on the div\'s CSS style sheet so any valid CSS height values are accepted. The default value is 100%.",
       AttributeType.STRING, "100%");
      WIDTH = new OptionalTagAttribute("width", "Width of the region (only used in vertical mode). " + "The value is set on the div\'s CSS style sheet so any valid CSS height values are accepted. The default value is 100%.",
       AttributeType.STRING, "100%");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      int regionIndex = GetTagAttributeAsInt(REGIONINDEX);
      HTMLElementCollection result = new HTMLElementCollection();
      // get all the non pt: attributes, they are getting passed through
      String strXMLAttributes = GetXMLTagAttributesAsString();
      String strOpenTag;
      if ((strXMLAttributes != null) && (strXMLAttributes.Length == 0))
      {
        strXMLAttributes = "";
      }
      strOpenTag = "<div id=\"" + "region" + regionIndex + "\" " + strXMLAttributes + ">";
      // placeholder padding element, this gets replaced with a table in edit mode
      // don't remove!
      String strRegionPadding = "<span width=\"0\"></span>\n";
      String strCloseTag = "</div>";
      result.AddInnerHTMLString(strOpenTag);
      result.AddInnerHTMLString(strRegionPadding);
      result.AddInnerHTMLElement(GeneratePortletRegionHeader(regionIndex));
      result.AddInnerHTMLElement(ProcessTagBody());
      result.AddInnerHTMLElement(GeneratePortletRegionFooter(regionIndex));
      result.AddInnerHTMLString(strCloseTag);
      return result;
    }
    
    /// <summary>
    /// Generate the region header HTML 
    /// </summary>
    /// <param name="regionIndex"></param>
    /// <returns></returns>
    protected virtual HTMLElement GeneratePortletRegionHeader(int regionIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLComment comment = new HTMLComment(REGION_BEGINCOMMENT + regionIndex);
      result.AddInnerHTMLElement(comment);
      return result;
    }
    
    /// <summary>
    /// Generate the region footer HTML
    /// </summary>
    /// <param name="regionIndex"></param>
    /// <returns></returns>
    protected virtual HTMLElementCollection GeneratePortletRegionFooter(int regionIndex)
    {
      HTMLElementCollection ret = new HTMLElementCollection();
      HTMLComment comment = new HTMLComment(REGION_ENDCOMMENT + regionIndex);
      ret.AddInnerHTMLElement(comment);
      return ret;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new PortletRegionDisplayTag();
    }
  }
}