using System;
using junit.framework;
using com.bea.alui.taglib.portletpage;
using com.bea.alui.taglib.portletpage.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage.test
{
  /// <summary>
  /// Tests the content display tag by loading up portlets with the region data tag and generating
  /// HTML for those portlets.
  /// Verify HTML by checking that portlet elements are in the generated
  /// HTML
  /// </summary>
  /// <author>btse</author>
  public class TestPortletContentDisplayTag : TestCase
  {
    public TestPageContentAS m_environment;
    public MockLayoutManager m_layoutManager;
    public MockPTSession m_session;
    public MockConfigHelper m_configHelper;
    public MockPTConfigHelper m_helper;
    public TestMyPortalModel m_model;
    public override void setUp()
    {
      m_configHelper = new MockConfigHelper();
      ConfigService.setTestInstance(m_configHelper);
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      // Enable layouts globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      // an as with mock pagecontentmodel
      m_environment = new TestPageContentAS();
      m_model = (TestMyPortalModel) m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      m_layoutManager = new MockLayoutManager();
      LayoutService.setManagerTestInstance(m_layoutManager);
      // tags in the pagecontent library
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletContentDisplayTag(), PortletContentDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// Add portlets to all 3 regions
    /// Get portlets from region 1 and verify that they are displayed in the generated HTML
    /// </summary>
    public virtual void testPortletContentDisplayTag()
    {
      String tagvarname1 = "testvar1";
      // in region 1
      String name1 = "Portlet-Apple";
      String name2 = "Portlet-Orange";
      String name3 = "Portlet-Kiwi";
      // in region 2
      String name4 = "Portlet-Melon";
      // in region 3
      String name5 = "Portlet-Pomegranate";
      String name6 = "Portlet-Grape";
      int region1 = 1;
      int region2 = 2;
      int region3 = 3;
      // initialize mock model
      int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1",
       "adminPrefUrl1", "commPrefUrl1", "userPrefUrl1", "helpUrl1", "collapseExpandUrl1",
       "removeUrl1", true);
      int id2 = m_model.addPortletInColumn(name2, null, region1, "pt-portletid-2",
       "adminPrefUrl2", "commPrefUrl2", "userPrefUrl2", "helpUrl2", "collapseExpandUrl2",
       "removeUrl2", false);
      int id3 = m_model.addPortletInColumn(name3, null, region1, "pt-portletid-3",
       "adminPrefUrl3", "commPrefUrl3", "userPrefUrl3", "helpUrl3", "collapseExpandUrl3",
       "removeUrl3", true);
      int id4 = m_model.addPortletInColumn(name4, null, region2, "pt-portletid-4",
       "adminPrefUrl4", "commPrefUrl4", "userPrefUrl4", "helpUrl4", "collapseExpandUrl4",
       "removeUrl4", false);
      int id5 = m_model.addPortletInColumn(name5, null, region3, "pt-portletid-5",
       "adminPrefUrl5", "commPrefUrl5", "userPrefUrl5", "helpUrl5", "collapseExpandUrl5",
       "removeUrl5", true);
      int id6 = m_model.addPortletInColumn(name6, null, region3, "pt-portletid-6",
       "adminPrefUrl6", "commPrefUrl6", "userPrefUrl6", "helpUrl6", "collapseExpandUrl6",
       "removeUrl6", false);
      // initialiaze markup
      XMLFragmentTestHelper regionDataTag = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region1 + "");
      regionDataTag.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
      // set it on the http request so that we can easily access it
      // Display without colindex attribute (should default to index 0)
      XMLFragmentTestHelper contentDisplayTag1 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletContentDisplayTag.TAG.GetName());
      contentDisplayTag1.AddPTAttribute(PortletContentDisplayTag.DATA_VAR.GetName(),
       tagvarname1);
      // set it on the http request so that we can easily access it
      // Display with index 1
      XMLFragmentTestHelper contentDisplayTag2 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletContentDisplayTag.TAG.GetName());
      // set it on the http request so that we can easily access it
      contentDisplayTag2.AddPTAttribute(PortletContentDisplayTag.DATA_VAR.GetName(),
       tagvarname1);
      // set it on the http request so that we can easily access it
      contentDisplayTag2.AddPTAttribute(PortletContentDisplayTag.COLINDEX.GetName(),
       "1");
      // Display with index 2
      XMLFragmentTestHelper contentDisplayTag3 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletContentDisplayTag.TAG.GetName());
      // set it on the http request so that we can easily access it
      contentDisplayTag3.AddPTAttribute(PortletContentDisplayTag.DATA_VAR.GetName(),
       tagvarname1);
      // set it on the http request so that we can easily access it
      contentDisplayTag3.AddPTAttribute(PortletContentDisplayTag.COLINDEX.GetName(),
       "2");
      XMLFragmentTestHelper tags = new XMLFragmentTestHelper(new XMLFragmentTestHelper[]{regionDataTag,
       contentDisplayTag1, contentDisplayTag2, contentDisplayTag3});
      // process the markup which will execute the tags
      Object[][] markup = tags.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, markup);
      String strHTML = result.GetDisplayString();
      // validate the output
      // name of the portlet in the header
      if (XPStringUtility.IndexOf(strHTML, "id=\"pt-portlet-content-" + id1 + "\"") == -1)
      {
        XPSystem.Out.WriteLine("Portlet Content 1 not found in the generated HTML! Generated content: ");
        XPSystem.Out.WriteLine(strHTML);
      }
      // make sure the portlet is referencable
      assertTrue("Portlet 2 div found in the generated HTML!", XPStringUtility.IndexOf(strHTML,
       "id=\"pt-portlet-content-" + id2 + "\"") != -1);
      assertTrue("Portlet 3 div found in the generated HTML!", XPStringUtility.IndexOf(strHTML,
       "id=\"pt-portlet-content-" + id3 + "\"") != -1);
    }
  }
}