using System;
using junit.framework;
using com.bea.alui.taglib.portletpage;
using com.bea.alui.taglib.portletpage.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.uiinfrastructure.login;
namespace com.bea.alui.taglib.portletpage.test
{
  /// <summary>
  /// Tests the preference display tag by loading up a portlet with the region data tag and generating
  /// HTML for the portlet.
  /// Verify HTML by checking that portlet elements are in the generated
  /// HTML
  /// </summary>
  /// <author>btse</author>
  public class TestPortletPreferenceActionsDataTag : TestCase
  {
    public TestPageContentAS m_environment;
    public MockLayoutManager m_layoutManager;
    public MockPTSession m_session;
    public MockConfigHelper m_configHelper;
    public MockPTConfigHelper m_helper;
    public TestMyPortalModel m_model;
    public override void setUp()
    {
      LoginHelper.StaticInit(new PTLoginHelper());
      m_configHelper = new MockConfigHelper();
      ConfigService.setTestInstance(m_configHelper);
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      // Enable layouts globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      // an as with mock pagecontentmodel
      m_environment = new TestPageContentAS();
      m_model = (TestMyPortalModel) m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      m_layoutManager = new MockLayoutManager();
      LayoutService.setManagerTestInstance(m_layoutManager);
      // tags in the pagecontent library
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletPreferenceActionsDataTag(), PortletPreferenceActionsDataTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// Add a portlet to region 1
    /// Get portlet from region 1 and verify that the preference html span is displayed in the generated HTML
    /// </summary>
    public virtual void testPortletPreferenceActionsDataTagWith3Prefs()
    {
      String tagvarname1 = "testvar1";
      String tagidname1 = "tagidname1";
      // in region 1
      String name1 = "Portlet-Apple";
      int region1 = 1;
      // initialize mock model
      int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1",
       "adminPrefUrl1", "commPrefUrl1", "userPrefUrl1", "helpUrl1", "collapseExpandUrl1",
       "removeUrl1", true);
      // initialiaze markup
      XMLFragmentTestHelper regionDataTag = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region1 + "");
      regionDataTag.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
      // set it on the http request so that we can easily access it
      // Display without colindex attribute (should default to index 0)
      XMLFragmentTestHelper preferenceActionsDataTag1 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletPreferenceActionsDataTag.TAG.GetName());
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.DATA_VAR.GetName(),
       tagvarname1);
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.ATTRIB_ID.GetName(),
       tagidname1);
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.STORE_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      // set it on the http request so that we can easily access it
      XMLFragmentTestHelper tags = new XMLFragmentTestHelper(new XMLFragmentTestHelper[]{regionDataTag,
       preferenceActionsDataTag1});
      // process the markup which will execute the tags
      Object[][] markup = tags.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, markup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + tagidname1);
      IXPList prefsList = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the preference list in memory is incorrect.",
       3, prefsList.GetSize());
      IPTURL prefURL = (IPTURL) prefsList.GetElement(0);
      Assert.assertEquals("The URL of the admin pref is incorrect.", "adminPrefUrl1",
       prefURL.GetFullURL());
      prefURL = (IPTURL) prefsList.GetElement(1);
      Assert.assertEquals("The URL of the community pref is incorrect.", "commPrefUrl1",
       prefURL.GetFullURL());
      prefURL = (IPTURL) prefsList.GetElement(2);
      Assert.assertEquals("The URL of the personal pref is incorrect.", "userPrefUrl1",
       prefURL.GetFullURL());
    }
    
    /// <summary>
    /// Add a portlet to region 1
    /// Get portlet from region 1 and verify that the preference html span is displayed in the generated HTML
    /// </summary>
    public virtual void testPortletPreferenceActionsDataTagWith2Prefs()
    {
      String tagvarname1 = "testvar1";
      String tagidname1 = "tagidname1";
      // in region 1
      String name1 = "Portlet-Apple";
      int region1 = 1;
      // initialize mock model
      int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1",
       null, "commPrefUrl1", "userPrefUrl1", "helpUrl1", "collapseExpandUrl1",
       "removeUrl1", true);
      // initialiaze markup
      XMLFragmentTestHelper regionDataTag = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region1 + "");
      regionDataTag.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
      // set it on the http request so that we can easily access it
      // Display without colindex attribute (should default to index 0)
      XMLFragmentTestHelper preferenceActionsDataTag1 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletPreferenceActionsDataTag.TAG.GetName());
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.DATA_VAR.GetName(),
       tagvarname1);
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.ATTRIB_ID.GetName(),
       tagidname1);
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.STORE_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      // set it on the http request so that we can easily access it
      XMLFragmentTestHelper tags = new XMLFragmentTestHelper(new XMLFragmentTestHelper[]{regionDataTag,
       preferenceActionsDataTag1});
      // process the markup which will execute the tags
      Object[][] markup = tags.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, markup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + tagidname1);
      IXPList prefsList = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the preference list in memory is incorrect.",
       2, prefsList.GetSize());
      IPTURL prefURL = (IPTURL) prefsList.GetElement(0);
      Assert.assertEquals("The URL of the community pref is incorrect.", "commPrefUrl1",
       prefURL.GetFullURL());
      prefURL = (IPTURL) prefsList.GetElement(1);
      Assert.assertEquals("The URL of the personal pref is incorrect.", "userPrefUrl1",
       prefURL.GetFullURL());
    }
    
    /// <summary>
    /// Add a portlet to region 1
    /// Get portlet from region 1 and verify that the preference html span is displayed in the generated HTML
    /// </summary>
    public virtual void testPortletPreferenceActionsDataTagWith1Prefs()
    {
      String tagvarname1 = "testvar1";
      String tagidname1 = "tagidname1";
      // in region 1
      String name1 = "Portlet-Apple";
      int region1 = 1;
      // initialize mock model
      int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1",
       null, null, "userPrefUrl1", "helpUrl1", "collapseExpandUrl1", "removeUrl1",
       true);
      // initialiaze markup
      XMLFragmentTestHelper regionDataTag = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region1 + "");
      regionDataTag.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
      // set it on the http request so that we can easily access it
      // Display without colindex attribute (should default to index 0)
      XMLFragmentTestHelper preferenceActionsDataTag1 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletPreferenceActionsDataTag.TAG.GetName());
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.DATA_VAR.GetName(),
       tagvarname1);
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.ATTRIB_ID.GetName(),
       tagidname1);
      preferenceActionsDataTag1.AddPTAttribute(PortletPreferenceActionsDataTag.STORE_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      // set it on the http request so that we can easily access it
      XMLFragmentTestHelper tags = new XMLFragmentTestHelper(new XMLFragmentTestHelper[]{regionDataTag,
       preferenceActionsDataTag1});
      // process the markup which will execute the tags
      Object[][] markup = tags.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, markup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + tagidname1);
      IXPList prefsList = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the preference list in memory is incorrect.",
       1, prefsList.GetSize());
      IPTURL prefURL = (IPTURL) prefsList.GetElement(0);
      Assert.assertEquals("The URL of the personal pref is incorrect.", "userPrefUrl1",
       prefURL.GetFullURL());
    }
  }
}