using System;
using junit.framework;
using com.bea.alui.taglib.portletpage;
using com.bea.alui.taglib.portletpage.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage.test
{
  /// <summary>
  /// Tests the refresh display tag by loading up a portlet with the region data tag and generating
  /// HTML for the portlet.
  /// Verify HTML by checking that portlet elements are in the generated
  /// HTML
  /// </summary>
  /// <author>btse</author>
  public class TestPortletRefreshButtonDisplayTag : TestCase
  {
    public TestPageContentAS m_environment;
    public MockLayoutManager m_layoutManager;
    public MockPTSession m_session;
    public MockConfigHelper m_configHelper;
    public MockPTConfigHelper m_helper;
    public TestMyPortalModel m_model;
    public override void setUp()
    {
      m_configHelper = new MockConfigHelper();
      ConfigService.setTestInstance(m_configHelper);
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      // Enable layouts globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      // an as with mock pagecontentmodel
      m_environment = new TestPageContentAS();
      m_model = (TestMyPortalModel) m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      m_layoutManager = new MockLayoutManager();
      LayoutService.setManagerTestInstance(m_layoutManager);
      // tags in the pagecontent library
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletRefreshButtonDisplayTag(), PortletRefreshButtonDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// Add a portlet to region 1
    /// Get portlet from region 1 and verify that the refresh html span is displayed in the generated HTML
    /// </summary>
    public virtual void testPortletRefreshButtonDisplayTag()
    {
      String tagvarname1 = "testvar1";
      // in region 1
      String name1 = "Portlet-Apple";
      int region1 = 1;
      // initialize mock model
      int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1",
       "adminPrefUrl1", "commPrefUrl1", "userPrefUrl1", "helpUrl1", "collapseExpandUrl1",
       "removeUrl1", true);
      // initialiaze markup
      XMLFragmentTestHelper regionDataTag = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region1 + "");
      regionDataTag.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
      // set it on the http request so that we can easily access it
      // Display without colindex attribute (should default to index 0)
      XMLFragmentTestHelper refreshButtonDisplayTag1 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRefreshButtonDisplayTag.TAG.GetName());
      refreshButtonDisplayTag1.AddPTAttribute(PortletRefreshButtonDisplayTag.DATA_VAR.GetName(),
       tagvarname1);
      // set it on the http request so that we can easily access it
      XMLFragmentTestHelper tags = new XMLFragmentTestHelper(new XMLFragmentTestHelper[]{regionDataTag,
       refreshButtonDisplayTag1});
      // process the markup which will execute the tags
      Object[][] markup = tags.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, markup);
      String strHTML = result.GetDisplayString();
      // validate the output
      // name of the portlet in the header
      if (XPStringUtility.IndexOf(strHTML, "<span class=\"portletRefreshButton\">") == -1)
      {
        XPSystem.Out.WriteLine("Help Button not found in the generated HTML! Generated content: ");
        XPSystem.Out.WriteLine(strHTML);
      }
    }
  }
}