using System;
using junit.framework;
using com.bea.alui.taglib.portletpage.test.integration;
using com.bea.alui.taglib.portletpage;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpage.test
{
  /// <summary>
  /// Tests getting portlets from all three regions with three tags
  /// </summary>
  /// <author>rozhang</author>
  public class TestPortletRegionDataTag : TestCase
  {
    public TestPageContentAS m_environment;
    public MockLayoutManager m_layoutManager;
    public MockPTSession m_session;
    public MockConfigHelper m_configHelper;
    public MockPTConfigHelper m_helper;
    public TestMyPortalModel m_model;
    public override void setUp()
    {
      m_configHelper = new MockConfigHelper();
      ConfigService.setTestInstance(m_configHelper);
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      // Enable layouts globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      // an as with mock pagecontentmodel
      m_environment = new TestPageContentAS();
      m_model = (TestMyPortalModel) m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      m_layoutManager = new MockLayoutManager();
      LayoutService.setManagerTestInstance(m_layoutManager);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletDisplayTag(), PortletDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    // TODO CR DLH: Description of this test.
    public virtual void testRegionData()
    {
      String tagvarname1 = "testvar1";
      String tagvarname2 = "testvar2";
      String tagvarname3 = "testvar3";
      String name1 = "Test Portlet 1";
      String name2 = "Test Portlet 2";
      String name3 = "Test Portlet 3";
      String name4 = "Test Portlet 4";
      String name5 = "Test Portlet 5";
      String name6 = "Test Portlet 6";
      int region1 = 1;
      int region2 = 2;
      int region3 = 3;
      // initialize mock model
      int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1",
       "adminPrefUrl1", "commPrefUrl1", "userPrefUrl1", "helpUrl1", "collapseExpandUrl1",
       "removeUrl1", true);
      int id2 = m_model.addPortletInColumn(name2, null, region1, "pt-portletid-2",
       "adminPrefUrl2", "commPrefUrl2", "userPrefUrl2", "helpUrl2", "collapseExpandUrl2",
       "removeUrl2", false);
      int id3 = m_model.addPortletInColumn(name3, null, region1, "pt-portletid-3",
       "adminPrefUrl3", "commPrefUrl3", "userPrefUrl3", "helpUrl3", "collapseExpandUrl3",
       "removeUrl3", true);
      int id4 = m_model.addPortletInColumn(name4, null, region2, "pt-portletid-4",
       "adminPrefUrl4", "commPrefUrl4", "userPrefUrl4", "helpUrl4", "collapseExpandUrl4",
       "removeUrl4", false);
      int id5 = m_model.addPortletInColumn(name5, null, region3, "pt-portletid-5",
       "adminPrefUrl5", "commPrefUrl5", "userPrefUrl5", "helpUrl5", "collapseExpandUrl5",
       "removeUrl5", true);
      int id6 = m_model.addPortletInColumn(name6, null, region3, "pt-portletid-6",
       "adminPrefUrl6", "commPrefUrl6", "userPrefUrl6", "helpUrl6", "collapseExpandUrl6",
       "removeUrl6", false);
      // initialize markup
      XMLFragmentTestHelper regionDataTag1 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag1.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region1 + "");
      regionDataTag1.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
      // set it on the http request so that we can easily access it
      regionDataTag1.AddPTAttribute(PortletRegionDataTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      XMLFragmentTestHelper regionDataTag2 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag2.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region2 + "");
      regionDataTag2.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname2);
      // set it on the http request so that we can easily access it
      regionDataTag2.AddPTAttribute(PortletRegionDataTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      XMLFragmentTestHelper regionDataTag3 = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDataTag.TAG.GetName());
      regionDataTag3.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(),
       region3 + "");
      regionDataTag3.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname3);
      // set it on the http request so that we can easily access it
      regionDataTag3.AddPTAttribute(PortletRegionDataTag.SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      XMLFragmentTestHelper regionDataTags = new XMLFragmentTestHelper(new XMLFragmentTestHelper[]{regionDataTag1,
       regionDataTag2, regionDataTag3});
      Object[][] markup = regionDataTags.ToArrayEntireFragment();
      HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // TODO CR DLH: This is because they're public tag variables, and that's the format.
      // private ones are library.
      // for some reason the names are prefixed with a '.'
      Object o1 = scopeData.GetElement("." + tagvarname1);
      Object o2 = scopeData.GetElement("." + tagvarname2);
      Object o3 = scopeData.GetElement("." + tagvarname3);
      if (o1 == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + tagvarname1 + " set in tag memory");
        }
      if (o2 == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + tagvarname2 + " set in tag memory");
        }
      if (o3 == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + tagvarname3 + " set in tag memory");
        }
      try
      {
        XPArrayList portlets1 = (XPArrayList) ((SharedStateVariable) o1).GetValue();
        XPArrayList portlets2 = (XPArrayList) ((SharedStateVariable) o2).GetValue();
        XPArrayList portlets3 = (XPArrayList) ((SharedStateVariable) o3).GetValue();
        Assert.assertEquals(3, portlets1.GetSize());
        // return values are string so make sure to compare with strings
        testPortletData(id1, name1, 0, (IDataObject) portlets1.GetElement(0),
         "pt-portletid-1", "adminPrefUrl1", "commPrefUrl1", "userPrefUrl1",
         "helpUrl1", "collapseExpandUrl1", true);
        testPortletData(id2, name2, 1, (IDataObject) portlets1.GetElement(1),
         "pt-portletid-2", "adminPrefUrl2", "commPrefUrl2", "userPrefUrl2",
         "helpUrl2", "collapseExpandUrl2", false);
        testPortletData(id3, name3, 2, (IDataObject) portlets1.GetElement(2),
         "pt-portletid-3", "adminPrefUrl3", "commPrefUrl3", "userPrefUrl3",
         "helpUrl3", "collapseExpandUrl3", true);
        Assert.assertEquals(1, portlets2.GetSize());
        // return values are string so make sure to compare with strings
        testPortletData(id4, name4, 3, (IDataObject) portlets2.GetElement(0),
         "pt-portletid-4", "adminPrefUrl4", "commPrefUrl4", "userPrefUrl4",
         "helpUrl4", "collapseExpandUrl4", false);
        Assert.assertEquals(2, portlets3.GetSize());
        // return values are string so make sure to compare with strings
        testPortletData(id5, name5, 4, (IDataObject) portlets3.GetElement(0),
         "pt-portletid-5", "adminPrefUrl5", "commPrefUrl5", "userPrefUrl5",
         "helpUrl5", "collapseExpandUrl5", true);
        testPortletData(id6, name6, 5, (IDataObject) portlets3.GetElement(1),
         "pt-portletid-6", "adminPrefUrl6", "commPrefUrl6", "userPrefUrl6",
         "helpUrl6", "collapseExpandUrl6", false);
      }
      catch (XPException e)
      {
        fail("Found expected tag variable but it was not of the expected type. See stacktrace below for exact issue.");
        e.PrintStackTrace();
      }
    }
    
    /// <summary>
    /// Helper method to check the content in a portlet data tag variable
    /// </summary>
    /// <param name="id"></param>
    /// <param name="name"></param>
    /// <param name="index"></param>
    /// <param name="portletData"></param>
    protected virtual void testPortletData(int id, String name, int index,
     IDataObject portletData, String portletIDString, String adminPrefUrl,
     String commPrefUrl, String userPrefUrl, String helpUrl, String collapseExpandUrl,
     bool hasTitleBar)
    {
      Assert.assertEquals(id + "", portletData.GetData(PortletRegionDataTag.KEY_PORTLETOBJECTID));
      Assert.assertEquals(name, portletData.GetData(PortletRegionDataTag.KEY_PORTLETNAME));
      Assert.assertEquals(index + "", portletData.GetData(PortletRegionDataTag.KEY_PORTLETINDEX));
      Assert.assertEquals(portletIDString, portletData.GetData(PortletRegionDataTag.KEY_PORTLETIDSTRING));
      Assert.assertEquals(adminPrefUrl, portletData.GetData(PortletRegionDataTag.KEY_PORTLETADMINPREFURL));
      Assert.assertEquals(commPrefUrl, portletData.GetData(PortletRegionDataTag.KEY_PORTLETCOMMPREFURL));
      Assert.assertEquals(userPrefUrl, portletData.GetData(PortletRegionDataTag.KEY_PORTLETUSERPREFURL));
      Assert.assertEquals(helpUrl, portletData.GetData(PortletRegionDataTag.KEY_PORTLETHELPURL));
      Assert.assertEquals(collapseExpandUrl, portletData.GetData(PortletRegionDataTag.KEY_PORTLETCOLLAPSEEXPANDURL));
      Assert.assertEquals(XPConvert.ToString(hasTitleBar), portletData.GetData(PortletRegionDataTag.KEY_PORTLETHASTITLEBAR));
      }
  }
}