using System;
using com.bea.alui.taglib.portletpage.test.integration;
using com.bea.alui.taglib.portletpage;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.layout;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
using junit.framework;
using com.plumtree.openfoundation.util;
namespace com.bea.alui.taglib.portletpage.test
{
  /// <summary>
  /// Tests the PortletRegionDisplayTag
  /// </summary>
  /// <author>rozhang</author>
  public class TestPortletRegionDisplayTag : TestCase
  {
    public TestPageContentAS m_environment;
    public MockLayoutManager m_layoutManager;
    public MockPTSession m_session;
    public MockConfigHelper m_configHelper;
    public MockPTConfigHelper m_helper;
    public TestMyPortalModel m_model;
    
    /// <summary>
    /// Setup mock objects for the tag framework
    /// </summary>
    /// <seealso cref="junit.framework.TestCase#setUp()"></seealso>
    public override void setUp()
    {
      m_configHelper = new MockConfigHelper();
      ConfigService.setTestInstance(m_configHelper);
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      // Enable layouts globally in the config file
      m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
       PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");
      // an as with mock pagecontentmodel
      m_environment = new TestPageContentAS();
      m_model = (TestMyPortalModel) m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
      m_session = new MockPTSession();
      m_environment.SetUserSession(m_session);
      m_layoutManager = new MockLayoutManager();
      LayoutService.setManagerTestInstance(m_layoutManager);
      // tags in the pagecontent library
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletDisplayTag(), PortletDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(),
       PortletPageTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// Test that the region tag generates the proper HTML and that
    /// content in the body is displayed
    /// Tests vertical display
    /// </summary>
    /// <TODO>test horizontal display when it is implemented in a future sprint</TODO>
    public virtual void testPortletRegionDisplayVertical()
    {
      String region = "1";
      String content = "Test Content!";
      // initialiaze markup
      XMLFragmentTestHelper regionDisplayTag = new XMLFragmentTestHelper(PortletPageTagLibraryData.LIBRARY.GetName(),
       PortletRegionDisplayTag.TAG.GetName());
      regionDisplayTag.AddPTAttribute(PortletRegionDisplayTag.REGIONINDEX.GetName(),
       region);
      regionDisplayTag.AddContent(content);
      Object[][] markup = regionDisplayTag.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, markup);
      String strHTML = result.GetDisplayString();
      // look for the comments
      assertTrue("Region begin comment not found!", XPStringUtility.IndexOf(strHTML,
       PortletRegionDisplayTag.REGION_BEGINCOMMENT + region) != -1);
      assertTrue("Region end comment not found!", XPStringUtility.IndexOf(strHTML,
       PortletRegionDisplayTag.REGION_ENDCOMMENT + region) != -1);
      // look for the div with id
      assertTrue("Region div not found!", XPStringUtility.IndexOf(strHTML,
       "<div id=\"region" + region) != -1);
      // look for the content
      assertTrue("Region content not found!", XPStringUtility.IndexOf(strHTML,
       content) != -1);
    }
  }
}
// @TODO test with horizontal region
