package com.bea.alui.taglib.portletpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author Bobby Tse
 *
 */
public abstract class APortletBaseDisplayTag extends ATag
{
	/**
	 * @return The MyPortalContentView in the current ActivitySpace. 
	 * @throws XPException if the view is not in the current ActivitySpace
	 */
	protected MyPortalContentView GetMyPortalContentView()
	{
		AActivitySpace space = (AActivitySpace)GetEnvironment();
		MyPortalContentView view = null;
		try {
			view = (MyPortalContentView)space.GetView(MyPortalContentView.STR_MVC_CLASS_NAME);
		} catch (XPException e) {
			throw new XPException("Could not find MyPortalContentView in the current ActivitySpace. This tag only works on MyPages and Community Pages.", e);
		}
		
		return view;
	}
	
	/**
	 * @return The MyPortalModel in the current ActivitySpace. 
	 * @throws XPException if the model is not in the current ActivitySpace
	 */
	protected MyPortalModel GetMyPortalModel()
	{
		AActivitySpace space = (AActivitySpace)GetEnvironment();
		MyPortalModel model = null;
		try {
			model = (MyPortalModel)space.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
		} catch (XPException e) {
			throw new XPException("Could not find MyPortalModel in the current ActivitySpace. This tag only works on MyPages and Community Pages.", e);
		}
		
		return model;
	}

	/**
	 * @param data_var
	 * @param scope
	 * 
	 * @return The portlet index from the passed in data variable. 
	 * @throws XPIllegalArgumentException if there is no tag data variable set or unexpected
	 * type for the tag data variable.
	 */
	protected int GetPortletIndex(ATagAttribute data_var, ATagAttribute scope, ATagAttribute colIndex)
	{
		// Get the tag data variable from the passed in id 
		String portletVarId = GetTagAttributeAsString(data_var);
		Scope varScope = Scope.GetScope( GetTagAttributeAsString(scope) );
		Object o = GetState().GetSharedVariable(portletVarId, varScope);
		if ( null == o ) {
			throw new XPIllegalArgumentException("No tag variable set with id '"+portletVarId+"' found in scope:"+varScope.toString()+"."+
					"Verify that a data tag with that id is defined.");
		}
		
		IDataObject portletVar = null;
		// Handle a collection of portlet data
		if ( o instanceof IXPList ) {
			IXPList list = (IXPList)o;
			// which index in the collection are we getting?
			int index = GetTagAttributeAsInt(colIndex);
			try {
				portletVar = (IDataObject)list.GetElement(index);
			} catch (XPClassCastException e) {
				throw new XPIllegalArgumentException("Tag collection with id '"+portletVarId+"' does not contain valid IDataObject objects."+
						" Verify that the datavar attribute refers to a variable set by a portlet data tag.");
			} catch (XPException ee) {
				throw new XPIllegalArgumentException("Invalid collection index specified for the given tag variable collection: "+portletVarId+
						" The collection contains: "+list.GetSize()+" while the index references an index of: "+index);
			}
		// Single portlet data
		} else {
			try {
				portletVar = (IDataObject)o;
			} catch (XPClassCastException e) {
				throw new XPIllegalArgumentException("Tag variable with id '"+portletVarId+"' is not of expected IDataObject type."+
						"Verify that a Portlet data tag with that id is defined.");
			}
		}

		// Get the portlet index
		int portletIndex = -1;
		try {
			portletIndex = XPConvert.ToInteger( portletVar.GetData(PortletRegionDataTag.KEY_PORTLETINDEX) );
		} catch (XPException e) {
			throw new XPIllegalArgumentException("Portlet data variable contained a non numeric portlet index. ", e);
		}		
		
		return portletIndex;
	}
}