package com.bea.alui.taglib.portletpage;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Bobby Tse
 *
 */
public class PortletHelpButtonDisplayTag extends APortletBaseDisplayTag
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
			"com.bea.alui.taglib.portletpage.PortletHelpButtonDisplayTag");

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute DATA_VAR;
	public static final OptionalTagAttribute COLINDEX;
	public static final OptionalTagAttribute SCOPE;

	public static final String DISPLAYTAG_EXAMPLE = ATag.EncodeForTagDoc(
			"<pt:logic.foreach pt:data=\"var1\" pt:var=\"curr\"><br/>"+
			"<pt:portletpage.portlethelpbuttondisplay pt:datavar=\"curr\"/><br/>"+
			"</pt:logic.foreach><br/>"
		);

	public static final String DISPLAYTAG_COLLECTION_EXAMPLE = ATag.EncodeForTagDoc(
			"Displays the first entry in the collection<br/>"+
			"<pt:portletpage.portlethelpbuttondisplay pt:datavar=\"var1\" colindex=\"0\" /><br/>"
		);
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("portlethelpbuttondisplay",
			"Displays the help button of a portlet from a data object, specified by the pt:datavar attribute. ",
			PortletRegionDataTag.DATATAG_EXAMPLE+DISPLAYTAG_EXAMPLE+DISPLAYTAG_COLLECTION_EXAMPLE);

		DATA_VAR = new RequiredTagAttribute("datavar",
			"The key to the tag memory variable with portlet data to display. The data is set by portletpage.portletregiondata and other similar data tags. "+
			"This tag is also able to display a single portlet in a collection of portlet data. "+
			"Use the pt:colindex attribute to specify the index in the collection.");

		COLINDEX = new OptionalTagAttribute("colindex",
				"Used to get portlet data from a specific index in a collection if the pt:datavar attribute references a "+
				"portlet data collection instead of a single portlet. The default value is 0 (the first entry in the collection). "+
				"The value of this attribute is ignored if pt:datavar refers to a single portlet data IDataObject. "+
				"Use this tag together with the logic.foreach tag to iterate over all portlets in a collection and display them all.",
				AttributeType.INT, "0");
		
		SCOPE = new OptionalTagAttribute("scope",
			"The scope used to store the data collection. See the Logic tag library for further information on scope.",
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
	}

	/*
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() 
	{
		// Get the view and portlet index to retrieve the portlet content.
		MyPortalContentView view = GetMyPortalContentView();
		int portletIndex = GetPortletIndex(DATA_VAR, SCOPE, COLINDEX);

		// Get the help button content of the portlet		
		HTMLElement result = new HTMLElementCollection();
		// TODO: CR ROB: An empty collection is return if there is an exception in the view method. Maybe it should return an exception instead so 
		// that you can print out an informative error message instead of just returning empty content or if you can check that there
		// was an error somehow and handle it
		if (-1 != portletIndex)
		{
			log.Debug("Tag portlethelpbuttondisplay displaying portlet help button with index {0} from datavar {0}, scope {1}, colindex {2}.", 
					portletIndex, GetTagAttributeAsString(DATA_VAR), GetTagAttributeAsString(SCOPE), GetTagAttributeAsInt(COLINDEX));
			result.AddInnerHTMLElement(view.GetPortletHelpButtonContent(portletIndex));
		} else {
			log.Info("Tag portlethelpbuttondisplay not able to lookup portlet index from datavar {0}, scope {1}, colindex {2}", 
					GetTagAttributeAsString(DATA_VAR), GetTagAttributeAsString(SCOPE), GetTagAttributeAsInt(COLINDEX));
		}
		
		return result;
	}

	/*
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() 
	{
		return new PortletHelpButtonDisplayTag();
	}
}
