package com.bea.alui.taglib.portletpage.test;

import junit.framework.*;

import com.bea.alui.taglib.portletpage.test.integration.*;
import com.bea.alui.taglib.portletpage.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.layout.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tests getting breadcrumbs from breadcrumb data tag
 * 
 * @author btse
 *
 */
public class TestPageNameBreadCrumbsDataTag extends TestCase 
{
	public TestPageContentAS m_environment;
	public MockLayoutManager m_layoutManager;
	public MockPTSession m_session;
	public MockConfigHelper m_configHelper;
	public MockPTConfigHelper m_helper;
	public TestMyPortalModel m_model;
	
	public void setUp() 
	{
		m_configHelper = new MockConfigHelper();
		ConfigService.setTestInstance(m_configHelper);
	
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);

		// Enable layouts globally in the config file
		m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
			PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");

		// an as with mock pagecontentmodel
		m_environment = new TestPageContentAS();
		m_model = (TestMyPortalModel)m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
		m_session = new MockPTSession();
		
		m_environment.SetUserSession(m_session);
		
		m_layoutManager = new MockLayoutManager();
		LayoutService.setManagerTestInstance(m_layoutManager);

		// tags in the pagecontent library
		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new PageNameBreadCrumbsDataTag(), PageNameBreadCrumbsDataTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * Get breadcrumbs from data tag and verify contents of the breadcrumbs.
	 */
	public void testPortletBreadCrumbsDataTag()
	{
		String idValue = "breadcrumbs";
		
		// Testing MyPage base case with "EMPTY_STRING" set for the bread crumb URLs.
		// TODO: Make MockPTSubPortalInfo configurable to set up default page type
		// and test community bread crumbs. Update Mock classes to return required
		// data to test communities.
		String breadCrumb1Name = "Home";
		String breadCrumb1Url = PageNameBreadCrumbsDataTag.EMPTY_STRING;
		String breadCrumb2Name = m_model.GetPageName();
		String breadCrumb2Url = PageNameBreadCrumbsDataTag.EMPTY_STRING;
		
		// initialiaze markup
		XMLFragmentTestHelper breadCrumbsDataTag = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PageNameBreadCrumbsDataTag.TAG.GetName());
		breadCrumbsDataTag.AddPTAttribute(PageNameBreadCrumbsDataTag.ATTRIB_ID.GetName(), idValue);
		breadCrumbsDataTag.AddPTAttribute(PageNameBreadCrumbsDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());

		// process the markup which will execute the tags
		Object[][] markup = breadCrumbsDataTag.ToArrayEntireFragment();
		HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);

		// for some reason the names are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+idValue);

		if ( ssVariable == null ) {	
			XPSystem.Out.WriteLine("Output of processed markup:");
			XPSystem.Out.WriteLine(content.GetDisplayString());
			fail("Did not find expected tag variable with id "+idValue+" set in tag memory"); 
		}
		
		IXPList breadCrumbs = (IXPList) ssVariable.GetValue();
		Assert.assertEquals("The size of the bread crumbs list in memory is incorrect.", 2, breadCrumbs.GetSize());
		
		IDataObject dataObject = (IDataObject) breadCrumbs.GetElement(0);
		String name = dataObject.GetData(PageNameBreadCrumbsDataTag.NAME);
		Assert.assertEquals("Wrong name returned for breadCrumb1.", breadCrumb1Name, name);
		String url = dataObject.GetData(PageNameBreadCrumbsDataTag.URL);
		Assert.assertEquals("Wrong url returned for breadCrumb1.", breadCrumb1Url, url);
		
		dataObject = (IDataObject) breadCrumbs.GetElement(1);
		name = dataObject.GetData(PageNameBreadCrumbsDataTag.NAME);
		Assert.assertEquals("Wrong name returned for breadCrumb2.", breadCrumb2Name, name);
		url = dataObject.GetData(PageNameBreadCrumbsDataTag.URL);
		Assert.assertEquals("Wrong url returned for breadCrumb2.", breadCrumb2Url, url);
	}
}
