package com.bea.alui.taglib.portletpage.test;

import junit.framework.*;

import com.bea.alui.taglib.portletpage.*;
import com.bea.alui.taglib.portletpage.test.integration.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.layout.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

//TODO CR DLH: All of these tests need to be in a suite, and that needs to be added
// to the WebUISuite.
/**
 * Tests the display tag by loading up portlets with the region data tag and generating
 * HTML for those portlets.
 * 
 * Verify HTML by checking that portlet names and other portlet elements are in the generated
 * HTML
 * 
 * @TODO: Test content display
 * @TODO: Do we need Add test for error cases? 
 * 
 * 
 * @author Robert Zhang
 */
public class TestPortletDisplayTag extends TestCase 
{

	public TestPageContentAS m_environment;
	public MockLayoutManager m_layoutManager;
	public MockPTSession m_session;
	public MockConfigHelper m_configHelper;
	public MockPTConfigHelper m_helper;
	public TestMyPortalModel m_model;

	public void setUp()
	{
		m_configHelper = new MockConfigHelper();
		ConfigService.setTestInstance(m_configHelper);
	
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);

		// Enable layouts globally in the config file
		m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
			PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");

		// an as with mock pagecontentmodel
		m_environment = new TestPageContentAS();
		m_model = (TestMyPortalModel)m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
		m_session = new MockPTSession();
		
		m_environment.SetUserSession(m_session);
		
		m_layoutManager = new MockLayoutManager();
		LayoutService.setManagerTestInstance(m_layoutManager);
		
		// tags in the pagecontent library
		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new PortletDisplayTag(), PortletDisplayTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	// TODO CR DLH: This really tests both the portlet display tag and the portletregiondata tag.
	// Why don't you just do a simple display test, since you already test the region data tag
	// in the TestPortletRegionDataTag class?
	/**
	 * Add portlets to all 3 regions
	 * Get portlets from region 1 and verify that they are displayed in the generated HTML
	 */
	public void testPortletDisplayTag()
	{
		String tagvarname1 = "testvar1";
		
		// in region 1
		String name1 = "Portlet-Apple";
		String name2 = "Portlet-Orange";
		String name3 = "Portlet-Kiwi";
		// in region 2
		String name4 = "Portlet-Melon";
		// in region 3
		String name5 = "Portlet-Pomegranate";
		String name6 = "Portlet-Grape";
		
		int region1 = 1;
		int region2 = 2;
		int region3 = 3;
		
		// initialize mock model
		int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1", "adminPrefUrl1", "commPrefUrl1", "userPrefUrl1", "helpUrl1", "collapseExpandUrl1", "removeUrl1", true);
		int id2 = m_model.addPortletInColumn(name2, null, region1, "pt-portletid-2", "adminPrefUrl2", "commPrefUrl2", "userPrefUrl2", "helpUrl2", "collapseExpandUrl2", "removeUrl2", false);
		int id3 = m_model.addPortletInColumn(name3, null, region1, "pt-portletid-3", "adminPrefUrl3", "commPrefUrl3", "userPrefUrl3", "helpUrl3", "collapseExpandUrl3", "removeUrl3", true);
		int id4 = m_model.addPortletInColumn(name4, null, region2, "pt-portletid-4", "adminPrefUrl4", "commPrefUrl4", "userPrefUrl4", "helpUrl4", "collapseExpandUrl4", "removeUrl4", false);
		int id5 = m_model.addPortletInColumn(name5, null, region3, "pt-portletid-5", "adminPrefUrl5", "commPrefUrl5", "userPrefUrl5", "helpUrl5", "collapseExpandUrl5", "removeUrl5", true);
		int id6 = m_model.addPortletInColumn(name6, null, region3, "pt-portletid-6", "adminPrefUrl6", "commPrefUrl6", "userPrefUrl6", "helpUrl6", "collapseExpandUrl6", "removeUrl6", false);
		
		// initialiaze markup
		XMLFragmentTestHelper regionDataTag = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PortletRegionDataTag.TAG.GetName());
		regionDataTag.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(), region1+"");
		regionDataTag.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
		// set it on the http request so that we can easily access it
		
		// Display without colindex attribute (should default to index 0)
		XMLFragmentTestHelper displayTag1 = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PortletDisplayTag.TAG.GetName());
		displayTag1.AddPTAttribute(PortletDisplayTag.DATA_VAR.GetName(), tagvarname1);
		// set it on the http request so that we can easily access it
		
		// Display with index 1
		XMLFragmentTestHelper displayTag2 = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PortletDisplayTag.TAG.GetName());
		displayTag2.AddPTAttribute(PortletDisplayTag.DATA_VAR.GetName(), tagvarname1);
		// set it on the http request so that we can easily access it
		displayTag2.AddPTAttribute(PortletDisplayTag.COLINDEX.GetName(), "1");
		
		// Display with index 2
		XMLFragmentTestHelper displayTag3 = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PortletDisplayTag.TAG.GetName());
		displayTag3.AddPTAttribute(PortletDisplayTag.DATA_VAR.GetName(), tagvarname1);
		// set it on the http request so that we can easily access it
		displayTag3.AddPTAttribute(PortletDisplayTag.COLINDEX.GetName(), "2");
		
		XMLFragmentTestHelper tags = new XMLFragmentTestHelper(
				new XMLFragmentTestHelper[] {regionDataTag, displayTag1, displayTag2, displayTag3} );
		// process the markup which will execute the tags
		Object[][] markup = tags.ToArrayEntireFragment();
		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, markup);
		String strHTML = result.GetDisplayString();
		
		// validate the output
		// name of the portlet in the header
		if ( strHTML.indexOf(name1) == -1 ) {
			XPSystem.Out.WriteLine("Portlet 1 not found in the generated HTML! Generated content: ");
			XPSystem.Out.WriteLine(strHTML);
		}
		// make sure the portlet is referencable
		assertTrue( "Portlet 1 div found in the generated HTML!", strHTML.indexOf("id=\"pt-portlet-"+id1+"\"") != -1 );
		
		assertTrue( "Portlet 2 not found in the generated HTML!", strHTML.indexOf(name2) != -1 );
		assertTrue( "Portlet 2 div found in the generated HTML!", strHTML.indexOf("id=\"pt-portlet-"+id2+"\"") != -1 );
		
		assertTrue( "Portlet 3 not found in the generated HTML!", strHTML.indexOf(name3) != -1 );
		assertTrue( "Portlet 3 div found in the generated HTML!", strHTML.indexOf("id=\"pt-portlet-"+id3+"\"") != -1 );
	}
}