package com.bea.alui.taglib.portletpage.test;

import junit.framework.*;

import com.bea.alui.taglib.portletpage.*;
import com.bea.alui.taglib.portletpage.test.integration.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.layout.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Tests the help display tag by loading up a portlet with the region data tag and generating
 * HTML for the portlet.
 * 
 * Verify HTML by checking that portlet elements are in the generated
 * HTML
 * 
 * @author btse
 *
 */
public class TestPortletHelpButtonDisplayTag extends TestCase 
{

	public TestPageContentAS m_environment;
	public MockLayoutManager m_layoutManager;
	public MockPTSession m_session;
	public MockConfigHelper m_configHelper;
	public MockPTConfigHelper m_helper;
	public TestMyPortalModel m_model;
	
	public void setUp() 
	{
		m_configHelper = new MockConfigHelper();
		ConfigService.setTestInstance(m_configHelper);
	
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);

		// Enable layouts globally in the config file
		m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
			PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");

		// an as with mock pagecontentmodel
		m_environment = new TestPageContentAS();
		m_model = (TestMyPortalModel)m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
		m_session = new MockPTSession();
		
		m_environment.SetUserSession(m_session);
		
		m_layoutManager = new MockLayoutManager();
		LayoutService.setManagerTestInstance(m_layoutManager);
		
		// tags in the pagecontent library
		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new PortletHelpButtonDisplayTag(), PortletHelpButtonDisplayTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * Add a portlet to region 1
	 * Get portlet from region 1 and verify that the help html span is displayed in the generated HTML
	 */
	public void testPortletContentDisplayTag()
	{
		String tagvarname1 = "testvar1";
		
		// in region 1
		String name1 = "Portlet-Apple";
		int region1 = 1;
		
		// initialize mock model
		int id1 = m_model.addPortletInColumn(name1, null, region1, "pt-portletid-1", "adminPrefUrl1", "commPrefUrl1", "userPrefUrl1", "helpUrl1", "collapseExpandUrl1", "removeUrl1", true);
		
		// initialiaze markup
		XMLFragmentTestHelper regionDataTag = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PortletRegionDataTag.TAG.GetName());
		regionDataTag.AddPTAttribute(PortletRegionDataTag.REGIONINDEX.GetName(), region1+"");
		regionDataTag.AddPTAttribute(PortletRegionDataTag.KEY.GetName(), tagvarname1);
		// set it on the http request so that we can easily access it
		
		// Display without colindex attribute (should default to index 0)
		XMLFragmentTestHelper helpButtonDisplayTag1 = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PortletHelpButtonDisplayTag.TAG.GetName());
		helpButtonDisplayTag1.AddPTAttribute(PortletHelpButtonDisplayTag.DATA_VAR.GetName(), tagvarname1);
		// set it on the http request so that we can easily access it
		
		XMLFragmentTestHelper tags = new XMLFragmentTestHelper(
				new XMLFragmentTestHelper[] {regionDataTag, helpButtonDisplayTag1} );
		// process the markup which will execute the tags
		Object[][] markup = tags.ToArrayEntireFragment();
		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, markup);
		String strHTML = result.GetDisplayString();
		
		// validate the output
		// name of the portlet in the header
		if ( strHTML.indexOf("<span class=\"portletHelpButton\">") == -1 ) {
			XPSystem.Out.WriteLine("Help Button not found in the generated HTML! Generated content: ");
			XPSystem.Out.WriteLine(strHTML);
		}
	}
}
