package com.bea.alui.taglib.portletpage.test;

import com.bea.alui.taglib.portletpage.test.integration.*;
import com.bea.alui.taglib.portletpage.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.layout.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

import junit.framework.*;

/**
 * Tests the PortletRegionDisplayTag
 * 
 * @author rozhang
 *
 */
public class TestPortletRegionDisplayTag extends TestCase 
{
	public TestPageContentAS m_environment;
	public MockLayoutManager m_layoutManager;
	public MockPTSession m_session;
	public MockConfigHelper m_configHelper;
	public MockPTConfigHelper m_helper;
	public TestMyPortalModel m_model;

	/**
	 * Setup mock objects for the tag framework
	 * 
	 * @see junit.framework.TestCase#setUp()
	 */
	public void setUp()
	{
		m_configHelper = new MockConfigHelper();
		ConfigService.setTestInstance(m_configHelper);
	
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);

		// Enable layouts globally in the config file
		m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
			PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");

		// an as with mock pagecontentmodel
		m_environment = new TestPageContentAS();
		m_model = (TestMyPortalModel)m_environment.GetModel(TestMyPortalModel.STR_MVC_CLASS_NAME);
		m_session = new MockPTSession();
		
		m_environment.SetUserSession(m_session);
		
		m_layoutManager = new MockLayoutManager();
		LayoutService.setManagerTestInstance(m_layoutManager);
		
		// tags in the pagecontent library
		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new PortletDisplayTag(), PortletDisplayTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		tagLibs.SetTag(new PortletRegionDataTag(), PortletRegionDataTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		tagLibs.SetTag(new PortletRegionDisplayTag(), PortletRegionDisplayTag.TAG.GetName(), PortletPageTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}
	
	/**
	 * Test that the region tag generates the proper HTML and that
	 * content in the body is displayed
	 * 
	 * Tests vertical display
	 * @TODO test horizontal display when it is implemented in a future sprint
	 * 
	 */
	public void testPortletRegionDisplayVertical()
	{
		String region = "1";
		String content = "Test Content!";
		// initialiaze markup
		XMLFragmentTestHelper regionDisplayTag = 
			new XMLFragmentTestHelper(
				PortletPageTagLibraryData.LIBRARY.GetName(), 
				PortletRegionDisplayTag.TAG.GetName());
		regionDisplayTag.AddPTAttribute(PortletRegionDisplayTag.REGIONINDEX.GetName(), region);
		regionDisplayTag.AddContent(content);
		
		Object[][] markup = regionDisplayTag.ToArrayEntireFragment();
		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, markup);
		String strHTML = result.GetDisplayString();
		
		// look for the comments
		assertTrue( "Region begin comment not found!", strHTML.indexOf(PortletRegionDisplayTag.REGION_BEGINCOMMENT+region) != -1 );
		assertTrue( "Region end comment not found!", strHTML.indexOf(PortletRegionDisplayTag.REGION_ENDCOMMENT+region) != -1 );
		// look for the div with id
		assertTrue( "Region div not found!", strHTML.indexOf("<div id=\"region"+region) != -1 );
		// look for the content
		assertTrue( "Region content not found!", strHTML.indexOf(content) != -1 );
	}
	
	// @TODO test with horizontal region

}
