package com.bea.alui.taglib.portletpage.test.integration;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author btse
 *
 */
public class TestMyPortalContentView extends MyPortalContentView implements
		IView 
{
	/** Parent Activity Space */
	private AActivitySpace m_asOwner;

	/** Read Only Model for MyPortal */
	private IMyPortalModelRO m_asModel;
	
	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		
		m_asModel     = (IMyPortalModelRO) model;
		m_asOwner     = parent;
	}
	
	/**
	 * Obtain the collapse button from the portlet header given the portlet index.
	 * 
	 * @param nPortletIndex
	 * @return Collapse/Expand HTML button. NOTE: May contain null elements
	 */
	protected HTMLSpan GetPortletCollapseExpandAction(int nPortletIndex, String strOnclickFunction)
	{
		HTMLAnchor collapseAnchor = null;
		HTMLSpan collapseSpan	= null;
		
		// Only Add if portlet is not mandatory
		if (m_asModel.GetPortletCollapsed(nPortletIndex))
		{
			// Get Expand Anchor
			collapseAnchor = GetCollapseOrExpandAnchor(nPortletIndex,
				CollapsePortletControl.STR_EXPAND_CONTROL,
				PTImageType.ACTION_PORTLET_EXPAND,
				m_asOwner.GetString(1802, "ptmsgs_portalbrowsingmsgs")
			);
		}
		else if (!m_asModel.GetPortletCollapsed(nPortletIndex))
		{
			// Get Collapse Anchor
			collapseAnchor = GetCollapseOrExpandAnchor(nPortletIndex,
				CollapsePortletControl.STR_COLLAPSE_CONTROL,
				PTImageType.ACTION_PORTLET_COLLAPSE,
				m_asOwner.GetString(1803, "ptmsgs_portalbrowsingmsgs")
			);
		}
		
		if (null != collapseAnchor && null != strOnclickFunction) {
			// DCA - change Anchor from having an href to an onclick
			String strCollapseURL = collapseAnchor.GetHRef();
			collapseAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
			collapseAnchor.SetOnClick("return " + strOnclickFunction + "('" + strCollapseURL + "');");
		}
			
		collapseSpan = new HTMLSpan();
		collapseSpan.SetStyleClass(PTStyleClass.PORTLET_COLLAPSE_BUTTON);
		collapseSpan.AddInnerHTMLElement(collapseAnchor);

		return collapseSpan;
	}

	/**
	 * @param nPortletIndex
	 * @param strCollapseOrExpandControl
	 * @param imgType
	 * @param strTitle
	 * @return anchor for collapsing or expanding the portlet
	 */
	protected HTMLAnchor GetCollapseOrExpandAnchor(int nPortletIndex, String strControl, PTImageType imgType, String strTitle)
	{
		// Get Collapse or Expand Image
		PTConstruct myConstruct     = UIConstructFactory.GetConstruct(imgType);
		HTMLImg actionImage     = (HTMLImg) myConstruct.GetHTMLElement();
		actionImage.SetAlt(XPResourceManager.FormatMessage(strTitle, XPHttpUtility.HtmlEncode(m_asModel.GetPortletNameFromIndex(nPortletIndex))));
		actionImage.SetBorder(CommonHTMLStrings.ZERO);
		actionImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

		// Build URL for Collapse Or Expand
		ASURL collURL = m_asModel.GetPageASURL();
		collURL.AddControlArgument(CollapsePortletControl.STR_PORTLET_TO_COLLAPSE_EXPAND, m_asModel.GetPortletIDFromIndex(nPortletIndex));
		collURL.SetControl(strControl);
		
		// Get Anchor for Collapse or Expand
		HTMLAnchor actionAnchor = (HTMLAnchor)collURL.GetURLAsHTMLElement();
		actionAnchor.SetTitle(XPResourceManager.FormatMessage(strTitle, XPHttpUtility.HtmlEncode(m_asModel.GetPortletNameFromIndex(nPortletIndex))));
		actionAnchor.AddInnerHTMLElement(actionImage);

		return actionAnchor;
	}
	
	protected HTMLSpan GetPortletRemoveAction(int nPortletIndex)
	{
		HTMLAnchor removeAnchor = null;
		HTMLSpan removeSpan	= null;
		
		// Get Anchor Remove link
		removeAnchor = GetRemoveAnchor(nPortletIndex,
			AddRemovePortletControl.STR_MVC_CLASS_NAME,
			PTImageType.ACTION_PORTLET_REMOVE,
			m_asOwner.GetString(1906, "ptmsgs_portalbrowsingmsgs")
		);
				
		removeSpan = new HTMLSpan();
		removeSpan.SetStyleClass(PTStyleClass.PORTLET_REMOVE_BUTTON);
		removeSpan.AddInnerHTMLElement(removeAnchor);

		return removeSpan;
	}
	
	/**
	 * 
	 * @param nPortletIndex
	 * @param strControl
	 * @param imgType
	 * @param strTitle
	 * @return anchor for Removing Portlet.
	 */
	protected HTMLAnchor GetRemoveAnchor (int nPortletIndex, String strControl, PTImageType imgType, String strTitle)
	{
		// Get Remove Image
		PTConstruct myConstruct     = UIConstructFactory.GetConstruct(imgType);
		HTMLImg actionImage     = (HTMLImg) myConstruct.GetHTMLElement();
		actionImage.SetAlt(XPResourceManager.FormatMessage(strTitle, XPHttpUtility.HtmlEncode(m_asModel.GetPortletNameFromIndex(nPortletIndex))));
		actionImage.SetBorder(CommonHTMLStrings.ZERO);
		actionImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		
		// Build URL for Remove
		ASURL collURL = m_asModel.GetPageASURL();
		collURL.AddControlArgument(AddRemovePortletControl.STR_PORTLET_TO_REMOVE, m_asModel.GetPortletIDFromIndex(nPortletIndex));
		collURL.SetControl(strControl);
		
		// Get Anchor for Remove
		HTMLAnchor actionAnchor = (HTMLAnchor)collURL.GetURLAsHTMLElement();
		actionAnchor.SetTitle(XPResourceManager.FormatMessage(strTitle, XPHttpUtility.HtmlEncode(m_asModel.GetPortletNameFromIndex(nPortletIndex))));
		actionAnchor.AddInnerHTMLElement(actionImage);
		
		return actionAnchor;
	}
}
