package com.bea.alui.taglib.portletpage.test.integration;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;

public class TestMyPortalModel extends MyPortalModel implements IMyPortalModelRO
{
	protected String KEY_PORTLETNAME = "name";
	protected String KEY_PORTLETID = "objid";
	protected String KEY_PORTLETREGION = "region";
	protected String KEY_PORTLETCONTENT = "content";
	protected String KEY_PORTLETIDSTRING = "portletidstring";
	protected String KEY_PORTLETADMINPREFURL = "adminprefurl";
	protected String KEY_PORTLETCOMMPREFURL	= "commprefurl";
	protected String KEY_PORTLETUSERPREFURL	= "userprefurl";
	protected String KEY_PORTLETHELPURL	= "helpurl";
	protected String KEY_PORTLETCOLLAPSEEXPANDURL = "collapseexpandurl";
	protected String KEY_PORTLETREMOVEURL = "removeurl";
	protected String KEY_PORTLETHASTITLEBAR = "hastitlebar";
	
	public boolean m_isCommunityPage = true;
	public int m_pageId = 0;
	public int m_commId = 0;
	// start object ids at 200
	public int m_idcounter = 200;
	public String m_pageName = "TestMyPortalModel Page";
	
	public XPArrayList m_regions = new XPArrayList();
	
	public TestMyPortalModel(int regions)
	{
		// initialize regions list with list of portlets
		for ( int i = 0; i < regions; i++ ) {
			m_regions.Add(new XPArrayList());
		}
	}
	
	/**
	 * Call this method to initialize model with portlets
	 * 
	 * Adds a portlet
	 * @param portletName				name of portlet
	 * @param region					1 based region index
	 * @param portletContent 			markup 2d object array (optional)
	 * @param portletIDString			Identifier string of portlet (i.e. pt-portlet-1)
	 * @param portletAdminPrefUrl		Admin Preference Url of portlet
	 * @param portletCommPrefUrl		Community Preference Url of portlet
	 * @param portletUserPrefUrl		User Preference Url of portlet
	 * @param portletHelpUrl			Help Url of portlet
	 * @param portletCollapseExpanUrl	Collapse/Expand Url of portlet
	 * @param portletHasTitleBar		Is title bar displayed for portlet?
	 * @return	generated object id of the portlet
	 */
	public int addPortletInColumn(String portletName, Object[][] portletContent, int region,
			String portletIDString, String portletAdminPrefUrl, String portletCommPrefUrl,
			String portletUserPrefUrl, String portletHelpUrl, String portletCollapseExpandUrl,
			String portletRemoveUrl, boolean portletHasTitleBar)
	{
		// regions are 0 based in list
		--region;
		// store portlet info
		XPHashtable table = new XPHashtable();
		table.PutElement(KEY_PORTLETID, new Integer(m_idcounter));
		table.PutElement(KEY_PORTLETNAME, portletName);
		table.PutElement(KEY_PORTLETCONTENT, portletContent);
		table.PutElement(KEY_PORTLETREGION, new Integer(region));
		table.PutElement(KEY_PORTLETIDSTRING, portletIDString);
		table.PutElement(KEY_PORTLETADMINPREFURL, portletAdminPrefUrl);
		table.PutElement(KEY_PORTLETCOMMPREFURL, portletCommPrefUrl);
		table.PutElement(KEY_PORTLETUSERPREFURL, portletUserPrefUrl);
		table.PutElement(KEY_PORTLETHELPURL, portletHelpUrl);
		table.PutElement(KEY_PORTLETCOLLAPSEEXPANDURL, portletCollapseExpandUrl);
		table.PutElement(KEY_PORTLETREMOVEURL, portletRemoveUrl);
		table.PutElement(KEY_PORTLETHASTITLEBAR, XPConvert.ToString(portletHasTitleBar));
		
		((XPArrayList)m_regions.GetElement(region)).Add(table);
		
		return m_idcounter++; 
	}
	
	public int GetPortletCount()
	{
		int count = 0;
		for ( int i = 0; i < m_regions.GetSize(); i++ ) {
			count += ((XPArrayList)m_regions.GetElement(i)).GetSize();
		}
		return count;
	}
	/**
	 * Internal hepler function to lookup the portlet object from main index
	 * 
	 * Portlets are indexed by their order in a region and the region order so
	 * index = 0 starts with the first portlet in the first region. 
	 * 
	 * @param index
	 * @return
	 */
	protected XPHashtable GetPortletFromIndex(int index)
	{
		int totalCount = 0;
		for ( int i = 0; i < m_regions.GetSize(); i++ ) {
			int curCount = ((XPArrayList)m_regions.GetElement(i)).GetSize();
			
			// comparing size with index, so add 1 to index
			if ( (totalCount+curCount) >= index+1  ) {
				// we know the portlet is in the current region, calculate the index within the region
				int regionIndex = index-totalCount;
				
				XPHashtable portlet = (XPHashtable)((XPArrayList)m_regions.GetElement(i)).GetElement(regionIndex);
				return portlet;
			}
			totalCount += curCount;
		}
		throw new XPIllegalArgumentException("Invalid portlet index: "+index);
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetFirstPortletIndexInColumn(int)
	 */
	public int GetFirstPortletIndexInColumn(int nPortletColumn)
	{
		XPHashtable portlet = (XPHashtable)((XPArrayList)m_regions.GetElement(nPortletColumn)).GetElement(0);
		Integer id = (Integer)portlet.GetElement(KEY_PORTLETID); 
		return id.intValue();
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletColumnFromIndex(int)
	 */
	public int GetPortletColumnFromIndex(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		Integer region = (Integer)portlet.GetElement(KEY_PORTLETREGION);
		
		return region.intValue();
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletIDFromIndex(int)
	 */
	public int GetPortletIDFromIndex(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		Integer id = (Integer)portlet.GetElement(KEY_PORTLETID);
		
		return id.intValue();
		
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletNameFromIndex(int)
	 */
	public String GetPortletNameFromIndex(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String name = (String)portlet.GetElement(KEY_PORTLETNAME);
		
		return name;
		
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetIDStringForPortlet(int)
	 */
	public String GetIDStringForPortlet(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String name = (String)portlet.GetElement(KEY_PORTLETIDSTRING);
		
		return name;
		
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletHasTitleBar(int)
	 */
	public boolean GetPortletHasTitleBar(int nPortletIndex) {
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		boolean hasTitleBar = XPConvert.ToBoolean(portlet.GetElement(KEY_PORTLETHASTITLEBAR));
		
		return hasTitleBar;
		
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletHTMLTextFromIndex(int)
	 */
	public Object[][] GetPortletHTMLTextFromIndex(int nPortletIndex) {
		
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		Object[][] content = (Object[][])portlet.GetElement(KEY_PORTLETCONTENT);
		
		return content;
	}
	
	public boolean GetDisplayPortletHeaderDueToError(int nPortletIndex)
	{
		// @TODO: make this configurable
		return true;
	}
	
	public boolean GetPortletHasRefreshButton(int nPortletIndex)
	{
		// @TODO: make this configurable
		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletCollapsed(int)
	 */
	public boolean GetPortletCollapsed(int nPortletIndex) 
	{
		// @TODO: make this configurable
		return true;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletDisabledMessage(int)
	 */
	public String GetPortletDisabledMessage(int nPortletIndex) 
	{
		// @TODO: make this configurable
		return "Portlet disabled";
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletEnabled(int)
	 */
	public boolean GetPortletEnabled(int nPortletIndex) 
	{
		// @TODO: make this configurable
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletHasHelpURL(int)
	 */
	public boolean GetPortletHasHelpURL(int nPortletIndex) {
		// @TODO: make this configurable
		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.
	 * myportal.MyPortalModel#GetPortletHasAdminPrefsURL(int)
	 */
	public boolean GetPortletHasAdminPrefsURL(int nPortletIndex) {
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String adminPrefUrl = (String)portlet.GetElement(KEY_PORTLETADMINPREFURL);
		
		return null != adminPrefUrl;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.
	 * myportal.MyPortalModel#GetPortletHasCommunityPrefsURL(int)
	 */
	public boolean GetPortletHasCommunityPrefsURL(int nPortletIndex) {
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String commPrefUrl = (String)portlet.GetElement(KEY_PORTLETCOMMPREFURL);
		
		return null != commPrefUrl;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.
	 * myportal.MyPortalModel#GetPortletHasUserPrefsURL(int)
	 */
	public boolean GetPortletHasUserPrefsURL(int nPortletIndex) {
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String userPrefUrl = (String)portlet.GetElement(KEY_PORTLETUSERPREFURL);
		
		return null != userPrefUrl;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.
	 * myportal.MyPortalModel#GetPortletHasCollapseExpandURL(int)
	 */
	public boolean GetPortletHasCollapseExpandURL(int nPortletIndex) {
		// @TODO: make this configurable
		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletIsMandatory(int)
	 */
	public boolean GetPortletIsMandatory(int nPortletIndex) {
		// @TODO: make this configurable
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletSupports508(int)
	 */
	public boolean GetPortletSupports508(int nPortletIndex) {
		// @TODO: make this configurable
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletSupportsPersonalization(int)
	 */
	public int GetPortletSupportsPersonalization(int nPortletIndex) {
		// @TODO: make this configurable
		return 7;
	}
	
	public boolean GetIsCommunityPage()
	{
		return m_isCommunityPage;
	}
	
	public int GetPageID()
	{
		return m_pageId;
	}

	public String GetPageName()
	{
		return m_pageName;
	}
	
	public int GetCommunityID()
	{
		return m_commId;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetCommunity(int, int)
	 */
	public boolean SetCommunity(int nCommunityID, int nPageID) {
		m_nCommunityID = nCommunityID;
		m_pageId = nPageID;
		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetPage(int)
	 */
	public boolean SetPage(int nPageID) {
		m_pageId = nPageID;
		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPageASURL()
	 */
	public ASURL GetPageASURL() {
		//throw new XPNotImplementedException();
		ASURL url = new ASURL(m_asOwner);
		url.SetLinkGetCachedSpace(m_asOwner);

		url.AddControlArgument(SetPageControl.STR_PAGE_ID,
			XPConvert.ToString(GetPageID()));

		return url;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletHelpURL(int)
	 */
	public String GetPortletHelpURL(int nPortletIndex) {
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String helpUrl = (String)portlet.GetElement(KEY_PORTLETHELPURL);
		
		return helpUrl;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletAdminPrefsURL(int)
	 */
	public String GetPortletAdminPrefsURL(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String adminPrefUrl = (String)portlet.GetElement(KEY_PORTLETADMINPREFURL);
		
		return adminPrefUrl;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletCommunityPrefsURL(int)
	 */
	public String GetPortletCommunityPrefsURL(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String commPrefUrl = (String)portlet.GetElement(KEY_PORTLETCOMMPREFURL);
		
		return commPrefUrl;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletUserPrefsURL(int)
	 */
	public String GetPortletUserPrefsURL(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String userPrefUrl = (String)portlet.GetElement(KEY_PORTLETUSERPREFURL);
		
		return userPrefUrl;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletCollapseExpandURL(int)
	 */
	public String GetPortletCollapseExpandURL(int nPortletIndex, String strControl)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String collapseExpandUrl = (String)portlet.GetElement(KEY_PORTLETCOLLAPSEEXPANDURL);
		
		return collapseExpandUrl;
	}	
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletRemoveURL(int)
	 */
	public String GetPortletRemoveURL(int nPortletIndex)
	{
		XPHashtable portlet = GetPortletFromIndex(nPortletIndex);
		String removeUrl = (String)portlet.GetElement(KEY_PORTLETREMOVEURL);
		
		return removeUrl;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletPrefButtonBoolean()
	 */
	public String GetPortletPrefButtonBoolean() {
		// @TODO: make this configurable
		return "1";
	}

	/***
	 * 
	 * METHODS WITHOUT IMPLEMENTATIONS
	 * 
	 */
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#CollapsePortlet(int, int, int)
	 */
	public void CollapsePortlet(int nCommunityID, int nPageID, int nPortletToCollapse) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#CommunityJoinFailed()
	 */
	public boolean CommunityJoinFailed() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#DeletePage(int)
	 */
	public void DeletePage(int nPageID) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#ExpandPortlet(int, int, int)
	 */
	public void ExpandPortlet(int nCommunityID, int nPageID, int nPortletToExpand) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#Finish()
	 */
	public void Finish() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetCollapsedOrErrorContent(int)
	 */
	public Object[][] GetCollapsedOrErrorContent(int nPortletIndex) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetCommunityName()
	 */
	public String GetCommunityName() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetCommunityPages()
	 */
	public IPTQueryResult GetCommunityPages() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetCommunityURL()
	 */
	public String GetCommunityURL() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetCurCommName()
	 */
	public String GetCurCommName() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetDefaultCommunityURL()
	 */
	public String GetDefaultCommunityURL() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetHelper()
	 */
	public IMyPortalModelHelper GetHelper() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetLastPortletIndexInColumn(int)
	 */
	public int GetLastPortletIndexInColumn(int nPortletColumn) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPageType()
	 */
	public int GetPageType() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetParentSpace()
	 */
	public AActivitySpace GetParentSpace() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetPortletUUID(int)
	 */
	public String GetPortletUUID(int nPortletIndex) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetProfileID()
	 */
	public int GetProfileID() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#GetSession()
	 */
	public IPTSession GetSession() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#InitializePortletContent()
	 */
	public void InitializePortletContent() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#IsGuestSession(AActivitySpace)
	 */	
	public static boolean IsGuestSession(AActivitySpace owner) {
		// Assume non-guest user.
		return false;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#IsPageAvailable()
	 */
	public boolean IsPageAvailable() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#IsPreviewPage()
	 */
	public boolean IsPreviewPage() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#JoinCommunity()
	 */
	public boolean JoinCommunity() {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SavePage(java.lang.String, com.plumtree.openfoundation.util.XPHashtable)
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData) {
		throw new XPNotImplementedException();
	}



	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetDisplayPortletHeaderDueToError(int, boolean)
	 */
	public void SetDisplayPortletHeaderDueToError(int nPortletIndex, boolean bDisplayHeader) {
		super.SetDisplayPortletHeaderDueToError(nPortletIndex, bDisplayHeader);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetHostPageURI(java.lang.String)
	 */
	public void SetHostPageURI(String strHostPageURI) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetIsPreviewPage(boolean)
	 */
	public void SetIsPreviewPage(boolean _bIsPreviewPage) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetMyPortalModelHelper(com.plumtree.portalpages.browsing.myportal.IMyPortalModelHelper)
	 */
	public void SetMyPortalModelHelper(IMyPortalModelHelper myPortalModelHelper) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetProfileID(int)
	 */
	public boolean SetProfileID(int nProfileID) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetRawHeaders(java.lang.String)
	 */
	public void SetRawHeaders(String strRawHeaders) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetShowJoinCommConfirmPage(boolean)
	 */
	public void SetShowJoinCommConfirmPage(boolean show) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#SetupIntrinsicPortlet(java.lang.String, java.lang.String, int)
	 */
	public void SetupIntrinsicPortlet(String _strPortletClass, String _strStorageName, int _nPortletIndex) {
		throw new XPNotImplementedException();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.MyPortalModel#ShowJoinConfirmPage()
	 */
	public boolean ShowJoinConfirmPage() {
		throw new XPNotImplementedException();
	}
	
	public IXPList GetPortletPreferenceActionsData(int nPortletIndex)
	{
		IXPList arPrefActions = new XPArrayList();
		
		String strPrefsButtonURL = null;
		String strPrefsButtonTitle = null;
		String strImageServerURL = PTConfigHelper.GetImageServerBaseURL(m_asOwner);
		
		boolean bHasPersonalPrefs 	=  GetPortletHasUserPrefsURL(nPortletIndex);
		boolean bHasCommPrefs		=  GetPortletHasCommunityPrefsURL(nPortletIndex);
		boolean bHasAdminPrefs		=  GetPortletHasAdminPrefsURL(nPortletIndex);
		
		if ( bHasPersonalPrefs ) {
			// get link to the community-user-gadget prefs page, because this is a user clicking on edit preferences
			// from within a community or just regular user preference link
			strPrefsButtonURL = GetPortletUserPrefsURL(nPortletIndex);
			strPrefsButtonTitle = m_asOwner.GetString(1846, "ptmsgs_portalbrowsingmsgs");
			
			// Add to list
			FullURL url = new FullURL(strPrefsButtonTitle, strPrefsButtonURL);
			url.SetURLImageType(PTImageType.ACTION_PORTLET_EDIT, strImageServerURL);
			url.SetURLData(PORTLET_PREF_TYPE, PERSONAL_PREF_TYPE);
			arPrefActions.Add(url);
		}
		
		if ( bHasCommPrefs ) {
			String strCommPrefsURL = GetPortletCommunityPrefsURL(nPortletIndex);
			String strCommPrefsTitle 		= m_asOwner.GetString(1847, "ptmsgs_portalbrowsingmsgs"); 

			// Add to list
			FullURL url = new FullURL(strCommPrefsTitle, strCommPrefsURL);
			url.SetURLImageType(PTImageType.ACTION_PORTLET_EDIT, strImageServerURL);
			url.SetURLData(PORTLET_PREF_TYPE, COMMUNITY_PREF_TYPE);
			arPrefActions.Add(url);
			
		}
		
		if ( bHasAdminPrefs ) {
			String strAdminPrefsURL = GetPortletAdminPrefsURL(nPortletIndex);
			String strAdminTitle = m_asOwner.GetString(1848, "ptmsgs_portalbrowsingmsgs");

			// Add to list
			FullURL url = new FullURL(strAdminTitle, strAdminPrefsURL);
			url.SetURLImageType(PTImageType.ACTION_PORTLET_EDIT, strImageServerURL);
			url.SetURLData(PORTLET_PREF_TYPE, ADMIN_PREF_TYPE);
			arPrefActions.Add(url);
			
		}

		return arPrefActions;
	}
}
