/*
 * Created on Dec 17, 2007
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor
{
  /// <summary>
  /// Implementation of the AddPortletsFlyoutAction PTURL DO Data Tag
  /// </summary>
  /// <author>robertz</author>
  public class AddPortletsFlyoutActionDataTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute SORTSPROPS;
    public static readonly OptionalTagAttribute ATTRIB_PROPSCOPE;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    public static readonly OptionalTagAttribute MAX_RESULT_COLUMNS;
    static AddPortletsFlyoutActionDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("addportletsflyoutdata", "URL to add Portlet Flyout Editor on MyPages or Community pages. (The flyout editor allows users to add and " + "remove portlets from the current page.) ");
      ATTRIB_ID = new RequiredTagAttribute("id", "The name of the variable in memory where the PTURL DO data created by this tag is stored. " + "Specify this ID in the data attribute (most commonly the DATAVAR attribute) for any display tag consuming PTURL DO data. " + "Multiple data tags can share the same ID, in which case they are added to a list in the order they were processed. ",
       AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute("scope", "The scope used to store the data. See the Logic tag library for a list of all available scopes. ",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
      SORTSPROPS = new OptionalTagAttribute("sortprops", "The name of the data variable with list of supported sort properties for portlet search result.",
       AttributeType.STRING, "");
      ATTRIB_PROPSCOPE = new OptionalTagAttribute("propscope", "The scope of the portlet sort properties, portlet request by default.",
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
      MAX_RESULT_COLUMNS = new OptionalTagAttribute("maxresultcolumns", "The maximum number of columns used to display results. " + "Used to make sure the search results divide evenly " + "by the number of columns.  Also used in browse mode " + "if there are no subfolders to display.",
       AttributeType.INT, "3");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      IEnvironment env = GetEnvironment();
      IPTURL url = null;
      if (TaskAPIUIMyPages.IsCurrentPageMyPage(TaskAPIUICommon.GetEnvTypeObject(env)))
      {
        url = TaskAPIUIMyPages.GetURLForAddMyPagePortletsFlyout(TaskAPIUICommon.GetEnvTypeObject(env));
        } else
      {
        url = TaskAPIUICommunity.GetURLForAddCommunityPortletsFlyout(TaskAPIUICommon.GetEnvTypeObject(env));
        }
      //RT - Check if initial url is null that means user does not have proper access to flyout editor.		
      if (null == url)
      {
        return null;
      }
      // rob: check if there are any custom sort properties specified
      String propVarName = GetTagAttributeAsString(SORTSPROPS);
      XPArrayList propList = null;
      if (!"".Equals(propVarName))
      {
        Object data = GetState().GetSharedVariable(propVarName, Scope.GetScope(GetTagAttributeAsString(ATTRIB_PROPSCOPE)));
        if (data != null && data is XPArrayList)
        {
          propList = (XPArrayList) data;
        }
      }
      if (propList != null)
      {
        // create a comma separated string of all the specified sort properties
        // estimate size of string buffer
        XPStringBuilder buf = new XPStringBuilder(propList.GetSize() * 5);
        for (int i = 0;i < propList.GetSize();i++)
        {
          HashtableDataObject entry = (HashtableDataObject) propList.GetElement(i);
          buf.Append(entry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID)).Append(",");
          // check if the current entry is the one that is set to the default sort by
          if (entry.GetData(PortletSortPropertyDataTag.DATA_DEFAULTORDERBY) != null)
          {
            // specify to sort by this property id
            url.AddControlParameter(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SORTPROPERTYID,
             entry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID));
          }
        }
        // remove the last comma
        buf.RemoveCharAt(buf.GetLength() - 1);
        url.AddControlParameter(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SEARCH_RETURNPROPIDS,
         buf.ToString());
      }
      // Set the number of search columns being used so that our results will match evenly.
      url.AddControlParameter(ObjSelQueryArguments.MAX_RESULT_COLUMNS, GetTagAttributeAsInt(MAX_RESULT_COLUMNS));
      GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_ID), url,
       Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE)), false);
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new AddPortletsFlyoutActionDataTag();
    }
  }
}