using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor
{
  public class ObjectRenameHelperTag : ATag
  {
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    // required attributes
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute TAG_OBJECTID;
    public static readonly RequiredTagAttribute TAG_OBJECTNAME;
    public static readonly RequiredTagAttribute TAG_CLASSID;
    // optional attributes
    public static readonly OptionalTagAttribute TAG_RENAME_JS_METHOD;
    public static readonly OptionalTagAttribute TAG_SAVE_JS_METHOD;
    public static readonly OptionalTagAttribute TAG_INPUT_PREFIX;
    public static readonly OptionalTagAttribute TAG_SPAN_PREFIX;
    public static readonly OptionalTagAttribute TAG_EDIT_PREFIX;
    public static readonly OptionalTagAttribute TAG_SHOW_PREFIX;
    // default values for optional attributes
    public const String RENAME_JS_METHOD = "PTCommonOpener.showRenameField";
    public const String SAVE_JS_METHOD = "PTCommonOpener.renamePTObject";
    private const String INPUT_PREFIX = "r_text";
    private const String SPAN_PREFIX = "r_span";
    private const String EDIT_PREFIX = "r_edit";
    private const String SHOW_PREFIX = "r_show";
    // attribute outputs with PORTLET scope
    private const String OUT_RENAMEJS = "rename_js";
    private const String OUT_SAVEJS = "save_js";
    private const String OUT_INPUT_ID = "input_id";
    private const String OUT_SPAN_ID = "span_id";
    private const String OUT_EDIT_DIV_ID = "edit_div_id";
    private const String OUT_SHOW_DIV_ID = "show_div_id";
    private const String OUT_ANCHOR_ID = "anchor_id";
    private const String OUT_ISEDITABLE = "isEditable";
    static ObjectRenameHelperTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData("objectrenamehelper", "Provides a rename div around the requested object name.");
      TAG_OBJECTID = new RequiredTagAttribute("objectid", "The object ID of the object to rename.");
      TAG_OBJECTNAME = new RequiredTagAttribute("objectname", "The current name of the object to rename.");
      TAG_CLASSID = new RequiredTagAttribute("classid", "The class ID of the object to rename.");
      TAG_RENAME_JS_METHOD = new OptionalTagAttribute("renamejs", "The optional prefix of the javascript rename function.",
       AttributeType.STRING, RENAME_JS_METHOD);
      TAG_SAVE_JS_METHOD = new OptionalTagAttribute("savejs", "The optional prefix of the javascript save function.",
       AttributeType.STRING, SAVE_JS_METHOD);
      TAG_INPUT_PREFIX = new OptionalTagAttribute("in_prefix", "The optional prefix of the input text.",
       AttributeType.STRING, INPUT_PREFIX);
      TAG_SPAN_PREFIX = new OptionalTagAttribute("span_prefix", "The optional prefix of the text span.",
       AttributeType.STRING, SPAN_PREFIX);
      TAG_EDIT_PREFIX = new OptionalTagAttribute("edit_prefix", "The optional prefix of the edit div.",
       AttributeType.STRING, EDIT_PREFIX);
      TAG_SHOW_PREFIX = new OptionalTagAttribute("show_prefix", "The optional prefix of the show div.",
       AttributeType.STRING, SHOW_PREFIX);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()"></seealso>
    public override HTMLElement DisplayTag()
    {
      XPStringBuilder sb;
      HTMLScript script;
      // get input variables
      String strClassID = GetTagAttributeAsString(TAG_CLASSID);
      String strObjectID = GetTagAttributeAsString(TAG_OBJECTID);
      // check that this user has edit access
      SetStateSharedVariable(OUT_ISEDITABLE, false, Scope.PORTLET_REQUEST,
       false);
      IEnvironment env = GetEnvironment();
      bool bHasEditAccess = HasEditAccess((IPTSession) env.GetUserSession(),
       XPConvert.ToInteger(strClassID), XPConvert.ToInteger(strObjectID));
      if (!bHasEditAccess)
      {
        // DCA - set rename function to just reload page
        // We're reloading the page because IE has a bug that causes the community pages to disappear
        sb = new XPStringBuilder();
        sb.Append("renamePage = function(){\n");
        sb.Append("\t    window.location.reload(true);\n");
        sb.Append("}\n");
        script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        return script;
      }
      // get input variables
      String anchorID = "_" + strClassID + "_" + strObjectID;
      String strRenameJSMethod = GetTagAttributeAsString(TAG_RENAME_JS_METHOD);
      String strSaveJSMethod = GetTagAttributeAsString(TAG_SAVE_JS_METHOD);
      String strInputPre = GetTagAttributeAsString(TAG_INPUT_PREFIX);
      String strSpanPre = GetTagAttributeAsString(TAG_SPAN_PREFIX);
      String strEditPre = GetTagAttributeAsString(TAG_EDIT_PREFIX);
      String strShowPre = GetTagAttributeAsString(TAG_SHOW_PREFIX);
      // generate JS
      String strRenameJS = strRenameJSMethod + "(\'" + strClassID + "\',\'" + strObjectID + "\'); return false;";
      String strSaveJS = strSaveJSMethod + "(\'" + strClassID + "\',\'" + strObjectID + "\'" + ", PTPortalContext.pageName" + ", document.getElementById(\'" + strInputPre + anchorID + "\').value); return false;";
      // set output variables
      SetStateSharedVariable(OUT_ISEDITABLE, true, Scope.PORTLET_REQUEST,
       false);
      SetStateSharedVariable(OUT_ANCHOR_ID, anchorID, Scope.PORTLET_REQUEST,
       false);
      SetStateSharedVariable(OUT_EDIT_DIV_ID, strEditPre + anchorID, Scope.PORTLET_REQUEST,
       false);
      SetStateSharedVariable(OUT_SHOW_DIV_ID, strShowPre + anchorID, Scope.PORTLET_REQUEST,
       false);
      SetStateSharedVariable(OUT_SPAN_ID, strSpanPre + anchorID, Scope.PORTLET_REQUEST,
       false);
      SetStateSharedVariable(OUT_INPUT_ID, strInputPre + anchorID, Scope.PORTLET_REQUEST,
       false);
      SetStateSharedVariable(OUT_RENAMEJS, strRenameJS, Scope.PORTLET_REQUEST,
       false);
      SetStateSharedVariable(OUT_SAVEJS, strSaveJS, Scope.PORTLET_REQUEST,
       false);
      sb = new XPStringBuilder();
      sb.Append("renamePage = function(){\n");
      sb.Append("  var newPageName = document.getElementById(\'" + strInputPre + anchorID + "\').value; \n");
      sb.Append("  setTimeout(\"" + strSaveJSMethod + "(" + strClassID + ", " + strObjectID + ", \'\"+PTPortalContext.pageName+\"\', \'\"+newPageName+\"\');\", 900);\n");
      sb.Append("}\n");
      script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString(sb.ToString());
      return script;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)"></seealso>
    public override bool SupportsAccessStyle(AccessStyles _style)
    {
      // This tag does not display any JavaScript by itself, and therefore
      // supports all access styles.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#Create()"></seealso>
    public override ATag Create()
    {
      return new ObjectRenameHelperTag();
    }
    
    /// <summary>
    /// Helper method to know whether or not the current user has at least EDIT access to the object.
    /// In the case of user MyPages, just checks to ensure the pageID belongs to that user.
    /// </summary>
    /// <param name="_ptSession"></param>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <returns>boolean</returns>
    protected virtual bool HasEditAccess(IPTSession _ptSession, int _nClassID,
     int _nObjectID)
    {
      bool bHasAccess = false;
      try
      {
        switch (_nClassID){
        case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
        case PT_CLASSIDS.PT_CATALOGCARD_ID:
        bHasAccess = _ptSession.GetCatalog().IsCatalogObjectAccessible(_nClassID,
         _nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
        break;
        case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
        bHasAccess = _ptSession.GetAdminCatalog().IsAdminFolderAccessible(_nObjectID,
         PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
        break;
        case PT_CLASSIDS.PT_MYPAGESCONTAINER_ID:
        // the following call will throw an exception if this page is not the current users' myPage.
        // because there are no ACLs on myPages, if the call succeeds, then the user has access to edit it.
        ((IPTPageManager) ((IPTSession) _ptSession).GetPages()).CachedOpenPageInfo(_nObjectID,
         true, false);
        bHasAccess = true;
        break;
        default:
        bHasAccess = _ptSession.GetObjectManagers(_nClassID).IsObjectAccessible(_nObjectID,
         _ptSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
        break;
        }
      }
      catch (Exception e)
      {
      }
      // no access
      return bHasAccess;
    }
  }
}