using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.bea.alui.taglib.portletpageeditor
{
  /// <summary>
  /// This class handles generating pagination links for the portlet flyout
  /// in browse mode.
  /// It is based off the SearchPaginationHelper.
  /// </summary>
  public class PortletBrowsePaginationHelper
  {
    protected AActivitySpace m_asOwner;
    protected IObjectSelectionModelRO m_objectModel;
    protected int m_nPagesToDisplay;
    protected int m_nFirstPageToDisplay;
    protected int m_nLastPageToDisplay;
    protected int m_nCurrentPage;
    protected int m_nLastPage;
    protected int m_nCurrFirst;
    protected int m_nPageSize;
    protected int m_nTotalResults;
    public PortletBrowsePaginationHelper(AActivitySpace _asOwner, IObjectSelectionModelRO _objectModel,
     int _nPagesToDisplay)
    {
      m_asOwner = _asOwner;
      m_objectModel = _objectModel;
      m_nPagesToDisplay = _nPagesToDisplay;
      // Calculate various shared pieces of pagination data that are
      // used in both the main data object and the pages list.
      m_nTotalResults = m_objectModel.GetTotalItems();
      m_nCurrFirst = m_objectModel.GetFirstDisplayableItem();
      // This returns us the number of displayable items for
      // browse mode, corrected for the number of columns so that
      // it's evenly divisible.
      m_nPageSize = m_objectModel.GetItemsPerPage();
      m_nLastPage = m_nTotalResults / m_nPageSize;
      // If we spill over into the next page, add 1
      if ((m_nTotalResults % m_nPageSize > 0) && (m_nTotalResults > m_nPageSize))
      {
        m_nLastPage+=1;
      }
      m_nCurrentPage = (m_nCurrFirst - 1) / m_nPageSize;
      m_nFirstPageToDisplay = m_nCurrentPage - m_nPagesToDisplay;
      if (m_nFirstPageToDisplay < 0)
      {
        m_nFirstPageToDisplay = 0;
      }
      m_nLastPageToDisplay = m_nCurrentPage + m_nPagesToDisplay;
      if (m_nLastPageToDisplay > m_nLastPage)
      {
        m_nLastPageToDisplay = m_nLastPage;
      }
    }
    
    /// <summary>
    /// This method creates the main data object and adds the pagination data to it.
    /// </summary>
    /// <returns></returns>
    public virtual IDataObject createMainData()
    {
      HashtableDataObject htObject = new HashtableDataObject();
      htObject.SetData(PaginationDataConstants.TOTAL_RESULTS, XPConvert.ToString(m_nTotalResults));
      htObject.SetData(PaginationDataConstants.NUM_PER_PAGE, XPConvert.ToString(m_nPageSize));
      htObject.SetData(PaginationDataConstants.START_COUNT, XPConvert.ToString(m_nCurrFirst));
      // If there is only one page
      if (m_nTotalResults <= m_nPageSize)
      {
        htObject.SetData(PaginationDataConstants.END_COUNT, XPConvert.ToString(m_nTotalResults));
        } else
      {
        htObject.SetData(PaginationDataConstants.END_COUNT, XPConvert.ToString(m_nCurrFirst + m_nPageSize - 1));
        }
      // First, check whether we can display a "previous" link.
      int prevFirst = 0;
      if (m_nCurrFirst > m_nPageSize)
      {
        // we're at least one page beyond the beginning;
        // we can back up one page
        prevFirst = m_nCurrFirst - m_nPageSize;
      } else
      if (m_nCurrFirst > 1)
      {
        // odd case: we're partway thru the first page.
        // how did we get here?
        // display a link to go back to the first result
        prevFirst = 1;
      }
      if (0 < prevFirst)
      {
        String url = MakeURL(prevFirst);
        htObject.SetData(PaginationDataConstants.PREVIOUS_URL, url);
      }
      htObject.SetData(PaginationDataConstants.LAST_PAGE, XPConvert.ToString(m_nLastPage));
      // DCA - display first page link 
      if (m_nFirstPageToDisplay > 0)
      {
        htObject.SetData(PaginationDataConstants.FIRST_PAGE_URL, MakeURL(1));
        }
      if (m_nLastPageToDisplay < (m_nLastPage - 1))
      {
        htObject.SetData(PaginationDataConstants.LAST_PAGE_URL, MakeURL(((m_nLastPage - 1) * m_nPageSize) + 1));
        }
      // Finally, handle the "next" link
      // Calculate start of next page
      int nextFirst = m_nCurrFirst + m_nPageSize;
      // Check that "next" won't go beyond the end of
      // the result set
      if (nextFirst > m_nTotalResults)
      {
        nextFirst = 0;
      }
      // if displaying "next" link
      if (0 != nextFirst)
      {
        int numOnNextPage = m_nTotalResults - nextFirst + 1;
        if (numOnNextPage > m_nPageSize)
        {
          numOnNextPage = m_nPageSize;
        }
        htObject.SetData(PaginationDataConstants.NEXT_URL, MakeURL(nextFirst));
        }
      return htObject;
    }
    
    /// <summary>
    /// Create the list of pages.
    /// </summary>
    /// <returns></returns>
    public virtual IXPList createPageList()
    {
      IXPList listPages = new XPArrayList();
      // Output the data for the display page links
      HashtableDataObject htPageData;
      for (int page = m_nFirstPageToDisplay;page <= m_nLastPageToDisplay;
      page++)
      {
        if (page < 0)
        {
          continue;
        }
        int firstResultInPage = (page * m_nPageSize) + 1;
        int lastResultInPage = (firstResultInPage + m_nPageSize) - 1;
        // If we're over the total number of results
        if (firstResultInPage > m_nTotalResults)
        {
          if (page == 0)
          {
            htPageData = new HashtableDataObject();
            htPageData.SetData(PaginationDataConstants.PAGE_NUMBER, XPConvert.ToString(page + 1));
            htPageData.SetData(PaginationDataConstants.START_COUNT, "1");
            htPageData.SetData(PaginationDataConstants.END_COUNT, "1");
            listPages.Add(htPageData);
          }
          // we're all done
          break;
        }
        // If this is the last page
        if (lastResultInPage > m_nTotalResults)
        {
          // show the exact number of results we'll be displaying
          lastResultInPage = m_nTotalResults;
        }
        htPageData = new HashtableDataObject();
        htPageData.SetData(PaginationDataConstants.PAGE_NUMBER, XPConvert.ToString(page + 1));
        htPageData.SetData(PaginationDataConstants.START_COUNT, XPConvert.ToString(firstResultInPage));
        htPageData.SetData(PaginationDataConstants.END_COUNT, XPConvert.ToString(lastResultInPage));
        // If this isn't the current page
        if (page != m_nCurrentPage)
        {
          htPageData.SetData(PaginationDataConstants.PAGINATION_URL, MakeURL(firstResultInPage));
          }
        listPages.Add(htPageData);
      }
      return listPages;
    }
    
    /// <summary>
    /// Helper method to generate a pagination URL for browse mode.
    /// </summary>
    /// <param name="_nFirstResultInPage"></param>
    /// <returns>a pagination URL for browse mode.</returns>
    public virtual String MakeURL(int _nFirstResultInPage)
    {
      ASURL asURL = new ASURL(m_asOwner);
      asURL.SetLinkGetCachedSpace(m_asOwner);
      asURL.SetControl(ObjectSelectionActionControl.STR_MVC_CLASS_NAME);
      asURL.AddControlArgument(ObjectSelectionActionControl.FIRST_ITEM_TO_DISPLAY,
       _nFirstResultInPage);
      return asURL.GetURLAsString();
    }
  }
}