using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.browsing.objectselection.flyout;
using com.plumtree.portalpages.browsing.objectselection.portlets;
using com.plumtree.portalpages.browsing.portletpreview;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor
{
  public class PortletJSTag : ATag
  {
    public const String ATTRIBUTE_DESCRIPTION = "If this attribute is not present, the javascript will not be displayed. " + "The value of this attribute will be the name of the javascript function.";
    public const String SWAP_DESCRIPTION = "In order to change the state of a portlet from added to removed and vice-versa, " + "the portlet div needs to have the current type in the class attribute " + "(i.e. ali-edit-portlets-narrow) and the other type in the swapclass attribute " + "(i.e. ali-edit-portlets-chosen).  The add and remove portlet links both need to " + "be displayed on the page with the style attribute being \'display:none;\' or " + "\'display:visible;\', depending on which link is supposed to be shown.  The preview " + "portlet link needs to have an onpage attribute with a value of \'true\' or \'false\' " + "depending on whether or not the portlet is on the page.  The portlet div and add " + "and remove portlet links and preview portlet link all need to have ids of " + "\'portletxx\', \'add-portletxx\', \'remove-portletxx\', and \'preview-portletxx\' where " + "\'xx\' is the id of the portlet.";
    public const String SWAP_PORTLET_JS = "swapPortlet";
    public const String ADD_PORTLET_PREVIEW_JS = "addPortletFromPreview";
    public const String POPUP_REFERENCE = "popupWindow";
    public const String PORTLET_DIV_ID_PREFIX = "pt-portlet-";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly OptionalTagAttribute ADD_NAME;
    public static readonly OptionalTagAttribute REMOVE_NAME;
    public static readonly OptionalTagAttribute PREVIEW_NAME;
    public static readonly OptionalTagAttribute INVITATION_NAME;
    public static readonly OptionalTagAttribute ADD_BUNDLE_NAME;
    public static readonly OptionalTagAttribute OPEN_BUNDLE_NAME;
    public static readonly OptionalTagAttribute SORT_BY_PROPERTY_NAME;
    public static readonly OptionalTagAttribute ATTRIB_HANDLE_PAGERENAME;
    public static readonly RequiredTagAttribute ATTRIB_FLYOUT_ID;
    static PortletJSTag()
    {
      ATTRIB_FLYOUT_ID = PortletPageEditorTagLibraryData.ATTRIB_FLYOUTID;
      ADD_NAME = new OptionalTagAttribute("add", "Used to insert a javascript function to add a portlet to the page. " + ATTRIBUTE_DESCRIPTION + " " + "The function has one argument: portlet ID. " + SWAP_DESCRIPTION,
       AttributeType.STRING, "");
      REMOVE_NAME = new OptionalTagAttribute("remove", "Used to insert a javascript function to remove a portlet from the page. " + ATTRIBUTE_DESCRIPTION + " " + "The function has one argument: portlet ID. " + SWAP_DESCRIPTION,
       AttributeType.STRING, "");
      PREVIEW_NAME = new OptionalTagAttribute("preview", "Used to insert a javascript function to preview a portlet. " + ATTRIBUTE_DESCRIPTION + " " + "The function has three arguments: portlet ID, portlet type (" + PortletTypes.NARROW.ToString() + " and " + PortletTypes.WIDE.ToString() + "), " + "and whether or not the portlet is on the page (i.e. this.attributes.onpage.nodeValue).",
       AttributeType.STRING, "");
      INVITATION_NAME = new OptionalTagAttribute("invitation", "Used to insert a javascript function to display a popup " + "with an invitation link to the portlet. " + ATTRIBUTE_DESCRIPTION + " " + "The function has one argument: portlet invitation ID.",
       AttributeType.STRING, "");
      ADD_BUNDLE_NAME = new OptionalTagAttribute("addbundle", "Used to insert a javascript function to add a portlet bundle to the page. " + ATTRIBUTE_DESCRIPTION + " " + "The function has one argument: portlet bundle ID.",
       AttributeType.STRING, "");
      OPEN_BUNDLE_NAME = new OptionalTagAttribute("openbundle", "Used to insert a javascript function to display a popup to " + "open a portlet bundle. " + ATTRIBUTE_DESCRIPTION + " " + "The function has one argument: portlet bundle ID.",
       AttributeType.STRING, "");
      SORT_BY_PROPERTY_NAME = new OptionalTagAttribute("orderbyprop", "Used to insert a javascript function to send a request to" + "sort portlets by a specific property. " + ATTRIBUTE_DESCRIPTION + " " + "The function has one argument: property ID.",
       AttributeType.STRING, "");
      ATTRIB_HANDLE_PAGERENAME = new OptionalTagAttribute("renamehandler",
       "Used to insert a javascript function with flyout specific handling of page rename. ",
       AttributeType.STRING, "");
      // Put this last because the example references the attributes.  Any relatedchildtag
      // references would need to come after this.
      TAG = new TagMetaData("portletjs", "Generates the javascript functions required for portlet preview and invitation. " + PortletPageEditorTagLibraryData.FLYOUT_ONLY,
       ATag.EncodeForTagDoc("<pt:" + PortletPageEditorTagLibraryData.LIBRARY.GetName() + ".portletjs pt:" + ADD_NAME.GetName() + "=\'addPortlet\' pt:" + REMOVE_NAME.GetName() + "=\'removePortlet\' pt:" + PREVIEW_NAME.GetName() + "=\'previewPortlet\' pt:" + INVITATION_NAME.GetName() + "=\'invite\'/>"));
      }
    public override HTMLElement DisplayTag()
    {
      HTMLScriptCollection scripts = new HTMLScriptCollection();
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      // Page ID on the model is deprecated, so use object ID instead.
      int nPageID = objectModel.GetSelectorObjectID();
      int nCommId = objectModel.GetSelectorCommunityFolderID();
      // **********************************************************************************************
      // The JS for preview and invitations somewhat replicates the js in:
      // com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelectionViewHelper.DisplayJavascriptCollection()
      //
      // That is the method responsible for displaying the javascript in the original add portlets page.
      // **********************************************************************************************
      // Insert the various JS functions
      bool bRequiresSwapJS = false;
      bRequiresSwapJS = insertAddPortletJS(scripts, asOwner, nPageID) || bRequiresSwapJS;
      bRequiresSwapJS = insertRemovePortletJS(scripts, asOwner, nPageID) || bRequiresSwapJS;
      bRequiresSwapJS = insertAddPortletBundleJS(scripts, asOwner, nPageID) || bRequiresSwapJS;
      bool bRequiresWindowJS = false;
      bRequiresWindowJS = insertPreviewPortletJS(scripts, asOwner, nPageID) || bRequiresWindowJS;
      bRequiresWindowJS = insertInvitationJS(scripts, asOwner, nPageID) || bRequiresWindowJS;
      bRequiresWindowJS = insertOpenPortletBundleJS(scripts, asOwner, nPageID) || bRequiresWindowJS;
      InsertPropertySortJS(scripts, asOwner, nPageID, nCommId);
      InsertPageRenameJS(scripts, asOwner, nPageID, nCommId);
      InsertPortletReOrderJS(scripts, asOwner, nPageID, nCommId);
      if (bRequiresSwapJS)
      {
        insertSwapJS(scripts, asOwner, nPageID);
      }
      if (bRequiresWindowJS)
      {
        // The open new window scripts that either js method requires.
        HTMLScript include = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        include.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(asOwner) + "opennewwindow.js");
        scripts.AddInnerHTMLElement(include);
      }
      // NOTE: Since this page doesn't have a HEAD tag, we need to display
      // the javascript directly.
      return scripts;
    }
    
    /// <summary>
    /// This method adds the JS for the Add Portlet function.
    /// </summary>
    /// <param name="_scripts">Add the JS into this collection.</param>
    /// <param name="_asOwner">The current Activity Space</param>
    /// <param name="_nPageID">The current page iD</param>
    /// <returns>Whether or not we need the swap JS</returns>
    public virtual bool insertAddPortletJS(HTMLScriptCollection _scripts,
     AActivitySpace _asOwner, int _nPageID)
    {
      String addName = GetTagAttributeAsString(ADD_NAME);
      if ((addName != null) && (addName.Length > 0))
      {
        // Construct the base add URL
        ASURL asurl = new ASURL(_asOwner);
        asurl.SetLinkGetCachedSpace(_asOwner.GetParentSpace());
        asurl.SetControl(AddRemovePortletControl.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(_nPageID));
        asurl.AddControlArgument(ASConstants.PAGE, MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
        XPStringBuilder sb = new XPStringBuilder(200);
        // We need to be able to cache the reference to the preview portlet popup
        // so we can close it after the add portlet AJAX request has finished.
        sb.Append("var ").Append(POPUP_REFERENCE).Append(" = null;\n");
        sb.Append("closePopup = function()\n");
        sb.Append("{\n");
        sb.Append("  ").Append(POPUP_REFERENCE).Append(".close();\n");
        sb.Append("  ").Append(POPUP_REFERENCE).Append(" = null;\n");
        sb.Append("}\n");
        sb.Append("\n");
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append(addName).Append(" = function(id)\n");
        sb.Append("{\n");
        // Swap portlet state (add/remove)
        sb.Append("  ").Append(SWAP_PORTLET_JS).Append("(id);\n");
        sb.Append("  var strURL = \'").Append(asurl.GetURLAsString()).Append("&").Append(AddRemovePortletControl.STR_PORTLET_TO_ADD).Append("=\' + id").Append(";\n");
        sb.Append("  var request = new PTHTTPGETRequest(strURL, handleAddPortletResponse);\n");
        sb.Append("  request.invoke();\n");
        sb.Append("}\n");
        sb.Append("\n");
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append("handleAddPortletResponse = function(resp) {\n");
        sb.Append("\tregion = " + JSHelper.ALIDOJO_OBJECT + ".byId(\'region1\');\n");
        sb.Append("\tif (region) {\n");
        sb.Append("\t\tvar div = document.createElement(\'div\');\n");
        sb.Append("\t\tdiv.innerHTML = resp.responseText;\n");
        sb.Append("\t\tvar portlet = div.firstChild;\n");
        sb.Append("\t\tregion.appendChild(portlet);\n");
        // DCA - add to DND if it is available
        sb.Append("\t\tif ( bea.PortalPageDnD ) {\n");
        sb.Append("\t\t\t" + JSHelper.ALIDOJO_OBJECT + ".addClass(portlet, bea.PortalPageDnD.dojoDndMovableClass);\n");
        sb.Append("\t\t\tvar curSource = new " + JSHelper.ALIDOJO_OBJECT + ".dnd.Source(region);");
        // DCA - we're currently assuming this is the first row, destroy the old one and replace w/ new
        sb.Append("\t\t\tbea.PortalPageDnD.sources[0].destroy();\n");
        sb.Append("\t\t\tbea.PortalPageDnD.sources[0] = curSource;");
        sb.Append("\t\t}\n");
        // We need to close the preview portlet popup after the add
        // portlet AJAX request has finished, otherwise the request
        // will be cancelled.
        sb.Append("\t\tif (").Append(POPUP_REFERENCE).Append(" != null)\n");
        sb.Append("     {\n");
        sb.Append("\t\t  setTimeout(\'closePopup()\', 1);\n");
        sb.Append("\t    }\n");
        sb.Append("\t}\n");
        sb.Append("}\n");
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        _scripts.AddInnerHTMLElement(script);
        // We need the swap JS
        return true;
      }
      // We don't need the swap JS
      return false;
    }
    
    /// <summary>
    /// This method adds the JS for the Remove Portlet function.
    /// </summary>
    /// <param name="_scripts">Add the JS into this collection.</param>
    /// <param name="_asOwner">The current Activity Space</param>
    /// <param name="_nPageID">The current page iD</param>
    /// <returns>Whether or not we need the swap JS</returns>
    public virtual bool insertRemovePortletJS(HTMLScriptCollection _scripts,
     AActivitySpace _asOwner, int _nPageID)
    {
      String removeName = GetTagAttributeAsString(REMOVE_NAME);
      if ((removeName != null) && (removeName.Length > 0))
      {
        // Construct the base remove URL
        ASURL asurl = new ASURL(_asOwner);
        asurl.SetLinkGetCachedSpace(_asOwner.GetParentSpace());
        asurl.SetControl(AddRemovePortletControl.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(_nPageID));
        asurl.AddControlArgument(ASConstants.PAGE, MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
        XPStringBuilder sb = new XPStringBuilder(200);
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append(removeName).Append(" = function(id)\n");
        sb.Append("{\n");
        // Swap portlet state (add/remove)
        sb.Append("  ").Append(SWAP_PORTLET_JS).Append("(id);\n");
        sb.Append("  var strURL = \'").Append(asurl.GetURLAsString()).Append("&").Append(AddRemovePortletControl.STR_PORTLET_TO_REMOVE).Append("=\' + id").Append(";\n");
        sb.Append("  var request = new PTHTTPGETRequest(strURL, handleRemovePortletResponse);\n");
        sb.Append("  request.invoke();\n");
        sb.Append("}\n");
        sb.Append("\n");
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append("handleRemovePortletResponse = function(resp) {\n");
        sb.Append("\tvar portletDivId = resp.responseText;\n");
        sb.Append("\tvar commentIndex = portletDivId.indexOf(\'<\');\n");
        sb.Append("\tif (commentIndex > 0) {\n");
        sb.Append("\t\tportletDivId = portletDivId.substring(0, commentIndex);\n");
        sb.Append("\t}\n");
        sb.Append("\tportlet = " + JSHelper.ALIDOJO_OBJECT + ".byId(portletDivId);\n");
        sb.Append("\tif (portlet) {\n");
        sb.Append("\t\tcolumn = portlet.parentNode;\n");
        sb.Append("\t\tcolumn.removeChild(portlet);\n");
        sb.Append("\t}\n");
        sb.Append("}\n");
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        _scripts.AddInnerHTMLElement(script);
        // We need the swap JS
        return true;
      }
      // We don't need the swap JS
      return false;
    }
    
    /// <summary>
    /// This method adds the JS for swapping the portlet add/remove state.
    /// </summary>
    /// <param name="_scripts">Add the JS into this collection.</param>
    /// <param name="_asOwner">The current Activity Space</param>
    /// <param name="_nPageID">The current page iD</param>
    public virtual void insertSwapJS(HTMLScriptCollection _scripts, AActivitySpace _asOwner,
     int _nPageID)
    {
      String addName = GetTagAttributeAsString(ADD_NAME);
      String removeName = GetTagAttributeAsString(REMOVE_NAME);
      XPStringBuilder sb = new XPStringBuilder(200);
      // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
      sb.Append(SWAP_PORTLET_JS).Append(" = function(id)\n");
      sb.Append("{\n");
      // NOTE: For reserved names like class and style, it's usually safest
      // to use the specific member variable rather than the generic getAttribute().
      // Swap the class of the div controlling the image
      sb.Append("  var portletImg = document.getElementById(\'portlet\' + id);\n");
      // If this portlet isn't displayed in the portlet search list, just return.
      sb.Append("  if (portletImg == null) { return }\n");
      sb.Append("  var origImg = portletImg.src;\n");
      sb.Append("  portletImg.src = portletImg.getAttribute(\'swapsrc\');\n");
      sb.Append("  portletImg.setAttribute(\'swapsrc\', origImg);\n");
      // Swap the link onclick for the anchor around the img
      sb.Append("  var imgAnchor = portletImg.parentNode;\n");
      // If this portlet isn't displayed in the portlet search list, just return.
      sb.Append("  if (imgAnchor == null) { return }\n");
      sb.Append("  var onclickString = imgAnchor.getAttribute(\'onclickstring\');\n");
      sb.Append("  if (onclickString.indexOf(\'").Append(addName).Append("\') > -1) {\n");
      sb.Append("    onclickString = onclickString.replace(\'").Append(addName).Append("\',\'").Append(removeName).Append("\');\n");
      sb.Append("  } else if (onclickString.indexOf(\'").Append(removeName).Append("\') > -1) {\n");
      sb.Append("    onclickString = onclickString.replace(\'").Append(removeName).Append("\',\'").Append(addName).Append("\');\n");
      sb.Append("  }\n");
      sb.Append("  imgAnchor.setAttribute(\'onclickstring\', onclickString);\n");
      sb.Append("  imgAnchor.onclick = function() {eval(onclickString); return false;};\n");
      // Swap the display of the add/remove links
      sb.Append("  var portletAdd = document.getElementById(\'add-portlet\' + id);\n");
      sb.Append("  var portletRemove = document.getElementById(\'remove-portlet\' + id);\n");
      sb.Append("  var origAddStyle = portletAdd.style.display;\n");
      sb.Append("  portletAdd.style.display = portletRemove.style.display;\n");
      sb.Append("  portletRemove.style.display = origAddStyle;\n");
      // Swap whether the portlet is on the page or not
      sb.Append("  var portletPreview = document.getElementById(\'preview-portlet\' + id);\n");
      // Community portlets cannot be previewed, so they won't have this link.
      sb.Append("  if (portletPreview != null) {\n");
      sb.Append("    if (portletPreview.getAttribute(\'isonpage\') == \'true\')\n");
      sb.Append("    {\n");
      sb.Append("      portletPreview.setAttribute(\'isonpage\', \'false\');\n");
      sb.Append("    } else {\n");
      sb.Append("      portletPreview.setAttribute(\'isonpage\', \'true\');\n");
      sb.Append("    }\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString(sb.ToString());
      _scripts.AddInnerHTMLElement(script);
    }
    
    /// <summary>
    /// This method adds the JS for the Preview Portlet function.
    /// </summary>
    /// <param name="_scripts">Add the JS into this collection.</param>
    /// <param name="_asOwner">The current Activity Space</param>
    /// <param name="_nPageID">The current page iD</param>
    /// <returns>Whether or not we need the window opening JS</returns>
    public virtual bool insertPreviewPortletJS(HTMLScriptCollection _scripts,
     AActivitySpace _asOwner, int _nPageID)
    {
      String previewName = GetTagAttributeAsString(PREVIEW_NAME);
      if ((previewName != null) && (previewName.Length > 0))
      {
        // Construct the base preview URL
        ASURL asurl = new ASURL(_asOwner);
        asurl.SetSubSpaceKey("PortletSelection");
        asurl.SetLinkCreateNewSpace(PreviewPortletAS.STR_MVC_CLASS_NAME, _asOwner);
        asurl.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
        asurl.SetDisplayPage(PreviewPortletDP.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(PreviewPortletControl.m_PreviewType, XPConvert.ToString(PreviewPortletModel.SELECTIONPREVIEWHEADER));
        asurl.AddControlArgument(PreviewPortletControl.m_strAddPortletJavascriptOverride,
         "opener." + ADD_PORTLET_PREVIEW_JS);
        XPStringBuilder sb = new XPStringBuilder(200);
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append(previewName).Append(" = function(id, type, onpage)\n");
        sb.Append("{\n");
        sb.Append("  var strURL = \'").Append(asurl.GetURLAsString()).Append("&").Append(PreviewPortletControl.m_strPortletParam).Append("=\' + id + \'&").Append(PreviewPortletControl.m_strPortletChecked).Append("=\' + onpage;\n");
        sb.Append("  if (\'").Append(PortletTypes.NARROW.ToString()).Append("\' == type) {\n");
        sb.Append("    OpenNarrowGadgetPreviewWindow(strURL);\n");
        sb.Append("  } else {\n");
        sb.Append("    OpenWideGadgetPreviewWindow(strURL);\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        // TODO: If they don't specify the add js and don't allow users to add
        // (an unlikely scenario), we probably need some way to remove the add
        // button in the preview popup if adding is disabled.
        // We pass in the name of this JS method in the preview URL
        // so that the preview popup knows how to add the portlet correctly.
        String addName = GetTagAttributeAsString(ADD_NAME);
        if ((addName != null) && (addName.Length > 0))
        {
          // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
          sb.Append(ADD_PORTLET_PREVIEW_JS).Append(" = function(id, popup)\n");
          sb.Append("{\n");
          // NOTE: We can't close the popup here, because that will abort the AJAX request,
          // so we just store it so that the ajax request can close it.
          sb.Append("  ").Append(POPUP_REFERENCE).Append(" = popup;\n");
          sb.Append("  ").Append(addName).Append("(id);\n");
          sb.Append("}\n");
        }
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        _scripts.AddInnerHTMLElement(script);
        // We need the window opening JS.
        return true;
      }
      // We don't require the window opening JS
      return false;
    }
    
    /// <summary>
    /// This method adds the JS for the Invitation function.
    /// </summary>
    /// <param name="_scripts">Add the JS into this collection.</param>
    /// <param name="_asOwner">The current Activity Space</param>
    /// <param name="_nPageID">The current page iD</param>
    /// <returns>Whether or not we need the window opening JS</returns>
    public virtual bool insertInvitationJS(HTMLScriptCollection _scripts,
     AActivitySpace _asOwner, int _nPageID)
    {
      String invitationName = GetTagAttributeAsString(INVITATION_NAME);
      if ((invitationName != null) && (invitationName.Length > 0))
      {
        ASURL asurl = new ASURL(_asOwner);
        asurl.SetLinkGetCachedSpace(_asOwner);
        asurl.SetControl(InvitationPopupControl.STR_MVC_CLASS_NAME);
        asurl.SetDisplayPage(PortletInvitationPopupDP.STR_MVC_CLASS_NAME);
        XPStringBuilder sb = new XPStringBuilder(200);
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append("\n").Append(invitationName).Append(" = function(invitationID)\n");
        sb.Append("{\n");
        sb.Append("  OpenNewWindow(\'").Append(asurl.GetURLAsString()).Append("&").Append(InvitationPopupControl.strInviteIndex).Append("=\' + invitationID").Append(", \'SendToOthers\', \'status=no,toolbar=no,menubar=no,resizable=yes,scrollbars=yes,location=no,width=600,height=250\');\n");
        sb.Append("}\n");
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        _scripts.AddInnerHTMLElement(script);
        // We need the window opening JS.
        return true;
      }
      // We don't require the window opening JS
      return false;
    }
    
    /// <summary>
    /// This method adds the JS for the Add Portlet Bundle function.
    /// </summary>
    /// <param name="_scripts">Add the JS into this collection.</param>
    /// <param name="_asOwner">The current Activity Space</param>
    /// <param name="_nPageID">The current page iD</param>
    /// <returns>Whether or not we need the swap JS</returns>
    public virtual bool insertAddPortletBundleJS(HTMLScriptCollection _scripts,
     AActivitySpace _asOwner, int _nPageID)
    {
      String addName = GetTagAttributeAsString(ADD_BUNDLE_NAME);
      if ((addName != null) && (addName.Length > 0))
      {
        // Construct the base add URL
        ASURL asurl = new ASURL(_asOwner);
        asurl.SetLinkGetCachedSpace(_asOwner.GetParentSpace());
        asurl.SetControl(AddRemovePortletControl.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(_nPageID));
        asurl.AddControlArgument(ASConstants.PAGE, MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
        XPStringBuilder sb = new XPStringBuilder(200);
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append(addName).Append(" = function(id)\n");
        sb.Append("{\n");
        sb.Append("  var strURL = \'").Append(asurl.GetURLAsString()).Append("&").Append(AddRemovePortletControl.STR_PORTLET_BUNDLE_TO_ADD).Append("=\' + id").Append(";\n");
        sb.Append("  var request = new PTHTTPGETRequest(strURL, handleAddPortletBundleResponse);\n");
        sb.Append("  request.invoke();\n");
        sb.Append("}\n");
        sb.Append("\n");
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append("handleAddPortletBundleResponse = function(resp) {\n");
        sb.Append("  region = " + JSHelper.ALIDOJO_OBJECT + ".byId(\'region1\');\n");
        sb.Append("  if (region) {\n");
        sb.Append("    var div = document.createElement(\'div\');\n");
        sb.Append("    div.innerHTML = resp.responseText;\n");
        sb.Append("    if (div.hasChildNodes()) {\n");
        sb.Append("      var elem = div.firstChild;\n");
        sb.Append("      while (elem != null) {\n");
        // Have to do this before we append the child, cuz it changes it's place in the DOM
        sb.Append("        var nextelem = elem.nextSibling;\n");
        // We don't want to add comments, etc...
        sb.Append("        if (elem.tagName == \'DIV\') {\n");
        // DCA - add to DND if it is available
        sb.Append("          if ( bea.PortalPageDnD ) {\n");
        sb.Append("          \t" + JSHelper.ALIDOJO_OBJECT + ".addClass(elem, bea.PortalPageDnD.dojoDndMovableClass);\n");
        sb.Append("          }\n");
        sb.Append("          region.appendChild(elem);\n");
        // Get the div ID and remove 'pt-portlet-', leaving the portlet ID
        sb.Append("          var portletID = elem.getAttribute(\'ID\').substring(").Append(PORTLET_DIV_ID_PREFIX.Length).Append(");\n");
        // We should only need to add portlets, because the AJAX request only returns new portlets,
        // but the method does swap, so we'll assume it's correct.
        sb.Append("          ").Append(SWAP_PORTLET_JS).Append("(portletID);\n");
        sb.Append("        }\n");
        sb.Append("        elem = nextelem;\n");
        sb.Append("      }\n");
        sb.Append("      if ( bea.PortalPageDnD ) {\n");
        sb.Append("      \tvar curSource = new " + JSHelper.ALIDOJO_OBJECT + ".dnd.Source(region);");
        // DCA - we're currently assuming this is the first row, destroy the old one and replace w/ new
        sb.Append("\t\t\tbea.PortalPageDnD.sources[0].destroy();\n");
        sb.Append("      \tbea.PortalPageDnD.sources[0] = curSource;");
        sb.Append("      }\n");
        sb.Append("    }\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        _scripts.AddInnerHTMLElement(script);
        // We need the swap JS
        return true;
      }
      // We don't need the swap JS
      return false;
    }
    
    /// <summary>
    /// This method adds the JS for the Open Portlet Bundle function.
    /// </summary>
    /// <param name="_scripts">Add the JS into this collection.</param>
    /// <param name="_asOwner">The current Activity Space</param>
    /// <param name="_nPageID">The current page iD</param>
    /// <returns>Whether or not we need the window opening JS</returns>
    public virtual bool insertOpenPortletBundleJS(HTMLScriptCollection _scripts,
     AActivitySpace _asOwner, int _nPageID)
    {
      String openName = GetTagAttributeAsString(OPEN_BUNDLE_NAME);
      if ((openName != null) && (openName.Length > 0))
      {
        // Construct the base open URL
        ASURL asurl = new ASURL(_asOwner);
        asurl.SetLinkCreateNewSpace(PortletInBundleSelectionAS.STR_MVC_CLASS_NAME,
         _asOwner);
        asurl.SetSubSpaceKey("bundle");
        asurl.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_MISC));
        asurl.AddControlArgument(PortletInBundleSelectionEditorStartControl.SIMPLE_MODE,
         true);
        asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(_nPageID));
        XPStringBuilder sb = new XPStringBuilder(200);
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append(openName).Append(" = function(id)\n");
        sb.Append("{\n");
        sb.Append("  OpenNewWindow(\'").Append(asurl.GetURLAsString()).Append("&").Append(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID).Append("=\' + id").Append(", \'OpenBundle\', \'status=no,toolbar=no,menubar=no,resizable=yes,scrollbars=yes,location=no,width=600,height=250\');\n");
        sb.Append("}\n");
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        _scripts.AddInnerHTMLElement(script);
        // We need the window opening JS.
        return true;
      }
      // We don't require the window opening JS
      return false;
    }
    public virtual void InsertPropertySortJS(HTMLScriptCollection scripts,
     AActivitySpace owner, int pageId, int commId)
    {
      String sortName = GetTagAttributeAsString(SORT_BY_PROPERTY_NAME);
      if ((sortName != null) && (sortName.Length > 0))
      {
        bool searchURL = false;
        ASURL url = UpdateSortOrderControl.makeURL((ISearchResultModelRO) owner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME),
         owner, null);
        if (url != null)
        {
          url.AddControlArgument(ASConstants.PARENTSPACEID, owner.GetSpaceID());
          url.AddControlArgument(ASConstants.PARENTSPACENAME, owner.GetName());
          searchURL = true;
        } else
        {
          url = new ASURL(owner);
          url.SetLinkGetSpaceIfCached(FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME,
           owner);
          url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
          url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC + "");
          url.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORCOMMUNITYID,
           commId + "");
          url.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID,
           pageId + "");
        }
        XPStringBuilder sb = new XPStringBuilder(200);
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        sb.Append(sortName).Append(" = function(propId)\n");
        sb.Append("{\n");
        if (searchURL)
        {
          sb.Append("  var url = \'" + url.GetURLAsString() + "&" + UpdateSortOrderControl.ORDER_BY_DATA + "=\'+propId;\n");
          } else
        {
          sb.Append("  var url = \'" + url.GetURLAsString() + "&" + ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SORTPROPERTYID + "=\'+propId;\n");
          }
        String responseHandlerName = FlyoutJSTag.FLYOUT_OBJECT + GetTagAttributeAsString(ATTRIB_FLYOUT_ID) + "." + FlyoutJSTag.ADD_CONTENT;
        sb.Append("  var request = new PTHTTPGETRequest(url, " + responseHandlerName + ");\n");
        sb.Append("  request.invoke();\n");
        sb.Append("}\n");
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        scripts.AddInnerHTMLElement(script);
      }
    }
    public virtual void InsertPageRenameJS(HTMLScriptCollection scripts, AActivitySpace owner,
     int pageId, int commId)
    {
      String sortName = GetTagAttributeAsString(ATTRIB_HANDLE_PAGERENAME);
      XPStringBuilder sb = new XPStringBuilder(200);
      if ((sortName != null) && (sortName.Length > 0))
      {
        // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
        // this method is called by the rename helper tag
        sb.Append(sortName).Append(" = function(classId, objId, oldName, newName)\n");
        sb.Append("{\n");
        // don't do anything
        sb.Append("  if ( oldName == newName ) { return; }\n");
        sb.Append("  PTPortalContext.prevPageName = PTPortalContext.pageName;\n");
        sb.Append("  PTPortalContext.pageName = newName;\n");
        sb.Append("  PTPortalContext.pageRenamed = true;\n");
        // call into the default rename method
        sb.Append("  " + ObjectRenameHelperTag.SAVE_JS_METHOD + "(classId, objId, oldName, newName);\n");
        sb.Append("}\n");
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(sb.ToString());
        scripts.AddInnerHTMLElement(script);
      }
    }
    public virtual void InsertPortletReOrderJS(HTMLScriptCollection scripts,
     AActivitySpace owner, int pageId, int commId)
    {
      // create the url 
      CommonOpenerOpenASURL reUrl = new CommonOpenerOpenASURL("", owner.GetParentSpace().GetName(),
       owner);
      reUrl.AddControlParameter(ASConstants.CONTROL, ReorderPortletsControl.STR_MVC_CLASS_NAME);
      if (TaskAPIUICommunity.IsCurrentPageCommunityPage(owner))
      {
        reUrl.AddControlParameter(SetCommunityControl.STR_COMMUNITY_ID, TaskAPIUICommunity.GetCurrentCommunityID(owner));
        reUrl.AddControlParameter(SetCommunityControl.STR_PAGE_ID, TaskAPIUICommunity.GetCurrentCommunityPageID(owner));
        } else
      {
        reUrl.AddControlParameter(SetPageControl.STR_PAGE_ID, TaskAPIUIMyPages.GetCurrentMyPageID(owner));
        }
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("if ( bea.PortalPageDnD ) {\n");
      sb.Append("   bea.PortalPageDnD.reorderURL = \'" + reUrl.GetFullURL() + "\';\n");
      sb.Append("}\n");
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString(sb.ToString());
      scripts.AddInnerHTMLElement(script);
    }
    public override ATag Create()
    {
      return new PortletJSTag();
    }
  }
}