using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor
{
  public class PortletPaginationDataTag : ATag
  {
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    public static readonly RequiredTagAttribute ATTRIB_PAGES_LIST;
    public static readonly OptionalTagAttribute ATTRIB_PAGES_TO_DISPLAY;
    public static readonly OptionalTagAttribute PAGINATE_NAME;
    public static readonly RequiredTagAttribute ATTRIB_FLYOUT_ID;
    static PortletPaginationDataTag()
    {
      ATTRIB_FLYOUT_ID = PortletPageEditorTagLibraryData.ATTRIB_FLYOUTID;
      ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC, AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
      ATTRIB_PAGES_LIST = new RequiredTagAttribute(PaginationDataConstants.ATTRIB_PAGESLIST_NAME,
       PaginationDataConstants.ATTRIB_PAGESLIST_DESCRIPTION, AttributeType.STRING);
      ATTRIB_PAGES_TO_DISPLAY = new OptionalTagAttribute(PaginationDataConstants.ATTRIB_NUM_PAGES_NAME,
       PaginationDataConstants.ATTRIB_NUM_PAGES_DESCRIPTION, AttributeType.INT,
       PaginationDataConstants.ATTRIB_NUM_PAGES_DEFAULT);
      PAGINATE_NAME = new OptionalTagAttribute("paginate", "Used to insert a javascript function to send a request to" + "paginate through the results. " + "The function has one argument: the first result to display.",
       AttributeType.STRING, "paginate");
      TAG = new TagMetaData(PaginationDataConstants.TAG_NAME, PaginationDataConstants.MAIN_DESCRIPTION_PREFIX + "the search results " + PaginationDataConstants.MAIN_DESCRIPTION_SUFFIX + PaginationDataConstants.MAIN_DATA_DESCRIPTION + ATag.EncodeForTagDoc("<br/>") + PaginationDataConstants.PAGES_DATA_DESCRIPTION,
       PaginationDataConstants.EXAMPLE);
    }
    public override HTMLElement DisplayTag()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      if (objectModel == null)
      {
        throw new XPIllegalStateException("This tag requires a page with the ObjectSelectionModel. None was found in the current ActivitySpace.");
        }
      ISearchResultModelRO searchModel = (ISearchResultModelRO) asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
      bool bSearch = objectModel.GetDisplaySearch();
      int pagesToDisplay = GetTagAttributeAsInt(ATTRIB_PAGES_TO_DISPLAY);
      IDataObject mainData;
      IXPList pagesList;
      if (bSearch)
      {
        SearchPaginationHelper searchHelper = new SearchPaginationHelper(asOwner,
         searchModel, new PortletSearchURLHelper(), pagesToDisplay);
        mainData = searchHelper.createMainData();
        pagesList = searchHelper.createPageList();
      } else
      {
        PortletBrowsePaginationHelper browseHelper = new PortletBrowsePaginationHelper(asOwner,
         objectModel, pagesToDisplay);
        mainData = browseHelper.createMainData();
        pagesList = browseHelper.createPageList();
      }
      // Get the tag scope
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      // Store the main data object
      GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_ID), mainData,
       tagScope, true);
      // Store the page list
      if (pagesList != null && pagesList.GetSize() > 0)
      {
        GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_PAGES_LIST),
         pagesList, tagScope, true);
      }
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(createPaginationJS(asOwner));
      result.AddInnerHTMLElement(ProcessTagBody());
      return result;
    }
    
    /// <summary>
    /// This method creates the pagination JS.
    /// </summary>
    /// <param name="owner"></param>
    /// <returns></returns>
    public virtual HTMLScript createPaginationJS(AActivitySpace owner)
    {
      // NOTE: This JS just gets any URL.  This could be shared.
      XPStringBuilder sb = new XPStringBuilder(200);
      // We need to build js funcs like "name = function(args)" for evaling js with AJAX requests.
      sb.Append(GetTagAttributeAsString(PAGINATE_NAME)).Append(" = function(url)\n");
      sb.Append("{\n");
      String responseHandlerName = FlyoutJSTag.FLYOUT_OBJECT + GetTagAttributeAsString(ATTRIB_FLYOUT_ID) + "." + FlyoutJSTag.ADD_CONTENT;
      sb.Append("  var request = new PTHTTPGETRequest(url, " + responseHandlerName + ");\n");
      sb.Append("  request.invoke();\n");
      sb.Append("}\n");
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString(sb.ToString());
      return script;
    }
    public override ATag Create()
    {
      return new PortletPaginationDataTag();
    }
  }
}