using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor
{
  /// <summary>
  /// This tag returns a list of order by property entries. Custom order by properties are specified
  /// with the 
  /// {@link PortletSortPropertyEntry} tag 
  /// </summary>
  /// <author>rozhang</author>
  public class PortletSortPropertyDataTag : ATag
  {
    // This needs to be out side the static block so we can reference it
    // properly in the PortletDataTag.
    public const String TAG_NAME = "sortpropertiesdata";
    public const String DATAVARNAME_PROPENTRIES = "sortPropEntries";
    public const String DATA_OBJECTNAME = "title";
    public const String DATA_OBJECTID = "id";
    public const String DATA_DEFAULTPROP = "default";
    public const String DATA_CUSTOMPROP = "custom";
    public const String DATA_DEFAULTORDERBY = "defaultsort";
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_ID;
    public static readonly OptionalTagAttribute ATTRIB_SCOPE;
    public static readonly OptionalTagAttribute ATTRIB_INCLUDEDEFAULTPROPS;
    public static readonly OptionalTagAttribute ATTRIB_DEFAULTPROPSFIRST;
    public static readonly OptionalTagAttribute ATTRIB_DEFAULTSORTPROPID;
    public static readonly String EXAMPLE = ATag.EncodeForTagDoc("<pt:portletpageeditor.sortpropertiesdata pt:id=\"sortprops\" ><br/>" + "  <pt:portletpageeditor.sortpropertyentry pt:propid=\"200\" pt:proptitle=\"Custom Sort Ascending\"><br/>" + "  <pt:portletpageeditor.sortpropertyentry pt:propid=\"-200\" pt:proptitle=\"Custom Sort Descending\"><br/>" + "</pt:portletpageeditor.sortpropertiesdata><br/>");
    public static readonly String INIT_WARNING = "NOTE: This tag and the " + PortletDataTag.TAG.GetName() + " tag must be displayed before " + "the other portletpageeditor tags so the page can be initialized properly.";
    static PortletSortPropertyDataTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(TAG_NAME, "Sets a collection of properties used to specify sort order. " + "Default properties include object name and last modified date in ascending and descending order. " + "Additional order by properties are defined by adding sortpropertyentry tags in the body. " + INIT_WARNING,
       EXAMPLE);
      ATTRIB_ID = new RequiredTagAttribute("id", CommonTagAttributeConstants.ATTRIB_ID_DESC,
       AttributeType.STRING);
      ATTRIB_SCOPE = new OptionalTagAttribute("scope", CommonTagAttributeConstants.ATTRIB_SCOPE_DESC,
       AttributeType.STRING, Scope.PORTLET_REQUEST.ToString());
      ATTRIB_INCLUDEDEFAULTPROPS = new OptionalTagAttribute("usedefprop",
       "Defined whether or not to include the default sort properties in the list. " + "Only set the value to false if additional custom properties havs been specified. " + "True by default.",
       AttributeType.BOOLEAN, "true");
      ATTRIB_DEFAULTPROPSFIRST = new OptionalTagAttribute("defpropfirst",
       "Defines whether or not to display the default sort properties before or after custom properties. " + "This attribute is not used if no custom properties has been specified or if " + "default properties are not included. True by default.",
       AttributeType.BOOLEAN, "true");
      ATTRIB_DEFAULTSORTPROPID = new OptionalTagAttribute("defaultsort", "Specifies which custom properties values (extended object data) to retrieve with each associated portlet. " + "The attribute takes a comma separated list of property object IDs.",
       AttributeType.INT, -PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED + "");
      }
    public override HTMLElement DisplayTag()
    {
      AActivitySpace space = (AActivitySpace) GetEnvironment();
      // the list of entries to set
      XPArrayList dataList = new XPArrayList();
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
      GetState().SetSharedVariable(strDataReference, dataList, tagScope, true);
      XPArrayList propEntries = new XPArrayList();
      // set the list of sort property entries for the potential child tags to set
      GetState().SetVariable(DATAVARNAME_PROPENTRIES, propEntries, Scope.TAG);
      // process any child tags that set prop entries
      ProcessTagBody();
      bool defPropsFirst = GetTagAttributeAsBoolean(ATTRIB_DEFAULTPROPSFIRST);
      bool includeDefProps = GetTagAttributeAsBoolean(ATTRIB_INCLUDEDEFAULTPROPS);
      if (defPropsFirst && includeDefProps)
      {
        dataList.AddRange(GetDefaultSortProperties(space));
      }
      int defPropId = GetTagAttributeAsInt(ATTRIB_DEFAULTSORTPROPID);
      // add entry custom sort property entries to data list 
      for (int i = 0;i < propEntries.GetSize();i++)
      {
        HashtableDataObject entry = (HashtableDataObject) propEntries.GetElement(i);
        entry.SetData(DATA_CUSTOMPROP, "true");
        if (defPropId == XPConvert.ToInteger(entry.GetData(DATA_OBJECTID)))
        {
          entry.SetData(DATA_DEFAULTORDERBY, "true");
        }
        dataList.Add(entry);
      }
      if (!defPropsFirst && includeDefProps)
      {
        dataList.AddRange(GetDefaultSortProperties(space));
      }
      return null;
    }
    
    /// <summary>
    /// Helper method to create the default sort properties
    /// </summary>
    /// <returns></returns>
    public virtual XPArrayList GetDefaultSortProperties(IEnvironment env)
    {
      AActivitySpace space = (AActivitySpace) env;
      XPArrayList list = new XPArrayList();
      int defPropId = GetTagAttributeAsInt(ATTRIB_DEFAULTSORTPROPID);
      String name = space.GetString(1927, ResourceConstants.PORTALBROWSINGMSGS);
      String modified = space.GetString(1928, ResourceConstants.PORTALBROWSINGMSGS);
      String asc = space.GetString(1929, ResourceConstants.PORTALBROWSINGMSGS);
      String desc = space.GetString(1930, ResourceConstants.PORTALBROWSINGMSGS);
      HashtableDataObject nameAsc = new HashtableDataObject();
      nameAsc.SetData(DATA_OBJECTNAME, XPResourceManager.FormatMessage(asc,
       name));
      nameAsc.SetData(DATA_OBJECTID, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME + "");
      nameAsc.SetData(DATA_DEFAULTPROP, "true");
      if (defPropId == PT_INTRINSICS.PT_PROPERTY_OBJECTNAME)
      {
        nameAsc.SetData(DATA_DEFAULTORDERBY, "true");
      }
      HashtableDataObject nameDesc = new HashtableDataObject();
      nameDesc.SetData(DATA_OBJECTNAME, XPResourceManager.FormatMessage(desc,
       name));
      nameDesc.SetData(DATA_OBJECTID, -PT_INTRINSICS.PT_PROPERTY_OBJECTNAME + "");
      nameDesc.SetData(DATA_DEFAULTPROP, "true");
      if (defPropId == -PT_INTRINSICS.PT_PROPERTY_OBJECTNAME)
      {
        nameDesc.SetData(DATA_DEFAULTORDERBY, "true");
      }
      HashtableDataObject modAsc = new HashtableDataObject();
      modAsc.SetData(DATA_OBJECTNAME, XPResourceManager.FormatMessage(asc,
       modified));
      modAsc.SetData(DATA_OBJECTID, PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED + "");
      modAsc.SetData(DATA_DEFAULTPROP, "true");
      if (defPropId == PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED)
      {
        modAsc.SetData(DATA_DEFAULTORDERBY, "true");
      }
      HashtableDataObject modDesc = new HashtableDataObject();
      modDesc.SetData(DATA_OBJECTNAME, XPResourceManager.FormatMessage(desc,
       modified));
      modDesc.SetData(DATA_OBJECTID, -PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED + "");
      modDesc.SetData(DATA_DEFAULTPROP, "true");
      if (defPropId == -PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED)
      {
        modDesc.SetData(DATA_DEFAULTORDERBY, "true");
      }
      list.Add(nameAsc);
      list.Add(nameDesc);
      list.Add(modAsc);
      list.Add(modDesc);
      return list;
    }
    
    /// <summary>
    /// Parses a comma separated string with integer values and returns the integer values
    /// in an array
    /// </summary>
    /// <param name="attrib">Tag Attribute with the comma separated string</param>
    /// <returns></returns>
    protected virtual int[] ParsePropertyIDString(ATagAttribute attrib)
    {
      String ids = GetTagAttributeAsString(attrib);
      XPStringTokenizer list = new XPStringTokenizer(ids, ",", false);
      int numIds = list.GetTokenCount();
      int[] idList = new int[numIds];
      int index = 0;
      while (list.HasMoreTokens())
      {
        String strId = list.GetNextToken();
        int id = XPConvert.ToInteger(strId);
        idList[index] = id;
        index++;
      }
      return idList;
    }
    
    /// <summary>
    /// Helper method to compare two integer values and returns a string with "true"
    /// if the two values are identical, "false" otherwise
    /// </summary>
    /// <param name="propId1"></param>
    /// <param name="propId2"></param>
    /// <returns></returns>
    public virtual String GetSelectedStatus(String propId1, int propId2)
    {
      return (XPConvert.ToInteger(propId1) == propId2) ? "true" : "false";
      }
    public override ATag Create()
    {
      return new PortletSortPropertyDataTag();
    }
  }
}