using System;
using junit.framework;
using com.bea.alui.taglib.portletpageeditor;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor.test
{
  public class FlyoutJSTagTest : TestCase
  {
    private const String DIV_ID = "divId";
    private const String ONCLICK = "flyout";
    private const String URL = "http://fakeurl.com";
    private const String HEADER_ID = "header";
    private const String ANCHOR_ID = "anchor";
    private const String FLYOUT_ANCHOR_TEXT = "close";
    private const String FLYIN_ANCHOR_TEXT = "open";
    private AActivitySpace m_environment;
    public FlyoutJSTagTest(String name) : base(name)
    {
    }
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      m_environment = new MockEnvironment();
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new FlyoutJSTag(), FlyoutJSTag.TAG.GetName(), PortletPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
      m_environment = null;
    }
    public virtual void testDisplayJSNoURLNoHeaderBadId()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       FlyoutJSTag.TAG.GetName());
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), "badId");
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
      int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + "badId.wipeIn(\'badId\', true);");
      Assert.assertTrue("The javascript returned is not correct. The string \"" + FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".wipeIn(\'badId\', true);\" should be there.",
       index > 0);
    }
    public virtual void testDisplayJSNoURLNoHeaderBadOnclick()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       FlyoutJSTag.TAG.GetName());
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), "badOnclick");
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
      int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".badOnclick = function(");
      Assert.assertTrue("The javascript returned is not correct. The " + FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".badOnclick function should be there.",
       index > 0);
    }
    public virtual void testDisplayJSNoURL()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       FlyoutJSTag.TAG.GetName());
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_HEADER_ID.GetName(), HEADER_ID);
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
      int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".handleResponse = function(");
      Assert.assertEquals("The javascript returned is not correct. The " + FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".handleResponse function should not be there.",
       -1, index);
    }
    public virtual void testDisplayJS()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       FlyoutJSTag.TAG.GetName());
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_URL.GetName(), URL);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_HEADER_ID.GetName(), HEADER_ID);
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
      int index = XPStringUtility.IndexOf(result.GetInnerHTML(), ONCLICK);
      Assert.assertTrue("The javascript returned is not correct. The " + ONCLICK + " function should be there.",
       index > 0);
      index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText = function(");
      Assert.assertEquals("The javascript returned is not correct. The " + FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText function should not be there.",
       -1, index);
    }
    public virtual void testDisplayJSSwapAnchorText()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       FlyoutJSTag.TAG.GetName());
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_URL.GetName(), URL);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_HEADER_ID.GetName(), HEADER_ID);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ANCHOR_ID.GetName(), ANCHOR_ID);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ANCHOR_TEXT.GetName(),
       FLYOUT_ANCHOR_TEXT);
      helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYIN_ANCHOR_TEXT.GetName(),
       FLYIN_ANCHOR_TEXT);
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
      int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText = function(");
      Assert.assertTrue("The javascript returned is not correct. The " + FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText function should be there.",
       index > 0);
    }
  }
}