using System;
using junit.framework;
using com.bea.alui.taglib.portletpageeditor;
using com.bea.alui.taglib.portletpageeditor.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor.test
{
  public class TestPortletBrowseBreadCrumbDataTag : TestCase
  {
    private static String ID_VALUE = "breadcrumbs";
    private int breadCrumb1Id = 200;
    private String breadCrumb1Name = "breadcrumb 1";
    private int breadCrumb2Id = 201;
    private String breadCrumb2Name = "breadcrumb 2";
    private AActivitySpace m_environment;
    private MockObjectSelectionModel m_objModel;
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      MockConfigHelper helper = new MockConfigHelper();
      ConfigService.setTestInstance(helper);
      MockPTConfigHelper ptHelper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(ptHelper);
      MockPTQueryResult qrBreadCrumbs = new MockPTQueryResult();
      // False means the data needs to be flipped.
      qrBreadCrumbs.SetData(new int[]{PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME},
       new Object[][]{new Object[]{breadCrumb1Id, breadCrumb1Name}, new Object[]{breadCrumb2Id,
       breadCrumb2Name}}, false);
      IASQueryResult breadCrumbsPath = new ASQueryResultWrapper(qrBreadCrumbs);
      m_objModel = new MockObjectSelectionModel();
      m_objModel.SetBreadCrumbPath(breadCrumbsPath);
      m_environment = new MockEnvironment();
      ((MockEnvironment) m_environment).m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
       m_objModel);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletBrowseBreadCrumbDataTag(), PortletBrowseBreadCrumbDataTag.TAG.GetName(),
       PortletPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <seealso cref="TestCase#tearDown()"></seealso>
    public override void tearDown()
    {
      base.tearDown();
      m_environment = null;
      m_objModel = null;
    }
    public virtual void testDisplayNoBreadCrumbs()
    {
      // Set to search mode.
      m_objModel.m_bDisplaySearch = true;
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletBrowseBreadCrumbDataTag.TAG.GetName());
      helper.AddPTAttribute(PortletBrowseBreadCrumbDataTag.ATTRIB_ID.GetName(),
       ID_VALUE);
      helper.AddPTAttribute(PortletBrowseBreadCrumbDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      Assert.assertEquals("Checking that bread crumbs tag did not output any HTML.",
       "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      Assert.assertNotNull("Checking that bread crumbs list exists.", ssVariable);
      IXPList breadCrumbs = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("Checking that no bread crumbs were stored in search mode.",
       0, breadCrumbs.GetSize());
    }
    public virtual void testDisplayBreadCrumb()
    {
      XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletBrowseBreadCrumbDataTag.TAG.GetName());
      helper.AddPTAttribute(PortletBrowseBreadCrumbDataTag.ATTRIB_ID.GetName(),
       ID_VALUE);
      helper.AddPTAttribute(PortletBrowseBreadCrumbDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = helper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      Assert.assertEquals("Checking that bread crumbs tag did not output any HTML.",
       "", strResult);
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // for some reason the names are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + ID_VALUE);
      IXPList breadCrumbs = (IXPList) ssVariable.GetValue();
      Assert.assertEquals("The size of the bread crumbs list in memory is incorrect.",
       m_objModel.GetBreadCrumbPath().GetCount(), breadCrumbs.GetSize());
      IDataObject dataObject = (IDataObject) breadCrumbs.GetElement(0);
      String name = dataObject.GetData(PortletBrowseBreadCrumbDataTag.NAME);
      Assert.assertEquals("Wrong name returned for breadCrumb1.", breadCrumb1Name,
       name);
      String id = dataObject.GetData(PortletBrowseBreadCrumbDataTag.ID);
      Assert.assertEquals("Wrong id returned for breadCrumb1.", breadCrumb1Id,
       XPConvert.ToInteger(id));
      dataObject = (IDataObject) breadCrumbs.GetElement(1);
      name = dataObject.GetData(PortletBrowseBreadCrumbDataTag.NAME);
      Assert.assertEquals("Wrong name returned for breadCrumb2.", breadCrumb2Name,
       name);
      id = dataObject.GetData(PortletBrowseBreadCrumbDataTag.ID);
      Assert.assertEquals("Wrong id returned for breadCrumb2.", breadCrumb2Id,
       XPConvert.ToInteger(id));
    }
  }
}