using System;
using com.bea.alui.taglib.portletpageeditor;
using com.bea.alui.taglib.portletpageeditor.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.mock.search;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
using junit.framework;
namespace com.bea.alui.taglib.portletpageeditor.test
{
  /// <summary>
  /// This class tests that the portlet data outputs the right data for the portlets.
  /// In general, the tests build up a markup array, pass it to the tag engine, and then
  /// verify the results.
  /// </summary>
  public class TestPortletDataTag : TestCase
  {
    public const String DATA_ID = "myID";
    // Portlet 1 data
    public const String PORTLET_1_NAME = "my First Portlet";
    public const String PORTLET_1_DESCRIPTION = "my First Portlet description";
    public static readonly int PORTLET_1_CLASS_ID = PT_CLASSIDS.PT_GADGET_ID;
    public const int PORTLET_1_OBJECT_ID = 345;
    public static readonly int PORTLET_1_GADGET_ALIGNMENT = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW;
    public static readonly int PORTLET_1_GADGET_TYPE = PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL;
    // Portlet 1 results
    public static readonly String PORTLET_1_TYPE = PortletTypes.NARROW.ToString();
    public const bool PORTLET_1_PREVIEW_ENABLED = true;
    public const bool PORTLET_1_IS_ON_PAGE = true;
    // Portlet 2 data
    public const String PORTLET_BUNDLE_2_NAME = "my First Portlet Bundle";
    public const String PORTLET_BUNDLE_2_DESCRIPTION = "my First Portlet Bundle description";
    public static readonly int PORTLET_BUNDLE_2_CLASS_ID = PT_CLASSIDS.PT_GADGETBUNDLE_ID;
    public const int PORTLET_BUNDLE_2_OBJECT_ID = 658;
    // Portlet 2 results
    public static readonly String PORTLET_BUNDLE_2_TYPE = PortletTypes.BUNDLE.ToString();
    public const bool PORTLET_BUNDLE_2_PREVIEW_ENABLED = false;
    public const bool PORTLET_BUNDLE_2_IS_ON_PAGE = false;
    public const String INNER_CONTENT = "test content!";
    public MockEnvironment m_environment;
    public MockObjectSelectionModel m_objectModel;
    public MockSearchResultModel m_searchModel;
    public override void setUp()
    {
      ConfigService.setTestInstance(new MockConfigHelper());
      m_environment = new MockEnvironment();
      m_objectModel = new MockObjectSelectionModel();
      m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
       m_objectModel);
      m_searchModel = new MockSearchResultModel();
      m_environment.m_models.PutElement(SearchResultModel.STR_MVC_CLASS_NAME,
       m_searchModel);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletDataTag(), PortletDataTag.TAG.GetName(), PortletPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// This method tests basic functioning of the portlet data tag in search mode.
    /// </summary>
    public virtual void testPortletDataTagSearch()
    {
      m_objectModel.m_bDisplaySearch = true;
      // Put portlet 1 on the page
      m_objectModel.m_nSelectedObjectID = PORTLET_1_OBJECT_ID;
      // 1) Initialize the Mock search model.
      XPArrayList arrayListResults = new XPArrayList();
      // Create a fake portlet result and add it to the result list.
      MockSearchResult result1 = new MockSearchResult();
      arrayListResults.Add(result1);
      result1.setClassID(PORTLET_1_CLASS_ID);
      result1.setObjectID(PORTLET_1_OBJECT_ID);
      result1.setKwic(PORTLET_1_DESCRIPTION);
      result1.setName(PORTLET_1_NAME);
      result1.setLastModified(new XPDateTime());
      // Create a fake portlet bundleresult and add it to the result list.
      MockSearchResult result2 = new MockSearchResult();
      arrayListResults.Add(result2);
      result2.setClassID(PORTLET_BUNDLE_2_CLASS_ID);
      result2.setObjectID(PORTLET_BUNDLE_2_OBJECT_ID);
      result2.setKwic(PORTLET_BUNDLE_2_DESCRIPTION);
      result2.setName(PORTLET_BUNDLE_2_NAME);
      result2.setLastModified(new XPDateTime());
      // Initialize the search model.
      m_searchModel.SetFirstDisplayableItem(2);
      m_searchModel.SetNumDisplayableItems(2);
      m_searchModel.SetResultsList(arrayListResults);
      // initialize markup
      XMLFragmentTestHelper portletDataTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletDataTag.TAG.GetName());
      portletDataTagHelper.AddPTAttribute(PortletDataTag.ATTRIB_ID.GetName(),
       DATA_ID);
      portletDataTagHelper.AddPTAttribute(PortletDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletDataTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       result.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + DATA_ID);
      Assert.assertNotNull("Checking data list variable is present.", ssVariable);
      XPArrayList dataList = (XPArrayList) ssVariable.GetValue();
      check2PortletData(dataList);
    }
    
    /// <summary>
    /// This method tests basic functioning of the portlet data tag in folder query mode.
    /// </summary>
    public virtual void testPortletDataTagFolderQuery()
    {
      m_objectModel.m_bDisplaySearch = false;
      // Put portlet 1 on the page
      m_objectModel.m_nSelectedObjectID = PORTLET_1_OBJECT_ID;
      // Add a portlet to the object model.
      m_objectModel.AddObjectType(PT_CLASSIDS.PT_GADGET_ID);
      m_objectModel.SetObjectViewIndex(0);
      XPHashtable data = new XPHashtable();
      m_objectModel.AddResultItem(data);
      data.PutElement(PT_PROPIDS.PT_PROPID_NAME, PORTLET_1_NAME);
      data.PutElement(PT_PROPIDS.PT_PROPID_DESCRIPTION, PORTLET_1_DESCRIPTION);
      data.PutElement(PT_PROPIDS.PT_PROPID_OBJECTID, XPConvert.ToString(PORTLET_1_OBJECT_ID));
      // Gadget Alignment & Type need to be Integers
      data.PutElement(PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT, PORTLET_1_GADGET_ALIGNMENT);
      data.PutElement(PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE, PORTLET_1_GADGET_TYPE);
      data.PutElement(PT_PROPIDS.PT_PROPID_LASTMODIFIED, new XPDateTime());
      // Add a portlet bundle to the object model
      m_objectModel.AddObjectType(PT_CLASSIDS.PT_GADGETBUNDLE_ID);
      m_objectModel.SetObjectViewIndex(1);
      data = new XPHashtable();
      m_objectModel.AddResultItem(data);
      data.PutElement(PT_PROPIDS.PT_PROPID_NAME, PORTLET_BUNDLE_2_NAME);
      data.PutElement(PT_PROPIDS.PT_PROPID_DESCRIPTION, PORTLET_BUNDLE_2_DESCRIPTION);
      data.PutElement(PT_PROPIDS.PT_PROPID_OBJECTID, XPConvert.ToString(PORTLET_BUNDLE_2_OBJECT_ID));
      data.PutElement(PT_PROPIDS.PT_PROPID_LASTMODIFIED, new XPDateTime());
      // Portlet bundles don't have gadget alignment or types.
      // initialize markup
      XMLFragmentTestHelper portletDataTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletDataTag.TAG.GetName());
      portletDataTagHelper.AddPTAttribute(PortletDataTag.ATTRIB_ID.GetName(),
       DATA_ID);
      portletDataTagHelper.AddPTAttribute(PortletDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      Object[][] objArrMarkup = portletDataTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       result.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + DATA_ID);
      Assert.assertNotNull("Checking data list variable is present.", ssVariable);
      XPArrayList dataList = (XPArrayList) ssVariable.GetValue();
      check2PortletData(dataList);
    }
    
    /// <summary>
    /// This method tests that the tag displays whatever's inside it.
    /// </summary>
    public virtual void testPortletDataTagBodyPassThru()
    {
      m_objectModel.m_bDisplaySearch = true;
      // initialize markup
      XMLFragmentTestHelper portletDataTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletDataTag.TAG.GetName());
      portletDataTagHelper.AddPTAttribute(PortletDataTag.ATTRIB_ID.GetName(),
       DATA_ID);
      portletDataTagHelper.AddContent(INNER_CONTENT);
      Object[][] objArrMarkup = portletDataTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      Assert.assertEquals("Checking that data tag outputs the inner body content.",
       result.GetDisplayString(), INNER_CONTENT);
    }
    
    /// <summary>
    /// This helper method checks that a portlet and portlet bundle are present in the results.
    /// </summary>
    /// <param name="_dataList">the results.</param>
    public virtual void check2PortletData(XPArrayList _dataList)
    {
      Assert.assertNotNull("Checking data list is present.", _dataList);
      Assert.assertEquals("Checking data list contains 2 portlets.", 2, _dataList.GetSize());
      int index = 0;
      IDataObject doCurrentPortlet = (IDataObject) _dataList.GetElement(index);
      // Check pass-thru data
      Assert.assertEquals("Checking name of portlet " + index + ".", PORTLET_1_NAME,
       doCurrentPortlet.GetData(PortletDataTag.NAME));
      Assert.assertEquals("Checking description of portlet " + index + ".",
       PORTLET_1_DESCRIPTION, doCurrentPortlet.GetData(PortletDataTag.DESCRIPTION));
      Assert.assertEquals("Checking ID of portlet " + index + ".", PORTLET_1_OBJECT_ID,
       XPConvert.ToInteger(doCurrentPortlet.GetData(PortletDataTag.ID)));
      // Check derived data
      Assert.assertEquals("Checking type of portlet " + index + ".", PORTLET_1_TYPE,
       doCurrentPortlet.GetData(PortletDataTag.TYPE));
      Assert.assertEquals("Checking if preview is enabled for portlet " + index + ".",
       PORTLET_1_PREVIEW_ENABLED, XPConvert.ToBoolean(doCurrentPortlet.GetData(PortletDataTag.PREVIEW_ENABLED)));
      Assert.assertEquals("Checking invitation ID for portlet " + index + ".",
       index, XPConvert.ToInteger(doCurrentPortlet.GetData(PortletDataTag.INVITATION_ID)));
      Assert.assertEquals("Checking if portlet " + index + " is on page.",
       PORTLET_1_IS_ON_PAGE, XPConvert.ToBoolean(doCurrentPortlet.GetData(PortletDataTag.IS_ON_PAGE)));
      index++;
      doCurrentPortlet = (IDataObject) _dataList.GetElement(index);
      // Check pass-thru data
      Assert.assertEquals("Checking name of portlet bundle " + index + ".",
       PORTLET_BUNDLE_2_NAME, doCurrentPortlet.GetData(PortletDataTag.NAME));
      Assert.assertEquals("Checking description of portlet bundle " + index + ".",
       PORTLET_BUNDLE_2_DESCRIPTION, doCurrentPortlet.GetData(PortletDataTag.DESCRIPTION));
      Assert.assertEquals("Checking ID of portlet bundle " + index + ".",
       PORTLET_BUNDLE_2_OBJECT_ID, XPConvert.ToInteger(doCurrentPortlet.GetData(PortletDataTag.ID)));
      // Check derived data
      Assert.assertEquals("Checking type of portlet bundle " + index + ".",
       PORTLET_BUNDLE_2_TYPE, doCurrentPortlet.GetData(PortletDataTag.TYPE));
      Assert.assertEquals("Checking if preview is enabled for portlet bundle " + index + ".",
       PORTLET_BUNDLE_2_PREVIEW_ENABLED, XPConvert.ToBoolean(doCurrentPortlet.GetData(PortletDataTag.PREVIEW_ENABLED)));
      Assert.assertEquals("Checking for no invitation ID for portlet bundle " + index + ".",
       -1, XPConvert.ToInteger(doCurrentPortlet.GetData(PortletDataTag.INVITATION_ID)));
      Assert.assertEquals("Checking if portlet bundle " + index + " is on page.",
       PORTLET_BUNDLE_2_IS_ON_PAGE, XPConvert.ToBoolean(doCurrentPortlet.GetData(PortletDataTag.IS_ON_PAGE)));
      index++;
    }
  }
}