using System;
using junit.framework;
using com.bea.alui.taglib.portletpageeditor;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor.test
{
  /// <summary>
  /// This class tests the display and rename of Javascript functions from this tag,
  /// but does not test the javascript itself.
  /// </summary>
  public class TestPortletJSTag : TestCase
  {
    public MockEnvironment m_environment;
    // All of our AJAX JS funcs should be of the form "name = function(args)".
    public const String JS_FUNCTION_SUFFIX = " = function(";
    public const String FLYOUTID = "mockFlyoutId";
    public const String ADD_JS_NAME = "testAddPortlet";
    public const String REMOVE_JS_NAME = "testRemovePortlet";
    public const String PREVIEW_JS_NAME = "testPreviewPortlet";
    public const String INVITE_JS_NAME = "testPortletInvitation";
    public const String ADD_BUNDLE_JS_NAME = "testAddPortletBundle";
    public const String OPEN_BUNDLE_JS_NAME = "testOpenPortletBundle";
    public override void setUp()
    {
      ConfigService.setTestInstance(new MockConfigHelper());
      m_environment = new MockEnvironment();
      m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
       new ObjectSelectionModel());
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletJSTag(), PortletJSTag.TAG.GetName(), PortletPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// This method tests basic display of the JavaScript functions.
    /// </summary>
    public virtual void testJS()
    {
      // initialize markup
      XMLFragmentTestHelper portletJSTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletJSTag.TAG.GetName());
      portletJSTagHelper.AddPTAttribute(PortletJSTag.ATTRIB_FLYOUT_ID.GetName(),
       FLYOUTID);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.ADD_NAME.GetName(), ADD_JS_NAME);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.REMOVE_NAME.GetName(),
       REMOVE_JS_NAME);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.PREVIEW_NAME.GetName(),
       PREVIEW_JS_NAME);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.INVITATION_NAME.GetName(),
       INVITE_JS_NAME);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.ADD_BUNDLE_NAME.GetName(),
       ADD_BUNDLE_JS_NAME);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.OPEN_BUNDLE_NAME.GetName(),
       OPEN_BUNDLE_JS_NAME);
      Object[][] objArrMarkup = portletJSTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      CheckFunctionName(ADD_JS_NAME, strResult, true);
      CheckFunctionName(REMOVE_JS_NAME, strResult, true);
      CheckFunctionName(PREVIEW_JS_NAME, strResult, true);
      CheckFunctionName(INVITE_JS_NAME, strResult, true);
      CheckFunctionName(ADD_BUNDLE_JS_NAME, strResult, true);
      CheckFunctionName(OPEN_BUNDLE_JS_NAME, strResult, true);
    }
    
    /// <summary>
    /// This method tests that no JavaScript displays if you don't request it.
    /// </summary>
    public virtual void testNoJS()
    {
      // initialize markup
      XMLFragmentTestHelper portletJSTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletJSTag.TAG.GetName());
      Object[][] objArrMarkup = portletJSTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      CheckFunctionName(ADD_JS_NAME, strResult, false);
      CheckFunctionName(REMOVE_JS_NAME, strResult, false);
      CheckFunctionName(PREVIEW_JS_NAME, strResult, false);
      CheckFunctionName(INVITE_JS_NAME, strResult, false);
      CheckFunctionName(ADD_BUNDLE_JS_NAME, strResult, false);
      CheckFunctionName(OPEN_BUNDLE_JS_NAME, strResult, false);
    }
    
    /// <summary>
    /// This method tests partial display of some of the JavaScript functions.
    /// </summary>
    public virtual void testPartialJS()
    {
      // initialize markup
      XMLFragmentTestHelper portletJSTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletJSTag.TAG.GetName());
      portletJSTagHelper.AddPTAttribute(PortletJSTag.ATTRIB_FLYOUT_ID.GetName(),
       FLYOUTID);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.ADD_NAME.GetName(), ADD_JS_NAME);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.PREVIEW_NAME.GetName(),
       PREVIEW_JS_NAME);
      portletJSTagHelper.AddPTAttribute(PortletJSTag.OPEN_BUNDLE_NAME.GetName(),
       OPEN_BUNDLE_JS_NAME);
      Object[][] objArrMarkup = portletJSTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      // These should be present.
      CheckFunctionName(ADD_JS_NAME, strResult, true);
      CheckFunctionName(PREVIEW_JS_NAME, strResult, true);
      CheckFunctionName(OPEN_BUNDLE_JS_NAME, strResult, true);
      // These should not be present.
      CheckFunctionName(REMOVE_JS_NAME, strResult, false);
      CheckFunctionName(INVITE_JS_NAME, strResult, false);
      CheckFunctionName(ADD_BUNDLE_JS_NAME, strResult, false);
    }
    public virtual void CheckFunctionName(String _strJSName, String _strOutput,
     bool bPresent)
    {
      String strFunction = _strJSName + JS_FUNCTION_SUFFIX;
      if (bPresent)
      {
        // Check that it's there.
        Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction + "] is present in output: " + _strOutput,
         XPStringUtility.IndexOf(_strOutput, strFunction) >= 0);
      } else
      {
        // Check that it's not there.
        Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction + "] is not present in output: " + _strOutput,
         XPStringUtility.IndexOf(_strOutput, strFunction) < 0);
      }
    }
  }
}