using System;
using junit.framework;
using com.bea.alui.taglib.portletpageeditor;
using com.bea.alui.taglib.portletpageeditor.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor.test
{
  /// <summary>
  /// This class tests the display and rename of Javascript functions from this tag,
  /// but does not test the javascript itself.
  /// </summary>
  public class TestPortletSearchFormTag : TestCase
  {
    public MockEnvironment m_environment;
    public const String FORM_PREFIX = "<form name=\"";
    public const String FORM_ID_PREFIX = "\" id=\"";
    public const String FORM_SUFFIX = "\"";
    public const String FORM_NAME = "testForm";
    public const String FORM_ID = "testFormid";
    public const String SUBMIT_JS_NAME = "testSubmitForm";
    public const String KEY_DOWN_JS_NAME = "testKeyDown";
    public const String VALIDATE_JS_NAME = "testValidate";
    public const String DEFAULT_TEXT = "my default text";
    public override void setUp()
    {
      ConfigService.setTestInstance(new MockConfigHelper());
      m_environment = new MockEnvironment();
      m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
       new MockObjectSelectionModel());
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletSearchFormTag(), PortletSearchFormTag.TAG.GetName(),
       PortletPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// This method tests basic display of the JavaScript functions.
    /// </summary>
    public virtual void testJS()
    {
      // initialize markup
      XMLFragmentTestHelper portletSearchFormTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletSearchFormTag.TAG.GetName());
      portletSearchFormTagHelper.AddPTAttribute(PortletSearchFormTag.FORM_NAME.GetName(),
       FORM_NAME);
      portletSearchFormTagHelper.AddPTAttribute(PortletSearchFormTag.FORM_ID.GetName(),
       FORM_ID);
      portletSearchFormTagHelper.AddPTAttribute(PortletSearchFormTag.SUBMIT_FUNCTION.GetName(),
       SUBMIT_JS_NAME);
      portletSearchFormTagHelper.AddPTAttribute(PortletSearchFormTag.KEY_DOWN_FUNCTION.GetName(),
       KEY_DOWN_JS_NAME);
      portletSearchFormTagHelper.AddPTAttribute(PortletSearchFormTag.VALIDATE_FUNCTION.GetName(),
       VALIDATE_JS_NAME);
      portletSearchFormTagHelper.AddPTAttribute(PortletSearchFormTag.FLYOUT_ID.GetName(),
       "mock-flyout-id");
      portletSearchFormTagHelper.AddPTAttribute(PortletSearchFormTag.DEFAULT_TEXT.GetName(),
       DEFAULT_TEXT);
      Object[][] objArrMarkup = portletSearchFormTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
      String strResult = result.GetDisplayString();
      // Check that the form has the right name and ID.
      Assert.assertTrue("Checking that the form has name [" + FORM_NAME + "] and ID [" + FORM_ID + "] in output: " + strResult,
       XPStringUtility.IndexOf(strResult, FORM_PREFIX + FORM_NAME + FORM_ID_PREFIX + FORM_ID + FORM_SUFFIX) >= 0);
      TaglibPortletPageEditorTestSuite.CheckFunctionName(SUBMIT_JS_NAME, strResult,
       true);
      TaglibPortletPageEditorTestSuite.CheckFunctionName(KEY_DOWN_JS_NAME,
       strResult, true);
      TaglibPortletPageEditorTestSuite.CheckFunctionName(VALIDATE_JS_NAME,
       strResult, true);
      // TODO: Check that the flyout function is constructed correctly.
      // Check that the default text is there.
      Assert.assertTrue("Checking that the default text [" + DEFAULT_TEXT + "]for JS validation is present in output: " + strResult,
       XPStringUtility.IndexOf(strResult, DEFAULT_TEXT) >= 0);
    }
  }
}