using System;
using junit.framework;
using com.bea.alui.taglib.portletpageeditor;
using com.bea.alui.taglib.portletpageeditor.test.integration;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.mock.search;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.portletpageeditor.test
{
  /// <summary>
  /// Testing the PortletSortPropertyDataTag and PortletSortPropertyEntry tags. 
  /// </summary>
  /// <author>rozhang</author>
  public class TestPortletSortPropertyDataTag : TestCase
  {
    public const String CUSTOMPROP_NAME1 = "Custom Prop 1";
    public const String CUSTOMPROP_NAME2 = "Custom Prop 2";
    public const String CUSTOMPROP_NAME3 = "Custom Prop 3";
    public const int CUSTOMPROP_ID1 = 500;
    public const int CUSTOMPROP_ID2 = 1000;
    public const int CUSTOMPROP_ID3 = 2000;
    protected MockEnvironment m_env = null;
    protected MockObjectSelectionModel m_objectModel = null;
    protected MockSearchResultModel m_searchModel = null;
    public override void setUp()
    {
      ConfigService.setTestInstance(new MockConfigHelper());
      m_env = new MockEnvironment();
      m_objectModel = new MockObjectSelectionModel();
      m_env.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME, m_objectModel);
      m_searchModel = new MockSearchResultModel();
      m_env.m_models.PutElement(SearchResultModel.STR_MVC_CLASS_NAME, m_searchModel);
      MockTagLibManager tagLibs = new MockTagLibManager();
      tagLibs.SetTag(new PortletSortPropertyDataTag(), PortletSortPropertyDataTag.TAG.GetName(),
       PortletPageEditorTagLibraryData.LIBRARY.GetName());
      tagLibs.SetTag(new PortletSortPropertyEntry(), PortletSortPropertyEntry.TAG.GetName(),
       PortletPageEditorTagLibraryData.LIBRARY.GetName());
      TagLibManager.setTestInstance(tagLibs);
    }
    
    /// <summary>
    /// Testing the sortpropertiesdata tag with the default order by properties
    /// </summary>
    public virtual void testDefaultDataTag()
    {
      String dataId = "sortprops";
      // set up tag
      XMLFragmentTestHelper portletDataTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletSortPropertyDataTag.TAG.GetName());
      portletDataTagHelper.AddPTAttribute(PortletSortPropertyDataTag.ATTRIB_ID.GetName(),
       dataId);
      portletDataTagHelper.AddPTAttribute(PortletSortPropertyDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      // process the tag
      Object[][] objArrMarkup = portletDataTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_env, objArrMarkup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       "", result.GetDisplayString());
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_env);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + dataId);
      Assert.assertNotNull("Checking data list variable is present.", ssVariable);
      // validate set data type
      Assert.assertTrue("Expected the set data type to be XPArrayList", ssVariable.GetValue() is XPArrayList);
      XPArrayList dataList = (XPArrayList) ssVariable.GetValue();
      Assert.assertEquals(PortletSortPropertyDataTag.TAG.GetName() + "should only have 4 entries by default",
       4, dataList.GetSize());
      // test that each entry in the list is a idataobject and that they contain the expected data elements
      for (int i = 0;i < dataList.GetSize();i++)
      {
        Object entry = dataList.GetElement(i);
        Assert.assertTrue("Set entries in the data collection should be of type IDataObject",
         entry is IDataObject);
        IDataObject dataEntry = (IDataObject) entry;
        Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID));
        Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTNAME));
        Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_DEFAULTPROP));
        }
    }
    public virtual void testDataTagWithCustomEntries()
    {
      String dataId = "sortprops";
      // Main data tag
      XMLFragmentTestHelper portletDataTagHelper = SetupSortPropTagWithCustomEntries(dataId);
      // process the tag
      Object[][] objArrMarkup = portletDataTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_env, objArrMarkup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       "", result.GetDisplayString());
      // validation:
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_env);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + dataId);
      Assert.assertNotNull("Checking data list variable is present.", ssVariable);
      // validate set data type
      Assert.assertTrue("Expected the set data type to be XPArrayList", ssVariable.GetValue() is XPArrayList);
      XPArrayList dataList = (XPArrayList) ssVariable.GetValue();
      Assert.assertEquals(PortletSortPropertyDataTag.TAG.GetName() + "should only have 4 entries by default",
       7, dataList.GetSize());
      Object customEntry1 = dataList.GetElement(4);
      Object customEntry2 = dataList.GetElement(5);
      Object customEntry3 = dataList.GetElement(6);
      Assert.assertTrue("Set entries in the data collection should be of type IDataObject",
       customEntry1 is IDataObject);
      IDataObject dataEntry = (IDataObject) customEntry1;
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID),
       CUSTOMPROP_ID1 + "");
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTNAME),
       CUSTOMPROP_NAME1 + "");
      Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_CUSTOMPROP));
      Assert.assertTrue("Set entries in the data collection should be of type IDataObject",
       customEntry2 is IDataObject);
      dataEntry = (IDataObject) customEntry2;
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID),
       CUSTOMPROP_ID2 + "");
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTNAME),
       CUSTOMPROP_NAME2 + "");
      Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_CUSTOMPROP));
      Assert.assertTrue("Set entries in the data collection should be of type IDataObject",
       customEntry3 is IDataObject);
      dataEntry = (IDataObject) customEntry3;
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID),
       CUSTOMPROP_ID3 + "");
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTNAME),
       CUSTOMPROP_NAME3 + "");
      Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_CUSTOMPROP));
      }
    public virtual void testDataTagCustomEntriesNoDefaultProps()
    {
      String dataId = "sortprops";
      // Main data tag
      XMLFragmentTestHelper portletDataTagHelper = SetupSortPropTagWithCustomEntries(dataId);
      portletDataTagHelper.AddPTAttribute(PortletSortPropertyDataTag.ATTRIB_INCLUDEDEFAULTPROPS.GetName(),
       "false");
      // process the tag
      Object[][] objArrMarkup = portletDataTagHelper.ToArrayEntireFragment();
      HTMLElement result = DisplayTree.ProcessTagMarkup(m_env, objArrMarkup);
      // validation:
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       "", result.GetDisplayString());
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_env);
      // Shared state variables are prefixed with a '.'
      SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("." + dataId);
      Assert.assertNotNull("Checking data list variable is present.", ssVariable);
      // validate set data type
      Assert.assertTrue("Expected the set data type to be XPArrayList", ssVariable.GetValue() is XPArrayList);
      XPArrayList dataList = (XPArrayList) ssVariable.GetValue();
      Assert.assertEquals(PortletSortPropertyDataTag.TAG.GetName() + "should only have 3 entries by default",
       3, dataList.GetSize());
      Object customEntry1 = dataList.GetElement(0);
      Object customEntry2 = dataList.GetElement(1);
      Object customEntry3 = dataList.GetElement(2);
      Assert.assertTrue("Set entries in the data collection should be of type IDataObject",
       customEntry1 is IDataObject);
      IDataObject dataEntry = (IDataObject) customEntry1;
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID),
       CUSTOMPROP_ID1 + "");
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTNAME),
       CUSTOMPROP_NAME1 + "");
      Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_CUSTOMPROP));
      Assert.assertTrue("Set entries in the data collection should be of type IDataObject",
       customEntry2 is IDataObject);
      dataEntry = (IDataObject) customEntry2;
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID),
       CUSTOMPROP_ID2 + "");
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTNAME),
       CUSTOMPROP_NAME2 + "");
      Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_CUSTOMPROP));
      Assert.assertTrue("Set entries in the data collection should be of type IDataObject",
       customEntry3 is IDataObject);
      dataEntry = (IDataObject) customEntry3;
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTID),
       CUSTOMPROP_ID3 + "");
      Assert.assertEquals(dataEntry.GetData(PortletSortPropertyDataTag.DATA_OBJECTNAME),
       CUSTOMPROP_NAME3 + "");
      Assert.assertNotNull(dataEntry.GetData(PortletSortPropertyDataTag.DATA_CUSTOMPROP));
      }
    
    /// <summary>
    /// Helper to setup the tag
    /// </summary>
    /// <param name="dataId"></param>
    /// <returns></returns>
    private XMLFragmentTestHelper SetupSortPropTagWithCustomEntries(String dataId)
    {
      XMLFragmentTestHelper portletDataTagHelper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletSortPropertyDataTag.TAG.GetName());
      portletDataTagHelper.AddPTAttribute(PortletSortPropertyDataTag.ATTRIB_ID.GetName(),
       dataId);
      portletDataTagHelper.AddPTAttribute(PortletSortPropertyDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST.ToString());
      // Custom entry 1
      XMLFragmentTestHelper portletDataEntryHelper1 = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletSortPropertyEntry.TAG.GetName());
      portletDataEntryHelper1.AddPTAttribute(PortletSortPropertyEntry.ATTRIB_ID.GetName(),
       CUSTOMPROP_ID1 + "");
      portletDataEntryHelper1.AddPTAttribute(PortletSortPropertyEntry.ATTRIB_NAME.GetName(),
       CUSTOMPROP_NAME1);
      // Custom entry 2
      XMLFragmentTestHelper portletDataEntryHelper2 = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletSortPropertyEntry.TAG.GetName());
      portletDataEntryHelper2.AddPTAttribute(PortletSortPropertyEntry.ATTRIB_ID.GetName(),
       CUSTOMPROP_ID2 + "");
      portletDataEntryHelper2.AddPTAttribute(PortletSortPropertyEntry.ATTRIB_NAME.GetName(),
       CUSTOMPROP_NAME2);
      // Custom entry 3
      XMLFragmentTestHelper portletDataEntryHelper3 = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(),
       PortletSortPropertyEntry.TAG.GetName());
      portletDataEntryHelper3.AddPTAttribute(PortletSortPropertyEntry.ATTRIB_ID.GetName(),
       CUSTOMPROP_ID3 + "");
      portletDataEntryHelper3.AddPTAttribute(PortletSortPropertyEntry.ATTRIB_NAME.GetName(),
       CUSTOMPROP_NAME3);
      portletDataTagHelper.AddContent(portletDataEntryHelper1);
      portletDataTagHelper.AddContent(portletDataEntryHelper2);
      portletDataTagHelper.AddContent(portletDataEntryHelper3);
      return portletDataTagHelper;
    }
  }
}