package com.bea.alui.taglib.portletpageeditor;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

public class CollapseExpandJSTag extends ATag 
{
	public static final String ONCLICK_FUNCTION = "sendCollapseExpandRequest";
	//public static final String RESPONSE_HANDLER_FUNCTION = "handleCollapseExpandResponse";
	

	private static final String TAG_NAME = "collapseexpandjs";
	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_FLYOUT_ID;
	public static final OptionalTagAttribute ATTRIB_ONCLICK_FUNCTION;
	//public static final OptionalTagAttribute ATTRIB_RESPONSE_HANDLER;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, "Adds all javascript required to collapse " +
				"or expand a portlet through Ajax.");
		
		ATTRIB_ONCLICK_FUNCTION = new OptionalTagAttribute("onclick",
				"The onclick function name to use other than the default.",	
				AttributeType.STRING, ONCLICK_FUNCTION);
		//ATTRIB_RESPONSE_HANDLER = new OptionalTagAttribute("responsehandler",
		//		"The response handler function name to use other than the default.",	
		//		AttributeType.STRING, RESPONSE_HANDLER_FUNCTION);
		ATTRIB_FLYOUT_ID = PortletPageEditorTagLibraryData.ATTRIB_FLYOUTID;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new CollapseExpandJSTag();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() {
		return null;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// DCA - only works on standard mode
		if (AccessStyles.STANDARD.GetAccessID() == _style.GetAccessID()) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()
	 */
	public HTMLScriptCollection DisplaySharedJavascript()
	{
		String strOnclick = GetTagAttributeAsString(ATTRIB_ONCLICK_FUNCTION);
		//String strResponseHandler = GetTagAttributeAsString(ATTRIB_RESPONSE_HANDLER);
		String strFlyoutId = GetTagAttributeAsString(ATTRIB_FLYOUT_ID);

		XPStringBuilder sb = new XPStringBuilder();
		sb.Append(strOnclick).Append(" = function(url) {\n");
    	sb.Append("    if (typeof(ptEditMode").Append(strFlyoutId).Append(") != 'undefined' && ptEditMode").Append(strFlyoutId).Append(" == 2) {\n");
    	sb.Append("    		alert('").Append(GetEnvironment().GetString(1944, "ptmsgs_portalbrowsingmsgs")).Append("');\n");
    	sb.Append("    } else {\n");
    	sb.Append("    		window.location = url;\n");
    	sb.Append("    }\n");
    	sb.Append("    return false;\n");
    	sb.Append("}\n");
		
		/* DCA - Commenting out for now because of the issue with dynamic content (collab)
		sb.Append("var currentButton;\n");
		sb.Append("var onclickFunction = 'sendCollapseExpandRequest';\n");
		sb.Append(strOnclick).Append(" = function(url, button) {\n");
    	sb.Append("    currentButton = button;\n");
    	sb.Append("    // DCA - add 'MyPortalPartialPortlets' as display page so that we get an ajax response\n");
    	sb.Append("    url = url + '&page=MyPortalPartialPortlets';\n");
    	sb.Append("    var request = new PTHTTPGETRequest(url, handleCollapseExpandResponse);\n");
    	sb.Append("    request.invoke();\n");
    	sb.Append("    return false;\n");
    	sb.Append("}\n");
    	sb.Append(strResponseHandler).Append(" = function(resp) {\n");
    	sb.Append("    var div = document.createElement('div');\n");
    	sb.Append("	div.innerHTML = resp.responseText;\n");
    	sb.Append("	var portletContent = div.firstChild;\n");
    	sb.Append("	var expandButton = portletContent.nextSibling;\n");
    	sb.Append("	var oldPortletContent = dojo.byId(portletContent.id);\n");
		sb.Append("	// DCA - swap the content to the collapsed version\n");
		sb.Append("	var portletContentHolder = oldPortletContent.parentNode;\n");
		sb.Append("	portletContentHolder.replaceChild(portletContent, oldPortletContent);\n");
		sb.Append("	// DCA - fix expand button so that it makes an ajax request\n");
		sb.Append("	var anchor = expandButton.firstChild;\n");
		sb.Append("	var url = anchor.href;\n");
		sb.Append("	anchor.href = '#';\n");
		sb.Append("	anchor.onclick = function() {\n");
		sb.Append("	    return eval(onclickFunction + \"('\" + url + \"', this.parentNode);\")\n");
		sb.Append("	};\n");
		sb.Append("	// DCA - swap the collapse button for the expand button\n");
		sb.Append("	var buttonHolder = currentButton.parentNode;\n");
		sb.Append("	buttonHolder.replaceChild(expandButton, currentButton);\n");
		sb.Append("}	\n");
		*/
		
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.AddInnerHTMLString(sb.ToString());
		HTMLScriptCollection collection = new HTMLScriptCollection();
		collection.AddInnerHTMLElement(script);
		return collection;
	}
}
