package com.bea.alui.taglib.portletpageeditor;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag stores the bread crumb path to the current folder in memory.
 */
public class PortletBrowseBreadCrumbDataTag extends ATag
{
	private static final String TAG_NAME = "browsebreadcrumbsdata";

	// This is the same as the constant in AKDPageTag
	public static final String EMPTY_STRING = "EMPTY_STRING";

	public static final String NAME = "name";
	public static final String ID = "id";
	public static final String URL = "url";

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_ID;
	public static final OptionalTagAttribute ATTRIB_SCOPE;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME,
			"This tag stores the breadcrumb path to the current folder in memory. " +
			"Each breadcrumb data object will have the following variables: <code>" +
			NAME +"</code> for the breadcrumbs folder name, <code>" + ID +
			"</code> for the folder ID, " + "and <code>" + URL +
			"</code> for the URL to access the folder. The current folder will not contain the URL, instead it will have the constant '"
			+ EMPTY_STRING +"'. " +
			"This tag requires the " + PortletBrowseModeTag.TAG.GetName() +
			" to be displayed on the page before it." +
			PortletPageEditorTagLibraryData.FLYOUT_ONLY);

		ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
			CommonTagAttributeConstants.ATTRIB_ID_DESC,	
			AttributeType.STRING);

		ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
			CommonTagAttributeConstants.ATTRIB_SCOPE_DESC,
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
	}
	
	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new PortletBrowseBreadCrumbDataTag();
	}

	/*
	 * (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag() 
	{
		AActivitySpace asOwner = (AActivitySpace) GetEnvironment();

		IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO)
			asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);

		IXPList breadCrumbsList = new XPArrayList();

		if (!objectModel.GetDisplaySearch())
		{
			// NOTE: This basically follows the BreadCrumbsDataTag for KD 
			// get bread crumb path from model
			IASQueryResult qrFolders = objectModel.GetBreadCrumbPath();
			for (int i=0; i<qrFolders.GetCount(); i++) {
				// get name and id from query result
				String strName     = (String) qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
				int nFolderID	   = XPConvert.ToInteger(qrFolders.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));

				// get URL
				ASURL asurl = new ASURL(asOwner);
				asurl.SetLinkGetCachedSpace(asOwner);
				asurl.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
				asurl.AddControlArgument(OpenSubFolderControl.m_SubFolderID, nFolderID);
				
				// populate data object
				HashtableDataObject htObject = new HashtableDataObject();
				htObject.SetData(NAME, strName);
				htObject.SetData(ID, XPConvert.ToString(nFolderID));
				// Do not add the URL for the last item, since that will be
				// the current folder.
				if (i == qrFolders.GetCount() - 1) {
					htObject.SetData(URL, EMPTY_STRING);
				} else {
					htObject.SetData(URL, asurl.GetURLAsString());
				}
				breadCrumbsList.Add(htObject);
			}
		} else
		{
			// Only output breadcrumbs if we are in browse mode.
		}

		// add list to memory
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE));
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		GetState().SetSharedVariable(strDataReference, breadCrumbsList, tagScope, true);

		return ProcessTagBody();
	}
}