/*******************************************************************************
 *  BEA Systems, Inc. CONFIDENTIAL
 * _______________________________
 * 
 *  (c) Copyright 2007  BEA Systems, Inc.
 *  All Rights Reserved.
 * 
 *  NOTICE:  All information contained herein is, and remains
 *  the property of BEA Systems, Inc. and its suppliers, if any.
 *  The intellectual and technical concepts contained herein
 *  are proprietary to BEA Systems, Inc. and its suppliers and may
 *  be covered by U.S. and Foreign Patents, patents in process,
 *  and are protected by trade secret or copyright law.
 *  Dissemination of this information or reproduction of this material
 *  is strictly forbidden unless prior written permission is obtained
 *  from BEA Systems, Inc..
 *******************************************************************************/
package com.bea.alui.taglib.portletpageeditor;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.objectselection.portlets.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tag stores the portlets in tag memory.
 * 
 * @author Don H
 */
public class PortletDataTag extends ATag
{
	public static final String TAG_NAME = "portletdata";

	public static final String NAME			= "name";
	public static final String DESCRIPTION	= "description";
	public static final String ID           = "id";
	public static final String IS_ON_PAGE	= "isonpage";
	public static final String TYPE			= "type";
	public static final String PREVIEW_ENABLED	= "previewenabled";
	public static final String INVITATION_ID	= "invitationid";
	public static final String LAST_MODIFIED  = "lastmodified";
	public static final String MANDATORY  = "mandatory";
	
	public static final String DATATAG_DESCRIPTION = ATag.EncodeForTagDoc(
		PortletPageEditorTagLibraryData.FLYOUT_ONLY +
		"Generates the data required to show a list of portlets for the page editor " +
		"and stores it in memory using the variable name specified by the " +
		"<code>" + CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. " +
		"Each result is a DataObject with the following variables:<br/>" +
		"<ul>" +
		"<li> <code>" + NAME + "</code> - The name of the portlet.</li>" +
		"<li> <code>" + DESCRIPTION + "</code> - The description of the portlet.</li>" +
		"<li> <code>" + ID + "</code> - The portlet ID.</li>" +
		"<li> <code>" + IS_ON_PAGE + "</code> - True if the portlet is on the current page.</li>" +
		"<li> <code>" + TYPE + "</code> - The portlet type (" +
			PortletTypes.NARROW.ToString() + ", " + PortletTypes.WIDE.ToString() + ", or " +
			PortletTypes.BUNDLE.ToString() + "),  used as the div style class suffix and " +
			"passed in to the preview javascript function.</li>" +
		"<li> <code>" + PREVIEW_ENABLED + "</code> - True if preview is enabled for this portlet.</li>" +
		"<li> <code>" + INVITATION_ID + "</code> - The ID to be used in the invitation javascript function. Invitation is disabled if this is -1.</li>" +
		"<li> <code>" + LAST_MODIFIED + "</code> - The last modified date of the portlet.</li>" +
		"<li> <code>" + MANDATORY + "</code> - True if the portlet is mandatory for the current page.</li>" +
		"</ul>" +
		"Use tags from the Logic library to iterate over the list and display the results. <br/>" +
		"NOTE: This tag and the " + PortletSortPropertyDataTag.TAG_NAME +
		" tag must be displayed before other portletpageeditor tags so the page " +
		"can be initialized properly."
	);

	public static final String DATATAG_EXAMPLE = ATag.EncodeForTagDoc(
		"This simple example loops through results and shows the name for each result.<br/><br/>" +
		"<code>" +
		"<pt:" + PortletPageEditorTagLibraryData.LIBRARY.GetName() + "." + TAG_NAME + " pt:id=\"portlets\"/>" +
		"<pt:logic.foreach pt:data=\"portlets\" pt:var=\"portlet\">" +
		"  <pt:logic.value pt:value=\"$portlet." + NAME + "\"/>" +
		"  <br/>" +
		"</pt:logic.foreach>" +
		"</code>"
	);

	// All public static final metadata objects should be initialized
	// in a static initializer so that we can control the order of
	// initialization.
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_ID;
	public static final OptionalTagAttribute ATTRIB_SCOPE;
	
	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, DATATAG_DESCRIPTION, DATATAG_EXAMPLE);

		ATTRIB_ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
			CommonTagAttributeConstants.ATTRIB_ID_DESC,	
			AttributeType.STRING);

		ATTRIB_SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
			CommonTagAttributeConstants.ATTRIB_SCOPE_DESC,
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());
		
		
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplayTag()
	 */
	public HTMLElement DisplayTag()
	{
		AActivitySpace asOwner = (AActivitySpace) GetEnvironment();

		IObjectSelectionModelRO objectModel = (IObjectSelectionModelRO) asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
		if ( objectModel == null ) {
			throw new XPIllegalStateException("This tag requires a page with the ObjectSelectionModel. None was found in the current ActivitySpace."); 
		}

		ISearchResultModelRO searchModel = (ISearchResultModelRO)asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
		if ( searchModel == null ) {
			throw new XPIllegalStateException("This tag requires a page with the SearchResultModel. None was found in the current ActivitySpace."); 
		}

		boolean bSearch = objectModel.GetDisplaySearch();

		// Since we add and remove objects without using this model,
		// we should requery for the objects on the page every time
		// we display the objects again, otherwise they will show
		// their old state if they have been changed.
		((IObjectSelectionModel) objectModel).RefreshSelectedObjects();

		int nResultsToDisplay;
		int nFirstResult;
		int nMoreResults = 0;

		if (bSearch)
		{
			// Assume ungrouped display
			nResultsToDisplay = searchModel.GetNumDisplayableItems();

			// The search model handles pagination for us.
			nFirstResult = 0;
		} else
		{
			// The object model makes you cycle through all of the different object
			// types to display them.  The first we want to display is portlets.
			((IObjectSelectionModel) objectModel).SetObjectViewIndex(PortletSelectionDP.GADGET_INDEX);

			int nResults = objectModel.GetObjectCount();

			// This returns us the number of results to display based on the
			// default items per page and the number of columns being displayed.
			// I.E.  If there are no subfolders and we are displaying 3 columns,
			// this should return 9 instead of 10 so that there isn't an extra
			// result on the last row.
			int nItemsPerPage = objectModel.GetItemsPerPage();

			// Make this 0 based
			nFirstResult = objectModel.GetFirstDisplayableItem() - 1;
			nResultsToDisplay = nFirstResult + nItemsPerPage;

			if (nResultsToDisplay > nResults)
			{
				// Store how many results of type 2 we can display
				nMoreResults = nResultsToDisplay - nResults;
				nResultsToDisplay = nResults;
				if (nFirstResult > nResultsToDisplay)
				{
					nResultsToDisplay = nFirstResult;
				}
			}
		}

		// Create array list that will hold data objects for each result.
		IXPList resultsList = new XPArrayList();

		// For each result,
		for (int i = nFirstResult; i < nResultsToDisplay; i++)
        {
			// Add the data object of the result to the list of results.
			resultsList.Add(PopulateObject(i, bSearch, objectModel, searchModel));
        }

		if (!bSearch)
		{
			// The object model makes you cycle through all of the different object
			// types to display them.  The first type is portlets, and the second
			// type is portlet bundles.  We've already displayed the portlets,
			// but we still need to display the portlet bundles, if we have any more
			// items left to display in the current pagination model.
			if (nMoreResults > 0)
			{
				((IObjectSelectionModel) objectModel).SetObjectViewIndex(PortletSelectionDP.BUNDLE_INDEX);

				int nResults = objectModel.GetObjectCount();

				nResultsToDisplay = nFirstResult + nMoreResults;
	
				if (nResultsToDisplay > nResults)
				{
					nResultsToDisplay = nResults;
				}
	
				// For each bundle result,
				for (int i = nFirstResult; i < nResultsToDisplay; i++)
		        {
					// Add the data object of the result to the list of results.
					resultsList.Add(PopulateObject(i, bSearch, objectModel, searchModel));
		        }
			}
		}

		// Add list to memory
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE) );
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		GetState().SetSharedVariable(strDataReference, resultsList, tagScope, true);

		return ProcessTagBody();
	}

	/**
	 * This helper method returns the portlet property from either the
	 * search or object model, depending on whether search is enabled or not.
	 * 
	 * @param _nIndex
	 * @param _bSearch
	 * @param _searchModel
	 * @param _nSearchFieldID
	 * @param _objectModel
	 * @param _nPropertyID
	 * @return the portlet property
	 */
	public String GetProperty(int _nIndex, boolean _bSearch,
		ISearchResultModelRO _searchModel, int _nSearchFieldID,
		IObjectSelectionModelRO _objectModel, int _nPropertyID)
	{
		if (_bSearch)
		{
			return _searchModel.GetResultPortletField(_nIndex, _nSearchFieldID);
		} else {
			return (String) _objectModel.GetObjectFields(_nIndex, _nPropertyID);
		}
	}

	/**
	 * This helper method gets the current portlet/bundle object and
	 * populates a DataObject with it.
	 * 
	 * @param _nIndex the index of the current portlet/bundle
	 * @param _bSearch are we in search mode
	 * @param _objectModel
	 * @param _searchModel
	 * @return the IDataObject for the portlet/bundle
	 */
	public IDataObject PopulateObject(int _nIndex, boolean _bSearch,
		IObjectSelectionModelRO _objectModel, ISearchResultModelRO _searchModel)
	{
		// Create the data object.
		HashtableDataObject htObject = new HashtableDataObject();

		// **********************************************************************************************
		// The data added for each result somewhat replicates the logic in:
		// com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelectionViewHelper.DisplayObject()
		//
		// That is the method responsible for displaying each result in the original add portlets page.
		// **********************************************************************************************

		// Add the name (html encoded)
		String strName;
		if (_bSearch)
		{
			strName = _searchModel.GetResultName(_nIndex);
		} else {
			strName = (String) _objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_NAME);
		}
		htObject.SetData(NAME, strName);

		// Add the description (html encoded)
		String strDescription;
		if (_bSearch)
		{
			// The description is not available in search, so we use the KWIC
			// (Key word in context) instead.  This contains HTML marking the key word,
			// and search HTML encodes the rest of the string to make sure that it
			// can't be hacked.  Therefore, we don't need to HTML encode KWIC.
			strDescription = _searchModel.GetKWIC(_nIndex);
		} else {
			// HTML encode this.
			strDescription = XPHttpUtility.HtmlEncode((String) _objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_DESCRIPTION));
		}
		// BT: Bug 70052 - Set to empty string if null. Tag replacement can't handle null value.
		if (strDescription == null) {
			strDescription = "";
		}
		htObject.SetData(DESCRIPTION, strDescription);

		// Add the ID
		int nObjectID;
		// NOTE: In search mode, this is a String, but in browse mode, it's an Integer.
		if (_bSearch)
		{
			nObjectID = XPConvert.ToInteger(_searchModel.GetResultObjectID(_nIndex));
		} else {
			nObjectID = XPConvert.ToInteger(_objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
		}
		htObject.SetData(ID, XPConvert.ToString(nObjectID));

		// The class ID is used lower down
		int nClassID;
		if (_bSearch)
		{
			nClassID = _searchModel.GetResultClassID(_nIndex);
		} else
		{
			// Apparently the object model queries don't include class IDs, and
			// we have to ask the model whether it's a portlet or a bundle.
			nClassID = _objectModel.GetObjectType();
		}

		// -1 means no invitation - i.e. portlet bundle
		int nInvitationID = -1;
		if (nClassID != PT_CLASSIDS.PT_GADGETBUNDLE_ID)
		{
			nInvitationID = _nIndex;
		}
		// The invitation ID is just the portlet index in the results. (-1 if a bundle).
		// The invitation popup uses it to lookup the portlet name and ID.
		htObject.SetData(INVITATION_ID, XPConvert.ToString(nInvitationID));

		// Whether or not this portlet is on the current page.
		// Portlet bundles are never on the page, even if all portlets
		// in the bundle are selected.  They don't have the concept of
		// remove, so we treat them as always selected.
		boolean bOnPage = false;
		if (nClassID == PT_CLASSIDS.PT_GADGET_ID)
		{
			bOnPage = _objectModel.GetIsObjectSelected(nObjectID);
		}
		htObject.SetData(IS_ON_PAGE, XPConvert.ToString(bOnPage));
		
		// Whether or not this portlet is mandatory and cannot be removed
		boolean bManadatory = false;
		if (nClassID == PT_CLASSIDS.PT_GADGET_ID)
		{
			bManadatory = _objectModel.DoNotShowObjectWithID(nObjectID);
		}
		htObject.SetData(MANDATORY, XPConvert.ToString(bManadatory));

		boolean bPreviewEnabled = false;
		// If this is a regular portlet (not a portlet bundle or a community portlet),
		// then we can preview it.
		if (nClassID == PT_CLASSIDS.PT_GADGET_ID)
		{
			if (_bSearch)
			{
				String strGadgetType = GetProperty(_nIndex, _bSearch, _searchModel, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_TYPE,
					_objectModel, PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE);

				bPreviewEnabled = ((strGadgetType == null) ||
						(XPStringUtility.Compare(strGadgetType, XPConvert.ToString(PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL)) == 0));
			} else
			{
				int nGadgetType = (Integer) _objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE);

				bPreviewEnabled = (nGadgetType == PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL);
			}
		}
		htObject.SetData(PREVIEW_ENABLED, XPConvert.ToString(bPreviewEnabled));

		// The portlet type (i.e. portlet, bundle, etc...) - used in div style class suffix
		String strType = PortletTypes.NARROW.ToString();
		if (nClassID == PT_CLASSIDS.PT_GADGETBUNDLE_ID)
		{
			strType = PortletTypes.BUNDLE.ToString();
		} else
		{
			// Get the portlet alignment (i.e. narrow/wide as an int)
			if (_bSearch)
			{
				String strPortletAlignment = GetProperty(_nIndex, _bSearch, _searchModel, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_ALIGNMENT,
						_objectModel, PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);

				if ((strPortletAlignment != null) &&
					(XPStringUtility.Compare(strPortletAlignment, XPConvert.ToString(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE)) == 0))
				{
					strType = PortletTypes.WIDE.ToString();
				}
			} else
			{
				int nGadgetAlignment = (Integer) _objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);

				if (nGadgetAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE)
				{
					strType = PortletTypes.WIDE.ToString();
				}
			}
		}
		htObject.SetData(TYPE, strType);
		
		XPDateTime dtLMDate;
		if (_bSearch)
		{
			dtLMDate = _searchModel.GetResultLastModified(_nIndex);
		} else {
			dtLMDate =  (XPDateTime) _objectModel.GetObjectFields(_nIndex, PT_PROPIDS.PT_PROPID_LASTMODIFIED);
		}
		XPDateFormat dateFormat = _searchModel.GetDateFormat((AActivitySpace) GetEnvironment());
		htObject.SetData(LAST_MODIFIED, dateFormat.Format(dtLMDate));

		return htObject;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#SupportsAccessStyle(AccessStyles)
	 */
	public boolean SupportsAccessStyle(AccessStyles _style)
	{
		// This tag only handles standard mode.
		return _style == AccessStyles.STANDARD;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#Create()
	 */
	public ATag Create() {
		return new PortletDataTag();
	}
}