package com.bea.alui.taglib.portletpageeditor;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.xpshared.htmlelements.*;

public class PortletSortPropertyEntry extends ATag 
{
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_ID;
	public static final RequiredTagAttribute ATTRIB_NAME;
	public static final RequiredParentTag PARENT_TAG;

	static
	{
		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData("sortpropertyentry", 
				"Specifies a sort property entry for the sortpropertiesdata tag. This tag is only usable with the sortpropertiesdata tag. "+
				"The order of the entries is preserved in the resulting data collection.", 
				PortletSortPropertyDataTag.EXAMPLE);

		ATTRIB_ID = new RequiredTagAttribute("propid",
			ATag.EncodeForTagDoc(
					"The ID of the property. For custom object properties, this is the ID of property object. " +
					"Positive value for ascending order and negative for descending order. "+
					"IDs for other common properties:<br/>"+
					"<ul><li>1 - The item name.</li>"+
					"<li>2 - The item description.</li>"+
					"<li>3 - The item creation date. </li>"+
					"<li>4 - The item last modified date.</li>"+
					"</ul>"
					),	
			AttributeType.INT);

		ATTRIB_NAME = new RequiredTagAttribute("proptitle",
			"The display string for the property.",
			AttributeType.STRING);
		
		PARENT_TAG = new RequiredParentTag(PortletSortPropertyDataTag.TAG);
	}
	
	@Override
	public HTMLElement DisplayTag() 
	{
		int propId = GetTagAttributeAsInt(ATTRIB_ID);
		String propName = GetTagAttributeAsString(ATTRIB_NAME);
		HashtableDataObject entry = new HashtableDataObject();
		entry.SetData(PortletSortPropertyDataTag.DATA_OBJECTID, propId+"");
		entry.SetData(PortletSortPropertyDataTag.DATA_OBJECTNAME, propName);
		
		XPArrayList propEntries = (XPArrayList)GetState().GetVariable(PortletSortPropertyDataTag.DATAVARNAME_PROPENTRIES, Scope.TAG);
		propEntries.Add(entry);
		
		return null;
	}
	
	
	
	@Override
	public ATag Create() 
	{
		return new PortletSortPropertyEntry();
	}
	
}
