package com.bea.alui.taglib.portletpageeditor.test;

import junit.framework.*;

import com.bea.alui.taglib.portletpageeditor.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

public class FlyoutJSTagTest extends TestCase {
	
	private static final String DIV_ID = "divId";
	private static final String ONCLICK = "flyout";
	private static final String URL = "http://fakeurl.com";
	private static final String HEADER_ID = "header";
	private static final String ANCHOR_ID = "anchor";
	private static final String FLYOUT_ANCHOR_TEXT = "close";
	private static final String FLYIN_ANCHOR_TEXT = "open";
	
	private AActivitySpace m_environment;
	
	/**
	 */
	public FlyoutJSTagTest(String name)
   	{
		super(name);
   	}
   
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();
   		
   		m_environment = new MockEnvironment();
   		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new FlyoutJSTag(), FlyoutJSTag.TAG.GetName(), PortletPageEditorTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		
		m_environment = null;
	}
	
	public void testDisplayJSNoURLNoHeaderBadId() 
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(), FlyoutJSTag.TAG.GetName());
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), "badId");
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
   		int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + "badId.wipeIn('badId', true);");
   		Assert.assertTrue("The javascript returned is not correct. The string \""+FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".wipeIn('badId', true);\" should be there.", index>0);
	}
	
	public void testDisplayJSNoURLNoHeaderBadOnclick() 
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(), FlyoutJSTag.TAG.GetName());
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), "badOnclick");
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
   		int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".badOnclick = function(");
   		Assert.assertTrue("The javascript returned is not correct. The "+FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".badOnclick function should be there.", index > 0);
	}
	
	public void testDisplayJSNoURL() 
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(), FlyoutJSTag.TAG.GetName());
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_HEADER_ID.GetName(), HEADER_ID);
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
   		int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".handleResponse = function(");
   		Assert.assertEquals("The javascript returned is not correct. The "+FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".handleResponse function should not be there.", -1, index);
	}
	
	public void testDisplayJS() 
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(), FlyoutJSTag.TAG.GetName());
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_URL.GetName(), URL);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_HEADER_ID.GetName(), HEADER_ID);
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
   		int index = XPStringUtility.IndexOf(result.GetInnerHTML(), ONCLICK);
   		Assert.assertTrue("The javascript returned is not correct. The "+ONCLICK+" function should be there.", index > 0);
   		
   		index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText = function(");
   		Assert.assertEquals("The javascript returned is not correct. The "+FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText function should not be there.", -1, index);
	}
	
	public void testDisplayJSSwapAnchorText() 
	{
		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(), FlyoutJSTag.TAG.GetName());
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ID.GetName(), DIV_ID);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ONCLICK.GetName(), ONCLICK);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_URL.GetName(), URL);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_HEADER_ID.GetName(), HEADER_ID);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_ANCHOR_ID.GetName(), ANCHOR_ID);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYOUT_ANCHOR_TEXT.GetName(), FLYOUT_ANCHOR_TEXT);
   		helper.AddPTAttribute(FlyoutJSTag.ATTRIB_FLYIN_ANCHOR_TEXT.GetName(), FLYIN_ANCHOR_TEXT);
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);
   		HTMLElement result = DisplayTree.GetSharedJavaScriptFromMarkup(m_environment);
   		int index = XPStringUtility.IndexOf(result.GetInnerHTML(), FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText = function(");
   		Assert.assertTrue("The javascript returned is not correct. The "+FlyoutJSTag.FLYOUT_OBJECT + DIV_ID + ".swapAnchorText function should be there.", index > 0);
	}
}
