package com.bea.alui.taglib.portletpageeditor.test;

import junit.framework.*;

import com.bea.alui.taglib.portletpageeditor.*;
import com.bea.alui.taglib.portletpageeditor.test.integration.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.server.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This tests the basic functionality of the sub folders data tag.
 */
public class TestPortletBrowseSubFoldersDataTag extends TestCase
{
	private static String ID_VALUE = "my-subfolders";
	
	private int subFolder1Id = 201;
	private String subFolder1Name = "subfolder 1";
	
	private int subFolder2Id = 3425;
	private String subFolder2Name = "subfolder 2";
	
	private int subFolder3Id = 341;
	private String subFolder3Name = "subfolder 3";
	
	private AActivitySpace m_environment;
	private MockObjectSelectionModel m_objModel;
	  
   	/**
	 * Setup if any is required.
	 */
   	public void setUp() throws Exception
   	{
   		super.setUp();

   		MockConfigHelper helper = new MockConfigHelper();
		ConfigService.setTestInstance(helper);

   		MockPTConfigHelper ptHelper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(ptHelper);

   		MockPTQueryResult qrSubFolders = new MockPTQueryResult();
		// False means the data needs to be flipped.
   		qrSubFolders.SetData(new int[] {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME},
   			new Object[][] {
				{new Integer(subFolder1Id), subFolder1Name},
				{new Integer(subFolder2Id), subFolder2Name},
				{new Integer(subFolder3Id), subFolder3Name}}, false);
   		IASQueryResult folderQueryResult = new ASQueryResultWrapper(qrSubFolders);

   		m_objModel = new MockObjectSelectionModel();
   		m_objModel.SetFolderQueryResult(folderQueryResult);
   		m_environment = new MockEnvironment();
   		((MockEnvironment) m_environment).m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME, m_objModel);
   		
   		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new PortletBrowseSubFoldersDataTag(), PortletBrowseSubFoldersDataTag.TAG.GetName(), PortletPageEditorTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
   	}
   	
   	/**
	 * @see TestCase#tearDown()
	 */
	public void tearDown() throws Exception
	{
		super.tearDown();
		
		m_environment = null;
		m_objModel = null;
	}

	/**
	 * Test doing nothing if we're in search mode.
	 */
	public void testNoSubFolders() 
	{
		m_objModel.m_bDisplaySearch = true;

		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(), PortletBrowseSubFoldersDataTag.TAG.GetName());
   		helper.AddPTAttribute(PortletBrowseSubFoldersDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(PortletBrowseSubFoldersDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		Assert.assertEquals("Checking that data tag didn't output any HTML.",
   			result.GetDisplayString(), "");
   		
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);

   		// public variables are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);
		Assert.assertNotNull("Checking data list exists.", ssVariable);

		IXPList subFolders = (IXPList) ssVariable.GetValue();
		Assert.assertEquals("The size of the subfolders list in memory is incorrect.", 0, subFolders.GetSize());
	}

	/**
	 * Test outputting the subfolder data if we're in browse mode.
	 */
	public void testSubFolders() 
	{
		m_objModel.m_bDisplaySearch = false;

		XMLFragmentTestHelper helper = new XMLFragmentTestHelper(PortletPageEditorTagLibraryData.LIBRARY.GetName(), PortletBrowseSubFoldersDataTag.TAG.GetName());
   		helper.AddPTAttribute(PortletBrowseSubFoldersDataTag.ATTRIB_ID.GetName(), ID_VALUE);
   		helper.AddPTAttribute(PortletBrowseSubFoldersDataTag.ATTRIB_SCOPE.GetName(), Scope.HTTP_REQUEST.toString());
   		
   		Object[][] objArrMarkup = helper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		Assert.assertEquals("Checking that data tag didn't output any HTML.",
   			result.GetDisplayString(), "");
   		
   		XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);

   		// public variables are prefixed with a '.'
		SharedStateVariable ssVariable = (SharedStateVariable) scopeData.GetElement("."+ID_VALUE);
		Assert.assertNotNull("Checking data list exists.", ssVariable);

		IXPList subFolders = (IXPList) ssVariable.GetValue();
		Assert.assertEquals("The size of the subfolders list in memory is incorrect.", 3, subFolders.GetSize());

		int nIndex = 0;

		checkSubFolder((IDataObject) subFolders.GetElement(nIndex), nIndex,
				subFolder1Name, subFolder1Id);
		nIndex++;
		
		checkSubFolder((IDataObject) subFolders.GetElement(nIndex), nIndex,
				subFolder2Name, subFolder2Id);
		nIndex++;
		
		checkSubFolder((IDataObject) subFolders.GetElement(nIndex), nIndex,
				subFolder3Name, subFolder3Id);
		nIndex++;
	}

	/**
	 * Helper method to check the subfolder data.
	 * @param _folder
	 * @param _nIndex
	 * @param _strName
	 * @param _nID
	 */
	public void checkSubFolder(IDataObject _folder, int _nIndex, String _strName, int _nID)
	{
		String name = _folder.GetData(PortletBrowseSubFoldersDataTag.NAME);
		Assert.assertEquals("Wrong name returned for subfolder " + _nIndex + ".", _strName, name);
		int id = XPConvert.ToInteger(_folder.GetData(PortletBrowseSubFoldersDataTag.ID));
		Assert.assertEquals("Wrong id returned for subfolder " + _nIndex + ".", _nID, id);
	}
}