package com.bea.alui.taglib.portletpageeditor.test;

import junit.framework.*;

import com.bea.alui.taglib.portletpageeditor.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.tags.displaytree.*;
import com.plumtree.portaluiinfrastructure.tags.manager.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class tests the display and rename of Javascript functions from this tag,
 * but does not test the javascript itself.
 */
public class TestPortletJSTag extends TestCase
{
	public MockEnvironment m_environment;

	// All of our AJAX JS funcs should be of the form "name = function(args)".
	public static final String JS_FUNCTION_SUFFIX = " = function(";
	
	public static final String FLYOUTID = "mockFlyoutId";
	public static final String ADD_JS_NAME = "testAddPortlet";
	public static final String REMOVE_JS_NAME = "testRemovePortlet";
	public static final String PREVIEW_JS_NAME = "testPreviewPortlet";
	public static final String INVITE_JS_NAME = "testPortletInvitation";
	public static final String ADD_BUNDLE_JS_NAME = "testAddPortletBundle";
	public static final String OPEN_BUNDLE_JS_NAME = "testOpenPortletBundle";

	public void setUp()
	{
		ConfigService.setTestInstance(new MockConfigHelper());

		m_environment = new MockEnvironment();

		m_environment.m_models.PutElement(ObjectSelectionModel.STR_MVC_CLASS_NAME,
			new ObjectSelectionModel());

		MockTagLibManager tagLibs = new MockTagLibManager();
		tagLibs.SetTag(new PortletJSTag(), PortletJSTag.TAG.GetName(), PortletPageEditorTagLibraryData.LIBRARY.GetName());
		TagLibManager.setTestInstance(tagLibs);
	}

	/**
	 * This method tests basic display of the JavaScript functions.
	 */
	public void testJS()
	{
		
		
		// initialize markup
		XMLFragmentTestHelper portletJSTagHelper = new XMLFragmentTestHelper(
			PortletPageEditorTagLibraryData.LIBRARY.GetName(), 
			PortletJSTag.TAG.GetName());
		portletJSTagHelper.AddPTAttribute(PortletJSTag.ATTRIB_FLYOUT_ID.GetName(), FLYOUTID);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.ADD_NAME.GetName(), ADD_JS_NAME);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.REMOVE_NAME.GetName(), REMOVE_JS_NAME);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.PREVIEW_NAME.GetName(), PREVIEW_JS_NAME);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.INVITATION_NAME.GetName(), INVITE_JS_NAME);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.ADD_BUNDLE_NAME.GetName(), ADD_BUNDLE_JS_NAME);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.OPEN_BUNDLE_NAME.GetName(), OPEN_BUNDLE_JS_NAME);
  		
   		Object[][] objArrMarkup = portletJSTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		CheckFunctionName(ADD_JS_NAME, strResult, true);
   		CheckFunctionName(REMOVE_JS_NAME, strResult, true);
   		CheckFunctionName(PREVIEW_JS_NAME, strResult, true);
   		CheckFunctionName(INVITE_JS_NAME, strResult, true);
   		CheckFunctionName(ADD_BUNDLE_JS_NAME, strResult, true);
   		CheckFunctionName(OPEN_BUNDLE_JS_NAME, strResult, true);
	}

	/**
	 * This method tests that no JavaScript displays if you don't request it.
	 */
	public void testNoJS()
	{
		// initialize markup
		XMLFragmentTestHelper portletJSTagHelper = new XMLFragmentTestHelper(
			PortletPageEditorTagLibraryData.LIBRARY.GetName(), 
			PortletJSTag.TAG.GetName());
  		
   		Object[][] objArrMarkup = portletJSTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		CheckFunctionName(ADD_JS_NAME, strResult, false);
   		CheckFunctionName(REMOVE_JS_NAME, strResult, false);
   		CheckFunctionName(PREVIEW_JS_NAME, strResult, false);
   		CheckFunctionName(INVITE_JS_NAME, strResult, false);
   		CheckFunctionName(ADD_BUNDLE_JS_NAME, strResult, false);
   		CheckFunctionName(OPEN_BUNDLE_JS_NAME, strResult, false);
	}

	/**
	 * This method tests partial display of some of the JavaScript functions.
	 */
	public void testPartialJS()
	{
		// initialize markup
		XMLFragmentTestHelper portletJSTagHelper = new XMLFragmentTestHelper(
			PortletPageEditorTagLibraryData.LIBRARY.GetName(), 
			PortletJSTag.TAG.GetName());
		portletJSTagHelper.AddPTAttribute(PortletJSTag.ATTRIB_FLYOUT_ID.GetName(), FLYOUTID);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.ADD_NAME.GetName(), ADD_JS_NAME);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.PREVIEW_NAME.GetName(), PREVIEW_JS_NAME);
		portletJSTagHelper.AddPTAttribute(PortletJSTag.OPEN_BUNDLE_NAME.GetName(), OPEN_BUNDLE_JS_NAME);
  		
   		Object[][] objArrMarkup = portletJSTagHelper.ToArrayEntireFragment();
   		HTMLElement result = DisplayTree.ProcessTagMarkup(m_environment, objArrMarkup);

   		String strResult = result.GetDisplayString();

   		// These should be present.
   		CheckFunctionName(ADD_JS_NAME, strResult, true);
   		CheckFunctionName(PREVIEW_JS_NAME, strResult, true);
   		CheckFunctionName(OPEN_BUNDLE_JS_NAME, strResult, true);

   		// These should not be present.
   		CheckFunctionName(REMOVE_JS_NAME, strResult, false);
   		CheckFunctionName(INVITE_JS_NAME, strResult, false);
   		CheckFunctionName(ADD_BUNDLE_JS_NAME, strResult, false);
	}

	public void CheckFunctionName(String _strJSName, String _strOutput, boolean bPresent)
	{
   		String strFunction = _strJSName + JS_FUNCTION_SUFFIX;
   		if (bPresent)
   		{
   			// Check that it's there.
	   		Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction +
	   			"] is present in output: " + _strOutput,
	   			XPStringUtility.IndexOf(_strOutput, strFunction) >= 0);
   		} else
   		{
   			// Check that it's not there.
	   		Assert.assertTrue("Checking that the " + _strJSName + " JS function name [" + strFunction +
		   		"] is not present in output: " + _strOutput,
	   			XPStringUtility.IndexOf(_strOutput, strFunction) < 0);
   		}
	}
}