using System;
using com.plumtree.openfoundation.reflect;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.helpers;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.searchpage
{
  public class FollowupFormTag : ASearchPageTag
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADAPTIVETAGS),
     "com.bea.alui.taglib.searchpage.FollowupFormTag");
    private const String DEFAULT_NAME = "PTSWR";
    private const String DEFAULT_ID = "PTSWR";
    public const String SEARCH_INPUT_TEXT_NAME = "searchinputtextname";
    public const String ON_CLICK = "onclick";
    // All public static final metadata objects should be initialized
    // in a static initializer so that we can control the order of
    // initialization.
    public static readonly ITagMetaData TAG;
    public static readonly RelatedChildTag FOLLOWUPFORMTEXTBOX;
    public static readonly RelatedChildTag FOLLOWUPFORMDATA;
    public static readonly RelatedChildTag FOLLOWUPFORMSUBMITLINK;
    static FollowupFormTag()
    {
      // The TAG member variable needs to be initialized first since it
      // can be used in other tags (i.e. as a RequiredParentTag) that
      // are referenced by member variables of this tag (i.e. as a
      // RelatedChildTag).  This is necessary for tags that have
      // circular references such as a parent / child tag relationship.
      TAG = new TagMetaData(FollowUpFormTagConstants.TAG_NAME, "Generates a search form with the " + "previous search query and allows users to either modify their existing " + "search or do a new search. " + SEARCH_PAGE_ONLY_CONSTANT,
       FollowUpFormTagConstants.EXAMPLE_BUTTON);
      FOLLOWUPFORMTEXTBOX = new RelatedChildTag(FollowupFormTextBoxTag.TAG);
      FOLLOWUPFORMDATA = new RelatedChildTag(FollowupFormDataTag.TAG);
      FOLLOWUPFORMSUBMITLINK = new RelatedChildTag(FollowupFormSubmitLinkTag.TAG);
      }
    public override ATag Create()
    {
      return new FollowupFormTag();
    }
    public override HTMLElement DisplayTag()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      ISearchResultModelRO model = GetSearchResultModel();
      String formName = GetXMLTagAttribute("name");
      String formId = GetXMLTagAttribute("id");
      if (formName == null || formName.Length == 0)
      {
        formName = DEFAULT_NAME;
      }
      if (formId == null || formId.Length == 0)
      {
        formId = DEFAULT_ID;
      }
      XPStringBuilder strb = new XPStringBuilder();
      // Add the <form> tag.
      strb.Append("<form name=\"");
      strb.Append(formName);
      strb.Append("\" id=\"");
      strb.Append(formId);
      strb.Append("\" onsubmit=\"return checkSearchPTSWR();\" action=\"");
      strb.Append(getFormAction(asOwner));
      strb.Append("\" method=\"get\">");
      // Add the required hidden input tags.
      if (!model.isAdvancedSearch())
      {
        addHiddenInputHTML(strb, "in_hi_space", "in_hi_space", asOwner.GetName());
        addHiddenInputHTML(strb, "in_hi_spaceID", "in_hi_spaceID", asOwner.GetSpaceID());
        addHiddenInputHTML(strb, "in_hi_control", "in_hi_control", SearchWithinResultsControl.STR_MVC_CLASS_NAME);
        // Add a hidden input for the current model key
        addHiddenInputHTML(strb, "in_hi_key", "in_hi_key", model.GetCurrentKey());
        } else
      {
        addHiddenInputHTML(strb, "in_hi_space", "in_hi_space", SearchResultAS.STR_MVC_CLASS_NAME);
        // Brand new banner search
        addHiddenInputHTML(strb, "in_hi_control", "in_hi_control", BannerStartSearchControl.STR_MVC_CLASS_NAME);
        }
      addHiddenInputHTML(strb, "in_hi_model_mode", null, "browse");
      // Determine the text input name and store it in the tag scope for use by the
      // "followuptextbox" tag.
      String inputTextName;
      if (model.isAdvancedSearch())
      {
        // Target is brand new banner search
        inputTextName = StartSearchControl.USER_QUERY;
      } else
      {
        inputTextName = SearchWithinResultsControl.ADDITIONAL_QUERY_DATA;
        }
      // Try to add it and complain if it can't be added.
      try
      {
        // Make sure we have edit access to this variable
        SetStateSharedVariable(SEARCH_INPUT_TEXT_NAME, inputTextName, Scope.TAG,
         true);
        SetStateSharedVariable(ON_CLICK, "submitSearchPTSWR(); return false;",
         Scope.TAG, true);
      }
      catch (XPIllegalAccessException xpiae)
      {
        String strError = GetName() + " Tag needs edit access to the variable " + SEARCH_INPUT_TEXT_NAME;
        log.Error(xpiae, strError);
        return new HTMLComment(strError);
      }
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLString(strb.ToString());
      result.AddInnerHTMLElement(ProcessTagBody());
      result.AddInnerHTMLString("</form>");
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()"></seealso>
    public override HTMLScriptCollection DisplaySharedJavascript()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      String formName = GetXMLTagAttribute("name");
      if (formName == null || formName.Length == 0)
      {
        formName = DEFAULT_NAME;
      }
      ISearchResultModelRO model = GetSearchResultModel();
      String inputTextName;
      if (model.isAdvancedSearch())
      {
        // Target is brand new banner search
        inputTextName = StartSearchControl.USER_QUERY;
      } else
      {
        inputTextName = SearchWithinResultsControl.ADDITIONAL_QUERY_DATA;
        }
      XPStringBuilder strb = new XPStringBuilder();
      addFormJavascript(strb, formName, inputTextName, asOwner);
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString(strb.ToString());
      HTMLScriptCollection collection = new HTMLScriptCollection();
      collection.AddInnerHTMLElement(script);
      return collection;
    }
    private void addFormJavascript(XPStringBuilder strb, String formName,
     String inputTextName, AActivitySpace asOwner)
    {
      strb.Append("\n");
      strb.Append("function checkSearchPTSWR() {\n");
      strb.Append("var searchForm = document.");
      strb.Append(formName);
      strb.Append(";\n");
      strb.Append("for (var i = 0; i < searchForm.elements.length; i++) {\n");
      strb.Append("if (searchForm.elements[i].name == \"");
      strb.Append(inputTextName);
      strb.Append("\") {\n");
      strb.Append("if (searchForm.elements[i].value == \"\") {\n");
      strb.Append("return false;\n");
      strb.Append("}\n");
      strb.Append("return true;\n");
      strb.Append("}\n");
      strb.Append("}\n");
      strb.Append("return false;\n");
      strb.Append("}\n");
      strb.Append("function submitSearchPTSWR() {\n");
      strb.Append("if (checkSearchPTSWR()) {\n");
      strb.Append("var searchForm = document.");
      strb.Append(formName);
      strb.Append(";\n");
      strb.Append("searchForm.submit();\n");
      strb.Append("} else {\n");
      strb.Append("alert(\'");
      strb.Append(asOwner.GetString(468, "ptmsgs_portalinfrastructure"));
      strb.Append("\');\n");
      strb.Append("}\n");
      strb.Append("}\n");
      strb.Append("function handleKeyDownPTSWR(evt) {\n");
      strb.Append("evt = (evt) ? evt : ((event) ? event : null);\n");
      strb.Append("if (evt.keyCode == 13){\n");
      strb.Append("if (checkSearchPTSWR()) {\n");
      strb.Append("return true;\n");
      strb.Append("} else {\n");
      strb.Append("alert(\'");
      strb.Append(asOwner.GetString(468, "ptmsgs_portalinfrastructure"));
      strb.Append("\');\n");
      strb.Append("return false;\n");
      strb.Append("}\n");
      strb.Append("}\n");
      strb.Append("return true;\n");
      strb.Append("}\n");
    }
    private void addHiddenInputHTML(XPStringBuilder strb, String name, String id,
     String value)
    {
      strb.Append("<input type=\"hidden\" ");
      if (id != null)
      {
        strb.Append("id=\"");
        strb.Append(id);
        strb.Append("\" ");
      }
      strb.Append("name=\"");
      strb.Append(name);
      strb.Append("\" value=\"");
      strb.Append(value);
      strb.Append("\"/>");
    }
    private String getFormAction(AActivitySpace asOwner)
    {
      String action = ConfigService.getInstance().GetApplicationBaseURLToAS(asOwner.GetCurrentNormalizedBaseURL(),
       asOwner.GetName(), asOwner.IsSubSpace());
      return action;
    }
  }
}