using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.searchpage
{
  public class ItemsPerPageDataTag : ASearchPageTag
  {
    public const String TAG_NAME = "itemsperpagedata";
    public static readonly String EXAMPLE = ATag.EncodeForTagDoc("<select><br>" + "&nbsp;<pt:searchpage.itemsperpagedata pt:id=\"pageSize\"/><br>" + "&nbsp;<pt:core.comment>This collection contains the page size list meta-data.</pt:core.comment><br>" + "&nbsp;<pt:logic.collection pt:key=\"pagesizes\"><br>" + "&nbsp;&nbsp;<pt:logic.data size=\"10\"/><br>" + "&nbsp;&nbsp;<pt:logic.data size=\"20\"/><br>" + "&nbsp;</pt:logic.collection><br>" + "&nbsp;<pt:logic.foreach pt:data=\"pagesizes\" pt:var=\"thissize\"><br>" + "&nbsp;&nbsp;<pt:logic.intexpr pt:expr=\"($pageSize.selectedValue) == ($thissize.size)\" pt:key=\"selectedOption\"/><br>" + "&nbsp;&nbsp;<pt:logic.if pt:expr=\"$selectedOption\"><br>" + "&nbsp;&nbsp;&nbsp;<pt:logic.iftrue><pt:core.html pt:tag=\"option\" selected value=\"$thissize.size\"><br>" + "&nbsp;&nbsp;&nbsp;&nbsp;<pt:logic.value pt:value=\"$thissize.size\"/><br>" + "&nbsp;&nbsp;&nbsp;</pt:core.html></pt:logic.iftrue><br>" + "&nbsp;&nbsp;&nbsp;<pt:logic.iffalse><pt:core.html pt:tag=\"option\" value=\"$thissize.size\"><br>" + "&nbsp;&nbsp;&nbsp;&nbsp;<pt:logic.value pt:value=\"$thissize.size\"/><br>" + "&nbsp;&nbsp;&nbsp;</pt:core.html></pt:logic.iffalse><br>" + "&nbsp;&nbsp;</pt:logic.if><br>" + "&nbsp;</pt:logic.foreach><br>" + "</select>");
    public const String SELECTED_VALUE = "selectedValue";
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ID;
    public static readonly OptionalTagAttribute SCOPE;
    public static readonly OptionalTagAttribute ON_CHANGE;
    static ItemsPerPageDataTag()
    {
      TAG = new TagMetaData(TAG_NAME, "Stores the currently select number of " + "items per page in a Data Object with the key " + SELECTED_VALUE + ". " + SEARCH_PAGE_ONLY_CONSTANT,
       EXAMPLE);
      ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC + " The following attribute is added to this Data Object: " + SELECTED_VALUE + " - The value of the currently selected page size or -1 if none is selected.",
       AttributeType.STRING);
      SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
      ON_CHANGE = new OptionalTagAttribute("onchange", "The onchange function name that triggers the change of page size. " + "Requires the new value as a parameter.",
       AttributeType.STRING, "changeItemsPerPage");
    }
    public override ATag Create()
    {
      return new ItemsPerPageDataTag();
    }
    public override HTMLElement DisplayTag()
    {
      ISearchResultModelRO model = GetSearchResultModel();
      int pageSize = model.GetItemsPerPage();
      // TODO CR DLH: This is not the right way to do this.  Why do we have a
      // whole hashtable if we only need one value?
      // DCA - populate data object
      HashtableDataObject htObject = new HashtableDataObject();
      htObject.SetData(SELECTED_VALUE, XPConvert.ToString(pageSize));
      String strDataReference = GetTagAttributeAsString(ID);
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(SCOPE));
      GetState().SetSharedVariable(strDataReference, htObject, tagScope, true);
      return ProcessTagBody();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()"></seealso>
    public override HTMLScriptCollection DisplaySharedJavascript()
    {
      AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
      ISearchResultModelRO model = GetSearchResultModel();
      String sortOrder = model.GetSortOrder();
      ILinkElement url = PaginationControl.makeURL(model, asOwner, "", sortOrder,
       1);
      url.AddControlArgument(PaginationControl.PAGE_SIZE_DATA);
      String onchange = GetTagAttributeAsString(ON_CHANGE);
      XPStringBuilder sb = new XPStringBuilder();
      sb.Append(onchange).Append(" = function(value){\n");
      sb.Append("    var url = \'" + ((HTMLAnchor) url.GetURLAsHTMLElement()).GetHRef() + "\' + value\n");
      sb.Append("\t   window.location = url;\n");
      sb.Append("}\n");
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString(sb.ToString());
      HTMLScriptCollection collection = new HTMLScriptCollection();
      collection.AddInnerHTMLElement(script);
      return collection;
    }
  }
}