using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.searchpage
{
  /// <summary>
  /// This class implements the searchpage.paginationdata tag.  This tag is for use in the
  /// search results page - it fills in the data needed to build the pagination links.
  /// </summary>
  /// <author>smahendr</author>
  public class PaginationDataTag : ASearchPageDataTag
  {
    public static readonly String OPTIONAL_SEARCH_VARIABLES = "NOTE: The following " + "variables may not be present in all pagination data objects: " + PaginationDataConstants.LAST_PAGE + ", " + PaginationDataConstants.PREVIOUS_URL + ", " + PaginationDataConstants.NEXT_URL + ", " + PaginationDataConstants.FIRST_PAGE_URL + ", and " + PaginationDataConstants.LAST_PAGE_URL + ". ";
    public static readonly ITagMetaData TAG;
    public static readonly RequiredTagAttribute ATTRIB_PAGES_LIST;
    public static readonly OptionalTagAttribute PAGES_TO_DISPLAY;
    static PaginationDataTag()
    {
      TAG = new TagMetaData(PaginationDataConstants.TAG_NAME, PaginationDataConstants.MAIN_DESCRIPTION_PREFIX + "the search results " + PaginationDataConstants.MAIN_DESCRIPTION_SUFFIX + PaginationDataConstants.MAIN_DATA_DESCRIPTION + OPTIONAL_SEARCH_VARIABLES + ATag.EncodeForTagDoc("<br/>") + PaginationDataConstants.PAGES_DATA_DESCRIPTION + " " + SEARCH_PAGE_ONLY_CONSTANT,
       PaginationDataConstants.EXAMPLE);
      ATTRIB_PAGES_LIST = new RequiredTagAttribute(PaginationDataConstants.ATTRIB_PAGESLIST_NAME,
       PaginationDataConstants.ATTRIB_PAGESLIST_DESCRIPTION, AttributeType.STRING);
      PAGES_TO_DISPLAY = new OptionalTagAttribute(PaginationDataConstants.ATTRIB_NUM_PAGES_NAME,
       PaginationDataConstants.ATTRIB_NUM_PAGES_DESCRIPTION, AttributeType.INT,
       PaginationDataConstants.ATTRIB_NUM_PAGES_DEFAULT);
    }
    public override HTMLElement DisplayTag()
    {
      AActivitySpace parent = (AActivitySpace) GetEnvironment();
      ISearchResultModelRO model = GetSearchResultModel();
      int pagesToDisplay = GetTagAttributeAsInt(PAGES_TO_DISPLAY);
      SearchPaginationHelper helper = new SearchPaginationHelper(parent, model,
       new SearchURLHelper(), pagesToDisplay);
      IDataObject mainData = helper.createMainData();
      IXPList pagesList = helper.createPageList();
      // Get the tag scope
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(ATTRIB_SCOPE));
      // Store the main data object
      GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_ID), mainData,
       tagScope, true);
      // Store the page list
      if (pagesList != null && pagesList.GetSize() > 0)
      {
        GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_PAGES_LIST),
         pagesList, tagScope, true);
      }
      return ProcessTagBody();
    }
    public override ATag Create()
    {
      return new PaginationDataTag();
    }
  }
}