using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.common;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.metadata;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.searchpage
{
  public class SortFormDataTag : ASearchPageTag
  {
    public const String TAG_NAME = "sortformdata";
    // Sort list meta-data
    public const String INPUT_NAME = "inputName";
    public const String SORT_OPTIONS_KEY = "sortOptionsKey";
    public const String ON_CHANGE = "onchange";
    public const String SELECTED_VALUE = "selectedValue";
    // The values for each of the items in the sort list.
    public const String NAME = "name";
    public const String VALUE = "value";
    public static readonly ITagMetaData TAG;
    public static readonly RequiredParentTag PARENT;
    public static readonly RequiredTagAttribute ID;
    public static readonly OptionalTagAttribute SCOPE;
    static SortFormDataTag()
    {
      TAG = new TagMetaData(TAG_NAME, "Generates the data describing " + "the sort option list on this page, and stores it in memory " + "using the variable name specified by the <code>" + CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. " + "It also stores the list of sort options under a key available in the data object. " + SEARCH_PAGE_ONLY_CONSTANT,
       SortFormTagConstants.EXAMPLE);
      PARENT = new RequiredParentTag(SortFormTag.TAG);
      ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME,
       CommonTagAttributeConstants.ATTRIB_ID_DESC + " The following attributes are added to this Data Object: <br/>" + "<ul>" + "<li><code>" + INPUT_NAME + "</code> - The name to be used to submit the form with the value selected.</li>" + "<li><code>" + SELECTED_VALUE + "</code> - The value of the currently selected type or -1 if none is selected.</li>" + "<li><code>" + ON_CHANGE + "</code> - The onchange function name to trigger the javascript to submit the form.</li>" + "<li><code>" + SORT_OPTIONS_KEY + "</code> - The key used to store the list of sort options in memory. Each data object in the " + "sort option list has a <code>" + NAME + "</code> and a <code>" + VALUE + "</code> that can be retrieved.</li></ul>",
       AttributeType.STRING);
      SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
       CommonTagAttributeConstants.ATTRIB_SCOPE_DESC, AttributeType.STRING,
       Scope.PORTLET_REQUEST.ToString());
    }
    public override ATag Create()
    {
      return new SortFormDataTag();
    }
    public override HTMLElement DisplayTag()
    {
      IXPList optionsList = new XPArrayList();
      AActivitySpace owner = (AActivitySpace) GetEnvironment();
      ISearchResultModelRO model = GetSearchResultModel();
      String sortOrder = model.GetSortOrder();
      String selectedOption = " ";
      if (sortOrder.Equals(SearchResultModel.SORTORDER_NAME_ASC))
      {
        selectedOption = ReorganizationControl.SPECIAL_SORT_BY_NAME_VALUE;
        } else
      if (sortOrder.Equals(SearchResultModel.SORTORDER_MODIFIED_DESC))
      {
        selectedOption = ReorganizationControl.SPECIAL_SORT_BY_LASTMODIFIED_VALUE;
        }
      // relevance
      HashtableDataObject htOption = new HashtableDataObject();
      htOption.SetData(NAME, owner.GetString(819, "ptmsgs_portalbrowsingmsgs"));
      htOption.SetData(VALUE, " ");
      optionsList.Add(htOption);
      // name
      htOption = new HashtableDataObject();
      htOption.SetData(NAME, owner.GetString(825, "ptmsgs_portalbrowsingmsgs"));
      htOption.SetData(VALUE, "name");
      optionsList.Add(htOption);
      // last modified
      htOption = new HashtableDataObject();
      htOption.SetData(NAME, owner.GetString(820, "ptmsgs_portalbrowsingmsgs"));
      htOption.SetData(VALUE, "lastmodified");
      optionsList.Add(htOption);
      String strDataReference = GetTagAttributeAsString(ID);
      Scope tagScope = Scope.GetScope(GetTagAttributeAsString(SCOPE));
      String optionKey = strDataReference + "option";
      // DCA - populate data object
      HashtableDataObject htObject = new HashtableDataObject();
      htObject.SetData(SELECTED_VALUE, selectedOption);
      htObject.SetData(SORT_OPTIONS_KEY, optionKey);
      htObject.SetData(INPUT_NAME, ReorganizationControl.GROUP_BY_FIELD);
      htObject.SetData(ON_CHANGE, ReorganizationViewHelper.JAVASCRIPT_RESORT);
      GetState().SetSharedVariable(strDataReference, htObject, tagScope, true);
      GetState().SetSharedVariable(optionKey, optionsList, tagScope, true);
      return ProcessTagBody();
    }
  }
}