using System;
using junit.framework;
using com.bea.alui.taglib.searchpage;
using com.plumtree.openfoundation.util;
using MockPathwaysRestAPIService=com.plumtree.portaluiinfrastructure.mock.restconsumerframework.pathways.MockPathwaysRestAPIService;
using com.plumtree.portaluiinfrastructure.mock.search;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
using com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.xpshared.htmlelements;
namespace com.bea.alui.taglib.searchpage.test
{
  /// <summary>
  /// Tests for the searchpage.searchresultsdata data tag.
  /// </summary>
  /// <author>smahendr</author>
  public class SearchResultsDataTagTest : BaseSearchPageTest
  {
    public override void setUp()
    {
      base.setUp();
      // Create the mock TabLib manager.
      MockTagLibManager tagLibs = new MockTagLibManager();
      TagLibManager.setTestInstance(tagLibs);
      // Add the searchpage.searchresultsdata tag.
      tagLibs.SetTag(new SearchResultsDataTag(), SearchResultsDataTag.TAG.GetName(),
       SearchPageTagLibraryData.LIBRARY.GetName());
    }
    
    /// <summary>
    /// This test inserts the search results tag, and makes sure a variable is created with a list of
    /// results, and that the list of results contains the expected values.
    /// </summary>
    public virtual void testResultsData()
    {
      // 1) Initialize the Mock model.
      XPArrayList arrayListResults = new XPArrayList();
      String strPTSource = "PTPORTAL";
      int classID = 18;
      int objectID = 247;
      // Create a fake portal result.
      MockSearchResult result1 = new MockSearchResult();
      result1.setApp(strPTSource);
      result1.setBestBet(false);
      result1.setClassID(classID);
      result1.setObjectID(objectID);
      HTMLAnchor clickThroughURL = new HTMLAnchor("resultLink");
      clickThroughURL.SetOnClick("resultOnClick");
      result1.setClickthroughURL(clickThroughURL);
      result1.setContentLastPubUser(null);
      result1.setContentPortletIDs(null);
      result1.setFolderID(-1);
      HTMLImg icon = new HTMLImg("iconSrc", "iconAlt");
      result1.setIcon(icon);
      result1.setKwic("description1");
      XPDateTime currentDate = new XPDateTime();
      result1.setLastModified(currentDate);
      result1.setName("name1");
      HTMLAnchor propertiesURL = new HTMLAnchor("#");
      propertiesURL.SetOnClick("propsOnClick");
      result1.setPropertiesURL(propertiesURL);
      result1.setPathwaysResultScore(3.12925);
      PathwaysTagRestData[] tagsData = new PathwaysTagRestData[1];
      // Create some fake tag data and use it for testing the search results.
      tagsData[0] = new PathwaysTagRestData();
      tagsData[0].name = "Tag1";
      tagsData[0].isAppliedByCurrentUser = "true";
      result1.setPathwaysResultTags(tagsData);
      // Initialize the MockPathwaysRestAPIService.
      MockPathwaysRestAPIService pathwaysService = new MockPathwaysRestAPIService();
      PathwaysRestAPIService.setTestInstance(pathwaysService);
      // Add it to the result list
      arrayListResults.Add(result1);
      // Initialize the model.
      m_model.SetFirstDisplayableItem(1);
      m_model.SetNumDisplayableItems(1);
      m_model.SetResultsList(arrayListResults);
      // 2) Initialize Markup
      String resultsTagId = "results";
      XMLFragmentTestHelper searchResultsDataTag = new XMLFragmentTestHelper(SearchPageTagLibraryData.LIBRARY.GetName(),
       SearchResultsDataTag.TAG.GetName());
      searchResultsDataTag.AddPTAttribute(SearchResultsDataTag.ATTRIB_ID.GetName(),
       resultsTagId);
      searchResultsDataTag.AddPTAttribute(SearchResultsDataTag.ATTRIB_SCOPE.GetName(),
       Scope.HTTP_REQUEST + "");
      Object[][] markup = searchResultsDataTag.ToArrayEntireFragment();
      // 3) Now process the tag!
      HTMLElement content = DisplayTree.ProcessTagMarkup(m_environment, markup);
      Assert.assertEquals("Checking that data tag didn\'t output any HTML.",
       content.GetDisplayString(), "");
      XPHashtable scopeData = TagState.GetHTTPRequestData(m_environment);
      // 4) Get the data and check if we find what we expected.
      XPDateFormat dateFormat = m_model.GetDateFormat(m_environment);
      Object oResults = scopeData.GetElement("." + resultsTagId);
      if (oResults == null)
      {
        XPSystem.Out.WriteLine("Output of processed markup:");
        XPSystem.Out.WriteLine(content.GetDisplayString());
        fail("Did not find expected tag variable with id " + resultsTagId + " set in tag memory");
        }
      try
      {
        XPArrayList listResults = (XPArrayList) ((SharedStateVariable) oResults).GetValue();
        Assert.assertEquals(1, listResults.GetSize());
        IDataObject resultData = (IDataObject) listResults.GetElement(0);
        // Get the groupresults data where the actual search result collection is stored via the 'groupresultskey' key
        oResults = scopeData.GetElement("." + resultData.GetData(SearchResultsDataTag.GROUP_RESULTS_KEY));
        XPArrayList listResultCollection = (XPArrayList) ((SharedStateVariable) oResults).GetValue();
        Assert.assertEquals(1, listResultCollection.GetSize());
        IDataObject cardResultData = (IDataObject) listResultCollection.GetElement(0);
        // Get the tag collection associated to the search result via the 'resulttags' key
        oResults = scopeData.GetElement("." + cardResultData.GetData(SearchResultsDataTag.RESULT_TAGS_KEY));
        XPArrayList listTagCollection = (XPArrayList) ((SharedStateVariable) oResults).GetValue();
        Assert.assertEquals(1, listTagCollection.GetSize());
        IDataObject tagResultData = (IDataObject) listTagCollection.GetElement(0);
        // Test out our fake Portal card result.
        Assert.assertEquals(result1.getName(), cardResultData.GetData(SearchResultsDataTag.NAME));
        Assert.assertEquals(result1.getKwic(), cardResultData.GetData(SearchResultsDataTag.DESCRIPTION));
        Assert.assertEquals(1 + "", cardResultData.GetData(SearchResultsDataTag.RANK));
        Assert.assertEquals(result1.getClickthroughURL().GetHRef(), cardResultData.GetData(SearchResultsDataTag.RESULT_HREF));
        Assert.assertEquals(result1.getClickthroughURL().GetOnClick(), cardResultData.GetData(SearchResultsDataTag.RESULT_ONCLICK));
        Assert.assertEquals(MockConfigHelper.MOCK_BASE_URL + result1.getIcon().GetSrc(),
         cardResultData.GetData(SearchResultsDataTag.ICON));
        Assert.assertEquals(result1.getIcon().GetAlt(), cardResultData.GetData(SearchResultsDataTag.ICON_ALT_TEXT));
        Assert.assertEquals(dateFormat.Format(result1.getLastModified()),
         cardResultData.GetData(SearchResultsDataTag.LAST_MODIFIED));
        Assert.assertEquals(result1.getPropertiesURL().GetHRef(), cardResultData.GetData(SearchResultsDataTag.PROPERTIES_HREF));
        Assert.assertEquals(result1.getPropertiesURL().GetOnClick(), cardResultData.GetData(SearchResultsDataTag.PROPERTIES_ONCLICK));
        Assert.assertEquals(result1.isBestBet() ? "true" : "false", cardResultData.GetData(SearchResultsDataTag.IS_BEST_BET));
        Assert.assertEquals(result1.getFolderID() == 0 ? "true" : "false",
         cardResultData.GetData(SearchResultsDataTag.IS_IN_MULTIPLE_FOLDERS));
        Assert.assertEquals(null, cardResultData.GetData(SearchResultsDataTag.LAST_PUBLISHED_BY));
        Assert.assertEquals(null, cardResultData.GetData(SearchResultsDataTag.ASSOCIATED_OBJECTS_ONCLICK));
        Assert.assertEquals((classID + "_" + objectID), cardResultData.GetData(SearchResultsDataTag.PATHWAYS_ID));
        Assert.assertEquals(strPTSource, cardResultData.GetData(SearchResultsDataTag.PTSOURCE));
        // Verify tag data was stored correctly.
        Assert.assertEquals(tagsData[0].name, tagResultData.GetData(PathwaysConstants.TAG_VALUE));
        Assert.assertEquals(tagsData[0].isAppliedByCurrentUser, tagResultData.GetData(PathwaysConstants.TAG_OWNER));
        }
      catch (XPException e)
      {
        fail("Found expected tag variable but it was not of the expected type, or some other error occured. See the stacktrace below for the exact issue.");
        e.PrintStackTrace();
      }
    }
  }
}