package com.bea.alui.taglib.searchpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

public class SearchSummaryDataTag extends ASearchPageDataTag
{
	private static final String TAG_NAME = "searchsummarydata";

	private static final String ATTRIB_GROUPS_NAME = "groups";

	private static final String ATTRIB_SPELLCORRECTIONS_NAME = "spellcorrections";
	private static final String ATTRIB_BREADCRUMBS_NAME = "breadcrumbs";
	private static final String ATTRIB_PROPERTIES_NAME = "properties";
	
	private static final String ATTRIB_COLLAB_PROJECTS_NAME = "collabprojects";
	private static final String ATTRIB_PORTLETS_NAME = "portlets";
	private static final String ATTRIB_FOLDERS_NAME = "folders";
	private static final String ATTRIB_COMMUNITIES_NAME = "communities";
	private static final String ATTRIB_OBJECT_TYPES_NAME = "objecttypes";
	
	public static final String BREADCRUMB_NAME = "name";
	public static final String BREADCRUMB_TITLE = "title";
	public static final String BREADCRUMB_URL = "url";
	
	public static final String PROPERTY_NAME = "name";
	public static final String PROPERTY_OPERATOR = "operator";
	public static final String PROPERTY_VALUE = "value";
	public static final String PROPERTY_CLAUSE_OPERATOR = "clauseoperator";
	
	public static final String SPELLCORRECT_MISSPELLING = "misspelling";
	public static final String SPELLCORRECT_CORRECTIONS = "corrections";

	public static final String GROUP_NAME        = "name";
	public static final String GROUP_ICON_SRC    = "iconsrc";
	public static final String GROUP_ICON_ALT    = "iconalt";
	public static final String GROUP_ICON_HEIGHT = "iconheight";
	public static final String GROUP_ICON_WIDTH  = "iconwidth";
	public static final String GROUP_URL         = "url";
	public static final String GROUP_COUNT       = "count";

	// Data Object keys.  Some are optional.
	public static final String ORIGINAL_SEARCH = "originalsearch";
	public static final String SEARCH_WARNING = "searchwarning";
	// TODO CR DLH: Why is this here?  It's the same as original search.
	public static final String SEARCH_TEXT = "searchtext";
	public static final String OVERALL_CLAUSE_OPERATOR = "overallclauseoperator";
	public static final String LANGUAGE = "language";
	public static final String EDIT_BUTTON_URL = "editurl";
	public static final String ADVANCEDSEARCHURL      = "advancedsearchurl";
	public static final String ADVANCEDSEARCHLINKTEXT = "advancedsearchlinktext";
	public static final String SAVEDSEARCHHASBEENSAVED = "savedsearchhasbeensaved";
	public static final String SAVEDSEARCHNAME = "savedsearchname";
	public static final String SAVESEARCHONCLICK = "savesearchonclick";
	public static final String NO_SUBFOLDERS_FOUND = "nosubfoldersfound";
	public static final String HAS_ADVANCED_SEARCH_RESTRICTIONS = "hasadvancedrestrictions";
	public static final String INCLUDE_SUB_FOLDERS = "includesubfolders";

	public static final String DATATAG_DESCRIPTION = ATag.EncodeForTagDoc(
			"Generates the data needed to summarize the search and make various links, and stores it in memory " +
			"using the variable name specified by the " +
			"<code>" + CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. " +
			"The DataObject contains the following variables:<br/>" +
			"<ul>" +
			"<li> <code>" + ADVANCEDSEARCHURL + "</code> - The href for the Advanced search link.</li>" +
			"<li> <code>" + ADVANCEDSEARCHLINKTEXT + "</code> - The text of the Advanced search link.</li>" +
			"<li> <code>" + SAVEDSEARCHHASBEENSAVED + "</code> - \"true\" if the saved search has been saved before, \"false\" if it hasn't, " +
					"   and not present if there shouldn't be a saved search link on this page (e.g. for guest users).</li>" +
			"<li> <code>" + SAVEDSEARCHNAME + "</code> - The name of the previously saved searched search, if this search has been saved before.</li>" +
			"<li> <code>" + SAVESEARCHONCLICK + "</code> - The onclick for the saved search link, if this search has not been saved before.</li>" +
			"<li> <code>" + EDIT_BUTTON_URL + "</code> - The URL for the edit button, if the user has edit access and we are not already in edit mode.</li>" +
			"<li> <code>" + SEARCH_WARNING + "</code> - The search warning, if there is one.</li>" +
			"<li> <code>" + NO_SUBFOLDERS_FOUND + "</code> - \"true\" if there were no groups and we're grouping by folder, not present otherwise.</li>" +
			"<li> <code>" + ORIGINAL_SEARCH + "</code> - The original search text.</li>" +
			"<li> <code>" + SEARCH_TEXT + "</code> - The original search text. NOTE: This is only present in certain advanced searches.</li>" +
			"<li> <code>" + LANGUAGE + "</code> - The language restriction, if there is one.</li>" +
			"<li> <code>" + OVERALL_CLAUSE_OPERATOR + "</code> - The overall clause operator, to be used with the property constraints, if there are any.  This may not be present.</li>" +
			"<li> <code>" + INCLUDE_SUB_FOLDERS + "</code> - The subfolders include string, if there are folder restrictions.</li>" +
			"<li> <code>" + HAS_ADVANCED_SEARCH_RESTRICTIONS + "</code> - \"true\" if there are advanced search restrictions, \"false\" if there are not.</li>" +
			"</ul>" +
			SEARCH_PAGE_ONLY_CONSTANT);

	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ATTRIB_GROUPS;
	public static final RequiredTagAttribute ATTRIB_SPELLCORRECTIONS;
	public static final RequiredTagAttribute ATTRIB_BREADCRUMBS;
	public static final RequiredTagAttribute ATTRIB_PROPERTIES;
	public static final RequiredTagAttribute ATTRIB_COLLAB_PROJECTS;
	public static final RequiredTagAttribute ATTRIB_PORTLETS;
	public static final RequiredTagAttribute ATTRIB_FOLDERS;
	public static final RequiredTagAttribute ATTRIB_COMMUNITIES;
	public static final RequiredTagAttribute ATTRIB_OBJECT_TYPES;

	private static final String CHECK_FOR_EXISTENCE = "Check for its existence before using it.";

	static
	{
		ATTRIB_GROUPS = new RequiredTagAttribute(ATTRIB_GROUPS_NAME,
				"The list of groups; may not exist if there are no groups - check for its existence first.",	
				AttributeType.STRING);

		ATTRIB_SPELLCORRECTIONS = new RequiredTagAttribute(ATTRIB_SPELLCORRECTIONS_NAME,
				"List of spelling corrections, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		ATTRIB_BREADCRUMBS = new RequiredTagAttribute(ATTRIB_BREADCRUMBS_NAME,
				"List of breadcrumbs, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		ATTRIB_PROPERTIES = new RequiredTagAttribute(ATTRIB_PROPERTIES_NAME,
				"List of property constraints, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		ATTRIB_COLLAB_PROJECTS = new RequiredTagAttribute(ATTRIB_COLLAB_PROJECTS_NAME,
				"List of Collaboration project restrictions, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		ATTRIB_PORTLETS = new RequiredTagAttribute(ATTRIB_PORTLETS_NAME,
				"List of portlet restrictions, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		ATTRIB_FOLDERS = new RequiredTagAttribute(ATTRIB_FOLDERS_NAME,
				"List of administrative and Knowledge Directory folder restrictions, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		ATTRIB_COMMUNITIES = new RequiredTagAttribute(ATTRIB_COMMUNITIES_NAME,
				"List of community restrictions, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		ATTRIB_OBJECT_TYPES = new RequiredTagAttribute(ATTRIB_OBJECT_TYPES_NAME,
				"List of object type restrictions, if any. " + CHECK_FOR_EXISTENCE,	
				AttributeType.STRING);

		// The TAG member variable needs to be initialized first since it
		// can be used in other tags (i.e. as a RequiredParentTag) that
		// are referenced by member variables of this tag (i.e. as a
		// RelatedChildTag).  This is necessary for tags that have
		// circular references such as a parent / child tag relationship.
		TAG = new TagMetaData(TAG_NAME, DATATAG_DESCRIPTION);
	}

	@Override
	public ATag Create() {
		return new SearchSummaryDataTag();
	}

	@Override
	public HTMLElement DisplayTag()
	{
		ISearchResultModelRO model = GetSearchResultModel();
		AActivitySpace asOwner = (AActivitySpace)GetEnvironment();
		
		// DCA - log search results event
		SearchSummaryView summaryView = (SearchSummaryView) asOwner.GetView(SearchSummaryView.STR_MVC_CLASS_NAME);
		if (null != summaryView) {
			summaryView.LogSearchResultsEvent();
		}
		
	    // Get the tag scope
	    Scope tagScope = Scope.GetScope( GetTagAttributeAsString(ATTRIB_SCOPE) );
		
		HashtableDataObject htDataObject = new HashtableDataObject();

		// Add advanced search link data
	    AddAdvancedSearchLinkData(htDataObject, model, asOwner);

	    // Add saved search link
	    AddSavedSearchData(htDataObject, model, asOwner);
		
		addEditButtonUrl(htDataObject, model, asOwner);
		addSearchWarning(htDataObject, model);

	    // Check if we should do processing for groups
		final int MIN_RESULTS_TO_SHOW_ORG_VIEW = 6;
	    if ((model.GetTotalItems() >= MIN_RESULTS_TO_SHOW_ORG_VIEW) || (0 != model.GetDrilldownDepth()))
	    {
	    	// Add the list of groups.
		    IXPList listGroups = getListOfGroups(model, asOwner);
		    if(listGroups != null)
		    {
				GetState().SetSharedVariable(GetTagAttributeAsString(ATTRIB_GROUPS), listGroups, tagScope, true);
		    }
	    	
	    	// Add no sub-folders found flag.
		    int numGroups = model.GetNumResultGroups();
			String lastGroupByField = model.GetLastGroupByField();
	
		    // If there were no groups and we're grouping by folder...
	        if ((null != lastGroupByField) && (lastGroupByField.equals(SearchResultModel.GROUPBY_FOLDER)))
	        {
			    if (0 == numGroups)
			    {
			    	htDataObject.SetData(NO_SUBFOLDERS_FOUND, XPConvert.ToString(true));
			    }
	        }
	    }

	    IXPList listBreadcrumbs = getBreadcrumbs(model, asOwner);
	    if(listBreadcrumbs != null) GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_BREADCRUMBS), listBreadcrumbs, tagScope, true);

	    IXPList listSpellCorrections = getSpellingCorrections(model, asOwner);
	    if(listSpellCorrections != null) 
	    {
	    	GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_SPELLCORRECTIONS), listSpellCorrections, tagScope, true);
	    }

    	// Always store the previous search, as people may want to display it in the UI.
    	htDataObject.SetData(ORIGINAL_SEARCH, XPHttpUtility.HtmlEncode(model.GetSearchString()));

	    boolean bHasAdvancedSearchRestrictions = false;
	    
		if(addLanguageRestriction(htDataObject, model, asOwner)) bHasAdvancedSearchRestrictions = true;
		if(addTextRestrictionAndClauseOperator(htDataObject, model, asOwner)) bHasAdvancedSearchRestrictions = true;

	    IXPList listRestrictions = null;
		
	    listRestrictions = getCollabProjectRestrictions(model);
	    if(listRestrictions != null)
	    {
	    	bHasAdvancedSearchRestrictions = true;
	    	GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_COLLAB_PROJECTS), listRestrictions, tagScope, true);
	    }
	    		

	    listRestrictions = getCommunityRestrictions(model);
	    if(listRestrictions != null)
	    {
	    	bHasAdvancedSearchRestrictions = true;
	    	GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_COMMUNITIES), listRestrictions, tagScope, true);
	    }
	    
	    listRestrictions = getFolderRestrictions(model);
	    if(listRestrictions != null)
	    {
	    	bHasAdvancedSearchRestrictions = true;
	    	GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_FOLDERS), listRestrictions, tagScope, true);
	    	htDataObject.SetData(INCLUDE_SUB_FOLDERS, XPConvert.ToString(model.GetIncludeSubfolders()));
	    }
	    
	    listRestrictions = getObjectTypes(model, asOwner);
	    if(listRestrictions != null)
	    {
	    	bHasAdvancedSearchRestrictions = true;
	    	GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_OBJECT_TYPES), listRestrictions, tagScope, true);
	    }
	    
	    listRestrictions = getPortletRestrictions(model);
	    if(listRestrictions != null)
	    {
	    	bHasAdvancedSearchRestrictions = true;
	    	GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_PORTLETS), listRestrictions, tagScope, true);
	    }
	    
	    listRestrictions = getPropertyConstraints(model, asOwner);
	    if(listRestrictions != null)
	    {
	    	bHasAdvancedSearchRestrictions = true;
	    	GetState().SetSharedVariable(
	    		GetTagAttributeAsString(ATTRIB_PROPERTIES), listRestrictions, tagScope, true);
	    }

	    htDataObject.SetData(HAS_ADVANCED_SEARCH_RESTRICTIONS, XPConvert.ToString(bHasAdvancedSearchRestrictions));

		// Store the data object in memory
		String strDataReference = GetTagAttributeAsString(ATTRIB_ID);
		GetState().SetSharedVariable(strDataReference, htDataObject, tagScope, true);

	    return ProcessTagBody();
	}
	
	/**
	 * Get the list of groups.
	 * @param model Search result model
	 * @param asOwner Current activity space
	 * @return List of data objects, one for each group
	 */
	private XPArrayList getListOfGroups(ISearchResultModelRO model, AActivitySpace asOwner)
	{
	    // The search server returns info on the number of "groups" discovered
	    // during the query.  How many were there?
	    int numGroups = model.GetNumResultGroups();
	    
	    if(numGroups > 0)
	    {
		    XPArrayList listGroups = new XPArrayList();
		    // Loop over groups
		    for (int j = 0; j < numGroups; j++)
		    {
			  HashtableDataObject htGroup = new HashtableDataObject();
			  
		      String groupName = model.GetGroupName(j);
		      String numResults = model.GetTotalResultsInGroup(j);
		      Object groupIcon = model.GetGroupIcon(j);
	
		      String encodedGroupName = XPHttpUtility.HtmlEncode(groupName);
	
		      htGroup.SetData(GROUP_NAME, encodedGroupName);
		      
		      // If the group has an associated icon
		      if (null != groupIcon) {
		        // format the icon properly
		        HTMLImg icon = (HTMLImg) groupIcon;
		        
				String strImgSrvURL = ConfigService.getInstance().GetImageServerBaseURL((AActivitySpace) GetEnvironment());

				XPStringBuilder sb = new XPStringBuilder();
				sb.Append(strImgSrvURL);
				sb.Append(icon.GetSrc());
		        
			    htGroup.SetData(GROUP_ICON_SRC, sb.ToString());
			    htGroup.SetData(GROUP_ICON_ALT, icon.GetAlt());
			    htGroup.SetData(GROUP_ICON_HEIGHT, icon.GetHeight());
			    htGroup.SetData(GROUP_ICON_WIDTH, icon.GetWidth());
		      }
	
		      // If more than one group
		      if (numGroups > 1) {
		      	HTMLAnchor anchor = (HTMLAnchor)DrilldownControl.makeURL(model, asOwner, new HTMLGenericElement(""), j);
		      	String url = anchor.GetHRef();
		      	htGroup.SetData(GROUP_URL, url);
		      }
	
	    	  // If more than one group
		      if (numGroups > 1) {
		    	  htGroup.SetData(GROUP_COUNT, XPConvert.ToString(numResults));
		      } else {
		    	  htGroup.SetData(GROUP_COUNT, asOwner.GetString(1824, "ptmsgs_portalbrowsingmsgs"));
		      }
		      listGroups.Add(htGroup);
		    }  // end loop over groups
		    return listGroups;
	    }
	    return null;
	}

	/**
	 * Gets a list of data objects containing spell corrections. Each data object contains
	 * a misspelt token and a comma separated list of corrections.
	 * @param model
	 * @param asOwner
	 * @return
	 */
	private XPArrayList getSpellingCorrections(ISearchResultModelRO model, AActivitySpace asOwner)
	{
		int totalItems = model.GetTotalItems();

		// Display spelling correction message if there were corrections,
        // we haven't drilled down (since in that case we don't know which query was corrected), and
		// at least one item was returned.
		// The spell correct string will be shown even when Best Bets are present (fix for Bug 44187)
		if (model.wasSpellCorrected() && (totalItems > 0) && (1 == model.GetDrilldownDepth()))
		{
			IXPList misspelledTokens		  = new XPArrayList(10);
			IXPList correctionsPerMisspelling = new XPArrayList(10);
			SearchSummaryView.AssembleUniqueMisspellingsAndCorrections(model, misspelledTokens, correctionsPerMisspelling);

			if (misspelledTokens.GetSize() > 0)
			{
				XPArrayList listSpellCorrects = new XPArrayList();
				for (int i = 0; i < misspelledTokens.GetSize(); i++)
				{
					HashtableDataObject htCorrection = new HashtableDataObject();

					htCorrection.SetData(SPELLCORRECT_MISSPELLING, (String) misspelledTokens.GetElement(i));

					IXPList listCorrections = (IXPList) correctionsPerMisspelling.GetElement(i);
					XPStringBuilder sb = new XPStringBuilder(50);
					for (int j = 0; j < listCorrections.GetSize(); j++)
					{
						if (j > 0)
						{
							sb.Append(", ");
						}
						sb.Append(XPHttpUtility.HtmlEncode((String) listCorrections.GetElement(j)));
					}
					htCorrection.SetData(SPELLCORRECT_CORRECTIONS, sb.ToString());
					listSpellCorrects.Add(htCorrection);
				}
				return listSpellCorrects;
			}
		}
		return null;
	}
	
	/**
	 * Get the list of breadcrumbs for this search.
	 * 
	 * Based of off:
	 *  com.plumtree.portalpages.browsing.search.results.SearchSummaryView.DisplayBreadcrumbs
	 *  
	 * @param model Search result model
	 * @param asOwner Current activity space
	 * @return List of dataobjects with name, title and url for each breadcrumb
	 */
	private XPArrayList getBreadcrumbs(ISearchResultModelRO model, AActivitySpace asOwner)
	{
		// If user has drilled down...
		if (1 < model.GetDrilldownDepth())
		{
			// Each "crumb" has a name, an url and a mouseover title.
			HashtableDataObject htSingleBreadcrumb;
			XPArrayList breadcrumbsList = new XPArrayList();
			
			// After drilldown, show a row with breadcrumb links, like
			// Search for lunch : Restricted to Portlets 
			// Original search first
			String firstCrumb;
            String firstCrumbMouseOver = null;

			if (null != model.GetSearchString())
			{
				String searchString = XPHttpUtility.HtmlEncode(model.GetSearchString());
				firstCrumb = searchString;
                // Use the version without <b> tags for the mouseover message
                firstCrumbMouseOver = searchString;
			}
			else
			{
				if (model.isAdvancedSearch())
				{
					firstCrumb = asOwner.GetString(874, "ptmsgs_portalbrowsingmsgs");
				}
				else
				{
					firstCrumb = asOwner.GetString(873, "ptmsgs_portalbrowsingmsgs");
				}
			}

			// Create first breadcrumb data object.
			htSingleBreadcrumb = new HashtableDataObject();

			htSingleBreadcrumb.SetData(BREADCRUMB_NAME, firstCrumb);
			HTMLAnchor breadcrumbLink = (HTMLAnchor)BreadcrumbControl.makeURL(model, asOwner, "", model.GetBreadcrumbKey(1));
			htSingleBreadcrumb.SetData(BREADCRUMB_URL, breadcrumbLink.GetHRef());
			
	        if (null != firstCrumbMouseOver)
	        {
				htSingleBreadcrumb.SetData(BREADCRUMB_TITLE, firstCrumbMouseOver);
	        }
	        else
	        {
				htSingleBreadcrumb.SetData(BREADCRUMB_TITLE, firstCrumb);
	        }
	        
	        // Add to list
	        breadcrumbsList.Add(htSingleBreadcrumb);
	        
			int depth = model.GetDrilldownDepth();

			// from the first step after the initial search
			// to the next-to-last drilldown step
			for (int j = 2; j <= (depth - 1); j++)
			{
				htSingleBreadcrumb = new HashtableDataObject();

				String categoryLabel = XPHttpUtility.HtmlEncode(model.GetBreadcrumbLabel(j));

				String linkText = categoryLabel;
				htSingleBreadcrumb.SetData(BREADCRUMB_NAME, linkText);
				
				breadcrumbLink = (HTMLAnchor)BreadcrumbControl.makeURL(model, asOwner, "", model.GetBreadcrumbKey(j));
				htSingleBreadcrumb.SetData(BREADCRUMB_URL, breadcrumbLink.GetHRef());

                // Use a string without <b> tags for the mouseover message
				htSingleBreadcrumb.SetData(BREADCRUMB_TITLE, categoryLabel);

				breadcrumbsList.Add(htSingleBreadcrumb);
			}

			// Add final drilldown step; this isn't a link
			String strCategoryLabel = XPHttpUtility.HtmlEncode(model.GetBreadcrumbLabel(depth));
			String lastStep = strCategoryLabel;
			htSingleBreadcrumb = new HashtableDataObject();
			htSingleBreadcrumb.SetData(BREADCRUMB_NAME, lastStep);
			breadcrumbsList.Add(htSingleBreadcrumb);
			
			return breadcrumbsList;
		}
		return null;
	}

	/**
	 * Gets the list of collab project restrictions, if any.
	 * @param model
	 * @return
	 */
	private XPArrayList getCollabProjectRestrictions(ISearchResultModelRO model)
	{
        int[] projectIDs   = model.GetCollabProjectRestrictions();

        // Display project restrictions
		if ((projectIDs != null) && (projectIDs.length > 0))
		{
			XPArrayList projects = new XPArrayList();

			for (int j = 0; j < projectIDs.length; j++)
			{
                //!!! How can we lookup a project name given its ID?
                projects.Add(XPConvert.ToString(projectIDs[j]));
			}
			return projects;
		}
		return null;
	}

	/**
	 * Gets the list of portlet restrictions, if any.
	 * @param model
	 * @return
	 */
	private XPArrayList getPortletRestrictions(ISearchResultModelRO model)
	{
        int[] portletIDs   = model.GetPortletRestrictions();

        // Display portlet restrictions
		if ((portletIDs != null) && (portletIDs.length > 0))
		{
			XPArrayList portlets = new XPArrayList();

			for (int j = 0; j < portletIDs.length; j++)
			{
                portlets.Add(model.GetPortletNameForID(portletIDs[j]));
			}
			
			return portlets;
		}
		return null;
	}
	
	/**
	 * Gets the list of folder restrictions, if any.
	 * @param model
	 * @return
	 */
	private XPArrayList getFolderRestrictions(ISearchResultModelRO model)
	{
		int[] aFolderIDs   = model.GetAdminFolderRestrictions();
		int[] dFolderIDs   = model.GetDocFolderRestrictions();

		if (((aFolderIDs != null) && (aFolderIDs.length > 0)) ||
			((dFolderIDs != null) && (dFolderIDs.length > 0)))
		{
			XPArrayList folders = new XPArrayList();

			if ((aFolderIDs != null) && (aFolderIDs.length > 0))
			{
				for (int j = 0; j < aFolderIDs.length; j++)
				{
					folders.Add(model.GetFolderNameForID(aFolderIDs[j], true));
				}
			}
			
			if ((dFolderIDs != null) && (dFolderIDs.length > 0))
			{
				for (int j = 0; j < dFolderIDs.length; j++)
				{
					folders.Add(model.GetFolderNameForID(dFolderIDs[j], false));
				}
			}

			if (folders.GetSize() > 0)
			{
				return folders;
			}
		}
		return null;		
	}
	
	/**
	 * Gets the list of community restrictions, if any.
	 * @param model
	 * @return
	 */
	private XPArrayList getCommunityRestrictions(ISearchResultModelRO model)
	{
		int[] communityIDs = model.GetCommunityRestrictions();

		if ((communityIDs != null) && (communityIDs.length > 0))
		{
			XPArrayList communities = new XPArrayList();

			for (int j = 0; j < communityIDs.length; j++)
			{
				communities.Add(model.GetCommunityNameForID(communityIDs[j]));
			}

			return communities;
		}
		return null;
	}
	
	/**
	 * Gets the list of property contraints if any
	 * @param model
	 * @param asOwner
	 * @return
	 */
	private XPArrayList getPropertyConstraints(ISearchResultModelRO model, AActivitySpace asOwner)
	{
		if ((model.isAdvancedSearch()) && (! model.IsASTooComplexToSummarize()) &&
                (model.GetASNumPropertyConstraints() > 0))
		{
			// Each "property constraint" has a property constraint, an operator, a value,
			// and an optional clause operator (if it's not the last prop constraint)
			
			XPArrayList propertyConstraintList = new XPArrayList();

			int numConstraints = model.GetASNumPropertyConstraints();
			
			for (int j = 0; j < numConstraints; j++)
			{
				HashtableDataObject htSinglePropertyConstraint = new HashtableDataObject();

				htSinglePropertyConstraint.SetData(PROPERTY_NAME, XPHttpUtility.HtmlEncode(model.GetASConstraintProperty(j)));
				htSinglePropertyConstraint.SetData(PROPERTY_OPERATOR, model.GetASConstraintOperator(j));
				htSinglePropertyConstraint.SetData(PROPERTY_VALUE, XPHttpUtility.HtmlEncode(model.GetASConstraintValue(j)));

				if (j < (numConstraints - 1))
				{
					if (model.GetASPropertyClauseOperator())
					{
						htSinglePropertyConstraint.SetData(PROPERTY_CLAUSE_OPERATOR, asOwner.GetString(863, "ptmsgs_portalbrowsingmsgs"));
					}
					else
					{
						htSinglePropertyConstraint.SetData(PROPERTY_CLAUSE_OPERATOR, asOwner.GetString(864, "ptmsgs_portalbrowsingmsgs"));
					}
				}
				propertyConstraintList.Add(htSinglePropertyConstraint);
			}
			return propertyConstraintList;
		}
		return null;
	}
	
	/**
	 * Gets the list of object types to which to the search is restricted to.
	 * @param model
	 * @param asOwner
	 * @return
	 */
	private XPArrayList getObjectTypes(ISearchResultModelRO model, AActivitySpace asOwner)
	{
		if(model.isAdvancedSearch())
		{
			XPArrayList types = SearchSummaryView.GetObjectTypeRestrictionsList(model, asOwner);
			if(types.GetSize() > 0)
			{
				return types;
			}
		}
		return null;
	}
	
	/**
	 * Adds the language restriction string (if there is one)
	 * @param htDataObject Data object to add to
	 * @param model Search results model
	 * @param asOwner Current activity space
	 */
	private boolean addLanguageRestriction(HashtableDataObject htDataObject, ISearchResultModelRO model, AActivitySpace asOwner)
	{
		String language = model.GetLanguageRestriction();
		if (model.isAdvancedSearch() && ((null != language) && (0 < language.length())))
		{
			// Map two-character language code to a displayable string
			// get LocaleVarPack
			PTSearchLocaleVarPack langVP = (PTSearchLocaleVarPack) asOwner.GetApplication().GetVarPackManager()
				.GetVariablePackage(PTSearchLocaleVarPack.VARPACK_ID);

			// Get current user's locale
			String currUserLocale = null;

			currUserLocale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(asOwner).GetLanguage();

			// map code to localized string
			language = langVP.GetLanguageNameForCode(language,
					currUserLocale.substring(0, 2));

			// if this gave us something comprehensible
			if ((null != language) && (0 < language.length()))
			{
				htDataObject.SetData(LANGUAGE, language);
				return true;
			}
		}
		return false;
	}

	/**
	 * Adds the warning as a string (if there is one)
	 * @param htDataObject Data object to add to
	 * @param model Search results model
	 */
	private void addSearchWarning(HashtableDataObject htDataObject, ISearchResultModelRO model)
	{
		SearchExecutionWarning warning = model.GetWarning();

		if (null != warning)
		{
			htDataObject.SetData(SEARCH_WARNING, ((XPException)warning).GetMessage());
		}
	}

	/**
	 * Adds the text restriction and overall clause operator (to be used with the property constraints)
	 * 
	 * @param htDataObject Data object to add to
	 * @param model Search results model
	 * @param asOwner Current activity space
	 */
	private boolean addTextRestrictionAndClauseOperator(HashtableDataObject htDataObject, ISearchResultModelRO model, AActivitySpace asOwner)
	{
		// Next, text condition, if advanced search OR if any other constraints are listed.
		if (model.isAdvancedSearch() && !model.IsASTooComplexToSummarize())
		{
			String searchString = model.GetSearchString();

			if ((null != searchString) && (searchString.length() > 0))
			{
				htDataObject.SetData(SEARCH_TEXT, XPHttpUtility.HtmlEncode(searchString));

				// If there are property constraints as well, append the
				// top-level operator after the search string
				if (model.isAdvancedSearch() &&	(model.GetASNumPropertyConstraints() > 0))
				{
					boolean isAnd = model.GetASTopLevelOperator();

					if (isAnd)
					{
						htDataObject.SetData(OVERALL_CLAUSE_OPERATOR, asOwner.GetString(863, "ptmsgs_portalbrowsingmsgs"));
					}
					else
					{
						htDataObject.SetData(OVERALL_CLAUSE_OPERATOR, asOwner.GetString(864, "ptmsgs_portalbrowsingmsgs"));
					}
                }
				return true;
			}
		}
		return false;
	}
	
	/**
	 * Adds the URL for the Edit button.  If the user doesn't have access to edit mode, it returns null.
	 *
	 * @param htDataObject Data object to add to
	 * @param model Search results model
	 * @param asOwner Current activity space
	 */
	private void addEditButtonUrl(HashtableDataObject htDataObject, ISearchResultModelRO model, AActivitySpace asOwner)
	{
		SearchPageModeHelper pageMode = new SearchPageModeHelper();
		pageMode.Init((SearchResultModel)model, asOwner);
		if ((null != pageMode) && pageMode.UserHasEditModeAccess() && (! pageMode.IsAdminMode()))
		{
			ASURL urle = new ASURL(asOwner);
			urle.SetLinkGetCachedSpace(asOwner);
			urle.SetControl(SearchBrowseEditModeControl.STR_MVC_CLASS_NAME);
			urle.SetDisplayPage(SearchResultDP.STR_MVC_CLASS_NAME);
			urle.AddControlArgument(SearchBrowseEditModeControl.EDIT_MODE_INPUT, SearchBrowseEditModeControl.EDIT_VALUE);

			htDataObject.SetData(EDIT_BUTTON_URL, urle.GetURLAsString());
		}
	}

	/**
	 * Used to add saved search related variables to the data object.
	 * 
	 * @param htObject Data object to add to
	 * @param model Search results model
	 * @param asOwner Current activity space
	 */
	private void AddSavedSearchData(HashtableDataObject htObject,
			ISearchResultModelRO model, AActivitySpace asOwner)
	{
	    // Add "save this search" URL if the user has not already saved the search
	    // and has not drilled down
	    // .. and is not a guest
	    if ((! PlumtreeHelpers.IsGuestSession(asOwner)) && (1 == model.GetDrilldownDepth()))
	    {
	      if (!model.GetHasBeenSaved())
	      {
	    	htObject.SetData(SAVEDSEARCHHASBEENSAVED, XPConvert.ToString(false));
	    	  
	        ASURL saveSearch = new ASURL(asOwner);
	        saveSearch.SetLinkGetCachedSpace(asOwner);
	        saveSearch.SetDisplayPage(SaveSearchPopupDP.STR_MVC_CLASS_NAME);

	        String onclick = "window.open('" +
	                          saveSearch.GetURLAsString() + "','" +
	                          SaveSearchPopupDP.STR_MVC_CLASS_NAME +
	                          "','location=no,menubar=no,height=220,width=475');";
	    	htObject.SetData(SAVESEARCHONCLICK, onclick);
	      }
	      else
	      {
    	    htObject.SetData(SAVEDSEARCHHASBEENSAVED, XPConvert.ToString(true));
    	    htObject.SetData(SAVEDSEARCHNAME, XPHttpUtility.HtmlEncode(model.GetSavedSearchName()));
	      }
	    }
	}

	/**
	 * Adds the advanced search link text and href to the Data Object.
	 * @param htObject Data object to which to add to
	 * @param model Search results model
	 * @param asOwner Current activity space
	 */
	private void AddAdvancedSearchLinkData(HashtableDataObject htObject, ISearchResultModelRO model, AActivitySpace asOwner)
	{
	    ASURL url = new ASURL(asOwner);
	    String linkText;
	    url.SetLinkCreateNewSpace(com.plumtree.portalpages.browsing.search.advanced.AdvancedSearchAS.STR_MVC_CLASS_NAME,
	                              asOwner);
	    url.SetControl(com.plumtree.uiinfrastructure.editor.EditorStartControl.STR_MVC_CLASS_NAME);
	    url.AddControlArgument(com.plumtree.uiinfrastructure.editor.EditorStartControl.QS_EDITOR_TYPE,
	                           com.plumtree.uiinfrastructure.editor.EditorStartControl.EDITOR_START_FLAG_MISC);

	    FollowupSearchView.AddReconstructionArgs(model, url);

	    url.AddControlArgument(SearchResultModel.MODEL_MODE_INPUT, model.GetPageMode());

	    if (model.isAdvancedSearch())
	    {
	      //Back to Advanced
	    	linkText = asOwner.GetString(1699, "ptmsgs_portalbrowsingmsgs");
	    }
	    else
	    {
	      //Advanced		
	    	linkText = asOwner.GetString(815, "ptmsgs_portalbrowsingmsgs");
	    }
	    
	    htObject.SetData(ADVANCEDSEARCHURL, url.GetURLAsString());
	    htObject.SetData(ADVANCEDSEARCHLINKTEXT, linkText);
	}	
}
