package com.bea.alui.taglib.searchpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.tags.*;
import com.plumtree.portaluiinfrastructure.tags.common.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.portaluiinfrastructure.tags.metadata.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

public class TypeFilterDataTag extends ASearchPageTag
{
	public static final String TAG_NAME = "typefilterdata";

	public static final String EXAMPLE = ATag.EncodeForTagDoc(
		"<form name=\"item-type\"><br>" +
		"&nbsp;<pt:searchpage.typefilterdata pt:id=\"typeFilter\"/><br>" +
		"&nbsp;<select class=\"ali-kd-search-pulldown\" onchange=\"filterType(this.value); return false;\"><br>" +
		"&nbsp;&nbsp;<pt:logic.foreach pt:data=\"$typeFilter.typesKey\" pt:var=\"option\"><br>" +
		"&nbsp;&nbsp;&nbsp;<pt:logic.variable pt:key=\"optionValue\" pt:value=\"$option.value\"/><br>" +
		"&nbsp;&nbsp;&nbsp;<pt:logic.intexpr pt:expr=\"($typeFilter.selectedValue) == ($optionValue)\" pt:key=\"selectedOption\"/><br>" +
		"&nbsp;&nbsp;&nbsp;<pt:logic.if pt:expr=\"$selectedOption\"><br>" +
		"&nbsp;&nbsp;&nbsp;&nbsp;<pt:logic.iftrue><br>" +
		"&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<pt:core.html pt:tag=\"option\" selected value=\"$option.value\"><pt:logic.value pt:value=\"$option.name\"/></pt:core.html><br>" +
		"&nbsp;&nbsp;&nbsp;&nbsp;</pt:logic.iftrue><br>" +
		"&nbsp;&nbsp;&nbsp;&nbsp;<pt:logic.iffalse><br>" +
		"&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<pt:core.html pt:tag=\"option\" value=\"$option.value\"><pt:logic.value pt:value=\"$option.name\"/></pt:core.html><br>" +
		"&nbsp;&nbsp;&nbsp;&nbsp;</pt:logic.iffalse><br>" +
		"&nbsp;&nbsp;&nbsp;</pt:logic.if><br>" +
		"&nbsp;&nbsp;</pt:logic.foreach><br>" +
		"&nbsp;</select><br>" +
		"</form>");

	public static final String SELECTED_VALUE = "selectedValue";
	public static final String TYPES_KEY = "typesKey";
	public static final String NAME = "name";
	public static final String VALUE = "value";
	
	public static final ITagMetaData TAG;
	public static final RequiredTagAttribute ID;
	public static final OptionalTagAttribute SCOPE;
	public static final OptionalTagAttribute ON_CHANGE;
	
	static
	{
		TAG = new TagMetaData(TAG_NAME, "Generates the data describing " +
			"the type filter list on the current page, and stores it in memory " +
			"using the variable name specified by the <code>" +
			CommonTagAttributeConstants.ATTRIB_ID_NAME + "</code> attribute. " + 
			"It also stores the list of type filter options under a key available in the data object. " +
			SEARCH_PAGE_ONLY_CONSTANT, EXAMPLE);

		ID = new RequiredTagAttribute(CommonTagAttributeConstants.ATTRIB_ID_NAME, 
			CommonTagAttributeConstants.ATTRIB_ID_DESC + " The following attributes are added to this Data Object: <code>" +
			SELECTED_VALUE + "</code> - the value of the currently selected type or -1 if none is selected, and <code>" +
			TYPES_KEY + "</code> - the key used to store the list of filter types in memory. Each data object in the " +
			"filter type list has a <code>" + NAME + "</code> and a <code>" + VALUE + "</code> that can be retrieved.", AttributeType.STRING);

		SCOPE = new OptionalTagAttribute(CommonTagAttributeConstants.ATTRIB_SCOPE_NAME,
			CommonTagAttributeConstants.ATTRIB_SCOPE_DESC,
			AttributeType.STRING, Scope.PORTLET_REQUEST.toString());

		ON_CHANGE = new OptionalTagAttribute("onchange", "The name to use for the onchange javascript that this tag will create.", AttributeType.STRING, "filterType");
	}
	
	@Override
	public ATag Create() {
		return new TypeFilterDataTag();
	}

	@Override
	public HTMLElement DisplayTag()
	{
		AActivitySpace space = (AActivitySpace) GetEnvironment();
		AActivitySpace m_asOwner = (AActivitySpace) GetEnvironment();
		ISearchResultModelRO searchResultModel = GetSearchResultModel();
	    int selectedFilter = searchResultModel.GetSelectedTypeFilter();
	    
		IXPList optionsList = new XPArrayList();
		HashtableDataObject htOption = new HashtableDataObject();
		htOption.SetData(NAME, m_asOwner.GetString(817, "ptmsgs_portaladminmsgs"));
		htOption.SetData(VALUE, "-1");
		optionsList.Add(htOption);
		int[] classIds = SearchObjectTypes.GetOrderedSearchObjectTypes();
		int maxToDisplay = SearchObjectTypes.ENDUSERCOUNT;
		boolean bShouldDisplayAdminObjects = ((IPTSession) space.GetUserSession()).GetSessionInfo().
        	CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
	    if (bShouldDisplayAdminObjects && searchResultModel.isAdvancedSearch()) {
	    	maxToDisplay = SearchObjectTypes.DETAILEDCOUNT;
	    }
	    for (int i = 0; i < maxToDisplay; i += 1)
	    {
	    	boolean display = true;
	    	if(classIds[i] == SearchObjectTypes.COLLAB_APPLICATION || classIds[i] == SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE)
			{
				display = searchResultModel.CollabInstalled();
			}
			//Bug 21114
			else if(classIds[i] == PT_CLASSIDS.PT_SITEMAPFOLDER_ID)
			{
				display = false;
			}
			
			if(display)	
			{
				htOption = new HashtableDataObject();
				htOption.SetData(NAME, GetDisplayableNameForType(classIds[i]));
				htOption.SetData(VALUE, XPConvert.ToString(classIds[i]));
				optionsList.Add(htOption);
			}
		}
	    
	    String strDataReference = GetTagAttributeAsString(ID);
		Scope tagScope = Scope.GetScope( GetTagAttributeAsString(SCOPE));
		String optionKey = strDataReference + "option";
		
	    // DCA - populate data object
		HashtableDataObject htObject = new HashtableDataObject();
		htObject.SetData(SELECTED_VALUE, XPConvert.ToString(selectedFilter));
		htObject.SetData(TYPES_KEY, optionKey);
		
		GetState().SetSharedVariable(strDataReference, htObject, tagScope, true);
	    GetState().SetSharedVariable(optionKey, optionsList, tagScope, true);
		
		return ProcessTagBody();
	}
	
	private String GetDisplayableNameForType(int classID) {
		AActivitySpace space = (AActivitySpace) GetEnvironment();
	    switch (classID) {
	    	case SearchObjectTypes.DOCUMENT_ABSTRACTTYPE:
	    		return space.GetString(239, ResourceConstants.PORTALCOMMONMSGS);
		    case SearchObjectTypes.FOLDER_ABSTRACTTYPE:
		      return space.GetString(240, ResourceConstants.PORTALCOMMONMSGS);
		    case SearchObjectTypes.OTHER_ABSTRACTTYPE:
		      return space.GetString(241, ResourceConstants.PORTALCOMMONMSGS);
		    case SearchObjectTypes.PORTAL_APPLICATION:
		      return space.GetString(242, ResourceConstants.PORTALCOMMONMSGS);
		    case SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE:
		    case SearchObjectTypes.COLLAB_APPLICATION:
		      return space.GetString(237, ResourceConstants.PORTALCOMMONMSGS);
		    case SearchObjectTypes.CONTENT_APPLICATION:
		    case SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE:
		      return space.GetString(238, ResourceConstants.PORTALCOMMONMSGS);
		    default:
		      break;
	    }

	    return SearchResultModel.getDisplayableNameForType(space, classID);
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.tags.ATag#DisplaySharedJavascript()
	 */
	public HTMLScriptCollection DisplaySharedJavascript()
	{
		AActivitySpace asOwner = (AActivitySpace) GetEnvironment();
		ISearchResultModelRO model = GetSearchResultModel();
		ILinkElement url = TypeFilterControl.makeURL(model, asOwner);
		url.AddControlArgument(TypeFilterControl.FILTER_DATA);
		String onchange = GetTagAttributeAsString(ON_CHANGE);
		XPStringBuilder sb = new XPStringBuilder();
		
		sb.Append(onchange).Append(" = function(value){\n");
		sb.Append("    var url = '"+((HTMLAnchor)url.GetURLAsHTMLElement()).GetHRef()+"' + value\n");
		sb.Append("	   window.location = url;\n");
		sb.Append("}\n");
		
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.AddInnerHTMLString(sb.ToString());
		HTMLScriptCollection collection = new HTMLScriptCollection();
		collection.AddInnerHTMLElement(script);
		return collection;
	}
}
