package com.bea.alui.taglib.searchpage.test;

import junit.framework.*;

import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.mock.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.mock.helper.*;
import com.plumtree.portaluiinfrastructure.mock.search.*;
import com.plumtree.portaluiinfrastructure.mock.tags.*;
import com.plumtree.portaluiinfrastructure.mock.uiinfrastructure.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.mock.core.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.helpers.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * Class used to set up mock objects for the searchpage tag tests.
 * All search page tests should extend this class and call super.setUp()
 * 
 * @author smahendr
 *
 */
public class BaseSearchPageTest extends TestCase
{
	public AActivitySpace     m_environment;
	public MockPTSession      m_session;
	public MockConfigHelper   m_configHelper;
	public MockPTConfigHelper m_helper;

	public MockSearchResultModel m_model;
	
	@Override
	public void setUp() throws Exception
	{
		super.setUp();
		
		// 1) Set up Mock versions of static classes (singletons) used by the tags.  This
		// stuff is all the same for all the tests.
		
		// Initialize mock version of ConfigService
		m_configHelper = new MockConfigHelper();
		ConfigService.setTestInstance(m_configHelper);

		// Initialize mock version of PTConfigService
		m_helper = new MockPTConfigHelper();
		PTConfigService.setTestPTInstance(m_helper);
		
		// Create the Mock application and set it in the application manager.
   		IApplication application = new Application("","");
   		ApplicationManager.SetTestInstance(new MockApplicationManager());
		((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(), application);

		// Enable layouts globally in the config file
		m_helper.SetConfigVariable(PTConfigConstants.SYSTEM_PROPERTIES_SECTION,
				PTConfigConstants.LAYOUT_MODE_SUBSECTION, "1");

		// Create the mock activity space (which implements IEnvironment)
   		m_environment = new MockEnvironment();

   		// Create the mock PTSession, and set it in the mock Activity Space.
		m_session = new MockPTSession();
		m_environment.SetUserSession(m_session);

   		// 2) Now do the setup that is specific to the search page.
   		
		// Create the mock search results model.
		m_model = new MockSearchResultModel();
		
		// Add the model to the mock activity space.
		((MockEnvironment) m_environment).m_models.PutElement(SearchResultModel.STR_MVC_CLASS_NAME, m_model);
	}
}
