/*
 * Created on Mar 30, 2005
 */
 
using System;
using com.plumtree.portaluiinfrastructure.tags;
using com.plumtree.portaluiinfrastructure.tags.metadata;
namespace com.plumtree.taglib.ptdata
{
  /// <summary>
  /// This class provides the meta data for the PT Data tag library, including description and usage of the tags
  /// in this tag library.
  /// </summary>
  public class PTDataTagLibraryData : ITagLibraryMetaData
  {
    public static readonly TagLibraryMetaData LIBRARY = new TagLibraryMetaData("WCI Data Tags",
     "ptdata", "This library provides data tags that retrieve WebCenter Interation (WCI) related data for use in creating " + "links or finding out information about the current WCI page." + "<![CDATA[<p>]]>" + "Data tags provide content for display tags, which format and display the content. " + "The purpose of data tags is to retrieve various WCI data and set it in tag variables where the " + "data is accessible for display tags. Display tags, such as the value tag in logic library or any " + "of the tags in plugnav tag library, formats the data and generate HTML or javascript from it. " + "For example, the plugnav:ptddmenutab tag generates HTML for a DHTML dropdown menu. " + "It needs data from a data tag to populate the menu. Data tags are defined with a tag variable id. " + "This id is passed to the plugnav:ptddmenutab through an attribute to tell the display tag where to find the data. " + "<![CDATA[</p>]]>" + "<![CDATA[<p>]]>" + "Data in tag variables is accessible from tag XML in portlets and layouts. The value of this is used to pass in Tag variable references as Tag attribute values, " + "which allow portlet and layout developers to create portlets and layouts with dynamic data with XHTML in HTML files. It is no longer necessary to use IDK to retrieve " + "WCI data. " + "<![CDATA[</p>]]>" + "<![CDATA[<p>]]>" + "<![CDATA[<b>]]>Example:<![CDATA[</b>]]><![CDATA[<br/>]]>" + ATag.EncodeForTagDoc("<code>" + "<pt:ptdata.mandatorylinknamedata pt:key=\"title\" /><br/>" + "<pt:logic.value pt:value=\"$title\"/> // Outputs name of the current Page <br/>" + "</code>") + "<![CDATA[</p>]]>" + "<![CDATA[<p>]]>" + "The syntax for tag variable reference is the \'$\' character followed by the Tag variable name." + "<![CDATA[</p>]]>" + "The mandatorylinknamedata tag sets a String value in the Tag variable. Most data tags set a data collections, bags of properties where each property is name/value pair. " + "Properties in data collections are referenced in Tag attributes by appending \'.\' and the property name after the Tag variable name. " + "The available properties on each data collection is described in the TagDocs for each data tag. " + "The example below shows how to access the pageid property of the data collection that ptdata.currpagedata tag sets in the \'currpage\' Tag variable. " + "<![CDATA[<p>]]>" + "<![CDATA[<b>]]>Example:<![CDATA[</b>]]><![CDATA[<br/>]]>" + ATag.EncodeForTagDoc("<code>" + "<pt:ptdata.currpagedata pt:id=\"currpage\" pt:noarray=\"true\" /><br/>" + "<pt:logic.value pt:value=\"$currpage.pageid\"/>   // Outputs the value of the pageid property in data collection in \'currpage\' Tag variable<br/>" + "</code>") + "<![CDATA[</p>]]>" + "<![CDATA[<p>]]>" + "Note that referencing Tag variables with the \'$\' notation only works inside Adaptive Tag attributes. Using a Tag variable reference within an HTML elements will" + "not work. Use the core.html tag to insert values in Tag variables to HTML elements. " + "<![CDATA[<p>]]>" + "<![CDATA[<b>]]>Example:<![CDATA[</b>]]><![CDATA[<br/>]]>" + ATag.EncodeForTagDoc("<code>" + "<pt:ptdata.currpagedata pt:id=\"currpage\" pt:noarray=\"true\" /><br/>" + "<a href=\"$currpage.url\">$currpage.title</a> // this does not work<br/>" + "<pt:core.html pt:tag=\"a\" url=\"$currpage.url\" /><pt:logic.value pt:value=\"#currpage.title\"/></pt:core.html> // correct way <br/>" + "</code>") + "<![CDATA[</p>]]>" + "<![CDATA[<p>]]>" + "It is possible to aggregate data collections from multiple data tags into a single Tag variable. This is useful for creating a list of entries to use in for example a menu. " + "By default, if a Tag variable contains one or more data collections (a list of collections), adding additional data collections to the Tag variable appends it to the existing " + "collection list. The example below shows how data collections from three data tags are added to a single Tag variable. The result is one list of data collections containint " + "data collections from all three data tags. " + "<![CDATA[<br/><br/>]]><![CDATA[<b>]]>Example:<![CDATA[</b>]]><![CDATA[<br/>]]>" + ATag.EncodeForTagDoc("<code>" + "<pt:ptdata.currcommunitypagesdata pt:id=\"menu1\" /><br/>" + "<pt:ptdata.communityactionsdata  pt:id=\"menu1\" /><br/>" + "<pt:ptdata.administrationdata  pt:id=\"menu1\" /><br/>" + "</code>") + "<![CDATA[</p>]]>" + "<![CDATA[<p>]]>" + "Data collections in lists are accessed from Tag expression language by iterating over the list using the logic.foreach tag. Tags in the plugnav tag " + "library also expect Tag variables with list of data collections.  " + "<![CDATA[<br/><br/>]]><![CDATA[<b>]]>Example:<![CDATA[</b>]]><![CDATA[<br/>]]>" + ATag.EncodeForTagDoc("<code>" + "<pt:logic.foreach pt:data=\"menu1\" pt:var=\"curr\" /><br/>" + "&nbsp;<pt:logic.value pt:value=\"\" /><br/>" + "</pt:logic.foreach><br/>" + "</code>") + "<![CDATA[</p>]]>" + "<![CDATA[<p>]]>" + "Note that by default data tags will create a list in a Tag variable even if the data tag only returns a single data collection. To avoid having to use a logic.foreach " + "tag to iterate over a single data collection, use the \'noarray\' attribute. Passing \'true\' as value will tell the data tag to set the data collection directly in the Tag " + "attribute without the list. This only works for data tags that always sets a single data collection. This attribute does not do anything for data tags returning multiple " + "data collections. See TagDocs for each tag to find out whether a tag returns a single or multiple data collections. " + "<![CDATA[</p>]]>",
     1.1);
  }
}